using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using CCPM.Data;
using System.Data;

namespace CCPM.Contact
{
	/// <summary>
	/// Summary description for ContactCreateOrUpdate.
	/// 
	/// MAR 2005-04-12 - multiple changes to support addition of OrgID field, removal of 
	/// ContactOrg and ContactOrgTypeID 
	/// </summary>
	public class ContactCreateOrUpdate : System.Windows.Forms.Form
	{
		#region Class Fields
		private System.Windows.Forms.TextBox txtFirstName;
		private System.Windows.Forms.TextBox txtLastName;
		private System.Windows.Forms.TextBox txtOrganizationDept;
		private System.Windows.Forms.TextBox txtNotes;
		private System.Windows.Forms.TextBox txtAddress;
		private System.Windows.Forms.TextBox txtCity;
		private System.Windows.Forms.TextBox txtState;
		private System.Windows.Forms.TextBox txtZip;
		private System.Windows.Forms.TextBox txtPhone;
		private System.Windows.Forms.TextBox txtPhoneExt;
		private System.Windows.Forms.TextBox txtFax;
		private System.Windows.Forms.TextBox txtCellPhone;
		private System.Windows.Forms.TextBox txtEmail;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.Label label6;
		private System.Windows.Forms.Label label7;
		private System.Windows.Forms.Label label8;
		private System.Windows.Forms.Label label9;
		private System.Windows.Forms.Label label10;
		private System.Windows.Forms.Label label11;
		private System.Windows.Forms.Label label12;
		private System.Windows.Forms.Label label13;
		private System.Windows.Forms.Label label14;
		private System.Windows.Forms.Label label15;
		private System.Windows.Forms.Label label16;
		private System.Windows.Forms.GroupBox gbContactInfo;
		private System.Windows.Forms.Button btnCancel;
		private System.Windows.Forms.Button btnSave;
		private System.Windows.Forms.TextBox txtTitle;
		private Genghis.Windows.Forms.RegularExpressionValidator revEmail;
		private Genghis.Windows.Forms.ContainerValidator containerValidator1;
		private int contactId = 0;
		private int projectId = 0;
		private	string projectName = string.Empty;
		private System.Windows.Forms.Panel pnlAssociate;
		private System.Windows.Forms.CheckBox cbxAssociate;
		private System.Windows.Forms.Panel pnlContactType;
		private System.Windows.Forms.Label label17;
		private System.Windows.Forms.Label lblProjectName;
		private CCPM.Data.ContactDataSet cds;
		private bool isUpdateMode = false;
		private Genghis.Windows.Forms.RegularExpressionValidator revZip;
		private Genghis.Windows.Forms.RegularExpressionValidator revPhone;
		private Genghis.Windows.Forms.RegularExpressionValidator revFax;
		private Genghis.Windows.Forms.RegularExpressionValidator revCellPhone;
		private bool isCloneMode = false;
		private System.EventHandler organizationNameLeaveHandler;
		private System.EventHandler lastNameLeaveHandler;
		private System.Windows.Forms.ListBox lbContactType;
		private Genghis.Windows.Forms.RequiredFieldValidator rfvContactType;
		private bool isMatchingFundMode = false;
		private System.Windows.Forms.ComboBox cbOrganization;
		private System.Windows.Forms.Button btnAddOrg;

		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		#endregion

		public int ContactId
		{
			get{return contactId;}
			set{contactId = value;}
		}
//		public string OrganizationName
//		{
//			get{return txtOrganizationName.Text;}
//		}
		public int OrgID
		{
			get{ return Convert.ToInt32(this.cbOrganization.SelectedValue);}
		}

		public int ProjectId
		{
			get{return projectId;}
			set{projectId = value;}
		}

		public string ProjectName
		{
			get{return projectName;}
			set{projectName = value;}
		}

		public CCPM.Data.ContactDataSet CDS
		{
			get{return cds;}
			set{cds = value;}
		}

		public bool IsUpdateMode
		{
			get{return isUpdateMode;}
			set{isUpdateMode = value;}
		}

		public bool IsCloneMode
		{
			get{return isCloneMode;}
			set{isCloneMode = value;}
		}
		public bool IsMatchingFundMode
		{
			// MAR 2005-04-12 - Note: this form is no longer called from MatchingFunds page
			get{return isMatchingFundMode;}
			set{isMatchingFundMode = value;}
		}
		public ContactCreateOrUpdate()
		{
			this.BindingContext = new BindingContext();
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			SetOrganizationSelectionList();

			
			//Wire up Leave Event handlers
			organizationNameLeaveHandler =  new System.EventHandler(this.cbOrganization_Leave);
			this.cbOrganization.Leave += organizationNameLeaveHandler;
			lastNameLeaveHandler = new System.EventHandler(this.txtLastName_Leave);
			this.txtLastName.Leave += lastNameLeaveHandler;
		}

		private void SetOrganizationSelectionList()
		{
			cbOrganization.DataSource = ContactData.OrganizationSelectionList();//don't dhow inactive
			cbOrganization.DisplayMember = "Table.Organization";
			cbOrganization.ValueMember = "Table.OrgID";
		}

//		private void SetOrganizationList()
//		{
//			cbOrganizationType.DataSource = ContactData.OrganizationList(0);//don't dhow inactive
//			cbOrganizationType.DisplayMember = "Table.OrganizationType";
//			cbOrganizationType.ValueMember = "Table.OrganizationTypeId";
//		}

		private void SetContactTypeList()
		{
			lbContactType.DataSource = ContactData.ContactTypeList(0);//don't show inactive
			lbContactType.DisplayMember = "Table.ContactType";
			lbContactType.ValueMember = "Table.ContactTypeId";
		}

		protected bool ValidateForm()
		{
			bool isValid = true;
			//Don't run test for unique contact
			//this.txtOrganizationName.Leave -= organizationNameLeaveHandler;
			this.txtLastName.Leave -= lastNameLeaveHandler;

			foreach(Control cntrl in this.gbContactInfo.Controls)
			{
				if(cntrl.GetType() == typeof(TextBox))
				{
					cntrl.Focus();
				}
			}
			
			//Require either Last Name or Organization Name
//			if( !(rfvLastName.IsValid || rfvOrganization.IsValid))
//			{
//				isValid = false;
//			}
//			else//One of the required fields is valid so disable validation.
//			{
//				rfvLastName.Automatic = false;
//			}

			//Special validation for contacts that are associated with a project.
			if(ProjectId != 0 && cbxAssociate.Checked && !IsMatchingFundMode)//Contact is associated with a project
			{
				lbContactType.Focus();
				this.pnlContactType.Focus();
				if( ! rfvContactType.IsValid)
				{
					isValid = false;
				}
			}
			
			if( ! this.containerValidator1.IsValid())
			{
				isValid = false;
			}
			
//			//Either last name or organization name are required.
//			if(txtLastName.Text == string.Empty && txtOrganizationName.Text == string.Empty)
//			{
////				MessageBox.Show("Please enter either a last name or an organization name!",
////					"Contact Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
//				isValid = false;
//			}

			this.cbOrganization.Leave += organizationNameLeaveHandler;
			this.txtLastName.Leave += lastNameLeaveHandler;

			return isValid;
		}
			
//        protected int SaveContact()
//        {
//            //Matching fund partner insert must include an organization name.
////			if(IsMatchingFundMode)
////			{
////				if(txtOrganizationName.Text == string.Empty)
////				{
////					MessageBox.Show("Please enter an Organization Name!",
////						"Ogranization Name Required",
////						MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
////					return -1;
////				}
////			}
//            //ContactId = ContactData.InsertContact(
//            //    txtFirstName.Text,
//            //    txtLastName.Text,
//            //    txtTitle.Text,
//            //    (int)cbOrganization.SelectedValue,
//            //    txtOrganizationDept.Text,
//            //    txtAddress.Text,
//            //    txtCity.Text,
//            //    txtState.Text,
//            //    txtZip.Text,
//            //    FormatPhone(txtPhone.Text),
//            //    txtPhoneExt.Text,
//            //    FormatPhone(txtFax.Text),
//            //    FormatPhone(txtCellPhone.Text),
//            //    txtEmail.Text,
//            //    txtNotes.Text);
			
//            //return ContactId;
//        }

        //protected int UpdateContact()
        //{
        //    int result = ContactData.UpdateContact(
        //    txtFirstName.Text,
        //    txtLastName.Text,
        //    txtTitle.Text,
        //    (int)cbOrganization.SelectedValue,
        //    txtOrganizationDept.Text,
        //    txtAddress.Text,
        //    txtCity.Text,
        //    txtState.Text,
        //    txtZip.Text,
        //    FormatPhone(txtPhone.Text),
        //    txtPhoneExt.Text,
        //    FormatPhone(txtFax.Text),
        //    FormatPhone(txtCellPhone.Text),
        //    txtEmail.Text,
        //    txtNotes.Text,
        //    this.ContactId);

        //    //Associate this contact with a project
        //    if(cbxAssociate.Visible && cbxAssociate.Checked  && ContactId != 0)
        //    {
        //        //delete existing contact type associations
        //        ContactData.ContactTypeDelete(this.ProjectId, contactId);
        //        foreach(object item in lbContactType.SelectedItems)
        //        {
        //            ContactData.Contact_ContactTypeInsert(ProjectId, ContactId, (int)((DataRowView)item)["ContactTypeId"]);
        //        }
        //    }

        //    return result;
        //}

		protected void PersistContact()
		{
//			ContactDataSet.ContactListRow clr = CDS.ContactList.NewContactListRow();
//			clr.ContactFName = txtFirstName.Text;
//			clr.ContactLName = txtLastName.Text;
//			clr.ContactJobTitle = txtTitle.Text;
//			clr.ContactDept = txtOrganizationDept.Text;
//			clr.ContactOrg = txtOrganizationName.Text;
//			clr.ContactOrgTypeId = (int)cbOrganizationType.SelectedValue;
//			clr.ContactAddress = txtAddress.Text;
//			clr.ContactCity = txtCity.Text;
//			clr.ContactState = txtState.Text;
//			clr.ContactZip = txtZip.Text;
//			clr.ContactPhone = txtPhone.Text;
//			clr.ContactExtension = txtPhoneExt.Text;
//			clr.ContactFax = txtFax.Text;
//			clr.ContactCellPhone = txtCellPhone.Text;
//			clr.ContactEmail = txtEmail.Text;
//			clr.ContactNotes = txtNotes.Text;
//			CDS.ContactList.AddContactListRow(clr);
//			ContactData.PersistContact(CDS, "ProjectContact");
		}

		private string GetColName(System.Data.DataColumn dataColumn)
		{
			return string.Concat("ContactList.", dataColumn.ColumnName );
		}
		private void PopulateForEidt()
		{
			if(ProjectId != 0)//Contact is associated with a Project
			{
				CDS = ContactData.GetProjectContactForEdit(this.ContactId, this.ProjectId);
			}
			else
			{
				CDS = ContactData.GetContactForEdit(this.ContactId);
			}
			ContactDataSet.ContactListRow clr = CDS.ContactList[0];
			if(! IsCloneMode)
			{
				this.txtFirstName.Text = clr.ContactFName;
				this.txtLastName.Text = clr.ContactLName;
				this.txtEmail.Text = clr.ContactEmail;
				this.txtNotes.Text = clr.ContactNotes;
				if(ProjectId != 0)//contact is associated with a project
				{
					DataRow[] dr = clr.GetChildRows("ContactsToContactTypes");
					for(int j = 0; j < dr.Length; j++)	
					{
						for(int i = 0; i < lbContactType.Items.Count; i++)
						{
							if((int)((DataRowView)lbContactType.Items[i])["ContactTypeId"] == (int)dr[j]["ContactTypeId"])
							{
								lbContactType.SetSelected(i, true);
								break;
							}
						}
					}
				}
			}
			// MAR 2005-07-23 - don't clone title of phone number
			if (!isCloneMode)
			{
				this.txtTitle.Text = clr.ContactJobTitle;
			}

			this.txtOrganizationDept.Text = clr.ContactDept;
			//this.txtOrganizationName.Text = clr.ContactOrg;
			for(int i = 0; i < cbOrganization.Items.Count; i++)
			{
				DataRowView drv = (DataRowView)cbOrganization.Items[i];
				if((int)drv["OrgID"] == (int)clr.OrgID)
				{
					cbOrganization.SelectedIndex = i;
				}
			}
			this.txtAddress.Text = clr.ContactAddress;
			this.txtCity.Text = clr.ContactCity;
			this.txtState.Text = clr.ContactState;
			this.txtZip.Text = clr.ContactZip;
			if (!isCloneMode)
			{
				this.txtPhone.Text = clr.ContactPhone;
				this.txtPhoneExt.Text = clr.ContactExtension;
			}
			this.txtFax.Text = clr.ContactFax;
			this.txtCellPhone.Text = clr.ContactCellPhone;
		}

		private string FormatPhone(string input)
		{
			if(input.Length < 1) return input;
			string wrkString;
			string patern = @"[^\d]";
			wrkString = System.Text.RegularExpressions.Regex.Replace(input, patern, string.Empty);
			wrkString = wrkString.Insert(3, "-");
			wrkString = wrkString.Insert(7, "-");
			return wrkString;
		}
		private void IsContactPreexisting()
		{
//			//if(txtLastName.Text != string.Empty && txtOrganizationName.Text != string.Empty)
//			if(txtLastName.Text != string.Empty)
//			{
//				if(ContactData.IsContactPreexisting(txtLastName.Text, (int)cbOrganization.SelectedValue))
//				{
//					DuplicateContactAlert();
//				}
//			}
		}
		private void DuplicateContactAlert()
		{
			MessageBox.Show(
				"The contact you entered is already on file! Please check existing contacts.",
				"Contact Is Not Unique",
				MessageBoxButtons.OK,
				MessageBoxIcon.Stop);
		}
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}


		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ContactCreateOrUpdate));
			this.txtFirstName = new System.Windows.Forms.TextBox();
			this.txtLastName = new System.Windows.Forms.TextBox();
			this.txtTitle = new System.Windows.Forms.TextBox();
			this.txtOrganizationDept = new System.Windows.Forms.TextBox();
			this.txtNotes = new System.Windows.Forms.TextBox();
			this.txtAddress = new System.Windows.Forms.TextBox();
			this.txtCity = new System.Windows.Forms.TextBox();
			this.txtState = new System.Windows.Forms.TextBox();
			this.txtZip = new System.Windows.Forms.TextBox();
			this.txtPhone = new System.Windows.Forms.TextBox();
			this.txtPhoneExt = new System.Windows.Forms.TextBox();
			this.txtFax = new System.Windows.Forms.TextBox();
			this.txtCellPhone = new System.Windows.Forms.TextBox();
			this.txtEmail = new System.Windows.Forms.TextBox();
			this.label1 = new System.Windows.Forms.Label();
			this.label3 = new System.Windows.Forms.Label();
			this.label4 = new System.Windows.Forms.Label();
			this.label5 = new System.Windows.Forms.Label();
			this.label6 = new System.Windows.Forms.Label();
			this.label7 = new System.Windows.Forms.Label();
			this.label8 = new System.Windows.Forms.Label();
			this.label9 = new System.Windows.Forms.Label();
			this.label10 = new System.Windows.Forms.Label();
			this.label11 = new System.Windows.Forms.Label();
			this.label12 = new System.Windows.Forms.Label();
			this.label13 = new System.Windows.Forms.Label();
			this.label14 = new System.Windows.Forms.Label();
			this.label15 = new System.Windows.Forms.Label();
			this.label16 = new System.Windows.Forms.Label();
			this.gbContactInfo = new System.Windows.Forms.GroupBox();
			this.cbOrganization = new System.Windows.Forms.ComboBox();
			this.pnlContactType = new System.Windows.Forms.Panel();
			this.lbContactType = new System.Windows.Forms.ListBox();
			this.label17 = new System.Windows.Forms.Label();
			this.pnlAssociate = new System.Windows.Forms.Panel();
			this.lblProjectName = new System.Windows.Forms.Label();
			this.cbxAssociate = new System.Windows.Forms.CheckBox();
			this.btnSave = new System.Windows.Forms.Button();
			this.btnCancel = new System.Windows.Forms.Button();
			this.revEmail = new Genghis.Windows.Forms.RegularExpressionValidator();
			this.containerValidator1 = new Genghis.Windows.Forms.ContainerValidator();
			this.revZip = new Genghis.Windows.Forms.RegularExpressionValidator();
			this.revPhone = new Genghis.Windows.Forms.RegularExpressionValidator();
			this.revFax = new Genghis.Windows.Forms.RegularExpressionValidator();
			this.revCellPhone = new Genghis.Windows.Forms.RegularExpressionValidator();
			this.btnAddOrg = new System.Windows.Forms.Button();
			this.gbContactInfo.SuspendLayout();
			this.pnlContactType.SuspendLayout();
			this.pnlAssociate.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.revEmail)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.containerValidator1)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.revZip)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.revPhone)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.revFax)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.revCellPhone)).BeginInit();
			this.SuspendLayout();
			// 
			// txtFirstName
			// 
			this.txtFirstName.Location = new System.Drawing.Point(112, 24);
			this.txtFirstName.MaxLength = 75;
			this.txtFirstName.Name = "txtFirstName";
			this.txtFirstName.Size = new System.Drawing.Size(248, 20);
			this.txtFirstName.TabIndex = 1;
			this.txtFirstName.Text = "";
			// 
			// txtLastName
			// 
			this.txtLastName.Location = new System.Drawing.Point(112, 50);
			this.txtLastName.MaxLength = 75;
			this.txtLastName.Name = "txtLastName";
			this.txtLastName.Size = new System.Drawing.Size(248, 20);
			this.txtLastName.TabIndex = 2;
			this.txtLastName.Text = "";
			// 
			// txtTitle
			// 
			this.txtTitle.Location = new System.Drawing.Point(112, 154);
			this.txtTitle.MaxLength = 250;
			this.txtTitle.Name = "txtTitle";
			this.txtTitle.Size = new System.Drawing.Size(248, 20);
			this.txtTitle.TabIndex = 4;
			this.txtTitle.Text = "";
			// 
			// txtOrganizationDept
			// 
			this.txtOrganizationDept.Location = new System.Drawing.Point(112, 180);
			this.txtOrganizationDept.MaxLength = 250;
			this.txtOrganizationDept.Name = "txtOrganizationDept";
			this.txtOrganizationDept.Size = new System.Drawing.Size(248, 20);
			this.txtOrganizationDept.TabIndex = 5;
			this.txtOrganizationDept.Text = "";
			// 
			// txtNotes
			// 
			this.txtNotes.Location = new System.Drawing.Point(112, 272);
			this.txtNotes.Multiline = true;
			this.txtNotes.Name = "txtNotes";
			this.txtNotes.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
			this.txtNotes.Size = new System.Drawing.Size(608, 80);
			this.txtNotes.TabIndex = 16;
			this.txtNotes.Text = "";
			// 
			// txtAddress
			// 
			this.txtAddress.Location = new System.Drawing.Point(112, 209);
			this.txtAddress.MaxLength = 200;
			this.txtAddress.Name = "txtAddress";
			this.txtAddress.Size = new System.Drawing.Size(248, 20);
			this.txtAddress.TabIndex = 7;
			this.txtAddress.Text = "";
			// 
			// txtCity
			// 
			this.txtCity.Location = new System.Drawing.Point(112, 235);
			this.txtCity.MaxLength = 50;
			this.txtCity.Name = "txtCity";
			this.txtCity.Size = new System.Drawing.Size(248, 20);
			this.txtCity.TabIndex = 8;
			this.txtCity.Text = "";
			// 
			// txtState
			// 
			this.txtState.Location = new System.Drawing.Point(480, 24);
			this.txtState.MaxLength = 50;
			this.txtState.Name = "txtState";
			this.txtState.Size = new System.Drawing.Size(240, 20);
			this.txtState.TabIndex = 9;
			this.txtState.Text = "";
			// 
			// txtZip
			// 
			this.txtZip.Location = new System.Drawing.Point(480, 50);
			this.txtZip.MaxLength = 5;
			this.txtZip.Name = "txtZip";
			this.txtZip.Size = new System.Drawing.Size(240, 20);
			this.txtZip.TabIndex = 10;
			this.txtZip.Text = "";
			// 
			// txtPhone
			// 
			this.txtPhone.Location = new System.Drawing.Point(480, 76);
			this.txtPhone.MaxLength = 20;
			this.txtPhone.Name = "txtPhone";
			this.txtPhone.Size = new System.Drawing.Size(240, 20);
			this.txtPhone.TabIndex = 11;
			this.txtPhone.Text = "";
			// 
			// txtPhoneExt
			// 
			this.txtPhoneExt.Location = new System.Drawing.Point(480, 102);
			this.txtPhoneExt.MaxLength = 10;
			this.txtPhoneExt.Name = "txtPhoneExt";
			this.txtPhoneExt.Size = new System.Drawing.Size(240, 20);
			this.txtPhoneExt.TabIndex = 12;
			this.txtPhoneExt.Text = "";
			// 
			// txtFax
			// 
			this.txtFax.Location = new System.Drawing.Point(480, 128);
			this.txtFax.MaxLength = 20;
			this.txtFax.Name = "txtFax";
			this.txtFax.Size = new System.Drawing.Size(240, 20);
			this.txtFax.TabIndex = 13;
			this.txtFax.Text = "";
			// 
			// txtCellPhone
			// 
			this.txtCellPhone.Location = new System.Drawing.Point(480, 154);
			this.txtCellPhone.MaxLength = 20;
			this.txtCellPhone.Name = "txtCellPhone";
			this.txtCellPhone.Size = new System.Drawing.Size(240, 20);
			this.txtCellPhone.TabIndex = 14;
			this.txtCellPhone.Text = "";
			// 
			// txtEmail
			// 
			this.txtEmail.Location = new System.Drawing.Point(480, 180);
			this.txtEmail.MaxLength = 50;
			this.txtEmail.Name = "txtEmail";
			this.txtEmail.Size = new System.Drawing.Size(240, 20);
			this.txtEmail.TabIndex = 15;
			this.txtEmail.Text = "";
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(8, 23);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(64, 23);
			this.label1.TabIndex = 24;
			this.label1.Text = "First Name";
			this.label1.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(8, 49);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(64, 23);
			this.label3.TabIndex = 26;
			this.label3.Text = "Last Name";
			this.label3.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label4
			// 
			this.label4.Location = new System.Drawing.Point(8, 153);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(64, 23);
			this.label4.TabIndex = 27;
			this.label4.Text = "Title";
			this.label4.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label5
			// 
			this.label5.Location = new System.Drawing.Point(8, 179);
			this.label5.Name = "label5";
			this.label5.Size = new System.Drawing.Size(64, 23);
			this.label5.TabIndex = 28;
			this.label5.Text = "Department";
			this.label5.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label6
			// 
			this.label6.Location = new System.Drawing.Point(8, 207);
			this.label6.Name = "label6";
			this.label6.Size = new System.Drawing.Size(64, 23);
			this.label6.TabIndex = 29;
			this.label6.Text = "Address";
			this.label6.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label7
			// 
			this.label7.Location = new System.Drawing.Point(408, 153);
			this.label7.Name = "label7";
			this.label7.Size = new System.Drawing.Size(64, 23);
			this.label7.TabIndex = 30;
			this.label7.Text = "Cell Phone";
			this.label7.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label8
			// 
			this.label8.Location = new System.Drawing.Point(8, 75);
			this.label8.Name = "label8";
			this.label8.Size = new System.Drawing.Size(104, 23);
			this.label8.TabIndex = 31;
			this.label8.Text = "Organization Name";
			this.label8.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label9
			// 
			this.label9.Location = new System.Drawing.Point(8, 232);
			this.label9.Name = "label9";
			this.label9.Size = new System.Drawing.Size(64, 23);
			this.label9.TabIndex = 32;
			this.label9.Text = "City";
			this.label9.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label10
			// 
			this.label10.Location = new System.Drawing.Point(408, 23);
			this.label10.Name = "label10";
			this.label10.Size = new System.Drawing.Size(64, 23);
			this.label10.TabIndex = 33;
			this.label10.Text = "State";
			this.label10.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label11
			// 
			this.label11.Location = new System.Drawing.Point(408, 49);
			this.label11.Name = "label11";
			this.label11.Size = new System.Drawing.Size(64, 23);
			this.label11.TabIndex = 34;
			this.label11.Text = "ZIP Code";
			this.label11.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label12
			// 
			this.label12.Location = new System.Drawing.Point(408, 76);
			this.label12.Name = "label12";
			this.label12.Size = new System.Drawing.Size(64, 23);
			this.label12.TabIndex = 35;
			this.label12.Text = "Phone";
			this.label12.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label13
			// 
			this.label13.Location = new System.Drawing.Point(408, 102);
			this.label13.Name = "label13";
			this.label13.Size = new System.Drawing.Size(64, 23);
			this.label13.TabIndex = 36;
			this.label13.Text = "Ext.";
			this.label13.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label14
			// 
			this.label14.Location = new System.Drawing.Point(408, 127);
			this.label14.Name = "label14";
			this.label14.Size = new System.Drawing.Size(64, 23);
			this.label14.TabIndex = 37;
			this.label14.Text = "Fax";
			this.label14.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label15
			// 
			this.label15.Location = new System.Drawing.Point(408, 178);
			this.label15.Name = "label15";
			this.label15.Size = new System.Drawing.Size(64, 23);
			this.label15.TabIndex = 38;
			this.label15.Text = "Email";
			this.label15.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label16
			// 
			this.label16.Location = new System.Drawing.Point(8, 272);
			this.label16.Name = "label16";
			this.label16.Size = new System.Drawing.Size(64, 23);
			this.label16.TabIndex = 39;
			this.label16.Text = "Notes";
			this.label16.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// gbContactInfo
			// 
			this.gbContactInfo.Controls.Add(this.btnAddOrg);
			this.gbContactInfo.Controls.Add(this.cbOrganization);
			this.gbContactInfo.Controls.Add(this.pnlContactType);
			this.gbContactInfo.Controls.Add(this.pnlAssociate);
			this.gbContactInfo.Controls.Add(this.label6);
			this.gbContactInfo.Controls.Add(this.label7);
			this.gbContactInfo.Controls.Add(this.txtZip);
			this.gbContactInfo.Controls.Add(this.label8);
			this.gbContactInfo.Controls.Add(this.txtFirstName);
			this.gbContactInfo.Controls.Add(this.txtPhone);
			this.gbContactInfo.Controls.Add(this.label9);
			this.gbContactInfo.Controls.Add(this.txtState);
			this.gbContactInfo.Controls.Add(this.label10);
			this.gbContactInfo.Controls.Add(this.txtEmail);
			this.gbContactInfo.Controls.Add(this.txtAddress);
			this.gbContactInfo.Controls.Add(this.label11);
			this.gbContactInfo.Controls.Add(this.txtPhoneExt);
			this.gbContactInfo.Controls.Add(this.txtCellPhone);
			this.gbContactInfo.Controls.Add(this.label12);
			this.gbContactInfo.Controls.Add(this.txtTitle);
			this.gbContactInfo.Controls.Add(this.txtFax);
			this.gbContactInfo.Controls.Add(this.label13);
			this.gbContactInfo.Controls.Add(this.txtLastName);
			this.gbContactInfo.Controls.Add(this.label14);
			this.gbContactInfo.Controls.Add(this.label15);
			this.gbContactInfo.Controls.Add(this.txtNotes);
			this.gbContactInfo.Controls.Add(this.label16);
			this.gbContactInfo.Controls.Add(this.txtOrganizationDept);
			this.gbContactInfo.Controls.Add(this.label1);
			this.gbContactInfo.Controls.Add(this.label3);
			this.gbContactInfo.Controls.Add(this.label4);
			this.gbContactInfo.Controls.Add(this.txtCity);
			this.gbContactInfo.Controls.Add(this.label5);
			this.gbContactInfo.Controls.Add(this.btnSave);
			this.gbContactInfo.Controls.Add(this.btnCancel);
			this.gbContactInfo.Location = new System.Drawing.Point(16, 16);
			this.gbContactInfo.Name = "gbContactInfo";
			this.gbContactInfo.Size = new System.Drawing.Size(744, 432);
			this.gbContactInfo.TabIndex = 40;
			this.gbContactInfo.TabStop = false;
			this.gbContactInfo.Text = "Contact Information";
			// 
			// cbOrganization
			// 
			this.cbOrganization.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.cbOrganization.Location = new System.Drawing.Point(112, 76);
			this.cbOrganization.Name = "cbOrganization";
			this.cbOrganization.Size = new System.Drawing.Size(248, 21);
			this.cbOrganization.TabIndex = 3;
			// 
			// pnlContactType
			// 
			this.pnlContactType.Controls.Add(this.lbContactType);
			this.pnlContactType.Controls.Add(this.label17);
			this.pnlContactType.Location = new System.Drawing.Point(400, 208);
			this.pnlContactType.Name = "pnlContactType";
			this.pnlContactType.Size = new System.Drawing.Size(336, 64);
			this.pnlContactType.TabIndex = 41;
			this.pnlContactType.Visible = false;
			// 
			// lbContactType
			// 
			this.lbContactType.Location = new System.Drawing.Point(80, 0);
			this.lbContactType.Name = "lbContactType";
			this.lbContactType.SelectionMode = System.Windows.Forms.SelectionMode.MultiSimple;
			this.lbContactType.Size = new System.Drawing.Size(240, 56);
			this.lbContactType.TabIndex = 40;
			// 
			// label17
			// 
			this.label17.Location = new System.Drawing.Point(7, -4);
			this.label17.Name = "label17";
			this.label17.Size = new System.Drawing.Size(72, 23);
			this.label17.TabIndex = 39;
			this.label17.Text = "Contact Type";
			this.label17.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// pnlAssociate
			// 
			this.pnlAssociate.Controls.Add(this.lblProjectName);
			this.pnlAssociate.Controls.Add(this.cbxAssociate);
			this.pnlAssociate.Location = new System.Drawing.Point(112, 360);
			this.pnlAssociate.Name = "pnlAssociate";
			this.pnlAssociate.Size = new System.Drawing.Size(376, 64);
			this.pnlAssociate.TabIndex = 40;
			this.pnlAssociate.Visible = false;
			// 
			// lblProjectName
			// 
			this.lblProjectName.Location = new System.Drawing.Point(18, 32);
			this.lblProjectName.Name = "lblProjectName";
			this.lblProjectName.Size = new System.Drawing.Size(355, 23);
			this.lblProjectName.TabIndex = 18;
			// 
			// cbxAssociate
			// 
			this.cbxAssociate.Checked = true;
			this.cbxAssociate.CheckState = System.Windows.Forms.CheckState.Checked;
			this.cbxAssociate.Location = new System.Drawing.Point(1, 4);
			this.cbxAssociate.Name = "cbxAssociate";
			this.cbxAssociate.Size = new System.Drawing.Size(367, 24);
			this.cbxAssociate.TabIndex = 17;
			this.cbxAssociate.Text = " Associate this contact with project:";
			// 
			// btnSave
			// 
			this.btnSave.Location = new System.Drawing.Point(512, 384);
			this.btnSave.Name = "btnSave";
			this.btnSave.TabIndex = 17;
			this.btnSave.Text = "Save";
			this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
			// 
			// btnCancel
			// 
			this.btnCancel.Location = new System.Drawing.Point(632, 384);
			this.btnCancel.Name = "btnCancel";
			this.btnCancel.TabIndex = 18;
			this.btnCancel.Text = "Cancel";
			this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
			// 
			// revEmail
			// 
			this.revEmail.ControlToValidate = this.txtEmail;
			this.revEmail.ErrorMessage = "Email is invalid";
			this.revEmail.Icon = ((System.Drawing.Icon)(resources.GetObject("revEmail.Icon")));
			this.revEmail.Required = false;
			this.revEmail.ValidationExpression = "\\w+([-+.]\\w+)*@\\w+([-.]\\w+)*\\.\\w+([-.]\\w+)*";
			// 
			// containerValidator1
			// 
			this.containerValidator1.ContainerToValidate = this.gbContactInfo;
			// 
			// revZip
			// 
			this.revZip.ControlToValidate = this.txtZip;
			this.revZip.ErrorMessage = "ZIP code must be formatted ##### or #####-####";
			this.revZip.Icon = ((System.Drawing.Icon)(resources.GetObject("revZip.Icon")));
			this.revZip.Required = false;
			this.revZip.ValidationExpression = "\\d{5}(-\\d{4})?";
			// 
			// revPhone
			// 
			this.revPhone.ControlToValidate = this.txtPhone;
			this.revPhone.ErrorMessage = "Please review formatting of phone number; area code is required.";
			this.revPhone.Icon = ((System.Drawing.Icon)(resources.GetObject("revPhone.Icon")));
			this.revPhone.Required = false;
			this.revPhone.ValidationExpression = "^((\\(\\d{3}\\) ?)|(\\d{3}-)|(\\d{3} ?))\\d{3}[- ]?\\d{4}$";
			// 
			// revFax
			// 
			this.revFax.ControlToValidate = this.txtFax;
			this.revFax.ErrorMessage = "Please review fax number formatting; area code is required.";
			this.revFax.Icon = ((System.Drawing.Icon)(resources.GetObject("revFax.Icon")));
			this.revFax.Required = false;
			this.revFax.ValidationExpression = "^((\\(\\d{3}\\) ?)|(\\d{3}-)|(\\d{3} ?))\\d{3}[- ]?\\d{4}$";
			// 
			// revCellPhone
			// 
			this.revCellPhone.ControlToValidate = this.txtCellPhone;
			this.revCellPhone.ErrorMessage = "Please review formatting of cell phone number; area code is required.";
			this.revCellPhone.Icon = ((System.Drawing.Icon)(resources.GetObject("revCellPhone.Icon")));
			this.revCellPhone.Required = false;
			this.revCellPhone.ValidationExpression = "^((\\(\\d{3}\\) ?)|(\\d{3}-)|(\\d{3} ?))\\d{3}[- ]?\\d{4}$";
			// 
			// btnAddOrg
			// 
			this.btnAddOrg.Anchor = System.Windows.Forms.AnchorStyles.None;
			this.btnAddOrg.Font = new System.Drawing.Font("Arial", 8F);
			this.btnAddOrg.Location = new System.Drawing.Point(112, 104);
			this.btnAddOrg.Name = "btnAddOrg";
			this.btnAddOrg.Size = new System.Drawing.Size(76, 31);
			this.btnAddOrg.TabIndex = 42;
			this.btnAddOrg.Text = "Enter New Organization";
			this.btnAddOrg.Click += new System.EventHandler(this.btnAddOrg_Click);
			// 
			// ContactCreateOrUpdate
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(772, 466);
			this.Controls.Add(this.gbContactInfo);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.Name = "ContactCreateOrUpdate";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.Text = "Create Contact";
			this.Load += new System.EventHandler(this.ContactCreateOrUpdate_Load);
			this.gbContactInfo.ResumeLayout(false);
			this.pnlContactType.ResumeLayout(false);
			this.pnlAssociate.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.revEmail)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.containerValidator1)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.revZip)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.revPhone)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.revFax)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.revCellPhone)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion
		
		private void btnSave_Click(object sender, System.EventArgs e)
		{
			// MAR 2005-08-05 - MOVED TO MasterDetail page
			// MAR 2005-07-26 - added confirmation message on Save 
			//DialogResult intDiagResult = MessageBox.Show("BE CAREFUL about making changes!  Any changes made to this contact will affect every other project linked to this contact. If you want to enter a new contact from the same organization, use the Clone Contact command. Do you wish to Save now?","Save Contact", 
			//	MessageBoxButtons.YesNo, MessageBoxIcon.Warning);
			//if((intDiagResult == DialogResult.Yes) & ValidateForm())
			if(ValidateForm())
			{
				bool ok = false;
				if( ! IsUpdateMode | IsCloneMode)//New contact
				{
					//contactId = SaveContact();
					if(contactId == 0)//contact is not unique
					{
						DuplicateContactAlert();
					}
					else if(contactId == -1)//Organization name omitted
					{
						return;
					}
					else
					{
						ok = true;
						if(ProjectId != 0 && cbxAssociate.Checked)//Associate contact with Project
						{
							for(int i = 0; i < lbContactType.SelectedItems.Count; i++)
							{
								DataRowView drv = (DataRowView)lbContactType.SelectedItems[i];
								ContactData.Contact_ContactTypeInsert(this.ProjectId, this.ContactId, (int)drv["ContactTypeId"]);
							}	
						}
					}
					if(IsMatchingFundMode)//Associate the contact as a Funding Partner
					{
						ContactData.Contact_ContactTypeInsert(ProjectId, ContactId, 3);
					}
				}
				else//Update contact
				{
		
					//int result = this.UpdateContact();
					
                    //if(result == 1)
                    //{
                    //    ok = true;
                    //}
                    //else//contact is not unique
                    //{
                    //    DuplicateContactAlert();
                    //}
					
				}

				if(ok)
				{
					this.DialogResult = DialogResult.OK;
					this.Close();
				}
			}
			else//Invlid input
			{
				//Required fields
				//if(txtLastName.Text == string.Empty && txtOrganizationName.Text == string.Empty)
				if(txtLastName.Text == string.Empty)
				{
					MessageBox.Show("Please enter a last name!",
						"Contact Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
					
				}
				else //Format error on fields other than last name and organization name.
				{
					MessageBox.Show("Some fields have invalid input!\nIn your review of the form you will see a red icon to the right of each invalid field.\nRoll your mouse cursor over the icon for an explanation of the error.",
						"Formatting Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
				}
			}
		}

		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			this.DialogResult = DialogResult.Cancel;
			this.Close();
		}

		private void ContactCreateOrUpdate_Load(object sender, System.EventArgs e)
		{
			if(IsUpdateMode)
			{
				this.Text = "Update Contact";
			}
			else
			{
				this.Text = "Create New Contact";
			}
			if(ProjectId != 0 && !IsMatchingFundMode) //Contact is associated with a project
			{
				SetContactTypeList();
				this.pnlContactType.Visible = true;
				this.pnlAssociate.Visible = true;
				lbContactType.ClearSelected();
				this.lblProjectName.Text = this.ProjectName;
				//Set validation for contact type
				System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ContactCreateOrUpdate));
				this.rfvContactType = new Genghis.Windows.Forms.RequiredFieldValidator();
				this.rfvContactType.ControlToValidate = this.lbContactType;
				this.rfvContactType.ErrorMessage = "Please select at least one contact type";
				this.rfvContactType.Icon = ((System.Drawing.Icon)(resources.GetObject("rfvContactType.Icon")));
			}
			

			if(IsUpdateMode || IsCloneMode)
			{
				this.PopulateForEidt();
				this.cbxAssociate.Enabled = false;
			}
		}

		private void cbOrganization_Leave(object sender, System.EventArgs e)
		{
			IsContactPreexisting();
		}

		private void txtLastName_Leave(object sender, System.EventArgs e)
		{
			IsContactPreexisting();
		}

		private void btnAddOrg_Click(object sender, System.EventArgs e)
		{
			Project.Organizations frmOrgs = new Project.Organizations(true);
	
			DialogResult intDiagResult = MessageBox.Show("Have you checked to make sure the organization is not already on the Organization drop down list?","Confirm", 
				MessageBoxButtons.YesNo, MessageBoxIcon.Question);
			if (intDiagResult == DialogResult.Yes)
			{
				//frmOrgs.Show();	
				frmOrgs.ShowDialog();
				this.SetOrganizationSelectionList();
			}
		}

	}
}
