﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Shared;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using CCPM.Data;
using CCPM.Contract;
using Microsoft.ApplicationBlocks.Data;

namespace CCPM.Contract
{
    //used in ProjectForm contract/invoices tab
    public partial class Contracts : UserControl
    {
        int pid = 0;
        bool blnGridDirty = false;
        public Contracts(int ProjectId)
        {
            InitializeComponent();
            uwgContractsTab.DisplayLayout.Override.WrapHeaderText = DefaultableBoolean.True;
            pid = ProjectId;
            btnViewMonitoring.Enabled = false;
            btnViewRepayment.Enabled = false;
            LoadContractGrid();
            SetSecurity();
        }

        private void SetSecurity()
        {
            UltraGridBand band = uwgContractsTab.DisplayLayout.Bands[0];

            //Conditions Met by Contracts Manager, Contracts Staff
            if (!(GlobalSettings.IsContractsManager || GlobalSettings.IsContractsStaff))
            {
                band.Columns[5].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            }
        }


        private void LoadContractGrid()
        {
            DataSet dsAllContracts = ContractData.GetAllContractLog(pid);
            uwgContractsTab.DataSource = dsAllContracts.Tables[0];
            uwgContractsTab.DataBind();
            if (uwgContractsTab.Rows.Count < 0)
            {
                btnViewContract.Enabled = false;
                btnViewInvoice.Enabled = false;
            }
            else
            {
                btnViewContract.Enabled = true;
                btnViewInvoice.Enabled = true;
            }
            blnGridDirty = false;
        }

        private void uwgContractsTab_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            e.Layout.Bands[0].Columns[0].Width = 65;
            e.Layout.Bands[0].Columns[0].Header.Caption = "Contract#";
            e.Layout.Bands[0].Columns[0].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[0].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[0].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[0].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            //14 -> 1
            e.Layout.Bands[0].Columns[1].Width = 170;
            e.Layout.Bands[0].Columns[1].Header.Caption = "Grantee/Contractor";
            e.Layout.Bands[0].Columns[1].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[1].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[1].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[1].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[2].Width = 70;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Contract Status";
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[3].Width = 80;
            e.Layout.Bands[0].Columns[3].Header.Caption = "Contract Total";
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[3].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns[3].CellAppearance.TextHAlign = HAlign.Right;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[4].Width = 80;
            e.Layout.Bands[0].Columns[4].Header.Caption = "Balance";
            e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[4].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns[4].CellAppearance.TextHAlign = HAlign.Right;
            e.Layout.Bands[0].Columns[4].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[4].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[4].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[5].Width = 70;
            e.Layout.Bands[0].Columns[5].Header.Caption = "Contract Conditions Met?";
            e.Layout.Bands[0].Columns[5].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns[5].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.CheckBox;

            e.Layout.Bands[0].Columns[6].Width = 70;
            e.Layout.Bands[0].Columns[6].Header.Caption = "Date of Execution";
            e.Layout.Bands[0].Columns[6].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[6].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[6].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[6].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[7].Width = 70;
            e.Layout.Bands[0].Columns[7].Header.Caption = "Completion Date";
            e.Layout.Bands[0].Columns[7].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[7].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[7].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[7].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[8].Width = 70;
            e.Layout.Bands[0].Columns[8].Header.Caption = "Termination Date";
            e.Layout.Bands[0].Columns[8].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[8].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[8].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[8].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[9].Width = 100;
            e.Layout.Bands[0].Columns[9].Header.Caption = "Contract Expiration Alert";
            e.Layout.Bands[0].Columns[9].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[9].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[9].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[9].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[10].Width = 100;
            e.Layout.Bands[0].Columns[10].Header.Caption = "Liquidation Alert";
            e.Layout.Bands[0].Columns[10].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[10].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[10].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[10].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[11].Width = 100;
            e.Layout.Bands[0].Columns[11].Header.Caption = "Repayment Alert";
            e.Layout.Bands[0].Columns[11].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[11].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[11].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[11].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            //IsMonitoringRequired
            e.Layout.Bands[0].Columns[12].Width = 70;
            e.Layout.Bands[0].Columns[12].Header.Caption = "Monitoring Required?";
            e.Layout.Bands[0].Columns[12].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns[12].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.CheckBox;

            e.Layout.Bands[0].Columns[13].Width = 100;
            e.Layout.Bands[0].Columns[13].Header.Caption = "Monitoring Alert";
            e.Layout.Bands[0].Columns[13].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[13].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[13].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[13].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[14].Width = 100;
            e.Layout.Bands[0].Columns[14].Header.Caption = "Last Monitoring Outcome";
            e.Layout.Bands[0].Columns[14].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[14].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[14].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[14].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            //TypeCode
            e.Layout.Bands[0].Columns[15].Width = 100;
            e.Layout.Bands[0].Columns[15].Header.Caption = "Contract Type";
            e.Layout.Bands[0].Columns[15].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[15].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[15].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[15].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            //ContractId
            e.Layout.Bands[0].Columns[16].Hidden = true;
            //DirtyFlag
            e.Layout.Bands[0].Columns[17].Hidden = true;

        }

        private void btnViewContract_Click(object sender, EventArgs e)
        {
            if (uwgContractsTab.Rows.Count == 0)
                return;

            Form1 fm = (Form1)(this.ParentForm.MdiParent);
            fm.OpenContract(Convert.ToInt32(uwgContractsTab.ActiveRow.Cells["ContractId"].Value));
        }

        private void btnViewInvoice_Click(object sender, EventArgs e)
        {
            if (uwgContractsTab.Rows.Count == 0)
                return;

            FundSourceSelection fss = new FundSourceSelection(Convert.ToInt32(uwgContractsTab.ActiveRow.Cells["ContractId"].Value));
            fss.MyParentForm1 = this;
            if (fss.ShowDialog() == DialogResult.OK)
            {
                int fundSource = fss.FundingSource;
                Form1 fm = (Form1)this.ParentForm.MdiParent;
                fm.OpenInvoiceDrawdown(Convert.ToInt32(uwgContractsTab.ActiveRow.Cells["ContractId"].Value), fundSource);
            }
        }

        private void btnViewRepayment_Click(object sender, EventArgs e)
        {
            Form1 fm = (Form1)(this.ParentForm.MdiParent);
            fm.OpenRepayment(Convert.ToInt32(uwgContractsTab.ActiveRow.Cells["ContractId"].Value));
        }

        private void btnViewMonitoring_Click(object sender, EventArgs e)
        {
            Form1 fm = (Form1)(this.ParentForm.MdiParent);
            fm.OpenMonitoring(Convert.ToInt32(uwgContractsTab.ActiveRow.Cells["ContractId"].Value));
        }

        private void uwgContractsTab_AfterRowActivate(object sender, EventArgs e)
        {
            SetButtons();
        }

        private void SetButtons()
        {
            if (uwgContractsTab.ActiveRow.Cells["TypeCode"].Value.ToString() == "Repayable Grant")
            {
                btnViewRepayment.Enabled = true;
            }
            else
            {
                btnViewRepayment.Enabled = false;
            }
            if (uwgContractsTab.ActiveRow.Cells["IsMonitoringRequired"].Text.ToString() == "True")
            {
                btnViewMonitoring.Enabled = true;
            }
            else
            {
                btnViewMonitoring.Enabled = false;
            }
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            SaveContracts();
        }

        private void Contracts_Leave(object sender, EventArgs e)
        {
            if (blnGridDirty)
            {
                DialogResult intResult = MessageBox.Show("Do You want to save changes to the Contracts/Invoices tab ?", "Warning", MessageBoxButtons.YesNo);
                if (intResult == DialogResult.Yes)
                {
                    SaveContracts();
                }
                else
                {
                    uwgContractsTab.ActiveRow.Cells["AreContractsConditionMet"].Value = "False";
                }
            }
        }

        private void SaveContracts()
        {
            for (int i = 0; i < uwgContractsTab.Rows.Count; i++)
            {
                if (uwgContractsTab.Rows[i].Cells["DirtyFlag"].Value.ToString() == "1")
                {
                    string sql = "UPDATE ContractDetails SET AreContractsConditionMet = " + GlobalCode.SqlBoolean(uwgContractsTab.Rows[i].Cells["AreContractsConditionMet"].Value) +
                        ", IsMonitoringRequired = " + GlobalCode.SqlBoolean(uwgContractsTab.Rows[i].Cells["IsMonitoringRequired"].Value) +
                        " where ContractId = " + Convert.ToInt32(uwgContractsTab.Rows[i].Cells["ContractId"].Value);
                    int retVal = SqlHelper.ExecuteNonQuery(GlobalSettings.ConnectionString, CommandType.Text, sql);
                    if (retVal == -1)
                    {
                        MessageBox.Show("Update failed ", "Database Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    }
                }
            }
            LoadContractGrid();
        }
    
        private void btnRefresh_Click(object sender, EventArgs e)
        {
            if (blnGridDirty == true)
            {
                DialogResult diaRslt = MessageBox.Show("Do you want to save changes ?", "Warning", MessageBoxButtons.YesNo);
                if (diaRslt == DialogResult.Yes)
                {
                    SaveContracts();
                }
            }
            LoadContractGrid();
        }

        private void uwgContractsTab_AfterCellUpdate(object sender, CellEventArgs e)
        {
            if (uwgContractsTab.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
            {
                uwgContractsTab.ActiveRow.Cells["DirtyFlag"].Value = "1";
            }
            blnGridDirty = true;
        }

        private void uwgContractsTab_DoubleClickRow(object sender, DoubleClickRowEventArgs e)
        {
            Form1 fm = (Form1)(this.ParentForm.MdiParent);
            fm.OpenContract(Convert.ToInt32(uwgContractsTab.ActiveRow.Cells["ContractId"].Value));

        }

        private void uwgContractsTab_Enter(object sender, EventArgs e)
        {
            try
            {
             uwgContractsTab.Rows[0].Cells[0].Activate();
            }
            catch (Exception) { }
        }

    }
}
