﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Shared;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using CCPM.Data;
using Microsoft.ApplicationBlocks.Data;
using System.Data.SqlTypes;

namespace CCPM.Contract
{
    public partial class FundSubstitute : Form
    {
        private int projectID = 0;
        private string contractNumber;
        public decimal TotalFundingSourceAmount;
        DataSet dsAuthorization;
        public DataSet dsFundingSourceList;
        DataTable dtOrganization;
        DataTable dtContact;
        int cid = 0;
        int pid = 0;
        int orgid = 0;
        int contactid = 0;
        int contractstatusid = 0;
        int projectmanagerid = 0;
        int contracttypeid = 0;
        int newStatusId = 0;
        private bool blnDataChanged = false;    //for form
        private bool blnDataDirty = false;      //for grids
        private bool blnDataLoaded = false;
        bool blnDataDirtyAuth = false;
        bool blnGridResDirty = false;
        bool blnSkip = false;
        bool blnDisplay = false;
        bool blnViewGridOnly = true;
        string reason = "substitution of funds";

        object dtCompletionDate;

        public int ContractId
        {
            get { return cid; }
        }
             
        public FundSubstitute(int ContractId)
        {
            InitializeComponent();
            this.Location = new Point(0, 0);
            cid = ContractId;

            projectID = Convert.ToInt32(SqlHelper.ExecuteScalar(GlobalSettings.ConnectionString, CommandType.Text, "SELECT projectID FROM ContractDetails WHERE ContractID = " + cid.ToString()).ToString());

            LoadFundSubstitutePage();
            SetSecurity();

        }

        private void SetSecurity()
        {


            //edit & delete only:  Contracts Manager, Contracts Staff, and Accounting Manager
            if (GlobalSettings.IsContractsManager || GlobalSettings.IsContractsStaff || GlobalSettings.IsAccountingManager)
            {
                blnViewGridOnly = false;
            }
            else
            {
                //All users can not edit
                //•	Disencumber Amount
                //•	New Fund Id selection

                blnViewGridOnly = true;
                //disable grid edits and buttons
                btnSaveAuthorization.Enabled = false;
                btnCancel.Enabled = false;

                UltraGridBand band = uwgContractFund.DisplayLayout.Bands[0];                
                band.Columns["DisencumberAmount"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["NewFundId"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;            
            
            }

        }

        private void LoadFundSubstitutePage()
        {
            

            blnDataLoaded = false;

            LoadFundingSourceValueList();
            LoadFundSourceGrid();
            LoadAuthorizationGrid();

            blnDataDirty = false;
            blnDataChanged = false;
            blnDataLoaded = true;
            SetButtons();
        }

        private void LoadFundingSourceValueList()
        {
            //Create the funding source dataset and bind to the (dropdown list) grid
            dsFundingSourceList = ProjectFundingData.GetFundSelectionList(false);
            dsFundingSourceList.Tables[0].PrimaryKey = new DataColumn[] { dsFundingSourceList.Tables[0].Columns["FundID"] };
            uddFundingSource.DataSource = dsFundingSourceList.Tables[0];
            uddFundingSource.ValueMember = "FundID";
            uddFundingSource.DisplayMember = "FundingItem";
            uddFundingSource.DataBind();
          }

        private void LoadFundSourceGrid()
        {
            DataSet dsContractFund = ContractData.GetContractFunds(cid);
            uwgContractFund.DataSource = dsContractFund.Tables[0];
            uwgContractFund.DataBind();
            
            dsAuthorization = new DataSet();

            foreach (DataRow drFundingSource in dsContractFund.Tables[0].Rows)
            {
                dsAuthorization.Tables.Add(ProjectFundingData.GetFundingSourceAuthorizations(projectID, Convert.ToInt32(drFundingSource["FundId"].ToString())));
            }
        }



        private void LoadAuthorizationGrid()
        {
            // get fund id
            int FundId = 0;
            if (uwgContractFund.Rows.Count > 0)
            {
                UltraGridRow fundRow = this.uwgContractFund.ActiveRow;
                try
                {
                    uwgAuthorization.UpdateData();
                    uwgAuthorization.DataSource = dsAuthorization.Tables[fundRow.Index];
                    uwgAuthorization.DataBind();
                    uwgAuthorization.Refresh();
                }
                catch
                {
                }
            }
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            SaveFundSourceGrid();
            contractNumber = txtContractNumber.Text;
            LoadFundSubstitutePage();
            Point p = new Point(0, 0);
            this.AutoScrollPosition = p;

            bool found = false;
            for (int i = 0; i < this.MdiParent.MdiChildren.Length; i++)
            {
                if (this.MdiParent.MdiChildren[i] as CCPM.Project.ProjectForm != null)
                {
                    if (((CCPM.Project.ProjectForm)this.MdiParent.MdiChildren[i]).ProjectId == pid)
                    {
                        found = true;
                        ((CCPM.Project.ProjectForm)this.MdiParent.MdiChildren[i]).RefreshContracts();
                        break;
                    }
                }
            }
            
        }


        private void uwgAuthorization_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            // AuthorizationId
            e.Layout.Bands[0].Columns["AuthorizationId"].Hidden = true;
            e.Layout.Bands[0].Columns["AuthorizationTypeId"].Hidden = true;

            // AuthorizationTypeId
            e.Layout.Bands[0].Columns["AuthorizationType"].Width = 200;
            e.Layout.Bands[0].Columns["AuthorizationType"].Header.Caption = "Authorized By";
            e.Layout.Bands[0].Columns["AuthorizationType"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["AuthorizationType"].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["AuthorizationType"].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["AuthorizationType"].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;


            // AuthorizationDate
            e.Layout.Bands[0].Columns["AuthorizationDate"].Width = 100;
            e.Layout.Bands[0].Columns["AuthorizationDate"].Header.Caption = "Date Authorized";
            e.Layout.Bands[0].Columns["AuthorizationDate"].Format = "MM/dd/yyyy";
            e.Layout.Bands[0].Columns["AuthorizationDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["AuthorizationDate"].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["AuthorizationDate"].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["AuthorizationDate"].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;


            //Original Reservation Amount
            e.Layout.Bands[0].Columns["Amount"].Width = 120;
            e.Layout.Bands[0].Columns["Amount"].Header.Caption = "Original Reservation"; 
            e.Layout.Bands[0].Columns["Amount"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["Amount"].Format = GlobalSettings.MoneyFormat;
            e.Layout.Bands[0].Columns["Amount"].MaskInput = "nnnnnnnnnnnn.nn";
            e.Layout.Bands[0].Columns["Amount"].CellAppearance.TextHAlign = HAlign.Right;
            e.Layout.Bands[0].Columns["Amount"].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["Amount"].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["Amount"].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            //Substituted Amount
            e.Layout.Bands[0].Columns["SubstitutedAmount"].Width = 120;
            e.Layout.Bands[0].Columns["SubstitutedAmount"].Header.Caption = "Amount Substituted"; 
            e.Layout.Bands[0].Columns["SubstitutedAmount"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns["SubstitutedAmount"].Format = GlobalSettings.MoneyFormat;
            e.Layout.Bands[0].Columns["SubstitutedAmount"].Format = "$###,###,###,##0.00";     
            e.Layout.Bands[0].Columns["SubstitutedAmount"].MaskInput = "nnnnnnnnnnnn.nn";           
            e.Layout.Bands[0].Columns["SubstitutedAmount"].CellAppearance.TextHAlign = HAlign.Right;


            // Created By, Dirty Flag
            e.Layout.Bands[0].Columns["CreatedBy"].Hidden = true;
            e.Layout.Bands[0].Columns["DirtyFlag"].Hidden = true;

            //more columns used for save later
            e.Layout.Bands[0].Columns["ReservEncumbID"].Hidden = true;
            e.Layout.Bands[0].Columns["ReserveDate"].Hidden = true;
            e.Layout.Bands[0].Columns["GrantAmount"].Hidden = true;
            e.Layout.Bands[0].Columns["ReimbTypeId"].Hidden = true;
            e.Layout.Bands[0].Columns["GrantSource"].Hidden = true;

        }

        private void btnSaveAuthorization_Click(object sender, EventArgs e)
        {
            SaveFundSourceGrid();
            Point p = new Point(0, 0);
            this.AutoScrollPosition = p;
        }


        private void uwgAuthorization_AfterCellUpdate(object sender, CellEventArgs e)
        {
            if (blnSkip)
            {
                blnSkip = false;
                return;
            }

            blnDataDirty = true;
            blnGridResDirty = true;
            SetButtons();

        }

        private void btnCancelAuthorization_Click(object sender, EventArgs e)
        {

            if (blnDataDirty == true)
            {
                DialogResult intRes = MessageBox.Show("Data has changed - Do you want to cancel changes?", "Cancel Changes",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intRes == DialogResult.Yes)
                {
                    blnDataDirty = false;
                    blnGridResDirty = false;
                    this.LoadFundSourceGrid();
                }
                SetButtons();
            }
        }



        private void btnCancel_Click(object sender, EventArgs e)
        {
            btnRefresh_Click(sender, e);
            //this.Close();
            

        }

        private void uwgContractFund_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            //0=ContractFundId, 1=FundId, 2=BalanceToDate, 3=AmountSubstituted, 4=NewFundId, 
            //5=ContractId, 6=DirtyFlag
            e.Layout.Bands[0].Columns["ContractFundId"].Hidden = true;
            e.Layout.Bands[0].Columns["FundId"].Hidden = true;

            e.Layout.Bands[0].Columns["FundingItem"].Width = 190;
            e.Layout.Bands[0].Columns["FundingItem"].Header.Caption = "Funding Source";
            e.Layout.Bands[0].Columns["FundingItem"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["FundingItem"].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["FundingItem"].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDown;
            e.Layout.Bands[0].Columns["FundingItem"].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["FundingItem"].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns["BalanceToDate"].Width = 110;
            e.Layout.Bands[0].Columns["BalanceToDate"].Header.Caption = "Current Amount";
            e.Layout.Bands[0].Columns["BalanceToDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["BalanceToDate"].Format = GlobalSettings.MoneyFormat;
            e.Layout.Bands[0].Columns["BalanceToDate"].MaskInput = "nnnnnnnnnnnn.nn";
            e.Layout.Bands[0].Columns["BalanceToDate"].CellAppearance.TextHAlign = HAlign.Right;
            e.Layout.Bands[0].Columns["BalanceToDate"].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["BalanceToDate"].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["BalanceToDate"].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns["DisencumberAmount"].Width = 110;
            e.Layout.Bands[0].Columns["DisencumberAmount"].Header.Caption = "Amount Substituted";
            e.Layout.Bands[0].Columns["DisencumberAmount"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns["DisencumberAmount"].Format = "$###,###,###,##0.00";
            e.Layout.Bands[0].Columns["DisencumberAmount"].MaskInput = "nnnnnnnnnnnn.nn";
            e.Layout.Bands[0].Columns["DisencumberAmount"].CellAppearance.TextHAlign = HAlign.Right;
            //e.Layout.Bands[0].Columns["DisencumberAmount"].Hidden = true;

            e.Layout.Bands[0].Columns["NewFundId"].Width = 190;
            e.Layout.Bands[0].Columns["NewFundId"].Header.Caption = "New Funding Source";
            e.Layout.Bands[0].Columns["NewFundId"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns["NewFundId"].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDown;
            e.Layout.Bands[0].Columns["NewFundId"].ValueList = uddFundingSource;//uwgContractFund.DisplayLayout.ValueLists["FundingItem"];
            e.Layout.Bands[0].Columns["LiquidationDate"].Hidden = true;

            e.Layout.Bands[0].Columns["ContractId"].Hidden = true;
            e.Layout.Bands[0].Columns["DirtyFlag"].Hidden = true;

            e.Layout.Bands[0].Columns["ContractedAmount"].Hidden = true;
            
        }

      
        private void uwgContractFund_AfterCellListCloseUp(object sender, CellEventArgs e)
        {
            DataSet ds = null;
            DataRow dr = null;
            decimal totalBalanceToDate = 0;
            if (uwgContractFund.Rows.Count > 0)
            {
                
                if (uwgContractFund.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                    uwgContractFund.ActiveRow.Cells["DirtyFlag"].Value = "1";
            }
           
        }

  

        private void SaveFundSourceGrid()
        {
            //0=ContractFundId, 1=FundId, 2=BalanceToDate
            //"3=BalanceToDate, 4=LiquidationDate, 5=DisencumberAmount, 6=ContractId, 7=DirtyFlag, 8=hasInvoice

            bool allChangesValid = true;
            string retMsg;

            foreach(UltraGridRow gr in uwgContractFund.Rows)
            {
                int i = gr.Index;

                switch (uwgContractFund.Rows[i].Cells["DirtyFlag"].Value.ToString())
                {
                    case "1":
                        {
                            decimal totalAuthAmount = 0;

                            if (uwgContractFund.Rows[i].Cells["FundId"].Value.ToString() == string.Empty)
                            {
                                MessageBox.Show("Please select a valid substitution Funding Source for Funding Source " + uwgContractFund.Rows[i].Cells["FundingItem"].Value.ToString(),
                                    "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                                return;
                            }

                            if (uwgContractFund.Rows[i].Cells["FundId"].Value.ToString() == uwgContractFund.Rows[i].Cells["NewFundId"].Value.ToString())
                            {
                                MessageBox.Show("Please select a different Substituting Funding Source for the Funding Source " + uwgContractFund.Rows[i].Cells["FundingItem"].Value.ToString(),
                                    "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                                return;
                            }

                            decimal amt = GlobalCode.ToDecimal(uwgContractFund.Rows[i].Cells["DisencumberAmount"].Value);
                            //if (amt == 0)
                            //{
                            //    MessageBox.Show("Amount required in row " + i.ToString(), "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                            //    return;
                            //}

                            for (int iAuth = 0; iAuth < dsAuthorization.Tables[i].Rows.Count; iAuth++)
                            {
                                totalAuthAmount += GlobalCode.ToDecimal(dsAuthorization.Tables[i].Rows[iAuth]["SubstitutedAmount"].ToString());
                            }

                            decimal balance = amt - totalAuthAmount;
                            if (amt != totalAuthAmount)
                            {
                                MessageBox.Show("Total Amount Substituted for all Authorizations on a Funding Source must be equal to the Amount Substituted for that Funding Source in Contract Funds. " +
                                                "\n\r\n\r" + "Please check Contract Funds Funding Source: " + uwgContractFund.Rows[i].Cells["FundingItem"].Value.ToString() + "." +
                                                " There is currently an imbalance of " + balance.ToString("C")
                                                , "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);

                                return;
                            }

                            //do not save record if amount is 0
                            if (amt == 0 && totalAuthAmount == 0)
                            {
                                continue;
                            }

                            if (GlobalCode.ToDecimal(uwgContractFund.Rows[i].Cells["BalanceToDate"].Value) < Math.Abs(totalAuthAmount))
                            {
                                MessageBox.Show("Amount Substituted can not be more than the Current Amount. Please check Contract Funds Funding Source " + uwgContractFund.Rows[i].Cells["FundingItem"].Value.ToString(), "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                                return;
                            }

                            /*
                             In the contract funds grid (top grid), is the substituted amount > 0 AND Original FundID <> NEwFundID                 
                             */
                            uwgContractFund.Rows[i].Cells["DirtyFlag"].Value = "0";
                            if (amt > 0 && (uwgContractFund.Rows[i].Cells["FundId"].Value.ToString() != uwgContractFund.Rows[i].Cells["NewFundId"].Value.ToString()))
                            {
                                    uwgContractFund.Rows[i].Cells["DirtyFlag"].Value = "1";
                            }

                            break;
                        }
                }
            }

            System.Data.SqlClient.SqlConnection connection = new System.Data.SqlClient.SqlConnection(GlobalSettings.ConnectionString);
            connection.Open();
            System.Data.SqlClient.SqlTransaction transaction = connection.BeginTransaction("Substitute");

            string retVal1 = "";

            foreach (UltraGridRow grContractFundSource in uwgContractFund.Rows)
            {
                int i = grContractFundSource.Index;

                switch (grContractFundSource.Cells["DirtyFlag"].Value.ToString())
                {
                    case "1":
                    {
                        //disencumber amount from invoice
                        retVal1 = DisencumberAmountFromInvoice(transaction, grContractFundSource);
                        if (retVal1 != "success") break;

                        //reduce contract funds to a new amount                                               
                        retVal1 = ReduceContractFunds(transaction, grContractFundSource);
                        if (retVal1 != "success") break;


                        foreach (DataRow drReservationAuthorization in dsAuthorization.Tables[i].Rows)
                        {
                            //reservation reduced                    
                            retVal1 = ReduceReservation(transaction, grContractFundSource, drReservationAuthorization);
                            if (retVal1 != "success") break;

                            //ReserveEncumbInsert
                            retVal1 = AddReservation(transaction, grContractFundSource, drReservationAuthorization);
                            if (retVal1 != "success") break;

                        }

                        //add new contract fund with the new fund source
                        retVal1 = AddContractFund(transaction, grContractFundSource);
                        if (retVal1 != "success") break;

                        
                        break;
                    }
                }
            }

            if (retVal1 != "success")
            {
                transaction.Rollback("Substitute");
                MessageBox.Show("There was an error committing your changes to the database. Please contact your system administrator for more information.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            else
            {
                transaction.Commit();
            }

            if (connection.State==ConnectionState.Open)
                connection.Close();
            this.Refresh();

            blnDataDirty = false;
            blnGridResDirty = false;
            blnDataChanged = false;
            LoadFundSubstitutePage();
            SetBalance();
        }

        private string ReduceContractFunds(System.Data.SqlClient.SqlTransaction transaction, UltraGridRow grContractFundSource)
        {
            string retVal1 = ContractData.ContractFundUpdate(transaction,
                                    GlobalCode.ToInt32(grContractFundSource.Cells["ContractFundId"].Value),
                                    GlobalCode.ToString(grContractFundSource.Cells["FundId"].Value),
                                    GlobalCode.ToDecimal(grContractFundSource.Cells["ContractedAmount"].Value) - GlobalCode.ToDecimal(grContractFundSource.Cells["DisencumberAmount"].Value),
                                    GlobalCode.ToDecimal(grContractFundSource.Cells["BalanceToDate"].Value) - GlobalCode.ToDecimal(grContractFundSource.Cells["DisencumberAmount"].Value),
                                    grContractFundSource.Cells["LiquidationDate"].Value,
                                    GlobalCode.ToDecimal(grContractFundSource.Cells["DisencumberAmount"].Value),
                                    false);     //blnReduceAmount
            return retVal1;
        }

        private string AddContractFund(System.Data.SqlClient.SqlTransaction transaction, UltraGridRow grContractFundSource)
        {
            DateTime liquidDate = Convert.ToDateTime("1/1/1901");

            DataRow drFundingSource = dsFundingSourceList.Tables[0].Rows.Find(grContractFundSource.Cells["NewFundId"].Value);
            liquidDate = Convert.ToDateTime(drFundingSource["LiquidDate"].ToString());
            String.Format("{0:M/d/yyyy}", liquidDate);

            string retVal1 = ContractData.ContractFundInsert(transaction,
                                    Convert.ToString(grContractFundSource.Cells["NewFundId"].Value),
                                    GlobalCode.ToDecimal(grContractFundSource.Cells["DisencumberAmount"].Value),
                                    GlobalCode.ToDecimal(grContractFundSource.Cells["DisencumberAmount"].Value),
                                    liquidDate,
                                    GlobalCode.ToDecimal(0),          //DisencumberAmount,
                                    GlobalCode.ToInt32(grContractFundSource.Cells["ContractId"].Value),
                                    false);     //blnReduceAmount
            return retVal1;
        }

        private string AddReservation(System.Data.SqlClient.SqlTransaction transaction, UltraGridRow grContractFundSource, DataRow drReservationAuthorization)
        {
            string retVal1 = ProjectFundingData.ReservEncumbInsert(
                                transaction,
                                Convert.ToInt32(grContractFundSource.Cells["NewFundId"].Value),
                                GlobalCode.ToInt32(drReservationAuthorization["AuthorizationId"]),
                                Convert.ToDateTime(drReservationAuthorization["ReserveDate"]),
                                GlobalCode.ToDecimal(drReservationAuthorization["SubstitutedAmount"]),
                                GlobalCode.ToDecimal(drReservationAuthorization["GrantAmount"]),
                                Convert.ToString(drReservationAuthorization["ReimbTypeId"]),
                                Convert.ToString(drReservationAuthorization["GrantSource"]));
            return retVal1;
        }

        private string ReduceReservation(System.Data.SqlClient.SqlTransaction transaction, UltraGridRow grContractFundSource, DataRow drReservationAuthorization)
        {
            string retVal1 = ProjectFundingData.ReservEncumbUpdate(
                            transaction,
                            GlobalCode.ToInt32(drReservationAuthorization["ReservEncumbID"]),
                            GlobalCode.ToInt32(grContractFundSource.Cells["FundId"].Value),
                            GlobalCode.ToInt32(drReservationAuthorization["AuthorizationId"]),
                            Convert.ToDateTime(drReservationAuthorization["ReserveDate"]),
                            GlobalCode.ToDecimal(drReservationAuthorization["Amount"]) - GlobalCode.ToDecimal(drReservationAuthorization["SubstitutedAmount"]),
                            GlobalCode.ToDecimal(drReservationAuthorization["GrantAmount"]),
                            GlobalCode.ToString(drReservationAuthorization["ReimbTypeId"]),
                            GlobalCode.ToString(drReservationAuthorization["GrantSource"]));
            return retVal1;
        }

        private string DisencumberAmountFromInvoice(System.Data.SqlClient.SqlTransaction transaction, UltraGridRow grContractFundSource)
        {
           string retVal1 = ContractData.InvoiceDetailInsert(transaction,
                                 cid,
                                 DateTime.Today.ToString("yyyy-MM-dd"),                                 //Received Date
                                 GlobalCode.ToDecimal(0),                                                                     //GrossInvoiceAmount
                                 GlobalCode.ToString("1"),                                                 //IsFinal
                                 null,                                                                   //billing period start
                                 DateTime.Today.ToString("MM/dd/yyyy"),                                 //Invoicedate,
                                 0,                                                                     //GrossAmountApproved
                                 0,                                                                     //NetPaymentAmount
                                 GlobalCode.ToDecimal(10),                                              //WithholdingPercent
                                 0,                                                                     //WithholdingAmount
                                 GlobalCode.ToDecimal(grContractFundSource.Cells["BalanceToDate"].Value) - GlobalCode.ToDecimal(grContractFundSource.Cells["DisencumberAmount"].Value), // Balance
                                 null,                                                                //ToProjectManagerDate
                                 null,                                                                //ToAccountingDate
                                 null,                                                                //FromAccountingDate
                                 null,                                                                //ClaimScheduleNumber
                                 null,                                                                //ClaimScheduleDate
                                 null,                                                                //DisputeDateFromPM
                                 "substitution of funds",                                                       //Reason
                                 null,                                                                //DisputeDateMailedOut
                                 "0",                                                                  //IsDisputed
                                 GlobalCode.ToInt32(grContractFundSource.Cells["FundId"].Value),        //fundingSource
                                 "substitution of funds",                                                       //InvoiceNumber
                                 GlobalCode.ToDecimal(grContractFundSource.Cells["DisencumberAmount"].Value) * (-1));   //Disencumber
            return retVal1;
        }

        private void uwgContractFund_AfterCellUpdate(object sender, CellEventArgs e)
        {

            decimal SubstitutedAmountOriginal = 0;
            decimal SubstitutedAmount = 0;
            decimal BalanceToDate = 0;

            if (uwgContractFund.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                uwgContractFund.ActiveRow.Cells["DirtyFlag"].Value = "1";
            blnSkip = false;
            blnDataDirty = true;
            SetButtons();
        }


 

        private void uwgAuthorization_MouseDown(object sender, MouseEventArgs e)
        {
            if (cid == 0)
                return;
        }


        private void uddFundingSource_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            e.Layout.Bands[0].Columns[0].Hidden = true;

            e.Layout.Bands[0].Columns[1].Width = 65;
            e.Layout.Bands[0].Columns[1].Header.Caption = "FY";

            e.Layout.Bands[0].Columns[2].Width = 183;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Funding Item";

            e.Layout.Bands[0].Columns[3].Width = 165;
            e.Layout.Bands[0].Columns[3].Header.Caption = "Source/Nickname";

            e.Layout.Bands[0].Columns[4].Width = 225;
            e.Layout.Bands[0].Columns[4].Header.Caption = "Program Name";

            e.Layout.Bands[0].Columns[5].Width = 140;
            e.Layout.Bands[0].Columns[5].Header.Caption = "SubAccount";

            e.Layout.Bands[0].Columns[6].Hidden = true;

            e.Layout.Bands[0].Columns[7].Hidden = true;

            // Source
            e.Layout.Bands[0].Columns[8].Hidden = true;

        }       
     
        private void FundSubstitute_Load(object sender, EventArgs e)
        {
            blnDataChanged = false;
        }

        private void FundSubstitute_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (blnDataChanged == true || blnDataDirty == true)
            {
                DialogResult intResult = MessageBox.Show("Do you want to save changes ?", "Save Data", MessageBoxButtons.YesNo);
                if (intResult == DialogResult.Yes)
                {
                    SaveFundSourceGrid();
                }    
            }

        }


        private void FundSubstitute_Activated(object sender, EventArgs e)
        {
        }


        private void btnRefresh_Click(object sender, EventArgs e)
        {
            if (blnDataDirty == true || blnDataChanged == true)
            {
                DialogResult diaRslt = MessageBox.Show("Do you want to save changes ?", "Warning", MessageBoxButtons.YesNo);
                if (diaRslt == DialogResult.Yes)
                {
                    SaveFundSourceGrid();
                }
            }
            blnDataDirty = false;
            LoadFundSubstitutePage();
            SetBalance();
        }
        
        private void uwgContractFund_AfterEnterEditMode(object sender, EventArgs e)
        {
            blnDisplay = true;
        }


        private void uwgAuthorization_KeyUp(object sender, KeyEventArgs e)
        {

            SetBalance();
            if (uwgAuthorization.ActiveCell != null)
            {
                if (uwgAuthorization.ActiveCell.Column.Key == "SubstitutedAmount")
                {
                    decimal totalAuthAmount = 0;
                    decimal balance = 0;
                    for (int iAuth = 0; iAuth < uwgAuthorization.Rows.Count; iAuth++)
                    {
                        totalAuthAmount += GlobalCode.ToDecimal(uwgAuthorization.Rows[iAuth].Cells["SubstitutedAmount"].Text);
                    }

                    balance = (GlobalCode.ToDecimal(uwgContractFund.ActiveRow.Cells["DisencumberAmount"].Text) - totalAuthAmount);
                    lblBalance.Text = balance.ToString();
                    if (balance < 0)
                    {
                        lblBalance.ForeColor = Color.Red;
                    }

                }
            }
        }


        private void uwgContractFund_AfterRowActivate(object sender, EventArgs e)
        {
            SetButtons();
            // get fund id
            int FundId = 0;
            if (uwgAuthorization.Rows.Count > 0)
            {
                UltraGridRow fundRow = this.uwgContractFund.ActiveRow;
                try
                {
                    FundId = Convert.ToInt32(fundRow.Cells["FundId"].Value);
                }
                catch
                {
                    FundId = 0;
                }
            }
            LoadAuthorizationGrid();
            SetBalance();

            //Refresh Balance
            decimal totalAuthAmount = 0;
            decimal balance = 0;
            for (int iAuth = 0; iAuth < uwgAuthorization.Rows.Count; iAuth++)
            {
                totalAuthAmount += GlobalCode.ToDecimal(uwgAuthorization.Rows[iAuth].Cells["SubstitutedAmount"].Value);
            }

            balance = (GlobalCode.ToDecimal(uwgContractFund.ActiveRow.Cells["DisencumberAmount"].Text) - totalAuthAmount);
            lblBalance.Text = balance.ToString();
            if (balance < 0)
            {
                lblBalance.ForeColor = Color.Red;
            }
        }

        private void SetButtons()
        {
                if (blnDataDirty == false)
                {
                    // no edits have been made on either grid

                    this.uwgAuthorization.Enabled = true;
                    this.uwgContractFund.Enabled = true;
                    this.btnSaveAuthorization.Enabled = false;
                    this.btnCancelAuthorization.Enabled = false;
                    this.btnCancel.Enabled = false;
                }
                else
                    if (blnDataDirty == true)
                    {
                        // we're in edit mode on the Authorizations grid

                        this.uwgAuthorization.Enabled = true;
                        this.btnCancelAuthorization.Enabled = true;
                        this.btnSaveAuthorization.Enabled = true;
                        this.btnCancelAuthorization.Enabled = true;
                        this.btnCancel.Enabled = true;
                    }

            if (this.uwgContractFund.ActiveRow == null)
            {
                this.btnSaveAuthorization.Enabled = false;
                this.btnCancelAuthorization.Enabled = true;
                this.btnCancel.Enabled = false;
            }

            if (this.uwgAuthorization.ActiveRow == null)
            {
                this.btnSaveAuthorization.Enabled = false;
                this.btnCancelAuthorization.Enabled = false;
                this.btnCancel.Enabled = false;
            }

    
        }

        private void SetBalance()
        {
            lblBalance.ForeColor = Color.Black;
            lblBalance.Text = "0.00";
        }
        private void uwgContractFund_BeforeCellListDropDown(object sender, CancelableCellEventArgs e)
        {
            if (uwgContractFund.ActiveRow.Cells["NewFundId"].IsActiveCell)
            {
                string item = uwgContractFund.ActiveCell.Value.ToString();
                if (item != string.Empty)
                {
                    for (int i = 0; i < uwgContractFund.Rows.Count; i++)
                    {
                        if (item == uddFundingSource.Rows[i].Cells["FundingItem"].Value.ToString())
                        {

                            uddFundingSource.Rows[i].Selected = true;
                            uddFundingSource.Rows[i].Activated = true;
                            break;
                        }
                    }

                }
                //below
                blnDataDirty = true;
                SetButtons();

            }


        }

        private void FundSubstitute_Shown(object sender, EventArgs e)
        {
            //attempt to keep the window on top
            // this.TopMost = true;
           // this.Focus();
           // this.BringToFront();
           // this.TopMost = false;
        }

        private void uwgContractFund_KeyUp(object sender, KeyEventArgs e)
        {

            decimal SubstitutedAmountOriginal = GlobalCode.ToDecimal(uwgContractFund.ActiveRow.Cells["DisencumberAmount"].OriginalValue);
            decimal SubstitutedAmount = GlobalCode.ToDecimal(uwgContractFund.ActiveRow.Cells["DisencumberAmount"].Value);

            SetBalance();
            if (uwgContractFund.ActiveCell != null)
            {
                if (uwgContractFund.ActiveCell.Column.Key == "DisencumberAmount")
                {
                    decimal totalAuthAmount = 0;
                    decimal balance = 0;
                    for (int iAuth = 0; iAuth < uwgAuthorization.Rows.Count; iAuth++)
                    {
                        totalAuthAmount += GlobalCode.ToDecimal(uwgAuthorization.Rows[iAuth].Cells["SubstitutedAmount"].Value);
                    }

                    balance = (GlobalCode.ToDecimal(uwgContractFund.ActiveRow.Cells["DisencumberAmount"].Text) - totalAuthAmount);
                    lblBalance.Text = balance.ToString();
                    if (balance < 0)
                    {
                        lblBalance.ForeColor = Color.Red;
                    }

                }
            }

        }
               
    }
}
