﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Shared;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using CCPM.Data;
using System.Data.SqlTypes;
using Microsoft.ApplicationBlocks.Data;

namespace CCPM.Contract
{
    public partial class InvoiceDrawdownSheet : Form
    {
        int cid = 0;
        int pid = 0;
        bool blnDataDirty = false;
        bool blnGridValid = true;
        int fundingSource = 0;
        bool blnViewGridOnly = true;
        private InvoiceLog il;
        private decimal contractedAmount = 0;
        private decimal initialAmount = 0;
        bool blnSkip = false;
        bool blnBalanceWarning = true;
        public DataSet dsFundingSource;

        public int contractId
        {
            get { return cid; }
        }

        public int fundId
        {
            get { return fundingSource; }
        }

        public InvoiceDrawdownSheet(int ContractID, int FundingSource)
        {
            InitializeComponent();

            this.Location = new Point(0, 0);
            uwgInvoiceDrawdown.DisplayLayout.Override.WrapHeaderText = Infragistics.Win.DefaultableBoolean.True;
            uwgInvoiceDrawdown.DisplayLayout.TabNavigation = TabNavigation.NextControlOnLastCell;
            cid = ContractID;
            fundingSource = FundingSource;

            LoadPage();
            SetSecurity();
        }

        private void LoadPage()
        {
            DataSet ds1 = ContractData.GetContractor();
            cmbProjectManager.DataSource = ds1.Tables[0];
            cmbProjectManager.DisplayMember = "ContactFName";
            cmbProjectManager.ValueMember = "ContactId";

            DataSet ds2 = ContractData.GetContractFundOther(cid, fundingSource);
            if (ds2.Tables[0].Rows.Count > 1)
            {
                cmbOtherFund.DataSource = ds2.Tables[0];
                cmbOtherFund.DisplayMember = "FundingItem";
                cmbOtherFund.ValueMember = "FundId";
            }
            else
            {
                cmbOtherFund.Visible = false;
                lblOtherFund.Visible = false;
            }

            LoadInvoiceGrid();
            LoadData();
            CalculateBalances();
            LoadInvoiceNote();
            blnDataDirty = false;
        }

        private void SetSecurity()
        {
            //Conditions Met by Contracts Manager & Contracts Staff 
            if (!(GlobalSettings.IsContractsManager || GlobalSettings.IsContractsStaff))
            {
                chkContractConditionMet.Enabled = false;
            }
            
            //edit & delete only:  Contracts Manager, Contracts Staff, and Accounting Manager
            if (GlobalSettings.IsContractsManager || GlobalSettings.IsContractsStaff || GlobalSettings.IsAccountingManager)
            {
                blnViewGridOnly = false;
            }
            else
            {
                //All users can edit
                //•	Contract Conditions Met
                //•	Project Manager
                //•	Notes

                blnViewGridOnly = true;
                //disable grid edits and buttons
                btnSave.Enabled = false;
                btnAdd.Enabled = false;
                btnDelete.Enabled = false;

                UltraGridBand band = uwgInvoiceDrawdown.DisplayLayout.Bands[0];
                band.Columns["InvoiceNumber"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["ReceivedDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["GrossInvoiceAmount"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["WithholdingAmount"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["DisencumberAugment"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["IsFinal"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["BillingPeriodStart"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["Invoicedate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["GrossAmountApproved"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["ToProjectManagerDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["ToAccountingDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["FromAccountingDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["ClaimScheduleNumber"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["ClaimScheduleDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["DisputeDateFromPM"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["Reason"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["DisputeDateMailedOut"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["IsDisputed"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            }
        }

        private void LoadData()
        {
            DataSet dsContractInvoice = ContractData.GetContractInvoice(cid, fundingSource);
            if (dsContractInvoice.Tables[0].Rows.Count > 0)
            {
                DataRow dr = dsContractInvoice.Tables[0].Rows[0];
                this.Text = "Invoice Drawdown Sheet    (" + Convert.ToString(dr["ContractNumber"]) + ")";
                txtContractNumber.Text = Convert.ToString(dr["ContractNumber"]);
                txtGrantee.Text = Convert.ToString(dr["Organization"]);
                txtFundSource.Text = Convert.ToString(dr["FundingItem"]);
                txtExecutionDate.Text = Convert.ToString(dr["ExecutedDate"]);  
                txtComplDate.Text = Convert.ToString(dr["CompletedDate"]); 
                txtTerminDate.Text = Convert.ToString(dr["TerminationDate"]);
                txtLiquidationDate.Text = Convert.ToString(dr["LiquidationDate"]);
                cmbProjectManager.Text = Convert.ToString(dr["PName"]);
                contractedAmount = decimal.Parse(dr["ContractedAmount"].ToString());
                txtContractTotal.Text = contractedAmount.ToString(GlobalSettings.MoneyFormat);
                txtRegionalManager.Text = Convert.ToString(dr["RName"]);
                chkContractConditionMet.Checked = Convert.ToBoolean(dr["AreContractsConditionMet"]);
                txtBalance.Text = Convert.ToDecimal(dr["Balance"]).ToString(GlobalSettings.MoneyFormat);
                label10.Text = "Invoice Drawdown Sheet    (" + Convert.ToString(dr["ProjectName"]) + ")";
                txtPaidToDate.Text = Convert.ToDecimal(dr["PaidToDate"]).ToString(GlobalSettings.MoneyFormat);
                txtWithholdToDate.Text = Convert.ToDecimal(dr["WithholdingToDate"]).ToString(GlobalSettings.MoneyFormat);
                pid = (int)dr["ProjectId"];
                initialAmount = GlobalCode.ToDecimal(dr["InitialAmount"].ToString());
                txtInitialAmount.Text = initialAmount.ToString(GlobalSettings.MoneyFormat);
            }
            else
            {
                txtContractNumber.Text = cid.ToString();
            }

        }

        private void LoadInvoiceGrid()
        {
            DataSet dsInvoice = ContractData.GetInvoiceDrawDownSheet(cid, fundingSource);
            uwgInvoiceDrawdown.DataSource = dsInvoice.Tables[0];
            uwgInvoiceDrawdown.DataBind();

            if (uwgInvoiceDrawdown.Rows.Count < 1)
            {
                btnDelete.Enabled = false;
            }
            else
            {
                btnDelete.Enabled = true;
            }
        }

        private void LoadInvoiceNote()
        {
            txtNotes.Text = ContractData.GetInvoiceNote(cid, fundingSource);
        }

        private void uwgInvoiceDrawdown_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {                 
            //InvoiceId
            e.Layout.Bands[0].Columns["InvoiceId"].Hidden = true;

            e.Layout.Bands[0].Columns["ReceivedDate"].Width = 80;
            e.Layout.Bands[0].Columns["ReceivedDate"].Header.Caption = "Date Received";
            e.Layout.Bands[0].Columns["ReceivedDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;            

            e.Layout.Bands[0].Columns["InvoiceNumber"].Width = 80;
            e.Layout.Bands[0].Columns["InvoiceNumber"].Header.Caption = "Invoice Number";
            e.Layout.Bands[0].Columns["InvoiceNumber"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["Invoicedate"].Width = 80;
            e.Layout.Bands[0].Columns["Invoicedate"].Header.Caption = "Invoice Date";
            e.Layout.Bands[0].Columns["Invoicedate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["BillingPeriodStart"].Width = 80;
            e.Layout.Bands[0].Columns["BillingPeriodStart"].Header.Caption = "Billing Period";
            e.Layout.Bands[0].Columns["BillingPeriodStart"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["IsFinal"].Width = 50;
            e.Layout.Bands[0].Columns["IsFinal"].Header.Caption = "Final Invoice?";
            e.Layout.Bands[0].Columns["IsFinal"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns["IsFinal"].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.CheckBox;

            e.Layout.Bands[0].Columns["GrossInvoiceAmount"].Width = 80;
            e.Layout.Bands[0].Columns["GrossInvoiceAmount"].Header.Caption = "Gross Invoice Amount";
            e.Layout.Bands[0].Columns["GrossInvoiceAmount"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns["GrossInvoiceAmount"].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns["GrossInvoiceAmount"].MaskInput = "-nnnnnnnn.nn";
            e.Layout.Bands[0].Columns["GrossInvoiceAmount"].CellAppearance.TextHAlign = HAlign.Right;

            e.Layout.Bands[0].Columns["GrossAmountApproved"].Width = 140;
            e.Layout.Bands[0].Columns["GrossAmountApproved"].Header.Caption = "Gross Amt Approved";
            e.Layout.Bands[0].Columns["GrossAmountApproved"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns["GrossAmountApproved"].Format = "$###,###,###,###,##0.00";
            e.Layout.Bands[0].Columns["GrossAmountApproved"].MaskInput = "-nnnnnnnnnnnnnn.nn";
            e.Layout.Bands[0].Columns["GrossAmountApproved"].CellAppearance.TextHAlign = HAlign.Right;

            e.Layout.Bands[0].Columns["NetPaymentAmount"].Width = 80;
            e.Layout.Bands[0].Columns["NetPaymentAmount"].Header.Caption = "Net Amount of Payment";
            e.Layout.Bands[0].Columns["NetPaymentAmount"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["NetPaymentAmount"].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns["NetPaymentAmount"].MaskInput = "-nnnnnnn.nn";
            e.Layout.Bands[0].Columns["NetPaymentAmount"].CellAppearance.TextHAlign = HAlign.Right;
            e.Layout.Bands[0].Columns["NetPaymentAmount"].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["NetPaymentAmount"].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["NetPaymentAmount"].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns["AccumulatedPayment"].Width = 80;
            e.Layout.Bands[0].Columns["AccumulatedPayment"].Header.Caption = "Accumulated Payment";
            e.Layout.Bands[0].Columns["AccumulatedPayment"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["AccumulatedPayment"].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns["AccumulatedPayment"].MaskInput = "-nnnnnnn.nn";
            e.Layout.Bands[0].Columns["AccumulatedPayment"].CellAppearance.TextHAlign = HAlign.Right;
            e.Layout.Bands[0].Columns["AccumulatedPayment"].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["AccumulatedPayment"].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["AccumulatedPayment"].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns["WithholdingPercent"].Width = 80;
            e.Layout.Bands[0].Columns["WithholdingPercent"].Hidden = true;
            e.Layout.Bands[0].Columns["WithholdingPercent"].Header.Caption = "Withholding %";
            e.Layout.Bands[0].Columns["WithholdingPercent"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns["WithholdingPercent"].Format = "#0.00";
            e.Layout.Bands[0].Columns["WithholdingPercent"].MaskInput = "nn.nn";
            e.Layout.Bands[0].Columns["WithholdingPercent"].CellAppearance.TextHAlign = HAlign.Right;

            e.Layout.Bands[0].Columns["WithholdingAmount"].Width = 80;
            e.Layout.Bands[0].Columns["WithholdingAmount"].Header.Caption = "Withholding To Date";
            e.Layout.Bands[0].Columns["WithholdingAmount"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns["WithholdingAmount"].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns["WithholdingAmount"].MaskInput = "-nnnnnnnn.nn";
            e.Layout.Bands[0].Columns["WithholdingAmount"].CellAppearance.TextHAlign = HAlign.Right;

            e.Layout.Bands[0].Columns["WithholdingTotal"].Width = 80;
            e.Layout.Bands[0].Columns["WithholdingTotal"].Header.Caption = "Accumulated Withholding";
            e.Layout.Bands[0].Columns["WithholdingTotal"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["WithholdingTotal"].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns["WithholdingTotal"].MaskInput = "-nnnnnnnn.nn";
            e.Layout.Bands[0].Columns["WithholdingTotal"].CellAppearance.TextHAlign = HAlign.Right;
            e.Layout.Bands[0].Columns["WithholdingTotal"].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["WithholdingTotal"].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["WithholdingTotal"].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns["DisencumberAugment"].Width = 80;
            e.Layout.Bands[0].Columns["DisencumberAugment"].Header.Caption = "Disencumber/ Augment";
            e.Layout.Bands[0].Columns["DisencumberAugment"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns["DisencumberAugment"].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns["DisencumberAugment"].MaskInput = "-nnnnnnn.nn";
            e.Layout.Bands[0].Columns["DisencumberAugment"].CellAppearance.TextHAlign = HAlign.Right;

            e.Layout.Bands[0].Columns["Balance"].Width = 80;
            e.Layout.Bands[0].Columns["Balance"].Header.Caption = "Balance";
            e.Layout.Bands[0].Columns["Balance"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["Balance"].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns["Balance"].MaskInput = "-nnnnnnn.nn";
            e.Layout.Bands[0].Columns["Balance"].CellAppearance.TextHAlign = HAlign.Right;
            e.Layout.Bands[0].Columns["Balance"].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["Balance"].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["Balance"].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns["IsDisputed"].Width = 50;
            e.Layout.Bands[0].Columns["IsDisputed"].Header.Caption = "Is Disputed";
            e.Layout.Bands[0].Columns["IsDisputed"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns["IsDisputed"].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.CheckBox;

            e.Layout.Bands[0].Columns["Reason"].Width = 160;
            e.Layout.Bands[0].Columns["Reason"].Header.Caption = "Notes";
            e.Layout.Bands[0].Columns["Reason"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["ClaimScheduleNumber"].Width = 80;
            e.Layout.Bands[0].Columns["ClaimScheduleNumber"].Header.Caption = "Claim Schedule Number";
            e.Layout.Bands[0].Columns["ClaimScheduleNumber"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["ClaimScheduleDate"].Width = 80;
            e.Layout.Bands[0].Columns["ClaimScheduleDate"].Header.Caption = "Claim Sched Date";
            e.Layout.Bands[0].Columns["ClaimScheduleDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["ToProjectManagerDate"].Width = 80;
            e.Layout.Bands[0].Columns["ToProjectManagerDate"].Header.Caption = "Date to Project Manager";
            e.Layout.Bands[0].Columns["ToProjectManagerDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["ToAccountingDate"].Width = 80;
            e.Layout.Bands[0].Columns["ToAccountingDate"].Header.Caption = "Date to Accounting";
            e.Layout.Bands[0].Columns["ToAccountingDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["FromAccountingDate"].Width = 80;
            e.Layout.Bands[0].Columns["FromAccountingDate"].Header.Caption = "Date from Accounting";
            e.Layout.Bands[0].Columns["FromAccountingDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["DisputeDateFromPM"].Width = 80;
            e.Layout.Bands[0].Columns["DisputeDateFromPM"].Header.Caption = "Date from PM for dispute";
            e.Layout.Bands[0].Columns["DisputeDateFromPM"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["DisputeDateMailedOut"].Width = 80;
            e.Layout.Bands[0].Columns["DisputeDateMailedOut"].Header.Caption = "Date Disputed Mailed Out";
            e.Layout.Bands[0].Columns["DisputeDateMailedOut"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;


            e.Layout.Bands[0].Columns["DirtyFlag"].Hidden = true;

            e.Layout.Bands[0].Columns["ContractStatusId"].Hidden = true;
        }

        private void uwgInvoiceDrawdown_AfterCellUpdate(object sender, CellEventArgs e)
        {
            if (blnViewGridOnly)
                return;
            if (blnSkip)
                return;

            if (uwgInvoiceDrawdown.Rows.Count > 0)
            {
                int contractStatusId = GlobalCode.ToInt32(uwgInvoiceDrawdown.ActiveRow.Cells["ContractStatusId"].Value);
                if (contractStatusId < 3 || contractStatusId > 4)
                {
                    if (uwgInvoiceDrawdown.ActiveRow.Cells["ClaimScheduleNumber"].IsInEditMode == true || uwgInvoiceDrawdown.ActiveRow.Cells["IsFinal"].IsInEditMode == true)
                    {
                        if (uwgInvoiceDrawdown.ActiveRow.Cells["ClaimScheduleNumber"].Value.ToString() != string.Empty)
                        {
                            if (uwgInvoiceDrawdown.ActiveRow.Cells["IsFinal"].Text.ToString() == "True")
                            {
                                DialogResult diaRslt = MessageBox.Show("Please change Contract Status to 'Complete(20 yr)' or 'Closed'. If the contract status is changed, \n the entry will be removed from the Active Contract log", "Warning", MessageBoxButtons.OKCancel);
                                if (diaRslt == DialogResult.OK)
                                {
                                    ContractStatusDialog csd = new ContractStatusDialog();
                                    csd.myParentForm = this;
                                    if (csd.ShowDialog() == DialogResult.OK)
                                    {
                                        contractStatusId = 0;
                                        if (csd.ContractStatus == "Complete (20 yr)")
                                        {
                                            contractStatusId = 3;
                                        }
                                        else if (csd.ContractStatus == "Closed")
                                        {
                                            contractStatusId = 4;
                                        }
                                        int retVal = SqlHelper.ExecuteNonQuery(GlobalSettings.ConnectionString, CommandType.Text, "UPDATE ContractDetails SET ContractStatusId = " + contractStatusId + " WHERE ContractId = " + cid);
                                        blnSkip = true;
                                        uwgInvoiceDrawdown.ActiveRow.Cells["DirtyFlag"].Value = "1";
                                        uwgInvoiceDrawdown.ActiveRow.Cells["ContractStatusId"].Value = contractStatusId;
                                        blnSkip = false;
                                        if (contractStatusId == 4)       //Status to Closed
                                        {
                                            if (DialogResult.Yes == MessageBox.Show("Do you want to complete the closing comments now for Contract Number (" + txtContractNumber.Text + ") ?", "Warning", MessageBoxButtons.YesNo))
                                            {
                                                Form1 fm = (Form1)this.MdiParent;
                                                fm.OpenContract(cid);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        else if (uwgInvoiceDrawdown.ActiveRow.Cells["IsFinal"].Text.ToString() == "True")
                        {
                            if (contractStatusId < 3 || contractStatusId > 4)
                            {
                                if (uwgInvoiceDrawdown.ActiveRow.Cells["ClaimScheduleNumber"].Value.ToString() != string.Empty)
                                {
                                    DialogResult diaRslt = MessageBox.Show("Please change Contract Status to 'Complete(20 yr)' or 'Closed'. If the contract status is changed, \n the entry will be removed from the Active Contract log", "Warning", MessageBoxButtons.OKCancel);
                                    if (diaRslt == DialogResult.OK)
                                    {
                                        ContractStatusDialog csd = new ContractStatusDialog();
                                        csd.myParentForm = this;
                                        if (csd.ShowDialog() == DialogResult.OK)
                                        {
                                            contractStatusId = 0;
                                            if (csd.ContractStatus == "Complete (20 yr)")
                                            {
                                                contractStatusId = 3;
                                            }
                                            else if (csd.ContractStatus == "Closed")
                                            {
                                                contractStatusId = 4;
                                            }
                                            int retVal = SqlHelper.ExecuteNonQuery(GlobalSettings.ConnectionString, CommandType.Text, "UPDATE ContractDetails SET ContractStatusId = " + contractStatusId + " WHERE ContractId = " + cid);
                                            blnSkip = true;
                                            uwgInvoiceDrawdown.ActiveRow.Cells["DirtyFlag"].Value = "1";
                                            uwgInvoiceDrawdown.ActiveRow.Cells["ContractStatusId"].Value = contractStatusId;
                                            blnSkip = false;
                                            if (contractStatusId == 4)       //Status to Closed
                                            {
                                                if (DialogResult.Yes == MessageBox.Show("Do you want to complete the closing comments now for Contract Number (" + txtContractNumber.Text + ") ?", "Warning", MessageBoxButtons.YesNo))
                                                {
                                                    Form1 fm = (Form1)this.MdiParent;
                                                    fm.OpenContract(cid);
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                        uwgInvoiceDrawdown.ActiveRow.Cells["IsFinal"].IsInEditMode = false;
                        uwgInvoiceDrawdown.ActiveRow.Cells["ClaimScheduleNumber"].IsInEditMode = false;
                    }

                }
            }

            
            if (uwgInvoiceDrawdown.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                uwgInvoiceDrawdown.ActiveRow.Cells["DirtyFlag"].Value = "1";
            blnDataDirty = true;
        }

        private void btnAdd_Click(object sender, EventArgs e)
        {
            UltraGridRow addRow = uwgInvoiceDrawdown.DisplayLayout.Bands[0].AddNew();
            addRow.Cells["DirtyFlag"].Value = "3";
            addRow.Cells["IsFinal"].Value = "False";
            addRow.Cells["IsDisputed"].Value = "False";
            addRow.Cells["GrossAmountApproved"].Value = "0";
            addRow.Cells["NetPaymentAmount"].Value = "0";
            addRow.Cells["AccumulatedPayment"].Value = "0";
            addRow.Cells["WithholdingPercent"].Value = "10";
            addRow.Cells["WithholdingAmount"].Value = "0";
            addRow.Cells["WithholdingTotal"].Value = "0";
            addRow.Cells["Balance"].Value = "0";
            addRow.Cells["DisencumberAugment"].Value = "0";
            
            blnDataDirty = true;
        }


        private void btnSave_Click(object sender, EventArgs e)
        {
            SaveInvoiceDrawdownGrid();
            BalanceWarning();
        }

        private void SaveInvoiceDrawdownGrid()
        {
            if (blnViewGridOnly)
                return;

            string retMsg;
            int retVal1;
            for (int i = 0; i < uwgInvoiceDrawdown.Rows.Count; i++)
            {
                if (uwgInvoiceDrawdown.Rows[i].Cells["DirtyFlag"].Value.ToString() != "2")
                {
                    if (uwgInvoiceDrawdown.Rows[i].Cells["ReceivedDate"].Value.ToString() == string.Empty)
                    {
                        MessageBox.Show("Please enter Received Date !!", "Data Entry Error", MessageBoxButtons.OK);
                        return;
                    }
                    else if (uwgInvoiceDrawdown.Rows[i].Cells["GrossInvoiceAmount"].Value.ToString() == string.Empty)
                    {
                        MessageBox.Show("Please enter Gross Invoice Amount !!", "Data Entry Error", MessageBoxButtons.OK);
                        return;
                    }
                    else if (GlobalCode.ToInt32(uwgInvoiceDrawdown.Rows[i].Cells["Balance"].Value) < 0)
                    {
                        uwgInvoiceDrawdown.Rows[i].Cells["GrossAmountApproved"].Value = 0;
                        uwgInvoiceDrawdown.Rows[i].Cells["Balance"].Value = 0;
                        return;
                    }
                }
                decimal bal = GlobalCode.ToDecimal(txtBalance.Text);
                if (uwgInvoiceDrawdown.Rows[i].Cells["DirtyFlag"].Value.ToString() == "3")  //insert
                {
                    decimal amt = GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["GrossAmountApproved"].Value);
                    if (bal > 0 && (amt > bal))
                    {
                        MessageBox.Show("Gross Amount Approved can't be greater than remaining balance!", "Data Entry Error", MessageBoxButtons.OK);
                        uwgInvoiceDrawdown.Rows[i].Cells["GrossAmountApproved"].Value = 0;
                        return;
                    }
                }
                else
                {
                    decimal amt1 = GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["GrossAmountApproved"].Value);
                    decimal amt2 = GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["GrossAmountApproved"].OriginalValue);
                    if (bal > 0 && ((amt1 - amt2) > bal))
                    {
                        MessageBox.Show("Gross Amount Approved can't be greater than remaining balance!", "Data Entry Error", MessageBoxButtons.OK);
                        uwgInvoiceDrawdown.Rows[i].Cells["GrossAmountApproved"].Value = amt2;
                        return;
                    }
                }
            }

            if (blnGridValid == true)
            {
                for (int i = 0; i < uwgInvoiceDrawdown.Rows.Count; i++)
                {
                    switch (uwgInvoiceDrawdown.Rows[i].Cells["DirtyFlag"].Value.ToString())
                    {
                        case "1":
                            {
                                retMsg = ContractData.InvoiceDetailUpdate(
                                        Convert.ToInt32(uwgInvoiceDrawdown.Rows[i].Cells["InvoiceId"].Value),
                                        Convert.ToDateTime(uwgInvoiceDrawdown.Rows[i].Cells["ReceivedDate"].Value),
                                        GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["GrossInvoiceAmount"].Value),
                                        Convert.ToString(uwgInvoiceDrawdown.Rows[i].Cells["IsFinal"].Value),
                                        Convert.ToString(uwgInvoiceDrawdown.Rows[i].Cells["BillingPeriodStart"].Value),
                                        uwgInvoiceDrawdown.Rows[i].Cells["Invoicedate"].Value,
                                        GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["GrossAmountApproved"].Value),
                                        GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["NetPaymentAmount"].Value),
                                        uwgInvoiceDrawdown.Rows[i].Cells["WithholdingPercent"].Value,
                                        GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["WithholdingAmount"].Value),
                                        Convert.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["Balance"].Value),
                                        uwgInvoiceDrawdown.Rows[i].Cells["ToProjectManagerDate"].Value,
                                        uwgInvoiceDrawdown.Rows[i].Cells["ToAccountingDate"].Value, 
                                        uwgInvoiceDrawdown.Rows[i].Cells["FromAccountingDate"].Value,
                                        Convert.ToString(uwgInvoiceDrawdown.Rows[i].Cells["ClaimScheduleNumber"].Value),
                                        uwgInvoiceDrawdown.Rows[i].Cells["ClaimScheduleDate"].Value,
                                        uwgInvoiceDrawdown.Rows[i].Cells["DisputeDateFromPM"].Value,
                                        Convert.ToString(uwgInvoiceDrawdown.Rows[i].Cells["Reason"].Value),
                                        uwgInvoiceDrawdown.Rows[i].Cells["DisputeDateMailedOut"].Value,
                                        Convert.ToString(uwgInvoiceDrawdown.Rows[i].Cells["IsDisputed"].Value),
                                        fundingSource,
                                        Convert.ToString(uwgInvoiceDrawdown.Rows[i].Cells["InvoiceNumber"].Value),
                                        GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["DisencumberAugment"].Value)
                                        );
                                if (retMsg != "success")
                                {
                                    MessageBox.Show("Update failed ", "Database Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                                }
                                break;
                            }
                        case "2":
                            {
                                if (GlobalCode.ToInt32(uwgInvoiceDrawdown.ActiveRow.Cells[0].Value) > 0)
                                {
                                    retMsg = ContractData.InvoiceDetailDelete(Convert.ToInt32(uwgInvoiceDrawdown.ActiveRow.Cells[0].Value));
                                    if (retMsg != "success")
                                        MessageBox.Show("Delete failed", "Database Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                                }
                                break;
                            }
                        case "3":
                            {
                                retVal1 = ContractData.InvoiceDetailInsert(
                                        cid, 
                                        Convert.ToDateTime(uwgInvoiceDrawdown.Rows[i].Cells["ReceivedDate"].Value),
                                        GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["GrossInvoiceAmount"].Value),
                                        Convert.ToString(uwgInvoiceDrawdown.Rows[i].Cells["IsFinal"].Value),
                                        Convert.ToString(uwgInvoiceDrawdown.Rows[i].Cells["BillingPeriodStart"].Value),
                                        uwgInvoiceDrawdown.Rows[i].Cells["Invoicedate"].Value,
                                        GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["GrossAmountApproved"].Value),
                                        GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["NetPaymentAmount"].Value),
                                        uwgInvoiceDrawdown.Rows[i].Cells["WithholdingPercent"].Value,
                                        GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["WithholdingAmount"].Value),
                                        GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["Balance"].Value),
                                        uwgInvoiceDrawdown.Rows[i].Cells["ToProjectManagerDate"].Value,
                                        uwgInvoiceDrawdown.Rows[i].Cells["ToAccountingDate"].Value,
                                        uwgInvoiceDrawdown.Rows[i].Cells["FromAccountingDate"].Value,
                                        Convert.ToString(uwgInvoiceDrawdown.Rows[i].Cells["ClaimScheduleNumber"].Value),
                                        uwgInvoiceDrawdown.Rows[i].Cells["ClaimScheduleDate"].Value,
                                        uwgInvoiceDrawdown.Rows[i].Cells["DisputeDateFromPM"].Value,
                                        Convert.ToString(uwgInvoiceDrawdown.Rows[i].Cells["Reason"].Value),
                                        uwgInvoiceDrawdown.Rows[i].Cells["DisputeDateMailedOut"].Value,
                                        Convert.ToString(uwgInvoiceDrawdown.Rows[i].Cells["IsDisputed"].Value),
                                        fundingSource,
                                        Convert.ToString(uwgInvoiceDrawdown.Rows[i].Cells["InvoiceNumber"].Value), 
                                        GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["DisencumberAugment"].Value)
                                        );

                                if (retVal1 == -1)
                                {
                                    MessageBox.Show("Insert failed ", "Database Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                                }
                                break;
                            }
                    }
                }
                LoadInvoiceGrid();
                LoadData();
                CalculateBalances();
                blnGridValid = true;
                blnDataDirty = false;
            }
           
            blnGridValid = true;
            
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            UltraGridRow row = this.uwgInvoiceDrawdown.ActiveRow;

            if (null != row)
            {
                DialogResult intDiagResult = MessageBox.Show("Do you want to delete this Invoice?", "Delete Row",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intDiagResult == DialogResult.Yes)
                {
                    // if the row is a database row then mark it for deletion and hide it in the grid
                    row.Hidden = true;
                    row.Cells["DirtyFlag"].Value = "2";
                    blnDataDirty = true;
                   
                    // set the active row to first (non-hidden) row
                    SaveInvoiceDrawdownGrid();
                    GridManager.FirstButtonHandler(uwgInvoiceDrawdown);                    
                }
            }
            else
            {
                // If there is no active row, then prompt the user to select one. 
                MessageBox.Show("Please select a single row to delete.");
            } 	     
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            if (blnDataDirty == true)
            {
                DialogResult intRes = MessageBox.Show("Data has changed - Do you want to cancel changes?", "Cancel Changes",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intRes == DialogResult.Yes)
                {
                    CancelChanges();
                }
            }
        }

        private void CancelChanges()
        {
            blnDataDirty = false;
            this.LoadInvoiceGrid();
            CalculateBalances();
        }

        private void InvoiceDrawdownSheet_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (blnDataDirty)
            {
                DialogResult intResult = MessageBox.Show("Do you want to save changes ?", "Save Data", MessageBoxButtons.YesNo);
                if (intResult == DialogResult.Yes)
                {
                    SaveInvoiceDrawdown();
                    SaveInvoiceDrawdownGrid();
                }
            }
            blnDataDirty = false;
        }

        private void SaveInvoiceDrawdown()
        {
            if (blnDataDirty)
            {
                int retVal = SqlHelper.ExecuteNonQuery(GlobalSettings.ConnectionString, CommandType.Text, "UPDATE ContractDetails SET ProjectManagerId = " + cmbProjectManager.SelectedValue + ", AreContractsConditionMet = '" + chkContractConditionMet.Checked.ToString() + "' WHERE ContractId = " + cid);
                ContractData.ProjectProjectManagerInsert(cid);
                ContractData.InvoiceNoteSave(cid, GlobalSettings.UserId, txtNotes.Text.ToString(), fundingSource);
                blnDataDirty = false;
            }
        }

        private void btnInvoiceSave_Click(object sender, EventArgs e)
        {
            SaveAll();
        }

        private void SaveAll()
        {
            SaveInvoiceDrawdown();
            SaveInvoiceDrawdownGrid();
            BalanceWarning();
            blnDataDirty = false;
        }

        private void btnGoToInvoiceLog_Click(object sender, EventArgs e)
        {
            Form1 fm = (Form1)this.MdiParent;
            CCPM.Contract.InvoiceLog il = new CCPM.Contract.InvoiceLog();
            fm.OpenForm(il, "Invoice Log");
        }

        private void btnGoToContractDetails_Click(object sender, EventArgs e)
        {
            Form1 fm = (Form1)this.MdiParent;
            fm.OpenContract(txtContractNumber.Text.ToString());
            this.Close();
        }

        private void uwgInvoiceDrawdown_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Tab)
            {
                if (uwgInvoiceDrawdown.ActiveRow.Index == uwgInvoiceDrawdown.Rows.Count - 1)
                {
                    if (uwgInvoiceDrawdown.ActiveCell.Column.Index == 21)
                    {
                        e.SuppressKeyPress = true;
                        this.btnAdd.Focus();
                    }
                }
            }

        }

        private void btnRefresh_Click(object sender, EventArgs e)
        {
            LoadPage();
            BalanceWarning();
        }

        private void txtContractNumber_DoubleClick(object sender, EventArgs e)
        {
            Form1 fm = (Form1)this.MdiParent;
            fm.OpenContract(txtContractNumber.Text.ToString());
            this.Close();
        }

        private void cmbOtherFund_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (cmbOtherFund.SelectedIndex > 0)
            {
                int fid = (int)cmbOtherFund.SelectedValue;
                GlobalSettings.mainFormHandle.OpenInvoiceDrawdown(cid, fid);
            }
        }

        private void btnGoToProject_Click(object sender, EventArgs e)
        {
            Form1 mainForm = (Form1)this.MdiParent;
            mainForm.OpenProject(pid, ProjectData.GetProjectName(pid));
            CCPM.Project.ProjectForm projectForm = null;
            mainForm.GetCurrentProject(out projectForm);
            projectForm.SetTabIndex(4);
        }

        private void BalanceWarning()
        {
            if (uwgInvoiceDrawdown.Rows.Count == 0)
                return;

            string msg = "";
            decimal amt = 0;
            if (GlobalCode.ToDecimal(txtBalance.Text) < 0)
            {
                msg += "The balance is less than zero !!\n\n";
            }

            //balance warining
            //amt = ContractData.GetContractFundTotal(cid, fundId, "B");
            //if (amt != 0)
            //{
            //    msg += "Balance off by " + amt.ToString(GlobalSettings.MoneyFormat) + ".\n\n";
            //}

            amt = ContractData.GetContractFundTotal(cid, fundId, "DA");
            if (amt != 0)
            {
                msg += "Contracted Amount of fund source needs to be updated on the Contract Details pages to reflect disencumbered and/ or augmented funds.  " +
                    "Contracted Amount should be changed by " + amt.ToString(GlobalSettings.MoneyFormat) + ".\n\n";
            }
            if (msg != string.Empty)
                MessageBox.Show(msg, "Warning", MessageBoxButtons.OK);
        }

        private void InvoiceDrawdownSheet_Enter(object sender, EventArgs e)
        {
            if (!blnBalanceWarning)
                return;
            BalanceWarning();
            blnBalanceWarning = false;
        }


        private void CalculateBalances()
        {
            decimal waamt = 0;
            decimal grossAmount = 0;
            decimal netAmount = 0;
            decimal balanceTotal = initialAmount;   // contractedAmount;
            decimal paymentTotal = 0;
            decimal withholdingTotal = 0;
            decimal augmentAmount = 0;
            decimal augmentTotal = 0;        //DisencumberAugment

            for (int i = 0; i < uwgInvoiceDrawdown.Rows.Count; i++)
            {
                //Balance = InitialAmount - GrossAmountApproved + AugmentAmount 

                waamt = GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["WithholdingAmount"].Value);

                augmentAmount = GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["DisencumberAugment"].Value);
                grossAmount = GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["GrossAmountApproved"].Value);
                netAmount = GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["NetPaymentAmount"].Value);
                balanceTotal = balanceTotal - grossAmount + augmentAmount;
                if (waamt < 0)
                    balanceTotal -= waamt;
                paymentTotal += netAmount;
                withholdingTotal += waamt;
                if (balanceTotal != GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["Balance"].Value))
                    uwgInvoiceDrawdown.Rows[i].Cells["Balance"].Value = balanceTotal;
                if (paymentTotal != GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["AccumulatedPayment"].Value))
                    uwgInvoiceDrawdown.Rows[i].Cells["AccumulatedPayment"].Value = paymentTotal;
                if (withholdingTotal != GlobalCode.ToDecimal(uwgInvoiceDrawdown.Rows[i].Cells["WithholdingTotal"].Value))
                    uwgInvoiceDrawdown.Rows[i].Cells["WithholdingTotal"].Value = withholdingTotal;
            }

        }

        private void uwgInvoiceDrawdown_AfterExitEditMode(object sender, EventArgs e)
        {
            decimal pct = 0;
            decimal waamt = 0;
            decimal grossAmount = 0;
            decimal netAmount = 0;
            decimal amt = 0;
            //recalc withholding when GrossAmountApproved changed
            if (uwgInvoiceDrawdown.ActiveCell.Column.Key == "GrossAmountApproved")
            {
                grossAmount = GlobalCode.ToDecimal(uwgInvoiceDrawdown.ActiveRow.Cells["GrossAmountApproved"].Value);
                amt = GlobalCode.ToDecimal(uwgInvoiceDrawdown.ActiveRow.Cells["GrossAmountApproved"].OriginalValue);
                if (amt != grossAmount)
                {
                    blnSkip = true;
                    pct = GlobalCode.ToDecimal(uwgInvoiceDrawdown.ActiveRow.Cells["WithholdingPercent"].Value) / (decimal)100.00;
                    if (pct != 0)
                        waamt = Math.Round(pct * (grossAmount), 2);
                    uwgInvoiceDrawdown.ActiveRow.Cells["WithholdingAmount"].Value = waamt;
                    netAmount = grossAmount - waamt;
                    uwgInvoiceDrawdown.ActiveRow.Cells["NetPaymentAmount"].Value = netAmount;
                    blnSkip = false;
                    CalculateBalances();
                }
            }
            else if (uwgInvoiceDrawdown.ActiveCell.Column.Key == "WithholdingAmount")
            {
                waamt = GlobalCode.ToDecimal(uwgInvoiceDrawdown.ActiveRow.Cells["WithholdingAmount"].Value);
                amt = GlobalCode.ToDecimal(uwgInvoiceDrawdown.ActiveRow.Cells["WithholdingAmount"].OriginalValue);
                if (amt != waamt)
                {
                    grossAmount = GlobalCode.ToDecimal(uwgInvoiceDrawdown.ActiveRow.Cells["GrossAmountApproved"].Value);
                    if (waamt > 0)
                        netAmount = grossAmount - waamt;
                    else
                        netAmount = grossAmount;
                    uwgInvoiceDrawdown.ActiveRow.Cells["NetPaymentAmount"].Value = netAmount;
                    CalculateBalances();
                }
            }
            else if (uwgInvoiceDrawdown.ActiveCell.Column.Key == "IsDisputed")
            {
                if (uwgInvoiceDrawdown.ActiveRow.Cells["IsDisputed"].Text.ToString() == "True")
                {
                    uwgInvoiceDrawdown.ActiveRow.Cells["GrossAmountApproved"].Value = GlobalCode.ToDecimal(0);
                    //recalculate
                    grossAmount = GlobalCode.ToDecimal(uwgInvoiceDrawdown.ActiveRow.Cells["GrossAmountApproved"].Value);
                    amt = GlobalCode.ToDecimal(uwgInvoiceDrawdown.ActiveRow.Cells["GrossAmountApproved"].OriginalValue);
                    if (amt != grossAmount)
                    {
                        blnSkip = true;
                        pct = GlobalCode.ToDecimal(uwgInvoiceDrawdown.ActiveRow.Cells["WithholdingPercent"].Value) / (decimal)100.00;
                        if (pct != 0)
                            waamt = Math.Round(pct * (grossAmount), 2);
                        uwgInvoiceDrawdown.ActiveRow.Cells["WithholdingAmount"].Value = waamt;
                        netAmount = grossAmount - waamt;
                        uwgInvoiceDrawdown.ActiveRow.Cells["NetPaymentAmount"].Value = netAmount;
                        blnSkip = false;
                        CalculateBalances();
                    }
                }

            }
        }

        private void txtNotes_TextChanged(object sender, EventArgs e)
        {
            blnDataDirty = true;
        }

        private void cmbProjectManager_SelectedIndexChanged(object sender, EventArgs e)
        {
            blnDataDirty = true;
        }

        private void chkContractConditionMet_CheckedChanged(object sender, EventArgs e)
        {
            blnDataDirty = true;
        }

        private void uwgInvoiceDrawdown_InitializeRow(object sender, InitializeRowEventArgs e)
        {
            if (uwgInvoiceDrawdown.Rows.Count > 0)
            {
                if (e.Row.Cells["IsDisputed"].Text.ToString() == "True")
                    e.Row.Appearance.FontData.Strikeout = DefaultableBoolean.True;
                else
                    e.Row.Appearance.FontData.Strikeout = DefaultableBoolean.False;
            }
        }

        private void btnReassignInvoices_Click(object sender, EventArgs e)
        {
            if (blnDataDirty)
            {
                DialogResult result = MessageBox.Show("You have made changes. Would you like to save them first before reassigning the invoices to a different funding source?", "Save Changes?", MessageBoxButtons.YesNoCancel, MessageBoxIcon.Question);

                switch (result)
                {
                    case DialogResult.Yes:
                        SaveAll();
                        break;
                    case DialogResult.No:
                        CancelChanges();
                        break;
                    case DialogResult.Cancel:
                        return;
                        break;
                }
            }

            //get list of funding sources for reassignment
            dsFundingSource = ContractData.GetProjectFundingSource(Convert.ToInt32(pid));

            DataTable dtFundingSources = dsFundingSource.Tables[0].Clone();

            foreach (DataRow fundingRow in dsFundingSource.Tables[0].Rows)
            {
                if (Convert.ToInt32(fundingRow.ItemArray.GetValue(0)) != fundingSource)
                {
                    dtFundingSources.ImportRow(fundingRow);
                }
            }

            if (dtFundingSources.Rows.Count > 0)
            {
                InvoiceReassignment invoiceReassignmentForm = new InvoiceReassignment();
                invoiceReassignmentForm.DtFundingSourceList = dtFundingSources;

                if (invoiceReassignmentForm.ShowDialog() == DialogResult.OK)
                {
                    int selectedFundID = invoiceReassignmentForm.FundIDSelected;

                    ContractData.ContractFundInvoicesReassigned(cid, fundingSource, selectedFundID);

                    LoadPage();
                    BalanceWarning();
                }
            }
            else
            {
                MessageBox.Show("There are no other available funding sources to assign the invoices to. You must add funding sources to the reserved funds of the project first.", "No Funding Sources Available", MessageBoxButtons.OK, MessageBoxIcon.Information);
            }
        }

        private void InvoiceDrawdownSheet_Load(object sender, EventArgs e)
        {

        }
    }
}
