﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Shared;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using CCPM.Data;
using Microsoft.ApplicationBlocks.Data;
using System.Data.SqlTypes;

namespace CCPM.Contract
{
    public partial class InvoiceLog : Form
    {
        bool blnDataDirty = false;
        bool blnGridValid = true;
        bool blnViewOnly = true;

        public InvoiceLog()
        {
            InitializeComponent();

            DataSet ds = null;
            ds = ContractData.GetContractList();
            txtContractNumber.DataSource = ds.Tables[0];
            txtContractNumber.DisplayLayout.Bands[0].Columns[0].Hidden = true;
            txtContractNumber.DisplayMember = "ContractNumber";
            txtContractNumber.ValueMember = "ContractId";

            this.Location = new Point(0, 0);
            uwgInvoiceLog.DisplayLayout.Override.WrapHeaderText = DefaultableBoolean.True;
            uwgInvoiceLog.DisplayLayout.Override.HeaderClickAction = Infragistics.Win.UltraWinGrid.HeaderClickAction.SortSingle;

            DataSet dsAllOrgs = ProjectFundingData.GetOrgList();
            uwgInvoiceLog.DisplayLayout.ValueLists.Add("Orgs");
            for (int i = 0; i < dsAllOrgs.Tables[0].Rows.Count; i++)
            {
                Infragistics.Win.ValueListItem ListItem = new Infragistics.Win.ValueListItem();
                ListItem.DataValue = dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(0);
                ListItem.DisplayText = (string)dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(1);
                uwgInvoiceLog.DisplayLayout.ValueLists["Orgs"].ValueListItems.Add(ListItem);
            }

            loadGridInvoiceAll();
            LoadCalculation();
            SetSecurity();
            
        }

        private void SetSecurity()
        {
            //edit & delete only:  Contracts Manager, Contracts Staff, and Accounting Manager
            if (GlobalSettings.IsContractsManager || GlobalSettings.IsContractsStaff || GlobalSettings.IsAccountingManager)
            {
                blnViewOnly = false;
            }
            else if (GlobalSettings.IsProjectManager)
            {
                btnSave.Enabled = false;
                btnAddInvoice.Enabled = false;

                UltraGridBand band = uwgInvoiceLog.DisplayLayout.Bands[0];
                band.Columns["ReceivedDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["BillingPeriodStart"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["InvoiceDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["GrossInvoiceAmount"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["IsFinal"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["ToProjectManagerDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["ToAccountingDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["ClaimScheduleNumber"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["ClaimScheduleDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["DisputeDateFromPM"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["Reason"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["DisputeDateMailedOut"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["IsDisputed"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            }
            else
            {
                btnSave.Enabled = false;
                btnAddInvoice.Enabled = false;
            }
        }

        private void loadGridInvoice()
        {
            if (uwgInvoiceLog.DataSource != null)
            {
                LoadData();
            }
            if (uwgInvoiceLog.Rows.Count < 1)
            {
                btnOpenInvoice.Enabled = false;
            }
            else
            {
                btnOpenInvoice.Enabled = true;
            }
        }

        private void loadGridInvoiceAll()
        {
            lblFilter.Text = "";
            lblFilterOn.Text = "";
            this.uwgInvoiceLog.DisplayLayout.Bands[0].ColumnFilters.ClearAllFilters();

            LoadData();
            if (uwgInvoiceLog.Rows.Count < 1)
            {
                btnOpenInvoice.Enabled = false;
            }
            else
            {
                btnOpenInvoice.Enabled = true;
            }
        }

        private void LoadCalculation()
        {           
        }

        private void LoadData()
        {
            this.Cursor = Cursors.WaitCursor;
            DataSet dsInvoice = ContractData.GetInvoiceLog();
            this.Cursor = Cursors.Default;
            uwgInvoiceLog.DataSource = dsInvoice;
            uwgInvoiceLog.DataBind();
        }

        private void uwgInvoiceLog_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            e.Layout.Bands[0].Columns["InvoiceId"].Hidden = true;

            e.Layout.Bands[0].Columns["ContractNumber"].Width = 70;
            e.Layout.Bands[0].Columns["ContractNumber"].Header.Caption = "Contract Number";
            e.Layout.Bands[0].Columns["ContractNumber"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["ContractNumber"].TabStop = false;
            e.Layout.Bands[0].Columns["ContractNumber"].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["ContractNumber"].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["ContractNumber"].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns["GranteeId"].Width = 160;
            e.Layout.Bands[0].Columns["GranteeId"].Header.Caption = "Grantee/Contractor";
            e.Layout.Bands[0].Columns["GranteeId"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["GranteeId"].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDown;
            e.Layout.Bands[0].Columns["GranteeId"].ValueList = uwgInvoiceLog.DisplayLayout.ValueLists["Orgs"];
            e.Layout.ValueLists["Orgs"].DisplayStyle = Infragistics.Win.ValueListDisplayStyle.DisplayText;

            e.Layout.Bands[0].Columns["ReceivedDate"].Width = 70;
            e.Layout.Bands[0].Columns["ReceivedDate"].Header.Caption = "Date Received";
            e.Layout.Bands[0].Columns["ReceivedDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["InvoiceNumber"].Width = 70;
            e.Layout.Bands[0].Columns["InvoiceNumber"].Header.Caption = "Invoice Number";
            e.Layout.Bands[0].Columns["InvoiceNumber"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["InvoiceDate"].Width = 70;
            e.Layout.Bands[0].Columns["InvoiceDate"].Header.Caption = "Invoice Date";
            e.Layout.Bands[0].Columns["InvoiceDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["BillingPeriodStart"].Width = 80;
            e.Layout.Bands[0].Columns["BillingPeriodStart"].Header.Caption = "Billing Period";
            e.Layout.Bands[0].Columns["BillingPeriodStart"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["IsFinal"].Width = 70;
            e.Layout.Bands[0].Columns["IsFinal"].Header.Caption = "Final Invoice";
            e.Layout.Bands[0].Columns["IsFinal"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns["IsFinal"].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.CheckBox;

            e.Layout.Bands[0].Columns["GrossInvoiceAmount"].Width = 80;
            e.Layout.Bands[0].Columns["GrossInvoiceAmount"].Header.Caption = "Gross Invoice Amt";
            e.Layout.Bands[0].Columns["GrossInvoiceAmount"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns["GrossInvoiceAmount"].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns["GrossInvoiceAmount"].MaskInput = "-nnnnnnn.nn";
            e.Layout.Bands[0].Columns["GrossInvoiceAmount"].CellAppearance.TextHAlign = HAlign.Right;

            e.Layout.Bands[0].Columns["GrossAmountApproved"].Width = 80;
            e.Layout.Bands[0].Columns["GrossAmountApproved"].Header.Caption = "Gross Amt Approved";
            e.Layout.Bands[0].Columns["GrossAmountApproved"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["GrossAmountApproved"].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns["GrossAmountApproved"].MaskInput = "-nnnnnnn.nn";
            e.Layout.Bands[0].Columns["GrossAmountApproved"].CellAppearance.TextHAlign = HAlign.Right;

            e.Layout.Bands[0].Columns["NetPaymentAmount"].Width = 80;
            e.Layout.Bands[0].Columns["NetPaymentAmount"].Header.Caption = "Net Amt of Payment";
            e.Layout.Bands[0].Columns["NetPaymentAmount"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["NetPaymentAmount"].TabStop = false;
            e.Layout.Bands[0].Columns["NetPaymentAmount"].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns["NetPaymentAmount"].MaskInput = "-nnnnnnn.nn";
            e.Layout.Bands[0].Columns["NetPaymentAmount"].CellAppearance.TextHAlign = HAlign.Right;
            e.Layout.Bands[0].Columns["NetPaymentAmount"].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["NetPaymentAmount"].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["NetPaymentAmount"].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns["IsDisputed"].Width = 80;
            e.Layout.Bands[0].Columns["IsDisputed"].Header.Caption = "Is Disputed";
            e.Layout.Bands[0].Columns["IsDisputed"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns["IsDisputed"].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.CheckBox;


            e.Layout.Bands[0].Columns["Status"].Width = 80;
            e.Layout.Bands[0].Columns["Status"].Header.Caption = "Status";
            e.Layout.Bands[0].Columns["Status"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns["Status"].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns["Status"].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns["Reason"].Width = 170;
            e.Layout.Bands[0].Columns["Reason"].Header.Caption = "Notes";
            e.Layout.Bands[0].Columns["Reason"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["ClaimScheduleNumber"].Width = 70;
            e.Layout.Bands[0].Columns["ClaimScheduleNumber"].Header.Caption = "Claim Sched Number";
            e.Layout.Bands[0].Columns["ClaimScheduleNumber"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["ClaimScheduleDate"].Width = 70;
            e.Layout.Bands[0].Columns["ClaimScheduleDate"].Header.Caption = "Claim Sched Date";
            e.Layout.Bands[0].Columns["ClaimScheduleDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["ToProjectManagerDate"].Width = 80;
            e.Layout.Bands[0].Columns["ToProjectManagerDate"].Header.Caption = "Date to Proj Manager";
            e.Layout.Bands[0].Columns["ToProjectManagerDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["ToAccountingDate"].Width = 70;
            e.Layout.Bands[0].Columns["ToAccountingDate"].Header.Caption = "Date to Accounting";
            e.Layout.Bands[0].Columns["ToAccountingDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["DisputeDateFromPM"].Width = 80;
            e.Layout.Bands[0].Columns["DisputeDateFromPM"].Header.Caption = "Date Disputed by Proj Manager";
            e.Layout.Bands[0].Columns["DisputeDateFromPM"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["DisputeDateMailedOut"].Width = 80;
            e.Layout.Bands[0].Columns["DisputeDateMailedOut"].Header.Caption = "Date Dispute Mailed Out";
            e.Layout.Bands[0].Columns["DisputeDateMailedOut"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns["DirtyFlag"].Hidden = true;
            e.Layout.Bands[0].Columns["FundId"].Hidden = true;
            e.Layout.Bands[0].Columns["ContractId"].Hidden = true;
            e.Layout.Bands[0].Columns["ProjectManagerId"].Hidden = true;
            e.Layout.Bands[0].Columns["FromAccountingDate"].Hidden = true;
            e.Layout.Bands[0].Columns["Balance"].Hidden = true;
            e.Layout.Bands[0].Columns["WithholdingPercent"].Hidden = true;
            e.Layout.Bands[0].Columns["WithholdingAmount"].Hidden = true;
            e.Layout.Bands[0].Columns["DisencumberAugment"].Hidden = true;

            //filter row
            e.Layout.Override.AllowRowFiltering = Infragistics.Win.DefaultableBoolean.True;
            e.Layout.Override.FilterClearButtonLocation = FilterClearButtonLocation.Row;
            e.Layout.Override.FilterUIType = Infragistics.Win.UltraWinGrid.FilterUIType.FilterRow;
            e.Layout.Override.FilterOperatorDefaultValue = FilterOperatorDefaultValue.Contains;

            //column sorting
            e.Layout.Override.HeaderClickAction = HeaderClickAction.SortMulti;
        }

        private void btnAddInvoice_Click(object sender, EventArgs e)
        {
            if (txtContractNumber.Text != string.Empty)
            {
                DataSet ds = SqlHelper.ExecuteDataset(GlobalSettings.ConnectionString, CommandType.Text, "SELECT ContractId FROM ContractDetails WHERE ContractNumber = '" + txtContractNumber.Text.ToString() + "'");
                if (ds.Tables[0].Rows.Count > 0)
                {
                    DataRow dr = ds.Tables[0].Rows[0];
                    int id = Convert.ToInt32(dr[0]);
                    Form1 fm = (Form1)this.MdiParent;
                    FundSourceSelection fss = new FundSourceSelection(id);
                    if (fss.ShowDialog() == DialogResult.OK)
                    {
                        int fundSource = fss.FundingSource;
                        fm.OpenInvoiceDrawdown(id, fundSource);
                    }
                }
                else
                {
                    MessageBox.Show("The Contract Number doesn't exist !!", "Data Entry Error", MessageBoxButtons.OK);
                }
            }
            else
            {
                MessageBox.Show("Please enter Contract Number !!", "Data Entry Error", MessageBoxButtons.OK);
            }
        }

        private void btnOpenInvoice_Click(object sender, EventArgs e)
        {
            OpenInvoice();
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            if (blnDataDirty == true)
            {
                blnDataDirty = false;
                LoadCalculation();
                SaveInvoiceGrid();
            }
        }
        private void SaveInvoiceGrid()
        {
            if (blnViewOnly)
                return;

            string retMsg;
            int retVal1;
            for (int i = 0; i < uwgInvoiceLog.Rows.Count; i++)
            {
                if (uwgInvoiceLog.Rows[i].Cells["DirtyFlag"].Value.ToString() != "0")
                {
                    if (uwgInvoiceLog.Rows[i].Cells["ReceivedDate"].Value.ToString() == string.Empty)
                    {
                        MessageBox.Show("Please enter Received Date !!", "Data Entry Error", MessageBoxButtons.OK);
                        blnGridValid = false;
                    }
                    else if (uwgInvoiceLog.Rows[i].Cells["GrossInvoiceAmount"].Value.ToString() == string.Empty)
                    {
                        MessageBox.Show("Please enter Gross Invoice Amount !!", "Data Entry Error", MessageBoxButtons.OK);
                        blnGridValid = false;
                    }
                    else if (uwgInvoiceLog.Rows[i].Cells["GrossAmountApproved"].Value.ToString() == string.Empty)
                    {
                        MessageBox.Show("Please enter Gross Amount Approved !!", "Data Entry Error", MessageBoxButtons.OK);
                        blnGridValid = false;
                    }
                }
            }
            if (blnGridValid == true)
            {
                for (int i = 0; i < uwgInvoiceLog.Rows.Count; i++)
                {
                    switch (uwgInvoiceLog.Rows[i].Cells["DirtyFlag"].Value.ToString())
                    {
                        case "1":
                            {
                                retMsg = ContractData.InvoiceDetailUpdate(
                                        Convert.ToInt32(uwgInvoiceLog.Rows[i].Cells["InvoiceId"].Value),
                                        Convert.ToDateTime(uwgInvoiceLog.Rows[i].Cells["ReceivedDate"].Value),
                                        Convert.ToDecimal(uwgInvoiceLog.Rows[i].Cells["GrossInvoiceAmount"].Value),
                                        Convert.ToString(uwgInvoiceLog.Rows[i].Cells["IsFinal"].Value),
                                        Convert.ToString(uwgInvoiceLog.Rows[i].Cells["BillingPeriodStart"].Value),
                                        uwgInvoiceLog.Rows[i].Cells["InvoiceDate"].Value,
                                        Convert.ToDecimal(uwgInvoiceLog.Rows[i].Cells["GrossamountApproved"].Value),
                                        Convert.ToDecimal(uwgInvoiceLog.Rows[i].Cells["NetPaymentAmount"].Value),
                                        uwgInvoiceLog.Rows[i].Cells["WithholdingPercent"].Value,
                                        Convert.ToDecimal(uwgInvoiceLog.Rows[i].Cells["WithholdingAmount"].Value),
                                        Convert.ToDecimal(uwgInvoiceLog.Rows[i].Cells["Balance"].Value),
                                        uwgInvoiceLog.Rows[i].Cells["ToProjectManagerDate"].Value,
                                        uwgInvoiceLog.Rows[i].Cells["ToAccountingDate"].Value,
                                        uwgInvoiceLog.Rows[i].Cells["FromAccountingDate"].Value,
                                        Convert.ToString(uwgInvoiceLog.Rows[i].Cells["ClaimScheduleNumber"].Value),
                                        uwgInvoiceLog.Rows[i].Cells["ClaimScheduleDate"].Value,
                                        uwgInvoiceLog.Rows[i].Cells["DisputeDateFromPM"].Value,
                                        Convert.ToString(uwgInvoiceLog.Rows[i].Cells["Reason"].Value),
                                        uwgInvoiceLog.Rows[i].Cells["DisputeDateMailedOut"].Value,
                                        Convert.ToString(uwgInvoiceLog.Rows[i].Cells["IsDisputed"].Value),
                                        Convert.ToInt32( uwgInvoiceLog.Rows[i].Cells["FundId"].Value),
                                        Convert.ToString(uwgInvoiceLog.Rows[i].Cells["InvoiceNumber"].Value),
                                        GlobalCode.ToDecimal(uwgInvoiceLog.Rows[i].Cells["DisencumberAugment"].Value) 
                                        );

                                int retVal = 0;
                                int gid = GlobalCode.ToInt32(uwgInvoiceLog.Rows[i].Cells["GranteeId"].Value);
                                if (gid > 0)
                                {
                                    retVal = ContractData.ContractGranteeUpdate(Convert.ToInt32(uwgInvoiceLog.Rows[i].Cells["ContractId"].Value), gid);
                                }

                                int pmid = GlobalCode.ToInt32(uwgInvoiceLog.Rows[i].Cells["ProjectManagerId"].Value);
                                if (pmid > 0)
                                {
                                    retVal = ContractData.ContractProjectManagerUpdate(Convert.ToInt32(uwgInvoiceLog.Rows[i].Cells["ContractId"].Value), pmid);
                                    retVal = ContractData.ProjectProjectManagerInsert(Convert.ToInt32(uwgInvoiceLog.Rows[i].Cells["ContractId"].Value));
                                }
                               
                                if (retMsg != "success" || retVal == -1)
                                {
                                    MessageBox.Show("Update failed ", "Database Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                                }
                                break;
                            }
                        case "2":
                            {
                                retMsg = ContractData.InvoiceDetailDelete(Convert.ToInt32(uwgInvoiceLog.ActiveRow.Cells["InvoiceId"].Value));
                                if (retMsg != "success")
                                    MessageBox.Show("Delete failed", "Database Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                                break;
                            }
                        case "3":
                            {
                                retVal1 = ContractData.InvoiceDetailInsert
                                      (Convert.ToInt32(uwgInvoiceLog.Rows[i].Cells["ContractId"].Value),
                                       Convert.ToDateTime(uwgInvoiceLog.Rows[i].Cells["ReceivedDate"].Value),
                                       Convert.ToDecimal(uwgInvoiceLog.Rows[i].Cells["GrossInvoiceAmount"].Value),
                                       Convert.ToString(uwgInvoiceLog.Rows[i].Cells["IsFinal"].Value),
                                       uwgInvoiceLog.Rows[i].Cells["BillingPeriodStart"].Value,
                                       uwgInvoiceLog.Rows[i].Cells["InvoiceDate"].Value,
                                       Convert.ToDecimal(uwgInvoiceLog.Rows[i].Cells["GrossamountApproved"].Value),
                                       Convert.ToDecimal(uwgInvoiceLog.Rows[i].Cells["NetPaymentAmount"].Value),
                                       uwgInvoiceLog.Rows[i].Cells["WithholdingPercent"].Value,
                                       Convert.ToDecimal(uwgInvoiceLog.Rows[i].Cells["WithholdingAmount"].Value),
                                       Convert.ToDecimal(uwgInvoiceLog.Rows[i].Cells["Balance"].Value),
                                       uwgInvoiceLog.Rows[i].Cells["ToProjectManagerDate"].Value,
                                       uwgInvoiceLog.Rows[i].Cells["ToAccountingDate"].Value,
                                       uwgInvoiceLog.Rows[i].Cells["FromAccountingDate"].Value,
                                       Convert.ToString(uwgInvoiceLog.Rows[i].Cells["ClaimScheduleNumber"].Value),
                                       uwgInvoiceLog.Rows[i].Cells["ClaimScheduleDate"].Value,
                                       uwgInvoiceLog.Rows[i].Cells["DisputeDateFromPM"].Value,
                                       Convert.ToString(uwgInvoiceLog.Rows[i].Cells["Reason"].Value),
                                       uwgInvoiceLog.Rows[i].Cells["DisputeDateMailedOut"].Value,
                                       Convert.ToString(uwgInvoiceLog.Rows[i].Cells["IsDisputed"].Value),
                                       Convert.ToInt32(uwgInvoiceLog.Rows[i].Cells["FundId"].Value),
                                       Convert.ToString(uwgInvoiceLog.Rows[i].Cells["InvoiceNumber"].Value),
                                       GlobalCode.ToDecimal(uwgInvoiceLog.Rows[i].Cells["DisencumberAugment"].Value) 
                                       );

                                if (retVal1 == -1)
                                {
                                    MessageBox.Show("Insert failed ", "Database Error",
                                       MessageBoxButtons.OK, MessageBoxIcon.Error);
                                }
                                break;
                            }
                    }
                }
                loadGridInvoice();
                LoadCalculation();
                blnGridValid = true;
            }
        }

        private void uwgInvoiceLog_AfterCellUpdate(object sender, CellEventArgs e)
        {
            if (blnViewOnly)
                return;
          

            if (uwgInvoiceLog.Rows.Count > 0)
            {
                if (uwgInvoiceLog.ActiveRow.Cells["ClaimScheduleNumber"].IsInEditMode == true || uwgInvoiceLog.ActiveRow.Cells["IsFinal"].IsInEditMode == true)
                {
                    if (uwgInvoiceLog.ActiveRow.Cells["ClaimScheduleNumber"].Value.ToString() != string.Empty)
                    {
                        if (uwgInvoiceLog.ActiveRow.Cells["IsFinal"].Text.ToString() == "True")
                        {
                            DialogResult diaRslt = MessageBox.Show("Please change Contract Status to 'Complete(20 yr)' or 'Closed'. If the contract status is changed, \n the entry will be removed from the Active Contract log", "Warning", MessageBoxButtons.OKCancel);
                            if (diaRslt == DialogResult.OK)
                            {
                                ContractStatusDialog csd = new ContractStatusDialog();
                                csd.myParentForm1 = this;
                                if (csd.ShowDialog() == DialogResult.OK)
                                {
                                    int contractStatusId = 0;
                                    if (csd.ContractStatus == "Complete (20 yr)")
                                    {
                                        contractStatusId = 3;
                                    }
                                    else if (csd.ContractStatus == "Closed")
                                    {
                                        contractStatusId = 4;
                                    }
                                    DbConnection dbConnection = DbConnection.GetDbConnection();
                                    string connectionString = dbConnection.DbConnectionString;
                                    int retVal = SqlHelper.ExecuteNonQuery(connectionString, CommandType.Text, "UPDATE ContractDetails SET ContractStatusId = " + contractStatusId + " WHERE ContractId = " + Convert.ToInt32(uwgInvoiceLog.ActiveRow.Cells["ContractId"].Value));
                                    uwgInvoiceLog.ActiveRow.Cells["IsFinal"].IsInEditMode = false;
                                    uwgInvoiceLog.ActiveRow.Cells["ClaimScheduleNumber"].IsInEditMode = false;
                                    uwgInvoiceLog.ActiveRow.Cells["DirtyFlag"].Value = "1";
                                    blnDataDirty = false;
                                    if (contractStatusId == 4)       //Status to Closed
                                    {
                                        if (DialogResult.Yes == MessageBox.Show("Do you want to complete the closing comments now for Contract Number (" + uwgInvoiceLog.ActiveRow.Cells["ContractNumber"].Value.ToString() + ") ?", "Warning", MessageBoxButtons.YesNo))
                                        {
                                            Form1 fm = (Form1)this.MdiParent;
                                            fm.OpenContract((int)uwgInvoiceLog.ActiveRow.Cells["ContractId"].Value);
                                        }
                                    }
                                }
                            }
                        }
                    }
                    else if (uwgInvoiceLog.ActiveRow.Cells["IsFinal"].Text.ToString() == "True")
                    {
                        if (uwgInvoiceLog.ActiveRow.Cells["ClaimScheduleNumber"].Value.ToString() != string.Empty)
                        {
                            DialogResult diaRslt = MessageBox.Show("Please change Contract Status to 'Complete(20 yr)' or 'Closed'. If the contract status is changed, \n the entry will be removed from the Active Contract log", "Warning", MessageBoxButtons.OKCancel);
                            if (diaRslt == DialogResult.OK)
                            {
                                ContractStatusDialog csd = new ContractStatusDialog();
                                csd.myParentForm1 = this;
                                if (csd.ShowDialog() == DialogResult.OK)
                                {
                                    int contractStatusId = 0;
                                    if (csd.ContractStatus == "Complete (20 yr)")
                                    {
                                        contractStatusId = 3;
                                    }
                                    else if (csd.ContractStatus == "Closed")
                                    {
                                        contractStatusId = 4;
                                    }
                                    DbConnection dbConnection = DbConnection.GetDbConnection();
                                    string connectionString = dbConnection.DbConnectionString;
                                    int retVal = SqlHelper.ExecuteNonQuery(connectionString, CommandType.Text, "UPDATE ContractDetails SET ContractStatusId = " + contractStatusId + " WHERE ContractId = " + Convert.ToInt32(uwgInvoiceLog.ActiveRow.Cells["ContractId"].Value));
                                    uwgInvoiceLog.ActiveRow.Cells["IsFinal"].IsInEditMode = false;
                                    uwgInvoiceLog.ActiveRow.Cells["ClaimScheduleNumber"].IsInEditMode = false;
                                    uwgInvoiceLog.ActiveRow.Cells["DirtyFlag"].Value = "1";
                                    if (contractStatusId == 4)       //Status to Closed
                                    {
                                        if (DialogResult.Yes == MessageBox.Show("Do you want to complete the closing comments now for Contract Number (" + uwgInvoiceLog.ActiveRow.Cells["ContractNumber"].Value.ToString() + ") ?", "Warning", MessageBoxButtons.YesNo))
                                        {
                                            Form1 fm = (Form1)this.MdiParent;
                                            fm.OpenContract((int)uwgInvoiceLog.ActiveRow.Cells["ContractId"].Value);
                                        }
                                    }
                                }
                            }
                        }
                    }
                    uwgInvoiceLog.ActiveRow.Cells["IsFinal"].IsInEditMode = false;
                    uwgInvoiceLog.ActiveRow.Cells["ClaimScheduleNumber"].IsInEditMode = false;
                }
            }
            if (uwgInvoiceLog.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                uwgInvoiceLog.ActiveRow.Cells["DirtyFlag"].Value = "1";
            blnDataDirty = true;
        
        }

        private void InvoiceLog_Activated(object sender, EventArgs e)
        {
            loadGridInvoice();
            LoadCalculation();
        }

        private void InvoiceLog_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (blnViewOnly)
                return;

            if (blnDataDirty == true)
            {
                DialogResult diaRslt = MessageBox.Show("Do you want to save changes ?", "Warning", MessageBoxButtons.YesNo);
                if (diaRslt == DialogResult.Yes)
                {
                    blnDataDirty = false;
                    LoadCalculation();
                    SaveInvoiceGrid();
                }
            }
        }

        private void btnRefresh_Click(object sender, EventArgs e)
        {
            if (blnDataDirty == true)
            {
                DialogResult diaRslt = MessageBox.Show("Do you want to save changes ?", "Warning", MessageBoxButtons.YesNo);
                if (diaRslt == DialogResult.Yes)
                {
                    LoadCalculation();
                    SaveInvoiceGrid();
                }
            }
            label4.Visible = false;
            loadGridInvoice();
            LoadCalculation();
        }

        private void btnExport_Click(object sender, EventArgs e)
        {
            string excelFile = GlobalCode.ExcelFileName("c:\\Temp", "ccpm_export.xls", false);
            if (excelFile != string.Empty)
            {
                GlobalCode.ExportGridToExcel(uwgInvoiceLog, excelFile);
                GlobalCode.OpenAssociatedFile(excelFile);
            }
        }

        private void btnFilter_Click(object sender, EventArgs e)
        {
            GridFilter gf = new GridFilter(uwgInvoiceLog, lblFilter, lblFilterOn, this.Text);
            gf.ShowDialog();
            if (lblFilter.Text != string.Empty)
            {
                label4.Visible = true;
            }
            else
            {
                label4.Visible = false;
            }
        }

        private void txtContractNumber_KeyDown(object sender, KeyEventArgs e)
        {
            if (this.txtContractNumber.Textbox.SelectionLength == 0)
            {
                this.txtContractNumber.Select();
            }
        }

        private void uwgInvoiceLog_DoubleClickRow(object sender, DoubleClickRowEventArgs e)
        {
            OpenInvoice();
        }

        private void OpenInvoice()
        {
            GlobalSettings.mainFormHandle.OpenInvoiceDrawdown(GlobalCode.ToInt32(uwgInvoiceLog.ActiveRow.Cells["ContractId"].Value), GlobalCode.ToInt32(uwgInvoiceLog.ActiveRow.Cells["FundId"].Value));
        }

        private void uwgInvoiceLog_Enter(object sender, EventArgs e)
        {
            if (uwgInvoiceLog.Rows.Count > 0)
                uwgInvoiceLog.Rows[0].Cells["ReceivedDate"].Activate();
        }

        private void uwgInvoiceLog_KeyPress(object sender, KeyPressEventArgs e)
        {
            if (e.KeyChar == Convert.ToChar(Keys.Tab))
            {
                uwgInvoiceLog.ActiveCell.Selected = true;
            }   
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            if (uwgInvoiceLog.Rows.Count > 0)
            {
                if (!String.IsNullOrEmpty(Convert.ToString(uwgInvoiceLog.ActiveRow.Cells["FundId"].Value)) )
                {
                    MessageBox.Show("Invoice can not be deleted, it has funding source assigned. " + "\n\r" + "For further invoice actions, please click Open Invoice/Drawdown Sheet button.", "Database Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return; 
                }

                int invoiceID =Convert.ToInt32(uwgInvoiceLog.ActiveRow.Cells["InvoiceId"].Value);


                string retMsg = ContractData.InvoiceDetailDelete( invoiceID);
                if (retMsg != "success" )
                {
                    MessageBox.Show("Delete failed ", "Database Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }

                loadGridInvoice();
                LoadCalculation();
                blnGridValid = true;
            }
        }

        private void uwgInvoiceLog_AfterRowActivate(object sender, EventArgs e)
        {
            if (String.IsNullOrEmpty(Convert.ToString(uwgInvoiceLog.ActiveRow.Cells["FundId"].Value)))
                btnDelete.Enabled = true;
            else
                btnDelete.Enabled = false;

        }

        private void btnSeeAll_Click(object sender, EventArgs e)
        {
            if (blnDataDirty == true)
            {
                DialogResult diaRslt = MessageBox.Show("Do you want to save changes ?", "Warning", MessageBoxButtons.YesNo);
                if (diaRslt == DialogResult.Yes)
                {
                    LoadCalculation();
                    SaveInvoiceGrid();
                }
            }
            label4.Visible = false;
            loadGridInvoiceAll();
            LoadCalculation();
        }

        }

    }
