﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Shared;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using CCPM.Data;
using Microsoft.ApplicationBlocks.Data;


namespace CCPM.Contract
{
    public partial class MonitoringDetails : Form
    {
        int cid = 0;
        int mid = 0;
        int pid = 0;
        bool blnDataDirty = false;
        bool blnDataChanged = false;
        DataSet dsProjectStaff = null;
        DataSet dsOutcome = null;
        bool blnViewOnly = true;

        public int contractId
        {
            get { return cid; }
        }

        public MonitoringDetails(int ContractId)
        {
            InitializeComponent();
            this.Location = new Point(0, 0);
            cid = ContractId;

            // Create and bind Outcome data
            dsOutcome = ContractData.GetMonitoringOutcome();
            uwgMonitoringDetails.DisplayLayout.ValueLists.Add("Outcome");
            for (int i = 0; i < dsOutcome.Tables[0].Rows.Count; i++)
            {
                Infragistics.Win.ValueListItem listItem = new Infragistics.Win.ValueListItem();
                listItem.DataValue = dsOutcome.Tables[0].Rows[i].ItemArray.GetValue(0);
                listItem.DisplayText = (string)dsOutcome.Tables[0].Rows[i].ItemArray.GetValue(1);
                uwgMonitoringDetails.DisplayLayout.ValueLists["Outcome"].ValueListItems.Add(listItem);
            }

            //Create and bind Project Staff database
            dsProjectStaff = ProjectData.ProjectStaffList();
            uwgMonitoringDetails.DisplayLayout.ValueLists.Add("Name");
            for (int i = 0; i < dsProjectStaff.Tables[0].Rows.Count; i++)
            {
                Infragistics.Win.ValueListItem listItem1 = new Infragistics.Win.ValueListItem();
                listItem1.DataValue = dsProjectStaff.Tables[0].Rows[i].ItemArray.GetValue(0);
                listItem1.DisplayText = (string)dsProjectStaff.Tables[0].Rows[i].ItemArray.GetValue(1);
                uwgMonitoringDetails.DisplayLayout.ValueLists["Name"].ValueListItems.Add(listItem1);
            }

            LoadMonitorForm();
            LoadMonitoringGrid();
            LoadNote();

            SetSecurity();

        }

        private void SetSecurity()
        {
            //edit & delete:  Contracts Manager, Contracts Staff, Accounting Manager, Project Manager
            if (GlobalSettings.IsContractsManager || GlobalSettings.IsContractsStaff || GlobalSettings.IsAccountingManager || GlobalSettings.IsProjectManager)
            {
                blnViewOnly = false;
            }
            else
            {
                blnViewOnly = false;

                //all users can edit
                //•	Project Manager
                //•	Scheduled Date
                //•	Date Monitored
                //•	Verified By
                //•	Outcome
                //•	Monitoring Document Linked?
                //•	Remarks
               //•	Notes

                //disable grid add and delete
                btnDelete.Enabled = false;

                //UltraGridBand band = uwgMonitoringDetails.DisplayLayout.Bands[0];
                //band.Columns[1].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            }
        }

        private void LoadMonitorForm()
        {
            DataSet dsMonitoringSummary = ContractData.GetContractMonitor(cid);
            DataRow dr = dsMonitoringSummary.Tables[0].Rows[0];
            mid = Convert.ToInt16( dr["MonitorId"]);
            pid = (int)dr["ProjectId"];
            this.Text = "Monitoring Details    (" + Convert.ToString(dr["ContractNumber"]) + ")";
            txtContractNumber.Text = Convert.ToString(dr["ContractNumber"]);
            txtGrantee.Text = Convert.ToString(dr["OrganizationName"]);
            txtRegion.Text = Convert.ToString(dr["Region"]);
            txtCounty.Text = Convert.ToString(dr["CountyName"]);
            txtProjectManager.Text = Convert.ToString(dr["ProjectManager"]);
            txtProjectType.Text = Convert.ToString(dr["ProjectType"]);
            txtCompletionDate.Text = Convert.ToString(dr["CompletedDate"]);
            txtTerminationDate.Text = Convert.ToString(dr["TerminationDate"]);
            txtRequirements.Text = Convert.ToString(dr["MonitoringRequirement"]);
            txtProcedure.Text = Convert.ToString(dr["MonitoringProcedure"]);
            txtGaugingSuccess.Text = Convert.ToString(dr["MonitoringGauging"]);
            txtDocumentation.Text = Convert.ToString(dr["MonitoringDocumentation"]);
            txtAddress.Text = dr["Address"].ToString() + " " + dr["City"].ToString() + " " + dr["State"].ToString() + " " + dr["Zip"].ToString();
            txtPhone.Text = dr["GeneralPhone"].ToString();
            label10.Text = "Monitoring Details    (" + Convert.ToString(dr["ProjectName"]) + ")";

            blnDataChanged = false;
            btnCancelAll.Enabled = false;
            btnSaveAll.Enabled = false;
        }

        private void LoadMonitoringGrid()
        {
            DataSet dsMonitoringGrid = ContractData.GetContractMonitoringDetail(mid);
            uwgMonitoringDetails.DataSource = dsMonitoringGrid.Tables[0];
            uwgMonitoringDetails.DataBind();

            blnDataDirty = false;
            btnSave.Enabled = false;
            btnCancel.Enabled = false;
        }

        private void LoadNote()
        {
            txtNotes.Text = ContractData.GetContractMonitorNote(mid);
        }

        private void uwgMonitoringDetails_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            e.Layout.AutoFitStyle = AutoFitStyle.ResizeAllColumns;

            //0=MonitorDetailId, 1=MonitorId, 2=ScheduledDate, 3=MonitoringAlert, 4=MonitoredDate, 5=Name
            //6=OutcomeCode, 7=IsDocumentLinked, 8=Remarks, 9=DirtyFlag

            //MonitorDetailId
            e.Layout.Bands[0].Columns[0].Hidden = true;
            //MonitorId
            e.Layout.Bands[0].Columns[1].Hidden = true;

            e.Layout.Bands[0].Columns[2].Width = 80;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Schedule Date";
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            //e.Layout.Bands[0].Columns[2].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            //e.Layout.Bands[0].Columns[2].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            //e.Layout.Bands[0].Columns[2].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[3].Width = 100;
            e.Layout.Bands[0].Columns[3].Header.Caption = "Monitoring Alert";
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[4].Width = 90;
            e.Layout.Bands[0].Columns[4].Header.Caption = "Date Monitored";
            e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            //e.Layout.Bands[0].Columns[4].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            //e.Layout.Bands[0].Columns[4].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            //e.Layout.Bands[0].Columns[4].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[5].Width = 100;
            e.Layout.Bands[0].Columns[5].Header.Caption = "Verified By";
            e.Layout.Bands[0].Columns[5].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns[5].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDown;
            e.Layout.Bands[0].Columns[5].ValueList = uwgMonitoringDetails.DisplayLayout.ValueLists["Name"];
            e.Layout.ValueLists["Name"].DisplayStyle = Infragistics.Win.ValueListDisplayStyle.DisplayText;
            e.Layout.Bands[0].Columns[5].ValueList = uwgMonitoringDetails.DisplayLayout.ValueLists["Name"];
           
            e.Layout.Bands[0].Columns[6].Width = 80;
            e.Layout.Bands[0].Columns[6].Header.Caption = "Outcome";
            e.Layout.Bands[0].Columns[6].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns[6].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDown;
            e.Layout.Bands[0].Columns[6].ValueList = uwgMonitoringDetails.DisplayLayout.ValueLists["Outcome"];
            e.Layout.ValueLists["Outcome"].DisplayStyle = Infragistics.Win.ValueListDisplayStyle.DisplayText;
           
            e.Layout.Bands[0].Columns[7].Width = 90;
            e.Layout.Bands[0].Columns[7].Header.Caption = "Monit Doc Linked?";
            e.Layout.Bands[0].Columns[7].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns[7].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.CheckBox;

            e.Layout.Bands[0].Columns[8].Width = 150;
            e.Layout.Bands[0].Columns[8].Header.Caption = "Remarks";
            e.Layout.Bands[0].Columns[8].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            //e.Layout.Bands[0].Columns[8].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            //e.Layout.Bands[0].Columns[8].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            //e.Layout.Bands[0].Columns[8].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            // Dirty Flag
            e.Layout.Bands[0].Columns[9].Hidden = true;
        }

        private void btnAdd_Click(object sender, EventArgs e)
        {
            UltraGridRow addRow = uwgMonitoringDetails.DisplayLayout.Bands[0].AddNew();
            addRow.Cells[1].Value = mid;
            addRow.Cells["DirtyFlag"].Value = "3";
            addRow.Cells["IsDocumentLinked"].Value = false;
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            SaveMonitoringGrid();
        }

        private object SqlDateTimeNull(object dt)
        {
            if (dt == null | dt.ToString() == "" | dt == (object)System.DateTime.MinValue)
                return System.Data.SqlTypes.SqlString.Null;
            else
                return dt;
        }

        private void SaveMonitoringGrid()
        {
            if (blnViewOnly)
                return;
            if (blnDataDirty == false)
                return;

            int retVal1;
            string retMsg;
            for (int i = 0; i < uwgMonitoringDetails.Rows.Count; i++)
            {
                string s = uwgMonitoringDetails.Rows[i].Cells[5].Text.ToString();
                string s1 = uwgMonitoringDetails.Rows[i].Cells[6].Text.ToString();
                int k = 0;
                switch (uwgMonitoringDetails.Rows[i].Cells["DirtyFlag"].Value.ToString())
                {
                    case "1":
                        {
                            retMsg = ContractData.ContractMonitorDetailUpdate
                                ( Convert.ToInt32(uwgMonitoringDetails.Rows[i].Cells[0].Value)
                                , Convert.ToInt32(uwgMonitoringDetails.Rows[i].Cells[1].Value)
                                , SqlDateTimeNull(uwgMonitoringDetails.Rows[i].Cells[2].Value)
                                , SqlDateTimeNull(uwgMonitoringDetails.Rows[i].Cells[4].Value)
                                , Convert.ToInt32(uwgMonitoringDetails.Rows[i].Cells[5].ValueListResolved.GetValue(s, ref k))
                                , Convert.ToInt32(uwgMonitoringDetails.Rows[i].Cells[6].ValueListResolved.GetValue(s1, ref k))
                                , Convert.ToString(uwgMonitoringDetails.Rows[i].Cells[7].Value)
                                , Convert.ToString(uwgMonitoringDetails.Rows[i].Cells[8].Value)
                                );
                            
                            if (retMsg != "success")
                            {
                                MessageBox.Show("Update failed ", "Database Error",
                                   MessageBoxButtons.OK, MessageBoxIcon.Error);
                            }
                            break;
                        }
                    case "2":
                        {
                            retMsg = ContractData.ContractMonitorDetailDelete(Convert.ToInt32(uwgMonitoringDetails.Rows[i].Cells[0].Value));
                            if (retMsg != "success")
                                MessageBox.Show("Delete failed", "Database Error",
                                    MessageBoxButtons.OK, MessageBoxIcon.Error);
                            break;
                        }
                    case "3":
                        {
                            retVal1 = ContractData.ContractMonitorDetailInsert
                                (Convert.ToInt32(uwgMonitoringDetails.Rows[i].Cells[1].Value)
                                , SqlDateTimeNull(uwgMonitoringDetails.Rows[i].Cells[2].Value)
                                , SqlDateTimeNull(uwgMonitoringDetails.Rows[i].Cells[4].Value)
                                , Convert.ToInt32(uwgMonitoringDetails.Rows[i].Cells[5].ValueListResolved.GetValue(s, ref k))
                                , Convert.ToInt32(uwgMonitoringDetails.Rows[i].Cells[6].ValueListResolved.GetValue(s1, ref k))
                                , Convert.ToString(uwgMonitoringDetails.Rows[i].Cells[7].Value)
                                , Convert.ToString(uwgMonitoringDetails.Rows[i].Cells[8].Value)
                                );
                            if (retVal1 == -1)
                            {
                                MessageBox.Show("Insert failed ", "Database Error",
                                   MessageBoxButtons.OK, MessageBoxIcon.Error);
                            }
                            this.Refresh();
                            break;
                        }
                }
            }
            LoadMonitoringGrid();
        }

        private void uwgMonitoringDetails_AfterCellUpdate(object sender, CellEventArgs e)
        {
            if (blnViewOnly)
                return;

            if (uwgMonitoringDetails.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                uwgMonitoringDetails.ActiveRow.Cells["DirtyFlag"].Value = "1";
            blnDataDirty = true;
            btnSave.Enabled = true;
            btnCancel.Enabled = true;
        }

        private void uwgMonitoringDetails_CellListSelect(object sender, CellEventArgs e)
        {
            if (uwgMonitoringDetails.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                uwgMonitoringDetails.ActiveRow.Cells["DirtyFlag"].Value = "1";
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            UltraGridRow row = this.uwgMonitoringDetails.ActiveRow;

            if (null != row)
            {
                DialogResult intDiagResult = MessageBox.Show("Do you want to delete this Monitoring Schedule record?", "Delete Row",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intDiagResult == DialogResult.Yes)
                {
                    // if the row is a database row then mark it for deletion and hide it in the grid
                    if (row.Cells["DirtyFlag"].Value.ToString() == "0")
                    {
                        row.Hidden = true;
                        row.Cells["DirtyFlag"].Value = "2";
                        blnDataDirty = true;
                    }
                    // else it was added by the user and not saved to the database - delete it from the grid
                    else
                    {
                        row.Delete(false);
                    }
                    // set the active row to first (non-hidden) row

                    SaveMonitoringGrid();
                }
                GridManager.FirstButtonHandler(uwgMonitoringDetails);
            }
            else
            {
                // If there is no active row, then prompt the user to select one. 
                MessageBox.Show("Please select a single row to delete.");
            } 	        
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            if (blnDataDirty == true)
            {
                DialogResult intRes = MessageBox.Show("Data has changed - Do you want to cancel changes?", "Cancel Changes",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intRes == DialogResult.Yes)
                {
                    blnDataDirty = false;
                    this.LoadMonitoringGrid();
                }
            }
        }

        private void SaveForm()
        {
            if (blnViewOnly)
                return;
            if (blnDataChanged == false)
                return;
            string retMsg = "";

            retMsg = ContractData.ContractMonitorUpdate
                    ( mid
                    , txtNotes.Text
                    , txtRequirements.Text
                    , txtProcedure.Text
                    , txtGaugingSuccess.Text
                    , txtDocumentation.Text
                    , GlobalSettings.UserId
                    );
            if (retMsg != "success")
            {
                MessageBox.Show("Update failed in row ", "Database Error",
                   MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            blnDataChanged = false;
            btnSaveAll.Enabled = false;
            btnCancelAll.Enabled = false;
        }

        private void btnSaveAll_Click(object sender, EventArgs e)
        {
            if (blnDataDirty == true)
                SaveMonitoringGrid();
            SaveForm();
        }

        private void txtNotes_TextChanged(object sender, EventArgs e)
        {
            DirtyForm();
        }

        private void txtRequirements_TextChanged(object sender, EventArgs e)
        {
            DirtyForm();
        }

        private void txtProcedure_TextChanged(object sender, EventArgs e)
        {
            DirtyForm();
        }

        private void txtGaugingSuccess_TextChanged(object sender, EventArgs e)
        {
            DirtyForm();
        }

        private void txtDocumentation_TextChanged(object sender, EventArgs e)
        {
            DirtyForm();
        }

        private void DirtyForm()
        {
            blnDataChanged = true;
            btnCancelAll.Enabled = true;
            btnSaveAll.Enabled = true;
        }

        private void uwgNotes_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            e.Layout.AutoFitStyle = AutoFitStyle.ResizeAllColumns;

            //0=MonitorNoteId, 1=MonitorNote, 2=AddDate, 3=Username

            //MonitorNoteId
            e.Layout.Bands[0].Columns[0].Hidden = true;

            e.Layout.Bands[0].Columns[1].Width = 300;
            e.Layout.Bands[0].Columns[1].Header.Caption = "Note";
            e.Layout.Bands[0].Columns[1].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[1].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[1].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[1].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[2].Width = 100;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Add Date";
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[3].Width = 100;
            e.Layout.Bands[0].Columns[3].Header.Caption = "User";
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

        }

        private void MonitoringDetails_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (blnViewOnly)
                return;

            if (blnDataChanged == true || blnDataDirty == true)
            {
                DialogResult intResult = MessageBox.Show("Do you want to save changes ?", "Save Data", MessageBoxButtons.YesNo);
                if (intResult == DialogResult.Yes)
                {
                    SaveForm();
                    SaveMonitoringGrid();
                }
            }
        }

        private void btnCancelAll_Click(object sender, EventArgs e)
        {
            if (blnDataChanged == true)
            {
                DialogResult intRes = MessageBox.Show("Data has changed - Do you want to save changes?", "Data Changed",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intRes == DialogResult.Yes)
                {
                    SaveForm();
                    SaveMonitoringGrid();
                    blnDataChanged = false;
                    blnDataDirty = false;
                }
                LoadMonitorForm();
                LoadNote();
                blnDataChanged = false;
            }
        }

        private void btnMonitoringLog_Click(object sender, EventArgs e)
        {
            if (blnViewOnly == false && (blnDataChanged == true || blnDataDirty == true))
            {
                DialogResult intResult = MessageBox.Show("Do you want to save changes ?", "Save Data", MessageBoxButtons.YesNo);
                if (intResult == DialogResult.Yes)
                {
                    SaveForm();
                    SaveMonitoringGrid();
                }
            }

            Form1 fm = (Form1)this.MdiParent;
            CCPM.Contract.MonitoringLog ml = new CCPM.Contract.MonitoringLog();
            fm.OpenForm(ml, "Monitoring Log");
        }

        private void txtContractNumber_DoubleClick(object sender, EventArgs e)
        {
            Form1 fm = (Form1)this.MdiParent;
            fm.OpenContract(txtContractNumber.Text.ToString());
            this.Close();
        }

        private void btnAddDates_Click(object sender, EventArgs e)
        {
            InputBox f1 = new InputBox();
            f1.Title = "Add Multiple Dates";
            f1.IsInteger = true;
            f1.TextValue = "";
            f1.dtpValue.Value = DateTime.Today;
            f1.Caption = "";
            f1.lblValue.Text = "Enter number of annual monitoring dates to add.";
            f1.lblDate.Text = "Enter first scheduled date.";
            f1.dtpValue.Visible = true;
            
            f1.ControlBox = false;
            f1.MinimizeBox = false;
            f1.ShowDialog(this);		//modal
            if (f1.DialogResult == DialogResult.OK && f1.TextValue != "")
            {
                //delete blank row
                foreach (UltraGridRow ugr in uwgMonitoringDetails.Rows)
                {
                    if (ugr.Cells["ScheduledDate"].Value.ToString() == string.Empty)
                    {
                        ugr.Hidden = true;
                        ugr.Cells["DirtyFlag"].Value = "2";
                    }
                }
                for (int i = 0; i < int.Parse(f1.TextValue); i++)
                {
                    UltraGridRow addRow = uwgMonitoringDetails.DisplayLayout.Bands[0].AddNew();
                    addRow.Cells[1].Value = mid;
                    addRow.Cells[2].Value = Convert.ToDateTime(f1.dtpValue.Value).AddYears(i);
                    addRow.Cells["IsDocumentLinked"].Value = false;
                    addRow.Cells["DirtyFlag"].Value = "3";
                }
                blnDataDirty = true;
            }

        }

        private void btnGoToProject_Click(object sender, EventArgs e)
        {
            Form1 mainForm = (Form1)this.MdiParent;
            mainForm.OpenProject(pid, ProjectData.GetProjectName(pid));
            CCPM.Project.ProjectForm projectForm = null;
            mainForm.GetCurrentProject(out projectForm);
            projectForm.SetTabIndex(0);
        }

        private void btnRefresh_Click(object sender, EventArgs e)
        {
            if (blnViewOnly == false && (blnDataChanged == true || blnDataDirty == true))
            {
                DialogResult intResult = MessageBox.Show("Do you want to save changes ?", "Save Data", MessageBoxButtons.YesNo);
                if (intResult == DialogResult.Yes)
                {
                    SaveForm();
                    SaveMonitoringGrid();
                }
            }
            LoadMonitorForm();
            LoadMonitoringGrid();
            LoadNote();
        }

    }
}
