﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Shared;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using CCPM.Data;
using CCPM.User;
using Microsoft.ApplicationBlocks.Data;

namespace CCPM.Contract
{
    public partial class RepaymentDetails : Form
    {
        int cid = 0;
        int pid = 0;
        bool blnDataDirty = false;
        bool blnDataChange = false;
        decimal TotalReimbAmount = 0;
        decimal TotalRepaidAmount = 0;
        decimal TotalDueAmount = 0;

        public int contractId
        {
            get { return cid; }
        }

        public RepaymentDetails(int ContractId)
        {
            InitializeComponent();

            this.Location = new Point(0, 0);
            uwgSchedule.DisplayLayout.Override.WrapHeaderText = Infragistics.Win.DefaultableBoolean.True;
            cid = ContractId;
            LoadRepaymentSummary();
            LoadRepaymentGrid();
            LoadRepaymentNote();

            SetSecurity();
            blnDataChange = false;
            blnDataDirty = false;
            btnSave.Enabled = false;
            btnRepaySave.Enabled = false;
        }

        private void SetSecurity()
        {
            //edit & delete only:  Contracts Manager, Contracts Staff, and Accounting Manager
            if (GlobalSettings.IsContractsManager || GlobalSettings.IsContractsStaff || GlobalSettings.IsAccountingManager)
            {
                //all rights
            }
            else if (GlobalSettings.IsProjectManager)
            {
                txtTerms.Enabled = false;

                UltraGridBand band = uwgSchedule.DisplayLayout.Bands[0];
                band.Columns["ScheduleDate"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["Remarks"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["AmountOwed"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["DatePaid"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["AmountPaid"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["RemainingBalance"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["RepaymentAlert"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["Terms"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

                btnDelete.Enabled = false;
            }
            else
            {
                //all users can edit
                //•	Terms
                //•	Schedule Date
                //•	Remarks
                //•	Amount Owed
                //•	Notes

                //disable grid cells except for:  schedule date, remarks, amount owed
                UltraGridBand band = uwgSchedule.DisplayLayout.Bands[0];
                band.Columns["DatePaid"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns["AmountPaid"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

                btnDelete.Enabled = false;
            }
        }

        private void LoadRepaymentSummary()
        {
            DataSet dsRepaymentSummary = ContractData.GetRepaymentSummary(cid);
            DataRow dr = dsRepaymentSummary.Tables[0].Rows[0];
            this.Text = "Repayment Details    (" + Convert.ToString(dr["ContractNumber"]) + ")";
            txtContractNumber.Text = Convert.ToString(dr["ContractNumber"]);
            txtGrantee.Text = Convert.ToString(dr["Organization"]);
            txtAddress.Text = Convert.ToString(dr["Address"]) + "\r\n" + Convert.ToString(dr["City"]) + "  " + Convert.ToString(dr["State"]) + "  " + Convert.ToString(dr["Zip"]);
            txtRegion.Text = Convert.ToString(dr["Region"]);
            txtProjectManager.Text = Convert.ToString(dr["Name"]);
            txtTerms.Text = Convert.ToString(dr["Terms"]);
            label10.Text = "Repayment Details    (" + Convert.ToString(dr["ProjectName"]) + ")";
            pid = (int)dr["ProjectId"];

            DataSet ds = ContractData.GetTotalReimbAmount(cid);
            if (ds.Tables[0].Rows.Count > 0)
            {
                dr = ds.Tables[0].Rows[0];
                if (dr[0].ToString() != string.Empty)
                    TotalReimbAmount = Convert.ToDecimal(dr[0]);
            }
            txtTotalAmount.Text = TotalReimbAmount.ToString("$###,###,###.00");

            ds = ContractData.GetTotalRepaidAmount(cid);
            if (ds.Tables[0].Rows.Count > 0)
            {
                dr = ds.Tables[0].Rows[0];
                if(dr != null)
                    TotalRepaidAmount = Convert.ToDecimal(dr[0]);
            }
            txtRepaidToDate.Text = TotalRepaidAmount.ToString("$###,###,###.00");
            txtBalanceToRepay.Text = (TotalReimbAmount - TotalRepaidAmount).ToString("$###,###,###.00");
            btnRepaySave.Enabled = false;
        }

        private void LoadRepaymentGrid()
        {
            DataSet dsRepayment = ContractData.GetRepaymentGrid(cid); 
            uwgSchedule.DataSource = dsRepayment.Tables[0];
            uwgSchedule.DataBind();
            if (dsRepayment.Tables[0].Rows.Count == 0)
                txtTerms.Enabled = false;
            btnSave.Enabled = false;
        }

        private void LoadRepaymentNote()
        {
            txtNotes.Text = ContractData.GetRepaymentNote(cid);
            btnRepaySave.Enabled = false;
        }

        private void uwgSchedule_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            
            // Repayment ID
            e.Layout.Bands[0].Columns[0].Hidden = true;

            e.Layout.Bands[0].Columns[1].Width = 100;
            e.Layout.Bands[0].Columns[1].Header.Caption = "Schedule Date";
            e.Layout.Bands[0].Columns[1].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            e.Layout.Bands[0].Columns[2].Width = 200;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Remarks";
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            
            e.Layout.Bands[0].Columns[3].Width = 100;
            e.Layout.Bands[0].Columns[3].Header.Caption = "Scheduled Payment Amount";
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns[3].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns[3].MaskInput = "nnnnnnn.nn";
            e.Layout.Bands[0].Columns[3].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;

            e.Layout.Bands[0].Columns[4].Width = 100;
            e.Layout.Bands[0].Columns[4].Header.Caption = "Date Paid";
            e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            
            e.Layout.Bands[0].Columns[5].Width = 100;
            e.Layout.Bands[0].Columns[5].Header.Caption = "Amount Paid";
            e.Layout.Bands[0].Columns[5].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns[5].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns[5].MaskInput = "nnnnnnn.nn";
            e.Layout.Bands[0].Columns[5].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;

            e.Layout.Bands[0].Columns[6].Width = 120;
            e.Layout.Bands[0].Columns[6].Header.Caption = "Remaining Balance";
            e.Layout.Bands[0].Columns[6].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[6].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns[6].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[6].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[6].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;
            e.Layout.Bands[0].Columns[6].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
           

            e.Layout.Bands[0].Columns[7].Width = 150;
            e.Layout.Bands[0].Columns[7].Header.Caption = "Repayment Alert";
            e.Layout.Bands[0].Columns[7].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[7].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[7].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[7].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns["Terms"].Hidden = true;
            e.Layout.Bands[0].Columns["Terms"].Width = 150;
            e.Layout.Bands[0].Columns["Terms"].Header.Caption = "Terms";
            e.Layout.Bands[0].Columns["Terms"].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            //Dirty Flag
            e.Layout.Bands[0].Columns["DirtyFlag"].Hidden = true;
        }

        private void btnAdd_Click(object sender, EventArgs e)
        {
            UltraGridRow addRow = uwgSchedule.DisplayLayout.Bands[0].AddNew();
            addRow.Cells["DirtyFlag"].Value = "3";
            addRow.Cells["Terms"].Value = txtTerms.Text;
            btnDelete.Enabled = false;
            txtTerms.Enabled = true;
            btnSave.Enabled = false;
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            if (SaveScheduleGrid())
            {
                LoadRepaymentGrid();
                btnDelete.Enabled = true;
            }
        }

        private bool SaveScheduleGrid()
        {
            int retVal1;
            decimal total = 0;
            string retMsg;
            for (int i = 0; i < uwgSchedule.Rows.Count; i++)
            {
                //Changed to allow to enter terms and notes and save without putting in any schedule. 
                //if (uwgSchedule.Rows[i].Cells["ScheduleDate"].Value.ToString() == string.Empty)
                //{
                    //MessageBox.Show("Please enter the next schedule date !!", "Data Entry Error", MessageBoxButtons.OK);
                    //return false;
                //}
                //if (uwgSchedule.Rows[i].Cells["AmountOwed"].Value.ToString() == string.Empty)
                //{
                    //MessageBox.Show("Please enter scheduled payment amount !!", "Data Entry Error", MessageBoxButtons.OK);
                    //return false;
                //}
                if (uwgSchedule.Rows[i].Cells["AmountPaid"].Value.ToString() == string.Empty)
                {
                        uwgSchedule.Rows[i].Cells["AmountPaid"].Value = 0;
                }
                if (uwgSchedule.Rows[i].Cells["AmountOwed"].Value.ToString() != string.Empty)
                    total += Convert.ToDecimal(uwgSchedule.Rows[i].Cells["AmountOwed"].Value);
            }
            if (TotalReimbAmount < total)
            {
                MessageBox.Show("The scheduled amounts (" + total.ToString(GlobalSettings.MoneyFormat) + ") can't exceed the total amount to be repaid (" + TotalReimbAmount.ToString(GlobalSettings.MoneyFormat) + ").", "Data Entry Error", MessageBoxButtons.OK);
                return false;
            }

            total = 0;
            for (int i = 0; i < uwgSchedule.Rows.Count; i++)
            {
                uwgSchedule.Rows[i].Activate();
                if (uwgSchedule.Rows[i].Cells["AmountOwed"].Value.ToString() != string.Empty)
                {
                    total += Convert.ToDecimal(uwgSchedule.Rows[i].Cells["AmountPaid"].Value);
                    uwgSchedule.Rows[i].Cells["RemainingBalance"].Value = Convert.ToDecimal(uwgSchedule.Rows[i].Cells["AmountOwed"].Value) - Convert.ToDecimal(uwgSchedule.Rows[i].Cells["AmountPaid"].Value);
                }
                switch (uwgSchedule.Rows[i].Cells["DirtyFlag"].Value.ToString())
                {
                    case "1":
                        {
                            retMsg = ContractData.RepaymentUpdate(
                                        Convert.ToInt32(uwgSchedule.Rows[i].Cells["RepaymentId"].Value),
                                        uwgSchedule.Rows[i].Cells["ScheduleDate"].Value,
                                        uwgSchedule.Rows[i].Cells["Remarks"].Value,
                                        uwgSchedule.Rows[i].Cells["AmountOwed"].Value,
                                        uwgSchedule.Rows[i].Cells["DatePaid"].Value,
                                        uwgSchedule.Rows[i].Cells["AmountPaid"].Value,
                                        total,
                                        Convert.ToString(uwgSchedule.Rows[i].Cells["Terms"].Value)
                                        );
                                       
                            if (retMsg != "success")
                            {
                                MessageBox.Show("Update failed ", "Database Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                                return false;
                            }
                            break;
                        }
                    case "2":
                        {
                            retMsg = ContractData.RepaymentDelete(Convert.ToInt32(uwgSchedule.ActiveRow.Cells["RepaymentId"].Value));
                            if (retMsg != "success")
                            {
                                MessageBox.Show("Delete failed", "Database Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                                return false;
                            }
                            break;
                        }
                    case "3":
                        {
                            retVal1 = ContractData.RepaymentInsert(
                                        cid,
                                        uwgSchedule.Rows[i].Cells["ScheduleDate"].Value,
                                        uwgSchedule.Rows[i].Cells["Remarks"].Value,
                                        uwgSchedule.Rows[i].Cells["AmountOwed"].Value,
                                        uwgSchedule.Rows[i].Cells["DatePaid"].Value,
                                        uwgSchedule.Rows[i].Cells["AmountPaid"].Value,
                                        total,
                                        Convert.ToString(uwgSchedule.Rows[i].Cells["Terms"].Value)
                                        );

                            if (retVal1 == -1)
                            {
                                MessageBox.Show("Insert failed ", "Database Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                                return false;
                            }
                            break;
                        }
                }
            }
            blnDataDirty = false;
            return true;
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            UltraGridRow row = this.uwgSchedule.ActiveRow;
            if (null != row)
            {
                DialogResult intDiagResult = MessageBox.Show("Do you want to delete this Repayment Schedule, and save all other pending changes?", "Delete Row",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intDiagResult == DialogResult.Yes)
                {
                    row.Hidden = true;
                    row.Cells["DirtyFlag"].Value = "2";
                    blnDataDirty = true;

                    if (SaveScheduleGrid())
                    {
                        LoadRepaymentGrid();
                        GridManager.FirstButtonHandler(uwgSchedule);
                    }
                }
            }
            else
            {
                // If there is no active row, then prompt the user to select one. 
                MessageBox.Show("Please select a single row to delete.");
            } 	           
        }

        private void uwgSchedule_AfterCellUpdate(object sender, CellEventArgs e)
        {
            if (uwgSchedule.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                uwgSchedule.ActiveRow.Cells["DirtyFlag"].Value = "1";
            blnDataDirty = true;
            btnSave.Enabled = true;
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            if (blnDataDirty == true)
            {
                DialogResult intRes = MessageBox.Show("Data has changed - Do you want to cancel changes?", "Cancel Changes",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intRes == DialogResult.Yes)
                {
                    blnDataDirty = false;
                    LoadRepaymentGrid();
                }
            }
            btnDelete.Enabled = true;
        }

        private bool SaveRepayment()
        {
            if (SaveScheduleGrid())
            {
                blnDataDirty = false;
                ContractData.RepaymentNoteSave(cid, txtNotes.Text);
                LoadRepaymentGrid();
                LoadRepaymentSummary();
                blnDataChange = false;
                return true;
            }
            return false;
        }

        private void RepaymentDetails_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (blnDataChange == true || blnDataDirty == true)
            {
                this.Focus();
                DialogResult intResult = MessageBox.Show("Do you want to save changes ?", "Save Data", MessageBoxButtons.YesNo);
                if (intResult == DialogResult.Yes)
                {
                    if (!SaveRepayment())
                    {
                        this.Focus();
                        e.Cancel = true;
                        return;
                    }
                }   
            }

            TotalDueAmount = 0;
            foreach (UltraGridRow ugr in uwgSchedule.Rows)
            {
                TotalDueAmount += GlobalCode.ToDecimal(ugr.Cells["AmountOwed"].Value);
            }
            if (TotalDueAmount != TotalReimbAmount)
            {
                this.Focus();
                DialogResult intResult = MessageBox.Show("There is an unscheduled payment amount balance of " + (TotalReimbAmount - TotalDueAmount).ToString("$#,##0.00") + ".  Do you want to enter the data now?", "Fix Data", MessageBoxButtons.YesNo);
                if (intResult == DialogResult.Yes)
                {
                    e.Cancel = true;
                }
            }
        }

        private void uwgNotes_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            //ReapymentNoteId
            e.Layout.Bands[0].Columns[0].Hidden = true;

            e.Layout.Bands[0].Columns[1].Width = 600;
            e.Layout.Bands[0].Columns[1].Header.Caption = "Notes";
            e.Layout.Bands[0].Columns[1].CellActivation = Infragistics.Win.UltraWinGrid.Activation.ActivateOnly;
            e.Layout.Bands[0].Columns[1].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[1].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[1].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[2].Width = 100;
            e.Layout.Bands[0].Columns[2].Header.Caption = "User";
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.ActivateOnly;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[3].Width = 80;
            e.Layout.Bands[0].Columns[3].Header.Caption = "Date";
            e.Layout.Bands[0].Columns[3].Format = "MM/dd/yyyy";
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.ActivateOnly;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;
        }

        private void button1_Click(object sender, EventArgs e)
        {
            Form1 fm = (Form1)this.MdiParent;
            fm.OpenContract(txtContractNumber.Text.ToString());
            //this.Close();
        }

        private void btnRepaySave_Click(object sender, EventArgs e)
        {
            SaveRepayment();
        }

        private void btnGoToRepaymentLog_Click(object sender, EventArgs e)
        {
            Form1 fm = (Form1)this.MdiParent;
            CCPM.Contract.RepaymentLog rl = new CCPM.Contract.RepaymentLog();
            fm.OpenForm(rl, "Repayment Log");
        }

        private void txtContractNumber_DoubleClick(object sender, EventArgs e)
        {
            Form1 fm = (Form1)this.MdiParent;
            fm.OpenContract(txtContractNumber.Text.ToString());
            this.Close();
        }

        private void txtAddress_TextChanged(object sender, EventArgs e)
        {

        }

        private void btnRefresh_Click(object sender, EventArgs e)
        {
            if (blnDataChange == true || blnDataDirty == true)
            {
                DialogResult intResult = MessageBox.Show("Do you want to save changes ?", "Save Data", MessageBoxButtons.YesNo);
                if (intResult == DialogResult.Yes)
                {
                    if (!SaveRepayment())
                        return;
                }
            }
            LoadRepaymentSummary();
            LoadRepaymentGrid();
            LoadRepaymentNote();
            blnDataDirty = false;
            blnDataChange = false;
        }

        private void btnGoToProject_Click(object sender, EventArgs e)
        {
            Form1 mainForm = (Form1)this.MdiParent;
            mainForm.OpenProject(pid, ProjectData.GetProjectName(pid));
            CCPM.Project.ProjectForm projectForm = null;
            mainForm.GetCurrentProject(out projectForm);
            projectForm.SetTabIndex(3);
        }

        private void txtNotes_TextChanged(object sender, EventArgs e)
        {
            blnDataChange = true;
            btnRepaySave.Enabled = true;
        }

        private void txtTerms_TextChanged(object sender, EventArgs e)
        {
            foreach (UltraGridRow ugr in uwgSchedule.Rows)
            {
                ugr.Cells["Terms"].Value = txtTerms.Text;
            }
        }

    }
}
