﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Shared;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using CCPM.Data;
using Microsoft.ApplicationBlocks.Data;

namespace CCPM.Contract
{
    public partial class RepaymentLog : Form
    {
        bool blnDataDirty = false;
        bool blnViewOnly = true;

        public RepaymentLog()
        {
            InitializeComponent();

            this.Location = new Point(0, 0);
            uwgRepaymentLog.DisplayLayout.Override.WrapHeaderText = Infragistics.Win.DefaultableBoolean.True;
            uwgRepaymentLog.DisplayLayout.Override.HeaderClickAction = Infragistics.Win.UltraWinGrid.HeaderClickAction.SortSingle;

            LoadRepaymentLogGridAll();
            blnDataDirty = false;
            SetSecurity();
            
        }

        private void SetSecurity()
        {
            //edit & delete only:  Contracts Manager, Contracts Staff, and Accounting Manager
            if (GlobalSettings.IsContractsManager || GlobalSettings.IsContractsStaff || GlobalSettings.IsAccountingManager)
            {
                blnViewOnly = false;
            }
            else if (GlobalSettings.IsProjectManager)
            {
                UltraGridBand band = uwgRepaymentLog.DisplayLayout.Bands[0];
                band.Columns[13].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                band.Columns[11].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            }
            else
            {
                btnSave.Enabled = false;
            }
        }

        private void LoadData()
        {
            this.Cursor = Cursors.WaitCursor;
            DataSet dsRepaymentLog = ContractData.GetRepaymentLog();
            this.Cursor = Cursors.Default;
            uwgRepaymentLog.DataSource = dsRepaymentLog.Tables[0];
            uwgRepaymentLog.DataBind();
        }
        private void LoadRepaymentLogGrid()
        {
            if (uwgRepaymentLog.DataSource != null)
            {
                LoadData();
            }

            if (uwgRepaymentLog.Rows.Count < 1)
            {
                btnViewRepay.Enabled = false;
            }
            blnDataDirty = false;
            btnSave.Enabled = false;
        }

        private void LoadRepaymentLogGridAll()
        {
            lblFilter.Text = "";
            lblFilterOn.Text = "";
            this.uwgRepaymentLog.DisplayLayout.Bands[0].ColumnFilters.ClearAllFilters();

            LoadData();
            if (uwgRepaymentLog.Rows.Count < 1)
            {
                btnViewRepay.Enabled = false;
            }
            blnDataDirty = false;
            btnSave.Enabled = false;
        }

        private void uwgRepaymentLog_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            //RepaymentId
            e.Layout.Bands[0].Columns[0].Hidden = true;
            
            e.Layout.Bands[0].Columns[1].Width = 120;
            e.Layout.Bands[0].Columns[1].Header.Caption = "Contract Number";
            e.Layout.Bands[0].Columns[1].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[1].TabStop = false;
            e.Layout.Bands[0].Columns[1].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[1].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[1].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[2].Width = 120;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Grantee/Contractor";
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[2].TabStop = false;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[3].Width = 100;
            e.Layout.Bands[0].Columns[3].Header.Caption = "Project Name";
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[3].TabStop = false;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[4].Width = 70;
            e.Layout.Bands[0].Columns[4].Header.Caption = "Payment Due Date";
            e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[4].TabStop = false;
            e.Layout.Bands[0].Columns[4].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[4].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[4].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[5].Width = 100;
            e.Layout.Bands[0].Columns[5].Header.Caption = "Repayment Alert";
            e.Layout.Bands[0].Columns[5].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[5].TabStop = false;
            e.Layout.Bands[0].Columns[5].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[5].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[5].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[6].Width = 80;
            e.Layout.Bands[0].Columns[6].Header.Caption = "Scheduled Payment Amount";
            e.Layout.Bands[0].Columns[6].Hidden = true;
            e.Layout.Bands[0].Columns[6].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[6].TabStop = false;
            e.Layout.Bands[0].Columns[6].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns[6].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
            e.Layout.Bands[0].Columns[6].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[6].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[6].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[7].Width = 80;
            e.Layout.Bands[0].Columns[7].Header.Caption = "Total Amt to be Repaid";
            e.Layout.Bands[0].Columns[7].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[7].TabStop = false;
            e.Layout.Bands[0].Columns[7].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns[7].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
            e.Layout.Bands[0].Columns[7].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[7].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[7].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[8].Width = 70;
            e.Layout.Bands[0].Columns[8].Header.Caption = "Repaid To-Date";
            e.Layout.Bands[0].Columns[8].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[8].TabStop = false;
            e.Layout.Bands[0].Columns[8].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns[8].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
            e.Layout.Bands[0].Columns[8].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[8].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[8].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[9].Width = 80;
            e.Layout.Bands[0].Columns[9].Header.Caption = "Remaining Balance";
            e.Layout.Bands[0].Columns[9].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[9].TabStop = false;
            e.Layout.Bands[0].Columns[9].Format = "$###,###,##0.00";
            e.Layout.Bands[0].Columns[9].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
            e.Layout.Bands[0].Columns[9].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[9].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[9].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[10].Width = 100;
            e.Layout.Bands[0].Columns[10].Header.Caption = "Remarks";
            e.Layout.Bands[0].Columns[10].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[10].TabStop = false;
            e.Layout.Bands[0].Columns[10].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[10].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[10].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[11].Width = 90;
            e.Layout.Bands[0].Columns[11].Header.Caption = "Project Contract Manager";
            e.Layout.Bands[0].Columns[11].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[11].TabStop = false;
            e.Layout.Bands[0].Columns[11].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[11].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[11].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[12].Width = 80;
            e.Layout.Bands[0].Columns[12].Header.Caption = "Region";
            e.Layout.Bands[0].Columns[12].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[12].TabStop = false;
            e.Layout.Bands[0].Columns[12].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[12].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[12].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[13].Width = 50;
            e.Layout.Bands[0].Columns[13].Header.Caption = "Flag";
            e.Layout.Bands[0].Columns[13].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns[13].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.CheckBox;
            
            //ContractID
            e.Layout.Bands[0].Columns[14].Hidden = true;

            //DirtyFlag
            e.Layout.Bands[0].Columns[15].Hidden = true;

            //filter row
            e.Layout.Override.AllowRowFiltering = Infragistics.Win.DefaultableBoolean.True;
            e.Layout.Override.FilterClearButtonLocation = FilterClearButtonLocation.Row;
            e.Layout.Override.FilterUIType = Infragistics.Win.UltraWinGrid.FilterUIType.FilterRow;
            e.Layout.Override.FilterOperatorDefaultValue = FilterOperatorDefaultValue.Contains;

            //column sorting
            e.Layout.Override.HeaderClickAction = HeaderClickAction.SortMulti;
        }

        private void OpenRepaymentDetails()
        {
            if (uwgRepaymentLog.ActiveRow != null)
            {
                Form1 fm = (Form1)this.MdiParent;
                fm.OpenRepayment(Convert.ToInt32(uwgRepaymentLog.ActiveRow.Cells["ContractId"].Value));
            }
        }
        private void btnViewRepay_Click(object sender, EventArgs e)
        {
            OpenRepaymentDetails();
        }

        private void btnAdd_Click(object sender, EventArgs e)
        {
            //UltraGridRow addRow = uwgRepaymentLog.DisplayLayout.Bands[0].AddNew();
            //addRow.Cells["DirtyFlag"].Value = "3";
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            //UltraGridRow row = this.uwgRepaymentLog.ActiveRow;

            //if (null != row)
            //{
            //    DialogResult intDiagResult = MessageBox.Show("Do you want to delete this Repayment Detail?", "Delete Row",
            //        MessageBoxButtons.YesNo, MessageBoxIcon.Question);
            //    if (intDiagResult == DialogResult.Yes)
            //    {
            //        // if the row is a database row then mark it for deletion and hide it in the grid
            //        if (row.Cells["DirtyFlag"].Value.ToString() == "0")
            //        {
            //            row.Hidden = true;
            //            row.Cells["DirtyFlag"].Value = "2";
            //            blnDataDirty = true;
            //        }
            //        // else it was added by the user and not saved to the database - delete it from the grid
            //        else
            //        {
            //            row.Delete(false);
            //        }
            //        // set the active row to first (non-hidden) row
            //        GridManager.FirstButtonHandler(uwgRepaymentLog);
            //        SaveRepaymentLog();
            //    }
            //}
            //else
            //{
            //    // If there is no active row, then prompt the user to select one. 
            //    MessageBox.Show("Please select a single row to delete.");
            //} 	     
        }

        private void SaveRepaymentLog()
        {
            if (blnViewOnly)
                return;

            for (int i = 0; i < uwgRepaymentLog.Rows.Count; i++)
            {
                //uwgRepaymentLog.Rows[i].Cells["RepaidToDate"].Value = (Convert.ToDecimal(uwgRepaymentLog.Rows[i].Cells["RepaidToDate"].Value) - Convert.ToDecimal(uwgRepaymentLog.Rows[i].Cells[8].OriginalValue)) + Convert.ToDecimal(uwgRepaymentLog.Rows[i].Cells[8].Value);
                if (uwgRepaymentLog.Rows[i].Cells["DirtyFlag"].Value.ToString() == "1")
                {
                    ContractData.RepaymentLogUpdate((int)uwgRepaymentLog.Rows[i].Cells["RepaymentId"].Value, uwgRepaymentLog.Rows[i].Cells["Flag"].Value);
                }
            }
            LoadRepaymentLogGrid();
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            if (blnDataDirty == true)
            {
                DialogResult intRes = MessageBox.Show("Data has changed - Do you want to cancel changes?", "Cancel Changes",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intRes == DialogResult.Yes)
                {
                    blnDataDirty = false;
                    this.LoadRepaymentLogGrid();
                }
            }
        }

        private void uwgRepaymentLog_CellListSelect(object sender, CellEventArgs e)
        {
            if(uwgRepaymentLog.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                uwgRepaymentLog.ActiveRow.Cells["DirtyFlag"].Value = "1";
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            if (blnViewOnly)
                return;

            SaveRepaymentLog();
        }

        private void RepaymentLog_Activated(object sender, EventArgs e)
        {
            RestoreWindowState();
            LoadRepaymentLogGrid();
        }
        
        private void RestoreWindowState()
        {
            // Looking for given form among all opened forms 
            Form instance = null;
            foreach (Form form in Application.OpenForms)
                if (form is RepaymentLog && form.Text.Trim() == this.Text)
                {
                    instance = form;

                    if (instance.WindowState == FormWindowState.Minimized)
                        instance.WindowState = FormWindowState.Normal;

                    instance.BringToFront();
                    if (instance.CanFocus)
                        instance.Focus();

                    break;
                }
        }

        private void uwgRepaymentLog_DoubleClickRow(object sender, DoubleClickRowEventArgs e)
        {
            OpenRepaymentDetails();
        }

        private void RepaymentLog_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (blnViewOnly)
                return;

            if (blnDataDirty == true)
            {
                 DialogResult diaRslt = MessageBox.Show("Do you want to save changes ?", "Warning", MessageBoxButtons.YesNo);
                 if (diaRslt == DialogResult.Yes)
                 {
                     SaveRepaymentLog();
                 }
            }
        }

        private void btnRefresh_Click(object sender, EventArgs e)
        {
            if (blnDataDirty == true)
            {
                DialogResult diaRslt = MessageBox.Show("Do you want to save changes ?", "Warning", MessageBoxButtons.YesNo);
                if (diaRslt == DialogResult.Yes)
                {
                    SaveRepaymentLog();
                }
            }
            label4.Visible = false;
            LoadRepaymentLogGrid();
        }

        private void btnExport_Click(object sender, EventArgs e)
        {
            string excelFile = GlobalCode.ExcelFileName("c:\\Temp", "ccpm_export.xls", false);
            if (excelFile != string.Empty)
            {
                GlobalCode.ExportGridToExcel(uwgRepaymentLog, excelFile);
                GlobalCode.OpenAssociatedFile(excelFile);
            }
        }

        private void btnFilter_Click(object sender, EventArgs e)
        {
            GridFilter gf = new GridFilter(uwgRepaymentLog, lblFilter, lblFilterOn, this.Text);
            gf.ShowDialog();
            if (lblFilter.Text != string.Empty)
            {
                label4.Visible = true;
            }
            else
            {
                label4.Visible = false;
            }
        }

        private void uwgRepaymentLog_CellChange(object sender, CellEventArgs e)
        {
            if (blnViewOnly)
                return;

            if (uwgRepaymentLog.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
            {
                uwgRepaymentLog.ActiveRow.Cells["DirtyFlag"].Value = "1";
                blnDataDirty = true;
                btnSave.Enabled = true;
            }
        }

        private void uwgRepaymentLog_Enter(object sender, EventArgs e)
        {
            if (uwgRepaymentLog.Rows.Count > 0)
                uwgRepaymentLog.Rows[0].Cells[1].Activate();
        }

        private void uwgRepaymentLog_KeyPress(object sender, KeyPressEventArgs e)
        {
            if (e.KeyChar == Convert.ToChar(Keys.Tab))
            {
                uwgRepaymentLog.ActiveCell.Selected = true;
            }   
        }

        private void btnSeeAll_Click(object sender, EventArgs e)
        {
            if (blnDataDirty == true)
            {
                DialogResult diaRslt = MessageBox.Show("Do you want to save changes ?", "Warning", MessageBoxButtons.YesNo);
                if (diaRslt == DialogResult.Yes)
                {
                    SaveRepaymentLog();
                }
            }
            label4.Visible = false;
            LoadRepaymentLogGridAll();

        }

    }
}
