using System;
using System.Configuration;
using System.Data.SqlClient;
using System.Data;
using Microsoft.ApplicationBlocks.Data;

namespace CCPM.Data
{
	/// <summary>
	/// MAR 2005-03-28
	/// Contains methods for managing data for FundingSource table
	/// </summary>
	public class FundingSourceData
	{
		
		static string userid = GlobalSettings.userid;
        
        private static string connectionString
        {
            get { return GlobalSettings.ConnectionString; }
        }

        static FundingSourceData()
		{
		}

        public static DataSet GetFundingSources()
		{
			// Get list of Funding Sources for grid
			string sql = 
				"SELECT FundingSource.FundID "+
				", dbo.usfFundingItem(dbo.FundingSource.FundID) AS FundingItem"+
				", FundingSource.Source" +
				", FundingSource.Description"+
				", FundingSource.SubScheduleName"+
				", FiscalYear.Years"+
                ", FundingSource.IsActive" +
                " FROM FundingSource INNER JOIN " +
				"FiscalYear ON FundingSource.FiscalYearID = FiscalYear.FiscalYearID "+
				"ORDER BY Years DESC, FundNumber ASC, RefCode ASC, ScheduleNum ASC, SubScheduleNum ASC";

			DataSet ds = null;
			try
			{
				ds = SqlHelper.ExecuteDataset(connectionString, CommandType.Text , sql);
			}
			catch(Exception ex)
			{
				throw ex;
			}
			return ds;
		}
		public static DataSet GetFiscalYearSelectionList()
		{
			// Get list of Fiscal Years for dropdown list
			string sql = "SELECT FiscalYearID, Years FROM FiscalYear ORDER BY Years"; 
			DataSet ds = null;
			try
			{
				ds = SqlHelper.ExecuteDataset(connectionString, CommandType.Text , sql);
			}
			catch(Exception ex)
			{
				throw ex;
			}
			return ds;
		}

		public static DataSet GetRelatedProjectsString(int FundID)
		{
			// Get list of Fiscal Years for dropdown list
			string sql = "select dbo.usfGetFundingSourceRelatedProjects(" + FundID.ToString() + ")";
			DataSet ds = null;
			try
			{
				ds = SqlHelper.ExecuteDataset(connectionString, CommandType.Text , sql);
			}
			catch(Exception ex)
			{
				throw ex;
			}
			return ds;
		}

		public static DataSet GetFundingSourceDetail(int FundID)
		{
			// Get specific FundingSource record
			string sql = "EXEC FundingSourceDetail '" + FundID.ToString() + "'";
			DataSet ds = null;
			try
			{
				ds = SqlHelper.ExecuteDataset(connectionString, CommandType.Text , sql);
			}
			catch(Exception ex)
			{
				throw ex;
			}
			return ds;
		}
		public static string FundingSourceUpdate(
			 int FundID
			,int FiscalYearID
			,string FYShort		// ADS 4-Dec-2007 - 2.13 Added new field
			,string FundTitle
			,string OrgCode
			,string RefCode
			,string FundNumber
		    ,string ScheduleNum
		    ,string Description
			,string Source
			,string SubScheduleNum
	    	,string SubScheduleName
		    ,string Program
		    ,string Element
		    ,string Component
		    ,string ReimbCode
		    ,DateTime EncumbExpDate
    	    ,DateTime LiquidDate
	    	,decimal AppropAmt
    		,string Category
            ,bool IsActive)
		{	
			// Update Funding Source record
			string msg="success";
			int retVal = 0;
			try
			{
				retVal = SqlHelper.ExecuteNonQuery(connectionString,"FundingSourceUpdate",
			             FundID
			            ,FiscalYearID
						,FYShort
			            ,FundTitle
			            ,OrgCode
			            ,RefCode
			            ,FundNumber
                        ,ScheduleNum
		                ,Description
					    ,Source
		                ,SubScheduleNum
	    	            ,SubScheduleName
		                ,Program
		                ,Element
		                ,Component
		                ,ReimbCode
		                ,EncumbExpDate
    	                ,LiquidDate
	    	            ,AppropAmt
    		            ,Category
                        ,userid
                        ,IsActive);					 
			}
			catch
			{
				//throw ex;
				msg="There was a problem updating the Funding Source record.";
			}
			return msg;
		}
   
        
   public static string FundingSourceUpdateActivation( int FundID , int IsActive)
        {
            // Update Funding Source record
            string msg = "success";
            int retVal = 0;
            try
            {
                retVal = SqlHelper.ExecuteNonQuery(GlobalSettings.ConnectionString, CommandType.Text, "UPDATE FundingSource SET IsActive = " + IsActive + " WHERE FundId = " + FundID);

            }
            catch
            {
                //throw ex;
                msg = "There was a problem updating activation for the Funding Source record.";
            }
            return msg;
        }
		public static int FundingSourceInsert(
			 int FiscalYearID
			,string FYShort		// ADS 4-Dec-2007 - 2.13 Added new field
			,string FundTitle
			,string OrgCode
			,string RefCode
			,string FundNumber
			,string ScheduleNum
			,string Description
			,string Source 
			,string SubScheduleNum
			,string SubScheduleName
			,string Program
			,string Element
			,string Component
			,string ReimbCode
			,DateTime EncumbExpDate
			,DateTime LiquidDate
			,decimal AppropAmt
			,string Category
            ,bool IsActive)
		{	
			// Insert Funding Source record
			int retVal = 0;
			try
			{
				object id = SqlHelper.ExecuteScalar(connectionString,"FundingSourceInsert",
			                FiscalYearID
						   ,FYShort
			               ,FundTitle
			               ,OrgCode
			               ,RefCode
			               ,FundNumber
			               ,ScheduleNum
			               ,Description
					       ,Source 
			               ,SubScheduleNum
			               ,SubScheduleName
			               ,Program
			               ,Element
			               ,Component
			               ,ReimbCode
			               ,EncumbExpDate
			               ,LiquidDate
			               ,AppropAmt
			               ,Category
                           ,userid
                           , IsActive);					 
				retVal = int.Parse(id.ToString());
			}
			catch (Exception ex)
			{
				throw ex;
			}
			return retVal;
		}

		public static bool FundingSourceDupCheck(
			 int FundID 
			,int FiscalYearID
			,string OrgCode
			,string RefCode
			,string FundNumber
			,string ScheduleNum
			,string SubScheduleNum
            ,string ReimbCode )
		{	
			// check for dups
			bool retVal = false;
			try
			{
				object id = SqlHelper.ExecuteScalar(connectionString,"FundingSourceDupCheck",
					FundID
					,FiscalYearID
					,OrgCode
					,RefCode
					,FundNumber
					,ScheduleNum
					,SubScheduleNum				 
					,ReimbCode);					 
				if (int.Parse(id.ToString())==1)
					retVal = true;
			}
			catch (Exception ex)
			{
				throw ex;
			}
			return retVal;
		}
		
		public static string FundingSourceDelete(int FundID)
		{	
			// Delete Organization record
			string msg="success";
			string fileNumbers = "";
			if (!FundingSourceHasChildren(FundID))
			{
				int retVal = 0;
				try
				{
					retVal = SqlHelper.ExecuteNonQuery(connectionString,"FundingSourceDelete",FundID);	
				}
				catch
				{
					//throw ex;
					msg="There was a problem deleting the Funding Source record.";
				}
			}
			else 
			    {
					DataSet dsRelated = GetRelatedProjectsString(FundID);
                    DataRow dr = dsRelated.Tables[0].Rows[0];
				    fileNumbers = dr[0].ToString();				
					msg="This Funding Source is referenced in the following projects: " + fileNumbers + ". Unable to Delete.";
			    }
			return msg;
		}
		public static bool FundingSourceHasChildren(int FundID)
		{	
			// check for FundingSource children
			bool retVal = false;
			//int numChildren = 0;
			try
			{
				object numChildren = SqlHelper.ExecuteScalar(connectionString,"FundingSourceHasChildren",FundID);	
				if (int.Parse(numChildren.ToString())>0)
					retVal = true;
			}
			catch (Exception ex)
			{
				throw ex;
			}

			return retVal;
		}


	
	}
}
