using System;
using System.Configuration;
using System.Data.SqlClient;
using System.Data;
using Microsoft.ApplicationBlocks.Data;

namespace CCPM.Data
{
	/// <summary>
	/// MAR 2005-03-28
	/// Contains methods for managing data for Organization table
	/// </summary>
	public class OrganizationData
	{

		static string userid = GlobalSettings.userid;
        
        private static string connectionString
        {
            get { return GlobalSettings.ConnectionString; }
        }

        static OrganizationData()
		{
		}

        public static DataSet GetOrganizations()
		{
			// Get list of all organizations (for organization admin page grid)
			// Format SQL string
			string sql = 
				"SELECT 'Remove Org' as button, Organization, OrganizationType, OrgID, TaxId, SBE, DVBE " + 
				  "FROM Organization org LEFT OUTER JOIN OrganizationType ot ON org.OrganizationTypeId = ot.OrganizationTypeId ORDER BY Organization";

			DataSet ds = null;
			try
			{
				ds = SqlHelper.ExecuteDataset(connectionString, CommandType.Text , sql);
			}
			catch(Exception ex)
			{
				throw ex;
			}
			return ds;
		}

		public static DataSet GetOrgTypeSelectionList()
		{
			// Get list of Organizations for a dropdown list
			string sql = "SELECT OrganizationTypeId, OrganizationType FROM OrganizationType ORDER BY OrganizationType"; 
			DataSet ds = null;
			try
			{
				ds = SqlHelper.ExecuteDataset(connectionString, CommandType.Text , sql);
			}
			catch(Exception ex)
			{
				throw ex;
			}
			return ds;
		}

		public static string OrganizationUpdate(
			 int OrgID
			,string Organization
			,int OrganizationTypeId)
		{	
			// Update Organization record
			string msg="success";
			int retVal = 0;
			try
			{
				retVal = SqlHelper.ExecuteNonQuery(connectionString,"OrganizationUpdate",
					 OrgID
					,Organization
					,OrganizationTypeId
					,userid);					 
			}
			catch
			{
				//throw ex;
				msg="There was a problem updating the Organization record.";
			}
			return msg;
		}
		public static int OrganizationInsert(
			 string Organization
			,int OrganizationTypeId)
		{	
			// Insert objective record
			int retVal = 0;
			try
			{
				object id = SqlHelper.ExecuteScalar(connectionString,"OrganizationInsert",
					 Organization
					,OrganizationTypeId
					,userid);					 
				retVal = int.Parse(id.ToString());
			}
			catch (Exception ex)
			{
				throw ex;
			}
			return retVal;
		}
		public static string OrganizationDelete(int OrgID)
		{	
			// Delete Organization record
			string msg="success";
			string fileNumbers = "";
			if (!OrgHasChildren(OrgID))
			{
				int retVal = 0;
				try
				{
					retVal = SqlHelper.ExecuteNonQuery(connectionString,"OrganizationDelete",OrgID);	
				}
				catch
				{
					//throw ex;
					msg="There was a problem deleting the Organization record.";
				}
			}
			else 
			{
				DataSet dsRelated = GetRelatedProjectsString(OrgID);
				DataRow dr = dsRelated.Tables[0].Rows[0];
				fileNumbers = dr[0].ToString();				
				msg="This Organization is referenced in the following projects: " + fileNumbers + ". Unable to Delete.";
			}
			return msg;
		}

        public static bool OrgHasProjectContract(int OrgId, int ProjectId)
        {
            // check for Organization contracts in project
            object retVal = null;
            string sql = "select top 1 1 from ContractDetails where Projectid = " + ProjectId + " and GranteeId = " + OrgId;
            try
            {
                retVal = SqlHelper.ExecuteScalar(connectionString, CommandType.Text, sql);
            }
            catch (Exception ex)
            {
                throw ex;
            }
            return (retVal == null ? false : true);
        }

        public static bool OrgHasProjectMatching(int OrgId, int ProjectId)
        {
            // check for Organization matching funds in project
            object retVal = null;
            string sql = "select top 1 1 from MatchingFund where Projectid = " + ProjectId + " and OrgId = " + OrgId;
            try
            {
                retVal = SqlHelper.ExecuteScalar(connectionString, CommandType.Text, sql);
            }
            catch (Exception ex)
            {
                throw ex;
            }
            return (retVal == null ? false : true);
        }



		public static bool OrgHasChildren(int OrgID)
		{	
			// check for Organization children (in projects)
			bool retVal = false;
			//int numChildren = 0;
			try
			{
				object numChildren = SqlHelper.ExecuteScalar(connectionString,"OrgHasChildren",OrgID);	
				if (int.Parse(numChildren.ToString())>0)
					retVal = true;
			}
			catch (Exception ex)
			{
				throw ex;
			}

			return retVal;
		}

		public static DataSet GetRelatedProjectsString(int OrgID)
		{
			// Get list of Fiscal Years for dropdown list
			string sql = "select dbo.usfGetOrgRelatedProjects(" + OrgID.ToString() + ")";
			DataSet ds = null;
			try
			{
				ds = SqlHelper.ExecuteDataset(connectionString, CommandType.Text , sql);
			}
			catch(Exception ex)
			{
				throw ex;
			}
			return ds;
		}

		public static bool OrganizationDupCheck(
			 int OrgID 
			,string Organization)
		{	
			// check for dups
			bool retVal = false;
			try
			{
				object id = SqlHelper.ExecuteScalar(connectionString,"OrganizationDupCheck",OrgID,Organization);
				if (int.Parse(id.ToString())==1)
					retVal = true;
			}
			catch (Exception ex)
			{
				throw ex;
			}
			return retVal;
		}

	
	}
}
