﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Shared;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using CCPM.Data;

namespace CCPM
{
    public partial class DynamicDropdowns : Form
    {
        #region Fields

        private DataSet dsDDLMaster;
        private DataSet dsDDLDetails;
        private DataSet dsMasterDetails;

        private bool blnGridDirty = false;
        private bool blnGridDetDirty = false;

        #endregion

        public DynamicDropdowns()
        {
            InitializeComponent();
            this.Text = "Manage Dynamic Dropdowns";
        }

        private void DynamicDropdowns_Load(object sender, EventArgs e)
        {
            LoadGridDDLMaster();
            LoadGridDDLDetails();
        }

        public bool GridDirty
        {
            get
            {
                if (blnGridDirty | blnGridDetDirty)
                    return (true);
                else
                    return (false);
            }
        }

        private void LoadGridDDLMaster()
        {
            dsDDLMaster = ProjectData.GetDDLMaster();
            uwgDDLMaster.DataSource = dsDDLMaster.Tables[0];
            uwgDDLMaster.DataBind();
        }

        private void LoadGridDDLDetails()
        {
            int DDLMasterId = 0;
            if (uwgDDLMaster.Rows.Count > 0)
            {
                UltraGridRow authRow = this.uwgDDLMaster.ActiveRow;
                try
                {
                    DDLMasterId = Convert.ToInt32(authRow.Cells["DropdownId"].Value);
                }
                catch
                {
                    DDLMasterId = 0;
                }
            }
            dsMasterDetails = ProjectData.GetDDLDetail(DDLMasterId);
            uwgDetails.DataSource = dsMasterDetails.Tables[0];
            uwgDetails.DataBind();
        }

        private void uwgDDLMaster_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            // DropdownId
            e.Layout.Bands[0].Columns[0].Hidden = true;

            // Dirty Flag
            e.Layout.Bands[0].Columns[1].Hidden = true;

            // Control Name
            e.Layout.Bands[0].Columns[2].Width = 200;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Control";
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.Disabled;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            // ProjectTableColumnName
            e.Layout.Bands[0].Columns[3].Width = 250;
            e.Layout.Bands[0].Columns[3].Header.Caption = "Location";
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.Disabled;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            // Label Name
            e.Layout.Bands[0].Columns[4].Width = 250;
            e.Layout.Bands[0].Columns[4].Header.Caption = "Label Name";
            e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

        }

        private void uwgDDLMaster_CellListSelect(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e)
        {
            // If this was a an existing row then set the dirty flag accordingly
            if (this.uwgDDLMaster.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                this.uwgDDLMaster.ActiveRow.Cells["DirtyFlag"].Value = "1";

            blnGridDirty = true;
        }

        private void uwgDDLMaster_AfterCellUpdate(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e)
        {
            if (this.uwgDDLMaster.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                this.uwgDDLMaster.ActiveRow.Cells["DirtyFlag"].Value = "1";
            blnGridDirty = true;
            SetButtons();
        }

        private void uwgDDLMaster_AfterRowActivate(object sender, System.EventArgs e)
        {
            SetButtons();
            LoadGridDDLDetails();
        }

        //allow user to tab off of last grid cell
        private void uwgDDLMaster_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Tab)
            {
                if (uwgDDLMaster.ActiveRow.Index == uwgDDLMaster.Rows.Count - 1)
                {
                    if (uwgDDLMaster.ActiveCell.Column.Index == 4)
                    {
                        e.SuppressKeyPress = true;
                        this.btnSave.Focus();
                    }
                }
            }
        }

        private void uwgDetails_CellListSelect(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e)
        {
            // If this was a an existing row then set the dirty flag accordingly
            if (this.uwgDetails.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                this.uwgDetails.ActiveRow.Cells["DirtyFlag"].Value = "1";

            blnGridDetDirty = true;
        }

        private void uwgDetails_AfterCellUpdate(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e)
        {
            // If editing an existing row then set the dirty flag to edit mode for this row
            if (this.uwgDetails.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                this.uwgDetails.ActiveRow.Cells["DirtyFlag"].Value = "1";
            blnGridDetDirty = true;
            SetButtons();
        }

        private void uwgDetails_AfterRowActivate(object sender, System.EventArgs e)
        {
            SetButtons();
        }

        private void uwgDetails_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {       
            // DropdownID
            e.Layout.Bands[0].Columns[0].Hidden = true;

            // DirtyFlag
            e.Layout.Bands[0].Columns[1].Hidden = true;

            // Code
            e.Layout.Bands[0].Columns[2].Width = 100;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Code";

            // Display Name
            e.Layout.Bands[0].Columns[3].Width = 200;
            e.Layout.Bands[0].Columns[3].Header.Caption = "Display Name";
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            // DirtyFlag
            e.Layout.Bands[0].Columns[4].Hidden = true;

            // DirtyFlag
            e.Layout.Bands[0].Columns[5].Hidden = true;

        }
        
        private void uwgDetails_InitializeRow(object sender, Infragistics.Win.UltraWinGrid.InitializeRowEventArgs e) 
        {
            int index = e.Row.Index;
                        
            // Code
            uwgDetails.Rows[index].Cells[2].IgnoreRowColActivation = true;
            if (e.Row.IsAddRow)
            {
                uwgDetails.Rows[index].Cells[2].Activation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
                uwgDetails.Rows[index].Cells[2]. Appearance.BackColor = GlobalSettings.EditableBackColor;
                uwgDetails.Rows[index].Cells[2].Appearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;
            }
            else
            {
                uwgDetails.Rows[index].Cells[2].Activation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                uwgDetails.Rows[index].Cells[2].Appearance.BackColor = GlobalSettings.nonEditableBackColor;
                uwgDetails.Rows[index].Cells[2].Appearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
                uwgDetails.Rows[index].Cells[2].Appearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;
            }

        }

        private void uwgDetails_MouseDown(object sender, MouseEventArgs e)
        {
            if (uwgDetails.Rows.Count == 0)
                return;
        }

        //allow user to tab out of reservations grid
        private void uwgDetails_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Tab)
            {
                if (uwgDetails.ActiveRow.Index == uwgDetails.Rows.Count - 1)
                {
                    if (uwgDetails.ActiveCell.Column.Index == 5)
                    {
                        e.SuppressKeyPress = true;
                        this.btnAddDet.Focus();
                    }
                }
            }
        }


        private void SetButtons()
        {
            if (blnGridDirty == false & blnGridDetDirty == false)
            {
                // no edits have been made on either grid
                this.uwgDDLMaster.Enabled = true;
                this.btnDelete.Enabled = true;
                this.btnCancel.Enabled = true;
                this.btnSave.Enabled = true;

                this.uwgDetails.Enabled = true;
                this.btnAddDet.Enabled = true;
                this.btnDeleteDet.Enabled = true;
                this.btnCancelDet.Enabled = true;
                this.btnSaveDet.Enabled = true;

            }
            else if (blnGridDirty == true)
            {
                this.uwgDDLMaster.Enabled = true;
                this.btnDelete.Enabled = true;
                this.btnCancel.Enabled = true;
                this.btnSave.Enabled = true;

                this.btnCancel.Enabled = true;
                this.btnSave.Enabled = true;

                this.uwgDetails.Enabled = true;
                this.btnAddDet.Enabled = true;
                this.btnDeleteDet.Enabled = true;
                this.btnCancelDet.Enabled = true;
                this.btnSaveDet.Enabled = true;

            }
            else if (blnGridDetDirty == true)
            {               
                this.uwgDDLMaster.Enabled = true;
                this.btnDelete.Enabled = true;
                this.btnCancel.Enabled = true;
                this.btnSave.Enabled = true;

                this.uwgDetails.Enabled = true;
                this.btnAddDet.Enabled = true;
                this.btnDeleteDet.Enabled = true;
                this.btnCancelDet.Enabled = true;
                this.btnSaveDet.Enabled = true;
            }

            if (this.uwgDDLMaster.ActiveRow == null)
            {
                this.btnDelete.Enabled = false;
                //this.btnAddDet.Enabled = false;
                this.btnAddDet.Enabled = true;
            }

            if (this.uwgDetails.ActiveRow == null)
                this.btnDeleteDet.Enabled = false;

        }

        private void btnCancel_Click(object sender, System.EventArgs e)
        {
            if (blnGridDirty == true)
            {
                DialogResult intDiagResult = MessageBox.Show("Data has changed - Do you want to cancel changes?", "Cancel Changes",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intDiagResult == DialogResult.Yes)
                {
                    LoadGridDDLMaster();
                    blnGridDirty = false;
                    SetButtons();
                }
            }
        }

        private void btnAdd_Click(object sender, System.EventArgs e)
        {
            UltraGridRow addedRow = uwgDDLMaster.DisplayLayout.Bands[0].AddNew();
            addedRow.Cells["DirtyFlag"].Value = "3";
            blnGridDirty = true;
            SetButtons();
        }

        private void btnSave_Click(object sender, System.EventArgs e)
        {
            int rowNum = Convert.ToInt32(this.uwgDDLMaster.ActiveRow.Index);
            SaveDDLMaster(rowNum);
        }
        private void SaveDDLMaster(int rowNum)
        {
            // Validate grid prior to update
            bool GridValid = true;
            int row;
            int retVal;
            string retMsg;

            for (int i = 0; i < uwgDDLMaster.Rows.Count; i++)
            {
                row = i + 1;
                if (uwgDDLMaster.Rows[i].Cells["LabelName"].Value.ToString() == "")
                {
                    MessageBox.Show("Please select a valid 'Label Name' for row " + row.ToString(),
                        "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    GridValid = false;
                    break;
                }
            }

            // Perform updates
            if (GridValid == true)
            {
                // Iterate through each grid row and determine if an update is needed
                for (int i = 0; i < uwgDDLMaster.Rows.Count; i++)
                {
                    switch (uwgDDLMaster.Rows[i].Cells["DirtyFlag"].Value.ToString())
                    {
                        case "1":
                            {
                                // updated
                                retMsg =
                                ProjectData.MasterDDLUpdate(
                                    Convert.ToInt32(uwgDDLMaster.Rows[i].Cells["DropdownId"].Value),
                                    Convert.ToString(uwgDDLMaster.Rows[i].Cells["LabelName"].Value)); 
                                  if (retMsg != "success")
                                    MessageBox.Show("Update failed in row " + (i + 1).ToString(), "Database Error",
                                        MessageBoxButtons.OK, MessageBoxIcon.Error);

                                break;
                            }
                        case "2":
                            {
                                retMsg = ProjectData.MasterDDLDelete(Convert.ToInt32(uwgDDLMaster.Rows[i].Cells["DropdownId"].Value),
                                                        uwgDDLMaster.ActiveRow.Cells["ProjectTableColumnName"].Value.ToString());
                                if (retMsg != "success")
                                    MessageBox.Show("Delete failed in row " + (i + 1).ToString(), "Database Error",
                                        MessageBoxButtons.OK, MessageBoxIcon.Error);

                                DbConnection dbConnection = DbConnection.GetDbConnection();
                                string connectionString = dbConnection.DbConnectionString;

                                break;
                            }
                        case "3":
                            {                        
                                break;
                            }
                    }
                }
                // Reset the dirty flag, reload the grid and reset the form buttons
                blnGridDirty = false;
                LoadGridDDLMaster();
                if (rowNum != 0)
                {
                    try
                    {
                        this.uwgDDLMaster.ActiveRow = this.uwgDDLMaster.Rows[rowNum];
                    }
                    catch
                    {
                    }
                }
                SetButtons();
            }
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            // Get the row to delete. In this case we will use the active row. 
            UltraGridRow row = this.uwgDDLMaster.ActiveRow;

            if (null != row)
            {
                DialogResult intDiagResult = MessageBox.Show("Do you want to delete this Dropdown Control with related Dropdown entries, and save all other pending changes? \nIf you decide to proceed, all the selected Dropdown codes will be deleted from the Projects that are using them. ", "Delete Row",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intDiagResult == DialogResult.Yes)
                {
                    // if the row is a database row then mark it for deletion and hide it in the grid
                    if (row.Cells["DirtyFlag"].Value.ToString() == "0")
                    {
                        row.Hidden = true;
                        row.Cells["DirtyFlag"].Value = "2";
                        blnGridDirty = true;
                    }
                    // else it was added by the user and not saved to the database - delete it from the grid
                    else
                    {
                        row.Delete(false);
                    }
                    // set the active row to first (non-hidden) row
                    SaveDDLMaster(0);

                    LoadGridDDLMaster();
                    LoadGridDDLDetails();   // reload entries grid as we may have deleted child records
                }
            }
            else
            {
                // If there is no active row, then prompt the user to select one. 
                MessageBox.Show("Please select a single row to delete.");
            }
        }

        private void btnAddDet_Click(object sender, System.EventArgs e)
        {
            this.AddDDLDetailRow();
        }

        private void AddDDLDetailRow()
        {
            UltraGridRow detRow = this.uwgDDLMaster.ActiveRow;
            int DropdownId = 0;
            bool blnValidRow = true;
            try
            {
                DropdownId = Convert.ToInt32(detRow.Cells["DropdownId"].Value);
            }
            catch
            {
                blnValidRow = false;
                MessageBox.Show("Please select a valid Dropdown control row before adding entries into it.",
                    "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            if (blnValidRow == true)
            {
                UltraGridRow addedRow = uwgDetails.DisplayLayout.Bands[0].AddNew();
                addedRow.Cells["Id"].Value = DropdownId;

                addedRow.Cells["DirtyFlag"].Value = "3";
                blnGridDetDirty = true;
                SetButtons();

            }
        }

        private void btnDeleteDet_Click(object sender, System.EventArgs e)
        {
            //delete active row
            UltraGridRow row = this.uwgDetails.ActiveRow;

            DialogResult intDiagResult = MessageBox.Show("Do you want to delete this Dropdown entry, and save all other pending changes? \nIf you decide to proceed, the selected Dropdown codes will be deleted from the Project that is using it.", "Delete Row",
                MessageBoxButtons.YesNo, MessageBoxIcon.Question);
            if (intDiagResult == DialogResult.Yes)
            {
                if (row.Cells["DirtyFlag"].Value.ToString() == "0")
                {
                    row.Cells["DirtyFlag"].Value = "2";
                    blnGridDetDirty = true;
                }
                else
                {
                    row.Delete(false);
                }
                // set the active row to first (non-hidden) row
                SaveDDLDetails(0);
                LoadGridDDLDetails();
            }
            else
            {
                // If there is no active row, then prompt the user to select one. 
                MessageBox.Show("Please select a single row to delete.");
            }
        }
        private void btnCancelDet_Click(object sender, System.EventArgs e)
        {
            if (blnGridDetDirty == true)
            {
                DialogResult intDiagResult = MessageBox.Show("Data has changed - Do you want to cancel changes?", "Cancel Changes",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intDiagResult == DialogResult.Yes)
                {
                    LoadGridDDLDetails();
                    blnGridDetDirty = false;
                    SetButtons();

                    uwgDDLMaster.ActiveRow.Appearance.BackColorDisabled = Color.Empty;
                    uwgDDLMaster.ActiveRow.Appearance.ForeColorDisabled = Color.Empty;
                }
            }
        }
        private void btnSaveDet_Click(object sender, System.EventArgs e)
        {
            int rowNum = Convert.ToInt32(this.uwgDetails.ActiveRow.Index);
            SaveDDLDetails(rowNum);
        }

        private void SaveDDLDetails(int rowNum)
        {
            int row;
            int retVal;
            string retMsg = "success";


            // Validate grid
            for (int i = 0; i < uwgDetails.Rows.Count; i++)
            {
                row = i + 1;

                if (uwgDetails.Rows[i].Cells["DirtyFlag"].Value.ToString() == "2")
                    continue;

                if (uwgDetails.Rows[i].Cells["Id"].Value.ToString() == "")
                {
                    MessageBox.Show("Please select a valid Dropdown's entry for row " + row.ToString(),
                        "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
                if (uwgDetails.Rows[i].Cells["Code"].Value.ToString() == String.Empty)
                {
                    MessageBox.Show("'Code' is required in row " + row.ToString(),
                        "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }

                if (uwgDetails.Rows[i].Cells["DisplayName"].Value.ToString() == String.Empty)
                {
                    MessageBox.Show("'Display Name' is required in row " + row.ToString(),
                        "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }

            for (int i = 0; i < uwgDetails.Rows.Count; i++)
            {
                switch (uwgDetails.Rows[i].Cells["DirtyFlag"].Value.ToString())
                {
                    case "1":
                        {
                            // updated
                            {
                                retMsg = ProjectData.DetailDDLUpdate(
                                    Convert.ToInt32(uwgDetails.Rows[i].Cells["Id"].Value),
                                    Convert.ToString(uwgDetails.Rows[i].Cells["Code"].Value),
                                    Convert.ToString(uwgDetails.Rows[i].Cells["DisplayName"].Value));

                                if (retMsg != "success")
                                    MessageBox.Show("Update failed in row " + (i + 1).ToString(), "Database Error",
                                        MessageBoxButtons.OK, MessageBoxIcon.Error);
                            }

                            break;
                        }
                    case "2":
                        {
                            if (uwgDetails.Rows[i].Cells["Id"].Value.ToString() != "")
                            {                                    
                                retMsg = ProjectData.DetailDDLDelete(Convert.ToInt32(uwgDetails.Rows[i].Cells["Id"].Value),
                                                                    Convert.ToString(uwgDetails.Rows[i].Cells["Code"].Value),
                                                                    uwgDDLMaster.ActiveRow.Cells["ProjectTableColumnName"].Value.ToString());

                                if (retMsg != "success")
                                {
                                    MessageBox.Show("Delete failed in row " + (i + 1).ToString() + " for Dropdown entry " + Convert.ToString(uwgDetails.Rows[i].Cells["DisplayName"].Value), "Database Error",
                                        MessageBoxButtons.OK, MessageBoxIcon.Error);
                                    return;
                                }
                            }
                          
                            break;

                        }
                    case "3":
                        {
                            retVal = ProjectData.DetailDDLInsert(
                           Convert.ToInt32(uwgDetails.Rows[i].Cells["Id"].Value),
                           Convert.ToString(uwgDetails.Rows[i].Cells["Code"].Value),
                           Convert.ToString(uwgDetails.Rows[i].Cells["DisplayName"].Value));
                            if (retVal == -1)
                                MessageBox.Show("Insert failed in row " + (i + 1).ToString(), "Database Error",
                                    MessageBoxButtons.OK, MessageBoxIcon.Error);

                            break;
                        }
                }
            }
            // Reset the dirty flag, reload the grid and reset the form buttons
            blnGridDetDirty = false;
            LoadGridDDLDetails();
            if (rowNum != 0)
            {
                try
                {
                    this.uwgDetails.ActiveRow = this.uwgDetails.Rows[rowNum];
                }
                catch
                {
                }
            }
            SetButtons();
            this.uwgDDLMaster.ActiveRow.Appearance.BackColorDisabled = Color.Empty;
            this.uwgDDLMaster.ActiveRow.Appearance.ForeColorDisabled = Color.Empty;
        }

    }
 }
