﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Shared;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using CCPM.Data;

namespace CCPM
{
    public partial class DynamicMultiSelects : Form
    {
        #region Fields

        private DataSet dsDMSMaster;
        private DataSet dsDMSDetails;
        private DataSet dsMasterDetails;

        private bool blnGridDirty = false;
        private bool blnGridDetDirty = false;

        #endregion

        public DynamicMultiSelects()
        {
            InitializeComponent();
            this.Text = "Manage Dynamic MultiSelects";
        }

        private void DynamicMultiSelects_Load(object sender, EventArgs e)
        {
            LoadGridDMSMaster();
            LoadGridDMSDetails();
        }

        public bool GridDirty
        {
            get
            {
                if (blnGridDirty | blnGridDetDirty)
                    return (true);
                else
                    return (false);
            }
        }

        private void LoadGridDMSMaster()
        {
            dsDMSMaster = ProjectData.GetDMSMaster();
            uwgDMSMaster.DataSource = dsDMSMaster.Tables[0];
            uwgDMSMaster.DataBind();
        }

        private void LoadGridDMSDetails()
        {
            int DMSMasterId = 0;
            if (uwgDMSMaster.Rows.Count > 0)
            {
                UltraGridRow authRow = this.uwgDMSMaster.ActiveRow;
                try
                {
                    DMSMasterId = Convert.ToInt32(authRow.Cells["MultiSelectId"].Value);
                }
                catch
                {
                    DMSMasterId = 0;
                }
            }
            dsMasterDetails = ProjectData.GetDMSDetail(DMSMasterId);
            uwgDetails.DataSource = dsMasterDetails.Tables[0];
            uwgDetails.DataBind();
        }

        private void uwgDMSMaster_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            // MultiSelectId
            e.Layout.Bands[0].Columns[0].Hidden = true;

            // Dirty Flag
            e.Layout.Bands[0].Columns[1].Hidden = true;

            // Control Name
            e.Layout.Bands[0].Columns[2].Width = 200;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Control";
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.Disabled;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            // TableName
            e.Layout.Bands[0].Columns[3].Width = 250;
            e.Layout.Bands[0].Columns[3].Header.Caption = "Location";
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.Disabled;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[3].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            // Label Name
            e.Layout.Bands[0].Columns[4].Width = 250;
            e.Layout.Bands[0].Columns[4].Header.Caption = "Label Name";
            e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

        }

        private void uwgDMSMaster_CellListSelect(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e)
        {
            // If this was a an existing row then set the dirty flag accordingly
            if (this.uwgDMSMaster.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                this.uwgDMSMaster.ActiveRow.Cells["DirtyFlag"].Value = "1";

            blnGridDirty = true;
        }

        private void uwgDMSMaster_AfterCellUpdate(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e)
        {
            if (this.uwgDMSMaster.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                this.uwgDMSMaster.ActiveRow.Cells["DirtyFlag"].Value = "1";
            blnGridDirty = true;
            SetButtons();
        }

        private void uwgDMSMaster_AfterRowActivate(object sender, System.EventArgs e)
        {
            SetButtons();
            LoadGridDMSDetails();
        }

        //allow user to tab off of last grid cell
        private void uwgDMSMaster_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Tab)
            {
                if (uwgDMSMaster.ActiveRow.Index == uwgDMSMaster.Rows.Count - 1)
                {
                    if (uwgDMSMaster.ActiveCell.Column.Index == 4)
                    {
                        e.SuppressKeyPress = true;
                        this.btnSave.Focus();
                    }
                }
            }
        }

        private void uwgDetails_CellListSelect(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e)
        {
            // If this was a an existing row then set the dirty flag accordingly
            if (this.uwgDetails.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                this.uwgDetails.ActiveRow.Cells["DirtyFlag"].Value = "1";

            blnGridDetDirty = true;
        }

        private void uwgDetails_AfterCellUpdate(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e)
        {
            // If editing an existing row then set the dirty flag to edit mode for this row
            if (this.uwgDetails.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                this.uwgDetails.ActiveRow.Cells["DirtyFlag"].Value = "1";
            blnGridDetDirty = true;
            SetButtons();
        }

        private void uwgDetails_AfterRowActivate(object sender, System.EventArgs e)
        {
            SetButtons();
        }

        private void uwgDetails_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {       
            // DropdownID
            e.Layout.Bands[0].Columns[0].Hidden = true;

            // DirtyFlag
            e.Layout.Bands[0].Columns[1].Hidden = true;

            // Code
            e.Layout.Bands[0].Columns[2].Width = 100;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Code";

            // Display Name
            e.Layout.Bands[0].Columns[3].Width = 200;
            e.Layout.Bands[0].Columns[3].Header.Caption = "Display Name";
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;

            //e.Layout.Bands[0].Columns[4].Hidden = true;

            //e.Layout.Bands[0].Columns[5].Hidden = true;

        }
        
        private void uwgDetails_InitializeRow(object sender, Infragistics.Win.UltraWinGrid.InitializeRowEventArgs e) 
        {
            int index = e.Row.Index;
                        
            // Code
            uwgDetails.Rows[index].Cells[2].IgnoreRowColActivation = true;
            if (e.Row.IsAddRow)
            {
                uwgDetails.Rows[index].Cells[2].Activation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
                uwgDetails.Rows[index].Cells[2]. Appearance.BackColor = GlobalSettings.EditableBackColor;
                uwgDetails.Rows[index].Cells[2].Appearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;
            }
            else
            {
                uwgDetails.Rows[index].Cells[2].Activation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                uwgDetails.Rows[index].Cells[2].Appearance.BackColor = GlobalSettings.nonEditableBackColor;
                uwgDetails.Rows[index].Cells[2].Appearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
                uwgDetails.Rows[index].Cells[2].Appearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;
            }

        }

        private void uwgDetails_MouseDown(object sender, MouseEventArgs e)
        {
            if (uwgDetails.Rows.Count == 0)
                return;
        }

        //allow user to tab out of reservations grid
        private void uwgDetails_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Tab)
            {
                if (uwgDetails.ActiveRow.Index == uwgDetails.Rows.Count - 1)
                {
                    if (uwgDetails.ActiveCell.Column.Index == 5)
                    {
                        e.SuppressKeyPress = true;
                        this.btnAddDet.Focus();
                    }
                }
            }
        }


        private void SetButtons()
        {
            if (blnGridDirty == false & blnGridDetDirty == false)
            {
                // no edits have been made on either grid
                this.uwgDMSMaster.Enabled = true;
                this.btnDelete.Enabled = true;
                this.btnCancel.Enabled = true;
                this.btnSave.Enabled = true;

                this.uwgDetails.Enabled = true;
                this.btnAddDet.Enabled = true;
                this.btnDeleteDet.Enabled = true;
                this.btnCancelDet.Enabled = true;
                this.btnSaveDet.Enabled = true;

            }
            else if (blnGridDirty == true)
            {
                this.uwgDMSMaster.Enabled = true;
                this.btnDelete.Enabled = true;
                this.btnCancel.Enabled = true;
                this.btnSave.Enabled = true;

                this.btnCancel.Enabled = true;
                this.btnSave.Enabled = true;

                this.uwgDetails.Enabled = true;
                this.btnAddDet.Enabled = true;
                this.btnDeleteDet.Enabled = true;
                this.btnCancelDet.Enabled = true;
                this.btnSaveDet.Enabled = true;

            }
            else if (blnGridDetDirty == true)
            {               
                this.uwgDMSMaster.Enabled = true;
                this.btnDelete.Enabled = true;
                this.btnCancel.Enabled = true;
                this.btnSave.Enabled = true;

                this.uwgDetails.Enabled = true;
                this.btnAddDet.Enabled = true;
                this.btnDeleteDet.Enabled = true;
                this.btnCancelDet.Enabled = true;
                this.btnSaveDet.Enabled = true;
            }

            if (this.uwgDMSMaster.ActiveRow == null)
            {
                this.btnDelete.Enabled = false;
                //this.btnAddDet.Enabled = false;
                this.btnAddDet.Enabled = true;
            }

            if (this.uwgDetails.ActiveRow == null)
                this.btnDeleteDet.Enabled = false;

        }

        private void btnCancel_Click(object sender, System.EventArgs e)
        {
            if (blnGridDirty == true)
            {
                DialogResult intDiagResult = MessageBox.Show("Data has changed - Do you want to cancel changes?", "Cancel Changes",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intDiagResult == DialogResult.Yes)
                {
                    LoadGridDMSMaster();
                    blnGridDirty = false;
                    SetButtons();
                }
            }
        }

        private void btnAdd_Click(object sender, System.EventArgs e)
        {
            UltraGridRow addedRow = uwgDMSMaster.DisplayLayout.Bands[0].AddNew();
            addedRow.Cells["DirtyFlag"].Value = "3";
            blnGridDirty = true;
            SetButtons();
        }

        private void btnSave_Click(object sender, System.EventArgs e)
        {
            int rowNum = Convert.ToInt32(this.uwgDMSMaster.ActiveRow.Index);
            SaveDMSMaster(rowNum);
        }
        private void SaveDMSMaster(int rowNum)
        {
            // Validate grid prior to update
            bool GridValid = true;
            int row;
            int retVal;
            string retMsg;

            for (int i = 0; i < uwgDMSMaster.Rows.Count; i++)
            {
                row = i + 1;
                if (uwgDMSMaster.Rows[i].Cells["LabelName"].Value.ToString() == "")
                {
                    MessageBox.Show("Please select a valid 'Label Name' for row " + row.ToString(),
                        "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    GridValid = false;
                    break;
                }
            }

            // Perform updates
            if (GridValid == true)
            {
                // Iterate through each grid row and determine if an update is needed
                for (int i = 0; i < uwgDMSMaster.Rows.Count; i++)
                {
                    switch (uwgDMSMaster.Rows[i].Cells["DirtyFlag"].Value.ToString())
                    {
                        case "1":
                            {
                                // updated
                                retMsg =
                                ProjectData.MasterDMSUpdate(
                                    Convert.ToInt32(uwgDMSMaster.Rows[i].Cells["MultiSelectId"].Value),
                                    Convert.ToString(uwgDMSMaster.Rows[i].Cells["LabelName"].Value)); 
                                  if (retMsg != "success")
                                    MessageBox.Show("Update failed in row " + (i + 1).ToString(), "Database Error",
                                        MessageBoxButtons.OK, MessageBoxIcon.Error);

                                break;
                            }
                        case "2":
                            {
                                retMsg = ProjectData.MasterDMSDelete(Convert.ToInt32(uwgDMSMaster.Rows[i].Cells["MultiSelectId"].Value),
                                                        uwgDMSMaster.ActiveRow.Cells["TableName"].Value.ToString());
                                if (retMsg != "success")
                                    MessageBox.Show("Delete failed in row " + (i + 1).ToString(), "Database Error",
                                        MessageBoxButtons.OK, MessageBoxIcon.Error);

                                DbConnection dbConnection = DbConnection.GetDbConnection();
                                string connectionString = dbConnection.DbConnectionString;

                                break;
                            }
                        case "3":
                            {                        
                                break;
                            }
                    }
                }
                // Reset the dirty flag, reload the grid and reset the form buttons
                blnGridDirty = false;
                LoadGridDMSMaster();
                if (rowNum != 0)
                {
                    try
                    {
                        this.uwgDMSMaster.ActiveRow = this.uwgDMSMaster.Rows[rowNum];
                    }
                    catch
                    {
                    }
                }
                SetButtons();
            }
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            // Get the row to delete. In this case we will use the active row. 
            UltraGridRow row = this.uwgDMSMaster.ActiveRow;

            if (null != row)
            {
                DialogResult intDiagResult = MessageBox.Show("Do you want to delete this MultiSelect Control with related MultiSelect entries, and save all other pending changes? \nIf you decide to proceed, all the selected MultiSelect codes will be deleted from the Projects that are using them. ", "Delete Row",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intDiagResult == DialogResult.Yes)
                {
                    // if the row is a database row then mark it for deletion and hide it in the grid
                    if (row.Cells["DirtyFlag"].Value.ToString() == "0")
                    {
                        row.Hidden = true;
                        row.Cells["DirtyFlag"].Value = "2";
                        blnGridDirty = true;
                    }
                    // else it was added by the user and not saved to the database - delete it from the grid
                    else
                    {
                        row.Delete(false);
                    }
                    // set the active row to first (non-hidden) row
                    SaveDMSMaster(0);

                    LoadGridDMSMaster();
                    LoadGridDMSDetails();   // reload entries grid as we may have deleted child records
                }
            }
            else
            {
                // If there is no active row, then prompt the user to select one. 
                MessageBox.Show("Please select a single row to delete.");
            }
        }

        private void btnAddDet_Click(object sender, System.EventArgs e)
        {
            this.AddDMSDetailRow();
        }

        private void AddDMSDetailRow()
        {
            UltraGridRow detRow = this.uwgDMSMaster.ActiveRow;
            int MultiSelectId = 0;
            bool blnValidRow = true;
            try
            {
                MultiSelectId = Convert.ToInt32(detRow.Cells["MultiSelectId"].Value);
            }
            catch
            {
                blnValidRow = false;
                MessageBox.Show("Please select a valid MultiSelect control row before adding entries into it.",
                    "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            if (blnValidRow == true)
            {
                UltraGridRow addedRow = uwgDetails.DisplayLayout.Bands[0].AddNew();
                addedRow.Cells["Id"].Value = MultiSelectId;

                addedRow.Cells["DirtyFlag"].Value = "3";
                blnGridDetDirty = true;
                SetButtons();

            }
        }

        private void btnDeleteDet_Click(object sender, System.EventArgs e)
        {
            //delete active row
            UltraGridRow row = this.uwgDetails.ActiveRow;

            DialogResult intDiagResult = MessageBox.Show("Do you want to delete this MultiSelect entry, and save all other pending changes? \nIf you decide to proceed, the selected MultiSelect codes will be deleted from the Project that is using it.", "Delete Row",
                MessageBoxButtons.YesNo, MessageBoxIcon.Question);
            if (intDiagResult == DialogResult.Yes)
            {
                if (row.Cells["DirtyFlag"].Value.ToString() == "0")
                {
                    row.Cells["DirtyFlag"].Value = "2";
                    blnGridDetDirty = true;
                }
                else
                {
                    row.Delete(false);
                }
                // set the active row to first (non-hidden) row
                SaveDMSDetails(0);
                LoadGridDMSDetails();
            }
            else
            {
                // If there is no active row, then prompt the user to select one. 
                MessageBox.Show("Please select a single row to delete.");
            }
        }
        private void btnCancelDet_Click(object sender, System.EventArgs e)
        {
            if (blnGridDetDirty == true)
            {
                DialogResult intDiagResult = MessageBox.Show("Data has changed - Do you want to cancel changes?", "Cancel Changes",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intDiagResult == DialogResult.Yes)
                {
                    LoadGridDMSDetails();
                    blnGridDetDirty = false;
                    SetButtons();

                    uwgDMSMaster.ActiveRow.Appearance.BackColorDisabled = Color.Empty;
                    uwgDMSMaster.ActiveRow.Appearance.ForeColorDisabled = Color.Empty;
                }
            }
        }
        private void btnSaveDet_Click(object sender, System.EventArgs e)
        {
            int rowNum = Convert.ToInt32(this.uwgDetails.ActiveRow.Index);
            SaveDMSDetails(rowNum);
        }

        private void SaveDMSDetails(int rowNum)
        {
            int row;
            int retVal;
            string retMsg = "success";


            // Validate grid
            for (int i = 0; i < uwgDetails.Rows.Count; i++)
            {
                row = i + 1;

                if (uwgDetails.Rows[i].Cells["DirtyFlag"].Value.ToString() == "2")
                    continue;

                if (uwgDetails.Rows[i].Cells["Id"].Value.ToString() == "")
                {
                    MessageBox.Show("Please select a valid MultiSelect's entry for row " + row.ToString(),
                        "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
                if (uwgDetails.Rows[i].Cells["Code"].Value.ToString() == String.Empty)
                {
                    MessageBox.Show("'Code' is required in row " + row.ToString(),
                        "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }

                if (uwgDetails.Rows[i].Cells["DisplayName"].Value.ToString() == String.Empty)
                {
                    MessageBox.Show("'Display Name' is required in row " + row.ToString(),
                        "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
            }

            for (int i = 0; i < uwgDetails.Rows.Count; i++)
            {
                switch (uwgDetails.Rows[i].Cells["DirtyFlag"].Value.ToString())
                {
                    case "1":
                        {
                            // updated
                            {
                                retMsg = ProjectData.DetailDMSUpdate(
                                    Convert.ToInt32(uwgDetails.Rows[i].Cells["Id"].Value),
                                    Convert.ToString(uwgDetails.Rows[i].Cells["Code"].Value),
                                    Convert.ToString(uwgDetails.Rows[i].Cells["DisplayName"].Value));

                                if (retMsg != "success")
                                    MessageBox.Show("Update failed in row " + (i + 1).ToString(), "Database Error",
                                        MessageBoxButtons.OK, MessageBoxIcon.Error);
                            }

                            break;
                        }
                    case "2":
                        {
                            if (uwgDetails.Rows[i].Cells["Id"].Value.ToString() != "")
                            {                                    
                                retMsg = ProjectData.DetailDMSDelete(Convert.ToInt32(uwgDetails.Rows[i].Cells["Id"].Value),
                                                                    Convert.ToString(uwgDetails.Rows[i].Cells["Code"].Value),
                                                                    uwgDMSMaster.ActiveRow.Cells["TableName"].Value.ToString());

                                if (retMsg != "success")
                                {
                                    MessageBox.Show("Delete failed in row " + (i + 1).ToString() + " for MultiSelect entry " + Convert.ToString(uwgDetails.Rows[i].Cells["DisplayName"].Value), "Database Error",
                                        MessageBoxButtons.OK, MessageBoxIcon.Error);
                                    return;
                                }
                            }
                          
                            break;

                        }
                    case "3":
                        {
                            retVal = ProjectData.DetailDMSInsert(
                           Convert.ToInt32(uwgDetails.Rows[i].Cells["Id"].Value),
                           Convert.ToString(uwgDetails.Rows[i].Cells["Code"].Value),
                           Convert.ToString(uwgDetails.Rows[i].Cells["DisplayName"].Value));
                            if (retVal == -1)
                                MessageBox.Show("Insert failed in row " + (i + 1).ToString(), "Database Error",
                                    MessageBoxButtons.OK, MessageBoxIcon.Error);

                            break;
                        }
                }
            }
            // Reset the dirty flag, reload the grid and reset the form buttons
            blnGridDetDirty = false;
            LoadGridDMSDetails();
            if (rowNum != 0)
            {
                try
                {
                    this.uwgDetails.ActiveRow = this.uwgDetails.Rows[rowNum];
                }
                catch
                {
                }
            }
            SetButtons();
            this.uwgDMSMaster.ActiveRow.Appearance.BackColorDisabled = Color.Empty;
            this.uwgDMSMaster.ActiveRow.Appearance.ForeColorDisabled = Color.Empty;
        }

    }
 }
