using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using CCPM.Data;
using System.Data;

namespace CCPM.Funding
{
	/// <summary>
	/// Summary description for CreateEditAuthorizations.
	/// </summary>
	public class CreateEditAuthorizations : System.Windows.Forms.Form
	{
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.TextBox txtNotes;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label lable2;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.TextBox txtAmount;
		private System.Windows.Forms.Button btnSave;
		private System.Windows.Forms.RadioButton rbExecutive;
		private System.Windows.Forms.RadioButton rbBoard;
		private System.Windows.Forms.Button btnCancel;
		private bool isEditMode = false;
		private int authorizationId = 0;
		private System.Windows.Forms.ComboBox cbMonth;
		private System.Windows.Forms.TextBox txtYear;
		private System.Windows.Forms.Label label4;
		private Genghis.Windows.Forms.RegularExpressionValidator revYear;
		private int projectId;
		private string errorMsg;

		public bool IsEditMode
		{
			get{return isEditMode;}
			set{isEditMode = value;}
		}
		public int ProjectId
		{
			get{return projectId;}
			set{projectId = value;}
		}
		public int AuthorizationId
		{
			get{return authorizationId;}
			set{authorizationId = value;}
		}

		public CreateEditAuthorizations(int projectId)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			ProjectId = projectId;
		}

		public static bool IsDecimal(string theValue)
		{
			try
			{
				Convert.ToDouble(theValue);
				return true;
			} 
			catch 
			{
				return false;
			}
		} //IsDecimal

		public void PopulateForEdit()
		{
			DataSet ds = FundingData.AuthorizationById(AuthorizationId);
			DataRow dr = ds.Tables[0].Rows[0];
			if((int)dr["AuthorizationTypeId"] == 1)
			{
				rbBoard.Checked = false;
				rbExecutive.Checked = true;
			}
			else
			{
				rbExecutive.Checked = false;
				rbBoard.Checked = true;
			}
			
			cbMonth.SelectedIndex = cbMonth.FindStringExact((string)dr["AuthorizationMonth"]);
			txtYear.Text = dr["AuthorizationYear"].ToString();
			this.txtAmount.Text = ((decimal)dr["DollarAmount"]).ToString("#.00");
			this.txtNotes.Text = (string)dr["Notes"];

		}

		private bool IsFormValid()
		{
			txtYear.Focus();
			txtAmount.Focus();
			txtNotes.Focus();
			bool formValid = true;

			errorMsg = "";

			if( ! revYear.IsValid)
			{
				txtYear.Focus();
				errorMsg = "Enter a 4 digit year. ";
				//isValid = false;
				formValid = false;
			}


			// MAR 2005-01-24 - strip out commas and replace range validator
			txtAmount.Text.Replace(",","");
			if (!IsDecimal(txtAmount.Text))
			{
				errorMsg = errorMsg + "Amount must be numeric. ";
				formValid = false;
			}	


//			if( ! rangeValidator1.IsValid)
//			{
//				txtAmount.Focus();
//				return false;
//			}


			return formValid;
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(CreateEditAuthorizations));
			this.txtNotes = new System.Windows.Forms.TextBox();
			this.label1 = new System.Windows.Forms.Label();
			this.rbExecutive = new System.Windows.Forms.RadioButton();
			this.rbBoard = new System.Windows.Forms.RadioButton();
			this.lable2 = new System.Windows.Forms.Label();
			this.label2 = new System.Windows.Forms.Label();
			this.label3 = new System.Windows.Forms.Label();
			this.txtAmount = new System.Windows.Forms.TextBox();
			this.btnSave = new System.Windows.Forms.Button();
			this.btnCancel = new System.Windows.Forms.Button();
			this.cbMonth = new System.Windows.Forms.ComboBox();
			this.txtYear = new System.Windows.Forms.TextBox();
			this.label4 = new System.Windows.Forms.Label();
			this.revYear = new Genghis.Windows.Forms.RegularExpressionValidator();
			((System.ComponentModel.ISupportInitialize)(this.revYear)).BeginInit();
			this.SuspendLayout();
			// 
			// txtNotes
			// 
			this.txtNotes.Location = new System.Drawing.Point(88, 142);
			this.txtNotes.MaxLength = 250;
			this.txtNotes.Multiline = true;
			this.txtNotes.Name = "txtNotes";
			this.txtNotes.Size = new System.Drawing.Size(392, 58);
			this.txtNotes.TabIndex = 6;
			this.txtNotes.Text = "";
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(8, 144);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(48, 23);
			this.label1.TabIndex = 1;
			this.label1.Text = "Notes";
			// 
			// rbExecutive
			// 
			this.rbExecutive.Location = new System.Drawing.Point(200, 24);
			this.rbExecutive.Name = "rbExecutive";
			this.rbExecutive.Size = new System.Drawing.Size(144, 24);
			this.rbExecutive.TabIndex = 2;
			this.rbExecutive.Text = "Executive Officer";
			// 
			// rbBoard
			// 
			this.rbBoard.Location = new System.Drawing.Point(88, 24);
			this.rbBoard.Name = "rbBoard";
			this.rbBoard.TabIndex = 1;
			this.rbBoard.Text = "Board";
			// 
			// lable2
			// 
			this.lable2.Location = new System.Drawing.Point(8, 25);
			this.lable2.Name = "lable2";
			this.lable2.Size = new System.Drawing.Size(72, 23);
			this.lable2.TabIndex = 4;
			this.lable2.Text = "Authorization";
			this.lable2.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(8, 65);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(56, 23);
			this.label2.TabIndex = 5;
			this.label2.Text = "Month";
			this.label2.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(8, 103);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(48, 23);
			this.label3.TabIndex = 8;
			this.label3.Text = "Amount";
			this.label3.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// txtAmount
			// 
			this.txtAmount.Location = new System.Drawing.Point(88, 104);
			this.txtAmount.Name = "txtAmount";
			this.txtAmount.TabIndex = 5;
			this.txtAmount.Text = "";
			// 
			// btnSave
			// 
			this.btnSave.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.btnSave.Location = new System.Drawing.Point(256, 224);
			this.btnSave.Name = "btnSave";
			this.btnSave.TabIndex = 6;
			this.btnSave.Text = "Save";
			this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
			// 
			// btnCancel
			// 
			this.btnCancel.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.btnCancel.Location = new System.Drawing.Point(408, 224);
			this.btnCancel.Name = "btnCancel";
			this.btnCancel.TabIndex = 7;
			this.btnCancel.Text = "Cancel";
			this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
			// 
			// cbMonth
			// 
			this.cbMonth.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.cbMonth.Items.AddRange(new object[] {
														 "January",
														 "February",
														 "March",
														 "April",
														 "May",
														 "June",
														 "July",
														 "August",
														 "September",
														 "October",
														 "November",
														 "December"});
			this.cbMonth.Location = new System.Drawing.Point(88, 66);
			this.cbMonth.Name = "cbMonth";
			this.cbMonth.Size = new System.Drawing.Size(121, 21);
			this.cbMonth.TabIndex = 3;
			// 
			// txtYear
			// 
			this.txtYear.Location = new System.Drawing.Point(264, 66);
			this.txtYear.Name = "txtYear";
			this.txtYear.Size = new System.Drawing.Size(56, 20);
			this.txtYear.TabIndex = 4;
			this.txtYear.Text = "";
			// 
			// label4
			// 
			this.label4.Location = new System.Drawing.Point(232, 64);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(32, 23);
			this.label4.TabIndex = 11;
			this.label4.Text = "Year";
			this.label4.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// revYear
			// 
			this.revYear.ControlToValidate = this.txtYear;
			this.revYear.ErrorMessage = "Please enter year with century.";
			this.revYear.Icon = ((System.Drawing.Icon)(resources.GetObject("revYear.Icon")));
			this.revYear.ValidationExpression = "^[12][90]\\d{2}$";
			// 
			// CreateEditAuthorizations
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(504, 266);
			this.Controls.Add(this.label4);
			this.Controls.Add(this.txtYear);
			this.Controls.Add(this.txtAmount);
			this.Controls.Add(this.txtNotes);
			this.Controls.Add(this.cbMonth);
			this.Controls.Add(this.btnCancel);
			this.Controls.Add(this.btnSave);
			this.Controls.Add(this.label3);
			this.Controls.Add(this.label2);
			this.Controls.Add(this.lable2);
			this.Controls.Add(this.rbBoard);
			this.Controls.Add(this.rbExecutive);
			this.Controls.Add(this.label1);
			this.Name = "CreateEditAuthorizations";
			this.Load += new System.EventHandler(this.CreateEditAuthorizations_Load);
			((System.ComponentModel.ISupportInitialize)(this.revYear)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		private void CreateEditAuthorizations_Load(object sender, System.EventArgs e)
		{
			cbMonth.SelectedIndex = 0;

			if(IsEditMode)
			{
				this.Text = "Add Authorization";
				this.PopulateForEdit();
			}
			else
			{
				this.Text = "Edit Authorization";
				// MAR 2005-01-31 - switched order of the 2 radio button controls, make rbBoard checked on Add
				this.rbBoard.Checked = true;
            }
		}

		private void btnSave_Click(object sender, System.EventArgs e)
		{
			if(IsFormValid())
			{
				int authType = 1;
				if(rbBoard.Checked) authType = 2;
				if(IsEditMode)
				{
					FundingData.AuthorizationUpdate(AuthorizationId, authType, Convert.ToInt16(txtYear.Text), cbMonth.SelectedItem.ToString(), txtNotes.Text, txtAmount.Text);
					this.DialogResult = DialogResult.OK;
					this.Close();
				}
				else
				{
					FundingData.AuthorizationInsert(this.ProjectId, authType, Convert.ToInt16(txtYear.Text), cbMonth.SelectedItem.ToString(),  txtAmount.Text, txtNotes.Text);
					this.DialogResult = DialogResult.OK;
					this.Close();
				}
			}
			else
			{
				//MessageBox.Show("Some entries are invalid! Please review your input");
				MessageBox.Show(errorMsg, "Validation Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}

		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			this.DialogResult = DialogResult.Ignore;
			this.Close();
		}
	}
}
