using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using CCPM.Data;
using System.Data;
using System.Text.RegularExpressions;

namespace CCPM.Funding
{
	/// <summary>
	/// Summary description for CreateEditMatchingFund.
	/// </summary>
	public class CreateEditMatchingFund : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Button btnNewContact;
		private System.Windows.Forms.Label lbFundingPartnerOrganization;
		private System.Windows.Forms.Button btnExistingContact;
		private System.Windows.Forms.Button btnSave;
		private System.Windows.Forms.Button btnCancel;
		private int projectId = 0;
		private int contactId = 0;
		private System.Windows.Forms.TextBox txtAmount;
		private System.Windows.Forms.Label lblAmount;
		private bool isEditMode;
		private int matchingFundId;
		private string errorMsg;

        private static Regex _isNumber = new Regex(@"^\d+$");

		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public int ProjectId
		{
			get{return projectId;}
			set{projectId = value;}
		}
		public int ContactId
		{
			get{return contactId;}
			set{contactId = value;}
		}
		public bool IsEditMode
		{
			get{return isEditMode;}
			set{isEditMode = value;}
		}
		public int MatchingFundId
		{
			get{return matchingFundId;}
			set{matchingFundId = value;}
		}

		public static bool IsInteger(string theValue)
		{
			Match m = _isNumber.Match(theValue);
			return m.Success;
		} //IsInteger

		public static bool IsDecimal(string theValue)
		{
			try
			{
				Convert.ToDouble(theValue);
				return true;
			} 
			catch 
			{
				return false;
			}
		} //IsDecimal

		public CreateEditMatchingFund(int projectId)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			ProjectId = projectId;
			this.Load += new EventHandler(CreateEditMatchingFund_Load);
		}

		private void PopulateForEdit()
		{
			DataSet ds = FundingData.MatchingFundById(MatchingFundId);
			DataRow dr = ds.Tables[0].Rows[0];
			this.lbFundingPartnerOrganization.Text = (string)dr["ContactOrg"];
			txtAmount.Text = ((decimal)dr["DollarAmount"]).ToString("#.00");
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		private bool IsFormValid()
		{
			bool isValid = true;
			errorMsg = "";
			txtAmount.Focus();
			lblAmount.Focus();

			if(this.lbFundingPartnerOrganization.Text == string.Empty)
			{
				isValid = false;
				errorMsg = "You must choose a Funding Partner. ";
			}

			// MAR 2005-01-24 - strip out commas and replace range validator
			txtAmount.Text.Replace(",","");
			if (!IsDecimal(txtAmount.Text))
			{
				isValid = false;
				errorMsg = errorMsg + "Amount must be numeric. ";
			}	
//			if( ! rangeValidator1.IsValid)
//			{
//				isValid = false;
//			}

			return isValid;
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.label1 = new System.Windows.Forms.Label();
			this.btnNewContact = new System.Windows.Forms.Button();
			this.lbFundingPartnerOrganization = new System.Windows.Forms.Label();
			this.btnExistingContact = new System.Windows.Forms.Button();
			this.lblAmount = new System.Windows.Forms.Label();
			this.txtAmount = new System.Windows.Forms.TextBox();
			this.btnSave = new System.Windows.Forms.Button();
			this.btnCancel = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(8, 24);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(88, 23);
			this.label1.TabIndex = 1;
			this.label1.Text = "Funding Partner";
			this.label1.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// btnNewContact
			// 
			this.btnNewContact.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.btnNewContact.Location = new System.Drawing.Point(232, 64);
			this.btnNewContact.Name = "btnNewContact";
			this.btnNewContact.Size = new System.Drawing.Size(80, 23);
			this.btnNewContact.TabIndex = 2;
			this.btnNewContact.Text = "New Contact";
			this.btnNewContact.Click += new System.EventHandler(this.btnNewContact_Click);
			// 
			// lbFundingPartnerOrganization
			// 
			this.lbFundingPartnerOrganization.Location = new System.Drawing.Point(104, 24);
			this.lbFundingPartnerOrganization.Name = "lbFundingPartnerOrganization";
			this.lbFundingPartnerOrganization.Size = new System.Drawing.Size(360, 23);
			this.lbFundingPartnerOrganization.TabIndex = 3;
			this.lbFundingPartnerOrganization.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// btnExistingContact
			// 
			this.btnExistingContact.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.btnExistingContact.Location = new System.Drawing.Point(104, 64);
			this.btnExistingContact.Name = "btnExistingContact";
			this.btnExistingContact.Size = new System.Drawing.Size(96, 23);
			this.btnExistingContact.TabIndex = 1;
			this.btnExistingContact.Text = "Existing Contact";
			this.btnExistingContact.Click += new System.EventHandler(this.btnExistingContact_Click);
			// 
			// lblAmount
			// 
			this.lblAmount.Location = new System.Drawing.Point(8, 128);
			this.lblAmount.Name = "lblAmount";
			this.lblAmount.Size = new System.Drawing.Size(64, 23);
			this.lblAmount.TabIndex = 6;
			this.lblAmount.Text = "Amount";
			this.lblAmount.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// txtAmount
			// 
			this.txtAmount.Location = new System.Drawing.Point(104, 128);
			this.txtAmount.Name = "txtAmount";
			this.txtAmount.Size = new System.Drawing.Size(120, 20);
			this.txtAmount.TabIndex = 3;
			this.txtAmount.Text = "";
			// 
			// btnSave
			// 
			this.btnSave.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.btnSave.Location = new System.Drawing.Point(248, 200);
			this.btnSave.Name = "btnSave";
			this.btnSave.TabIndex = 4;
			this.btnSave.Text = "Save";
			this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
			// 
			// btnCancel
			// 
			this.btnCancel.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
			this.btnCancel.Location = new System.Drawing.Point(392, 200);
			this.btnCancel.Name = "btnCancel";
			this.btnCancel.TabIndex = 5;
			this.btnCancel.Text = "Cancel";
			this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
			// 
			// CreateEditMatchingFund
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(488, 266);
			this.Controls.Add(this.btnCancel);
			this.Controls.Add(this.btnSave);
			this.Controls.Add(this.txtAmount);
			this.Controls.Add(this.lblAmount);
			this.Controls.Add(this.btnExistingContact);
			this.Controls.Add(this.lbFundingPartnerOrganization);
			this.Controls.Add(this.btnNewContact);
			this.Controls.Add(this.label1);
			this.Name = "CreateEditMatchingFund";
			this.Text = "CreateEditMatchingFund";
			this.ResumeLayout(false);

		}
		#endregion

		private void CreateEditMatchingFund_Load(object sender, System.EventArgs e)
		{
			if(IsEditMode)
			{
				PopulateForEdit();
				this.btnExistingContact.Enabled = false;
				this.btnNewContact.Enabled = false;
			}
		}

		private void btnExistingContact_Click(object sender, System.EventArgs e)
		{
			CCPM.Contact.MasterDetail mdc = new CCPM.Contact.MasterDetail();
			mdc._MasterDetailControl.ProjectId = ProjectId;
			mdc._MasterDetailControl.IsAddFundingPartnerMode = true;
			DialogResult dialogResult = mdc.ShowDialog(this);
			if(dialogResult == DialogResult.OK)
			{
				lbFundingPartnerOrganization.Text = mdc._MasterDetailControl.ContactOrganizationName;
				ContactId = mdc._MasterDetailControl.SelectedContact;
			}
		}

		private void btnNewContact_Click(object sender, System.EventArgs e)
		{
			CCPM.Contact.ContactCreateOrUpdate cou = new CCPM.Contact.ContactCreateOrUpdate();
			cou.ProjectId = this.ProjectId;
			cou.IsMatchingFundMode = true;
			DialogResult dialogResult = cou.ShowDialog(this);
			if(dialogResult == DialogResult.OK)
			{
				lbFundingPartnerOrganization.Text = cou.OrganizationName;
				ContactId = cou.ContactId;
			}
		}

		private void btnSave_Click(object sender, System.EventArgs e)
		{
			if(IsFormValid())
			{
				if(IsEditMode)
				{
					FundingData.MatchingFundUpdate(MatchingFundId, ContactId, txtAmount.Text);
				}
				else
				{
					FundingData.MatchingFundInsert(ProjectId, ContactId, txtAmount.Text);
					//If the contact is not already associated with the project then associate them.
					if( ! ContactData.ContactIsAssociated(ContactId, ProjectId))
					{
						//MAR 2005-01-31 - this sproc doesn't exist - not clear on what was intended here?
						// It appears that the line below ContactData.Contact_ContactTypeInsert does the necessary
						// association. 
						//ContactData.ContactAssociate(ProjectId, ContactId);
					}
					//The stored procedure for this method checks for duplicates
					ContactData.Contact_ContactTypeInsert(ProjectId, ContactId, 3); //Funding Partner Contact Type
				}
				
				this.DialogResult = DialogResult.OK;
				this.Close();
			}
			else
			{
				//MessageBox.Show(errorMsg,"Validation Error");
				MessageBox.Show(errorMsg, "Validation Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
			
		}

		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			this.Close();
		}
	}
}
