using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using CCPM.Data;

namespace CCPM.Funding
{
	/// <summary>
	/// Provides a basic display of funding authorizations and matching funds.
	/// *Note: Context menu items are on ProjectForm.cs; this was done Because
	/// of dificulty refreshing the grid views after a new item is added or an item
	/// is updated. Puting the context menu on ProjectForm.cs made it easier
	/// to refresh this whole user control instead of individual grid views.
	/// </summary>
	public class Funding : System.Windows.Forms.UserControl
	{
		private DataGridControl.DataGridControl dataGridControl1;
		DataSet authDataSet = null;
		DataSet matchingFundDataSet = null;
		private System.Windows.Forms.Splitter splitter1;
		private DataGridControl.DataGridControl dataGridControl2;
		private int projectId;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.Label lblAuthorizationTotal;
		private System.Windows.Forms.Label lblMatchingFundTotal;
		private System.Windows.Forms.Label lblGrandTotal;
		private System.Windows.Forms.Panel panel1;
		private System.ComponentModel.Container components = null;

		public int AuthorizationId
		{
			get
			{
				int currentRow = this.dataGridControl1.CurrentRowIndex;
				if(currentRow < (authDataSet.Tables[0].Rows.Count -1))
				{
					return (int)authDataSet.Tables[0].Rows[currentRow]["AuthorizationId"];
				}
				else
				{
					return 0;
				}
			}
		}
		public int MatchingFundId
		{
			get
			{
				int currentRow = this.dataGridControl2.CurrentRowIndex;
				if(currentRow < (this.matchingFundDataSet.Tables[0].Rows.Count -1))
				{
					return (int)matchingFundDataSet.Tables[0].Rows[currentRow]["MatchingFundId"];
				}
				else
				{
					return 0;
				}
			}
		}
		
		public int ProjectId
		{
			get{return projectId;}
			set{projectId = value;}
		}
	

		public Funding(int projectId)
		{
			this.BindingContext = new BindingContext();
			InitializeComponent();

			this.Load += new System.EventHandler(Form_Load);
			ProjectId = projectId;
		}

		private void BindAuthorizationGrid()
		{
			authDataSet = CCPM.Data.FundingData.GetAuthorizationsByProject(ProjectId);
			if(authDataSet.Tables[0].Rows.Count > 0)
			{
				dataGridControl1.GridDataSet = authDataSet;
				dataGridControl1.DataSourceTable = "Table";																									
				// Add the columns to sum to an array list. Use the following format:
				// "<ColumnNumber>,summing expression"
				ArrayList summary = new ArrayList();
				summary.Add("3,sum(Amount)");
				// Map the array list to the SummaryColumns property of DataGridControl
				dataGridControl1.SummaryColumns = summary;

				// Set the foreground color and the background color for the footer row.
				DataGridControl.DataGridControl.FooterColor = Brushes.BlueViolet;
				DataGridControl.DataGridControl.FooterFontColor = Brushes.White;

				dataGridControl1.BindDataGrid();

				DataGridTableStyle tableStyle = dataGridControl1.TableStyles["Table"];
				tableStyle.ReadOnly = true;
				tableStyle.GridColumnStyles["Authorization"].Width = 150;
				tableStyle.GridColumnStyles["Authorization Date"].Width = 100;
				tableStyle.GridColumnStyles["Notes"].Width = 335;
				DataGridControl.MyDataGridTextBox myCol = ((DataGridControl.MyDataGridTextBox)tableStyle.GridColumnStyles["Amount"]);
				myCol.HeaderText = "Amount -";
				myCol.Format = "C";
				myCol.Alignment = HorizontalAlignment.Right;
				myCol.Width = 125;
			}

		}
		private void BindMatchingFundGrid()
		{
			matchingFundDataSet = CCPM.Data.FundingData.GetMatchingFundByProject(ProjectId);
			if(matchingFundDataSet.Tables[0].Rows.Count > 0)
			{
				dataGridControl2.GridDataSet = matchingFundDataSet;
				dataGridControl2.DataSourceTable = "Table";																									
				// Add the columns to sum to an array list. Use the following format:
				// "<ColumnNumber>,summing expression"
				ArrayList summary = new ArrayList();
				summary.Add("1,sum(Amount)");
				// Map the array list to the SummaryColumns property of DataGridControl
				dataGridControl2.SummaryColumns = summary;

				// Set the foreground color and the background color for the footer row.
				DataGridControl.DataGridControl.FooterColor = Brushes.BlueViolet;
				DataGridControl.DataGridControl.FooterFontColor = Brushes.White;

				dataGridControl2.BindDataGrid();

				DataGridTableStyle tableStyle = dataGridControl2.TableStyles["Table"];
				tableStyle.ReadOnly = true;
				tableStyle.GridColumnStyles["Matching Fund Organization"].Width = 585;
				DataGridControl.MyDataGridTextBox myCol = ((DataGridControl.MyDataGridTextBox)tableStyle.GridColumnStyles["Amount"]);
				myCol.HeaderText = "Amount -";
				myCol.Format = "C";
				myCol.Alignment = HorizontalAlignment.Right;
				myCol.Width = 125;
			}
		}

		private void SetTotals()
		{
			//SQL will return 0 for each field if there are no records.
			DataSet dsTotals = FundingData.FundingTotals(ProjectId);
			DataRow drTotals = dsTotals.Tables[0].Rows[0];
			lblAuthorizationTotal.Text = ((decimal)drTotals["AuthTotal"]).ToString("C");
			lblMatchingFundTotal.Text = ((decimal)drTotals["MatchTotal"]).ToString("C");
			lblGrandTotal.Text = ((decimal)drTotals["GrandTotal"]).ToString("C");
		}
		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.dataGridControl1 = new DataGridControl.DataGridControl();
			this.splitter1 = new System.Windows.Forms.Splitter();
			this.dataGridControl2 = new DataGridControl.DataGridControl();
			this.label1 = new System.Windows.Forms.Label();
			this.label2 = new System.Windows.Forms.Label();
			this.label3 = new System.Windows.Forms.Label();
			this.lblAuthorizationTotal = new System.Windows.Forms.Label();
			this.lblMatchingFundTotal = new System.Windows.Forms.Label();
			this.lblGrandTotal = new System.Windows.Forms.Label();
			this.panel1 = new System.Windows.Forms.Panel();
			((System.ComponentModel.ISupportInitialize)(this.dataGridControl1)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.dataGridControl2)).BeginInit();
			this.panel1.SuspendLayout();
			this.SuspendLayout();
			// 
			// dataGridControl1
			// 
			this.dataGridControl1.AllowSorting = false;
			this.dataGridControl1.CaptionText = "Authorizations";
			this.dataGridControl1.DataMember = "";
			this.dataGridControl1.DataSourceTable = null;
			this.dataGridControl1.Dock = System.Windows.Forms.DockStyle.Top;
			this.dataGridControl1.HeaderForeColor = System.Drawing.SystemColors.ControlText;
			this.dataGridControl1.Location = new System.Drawing.Point(0, 0);
			this.dataGridControl1.Name = "dataGridControl1";
			this.dataGridControl1.ReadOnly = true;
			this.dataGridControl1.Size = new System.Drawing.Size(740, 170);
			this.dataGridControl1.TabIndex = 1;
			// 
			// splitter1
			// 
			this.splitter1.Dock = System.Windows.Forms.DockStyle.Top;
			this.splitter1.Location = new System.Drawing.Point(0, 170);
			this.splitter1.Name = "splitter1";
			this.splitter1.Size = new System.Drawing.Size(740, 3);
			this.splitter1.TabIndex = 2;
			this.splitter1.TabStop = false;
			// 
			// dataGridControl2
			// 
			this.dataGridControl2.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.dataGridControl2.CaptionText = "Matching Funds";
			this.dataGridControl2.DataMember = "";
			this.dataGridControl2.DataSourceTable = null;
			this.dataGridControl2.HeaderForeColor = System.Drawing.SystemColors.ControlText;
			this.dataGridControl2.Location = new System.Drawing.Point(0, 176);
			this.dataGridControl2.Name = "dataGridControl2";
			this.dataGridControl2.ReadOnly = true;
			this.dataGridControl2.Size = new System.Drawing.Size(740, 170);
			this.dataGridControl2.TabIndex = 3;
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(8, 8);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(112, 23);
			this.label1.TabIndex = 4;
			this.label1.Text = "Authorizations";
			this.label1.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(8, 32);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(112, 23);
			this.label2.TabIndex = 5;
			this.label2.Text = "Matching Funds";
			this.label2.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label3
			// 
			this.label3.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.label3.Location = new System.Drawing.Point(8, 64);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(80, 23);
			this.label3.TabIndex = 6;
			this.label3.Text = "Total";
			this.label3.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// lblAuthorizationTotal
			// 
			this.lblAuthorizationTotal.Location = new System.Drawing.Point(120, 8);
			this.lblAuthorizationTotal.Name = "lblAuthorizationTotal";
			this.lblAuthorizationTotal.Size = new System.Drawing.Size(136, 23);
			this.lblAuthorizationTotal.TabIndex = 7;
			this.lblAuthorizationTotal.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// lblMatchingFundTotal
			// 
			this.lblMatchingFundTotal.Location = new System.Drawing.Point(120, 32);
			this.lblMatchingFundTotal.Name = "lblMatchingFundTotal";
			this.lblMatchingFundTotal.Size = new System.Drawing.Size(136, 23);
			this.lblMatchingFundTotal.TabIndex = 8;
			this.lblMatchingFundTotal.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// lblGrandTotal
			// 
			this.lblGrandTotal.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.lblGrandTotal.Location = new System.Drawing.Point(103, 64);
			this.lblGrandTotal.Name = "lblGrandTotal";
			this.lblGrandTotal.Size = new System.Drawing.Size(148, 23);
			this.lblGrandTotal.TabIndex = 9;
			this.lblGrandTotal.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// panel1
			// 
			this.panel1.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
			this.panel1.Controls.Add(this.lblMatchingFundTotal);
			this.panel1.Controls.Add(this.lblGrandTotal);
			this.panel1.Controls.Add(this.label1);
			this.panel1.Controls.Add(this.label2);
			this.panel1.Controls.Add(this.label3);
			this.panel1.Controls.Add(this.lblAuthorizationTotal);
			this.panel1.Location = new System.Drawing.Point(480, 348);
			this.panel1.Name = "panel1";
			this.panel1.Size = new System.Drawing.Size(280, 100);
			this.panel1.TabIndex = 10;
			// 
			// Funding
			// 
			this.Controls.Add(this.panel1);
			this.Controls.Add(this.dataGridControl2);
			this.Controls.Add(this.splitter1);
			this.Controls.Add(this.dataGridControl1);
			this.Name = "Funding";
			this.Size = new System.Drawing.Size(740, 500);
			((System.ComponentModel.ISupportInitialize)(this.dataGridControl1)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.dataGridControl2)).EndInit();
			this.panel1.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		private void Form_Load(object sender, EventArgs e)
		{
			BindAuthorizationGrid();
			BindMatchingFundGrid();
			SetTotals();
		}
		
	}
}
