﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;


namespace CCPM
{
    class GlobalCode
    {
        public static void ComboSetValue(ComboBox cmb, int value)
        {
            System.Data.DataRowView drv;
            for (int i = 0; i < cmb.Items.Count; i++)
            {
                drv = (System.Data.DataRowView)cmb.Items[i];
                if (Convert.ToInt32(drv[0]) == value)
                {
                    cmb.SelectedIndex = i;
                    break;
                }
            }
        }

        public static void TextBoxInteger(TextBox txt, int min, int max)
        {
            int n = 0;
            string s = txt.Text;
            string p = "[^0-9]*";
            s = System.Text.RegularExpressions.Regex.Replace(s, p, string.Empty);
            if (s == "")
            {
                txt.Text = s;
                return;
            }
            try
            {
                n = int.Parse(s);
                if (min != -1 && n < min)
                    n = min;
                if (max != -1 && n > max)
                    n = max;
                txt.Text = n.ToString();
            }
            catch (Exception ex)
            {
                txt.Text = "";
            }
        }

        public static int ToInt32(object num)
        {
            if (num == null)
                return 0;
            String s = num.ToString();
            string p = @"[^0-9\.\-]*";
            s = System.Text.RegularExpressions.Regex.Replace(s, p, string.Empty);
            try
            {
                return int.Parse(s);
            }
            catch (Exception ex)
            {
                return 0;
            }
        }

        public static decimal ToDecimal(object num)
        {
            if (num == null)
                return 0;
            string s = num.ToString();
            string p = @"[^0-9\.\-]*";
            s = System.Text.RegularExpressions.Regex.Replace(s, p, string.Empty);
            try
            {
                return decimal.Parse(s);
            }
            catch (Exception)
            {
                return 0;
            }
        }

        public static string ToString(object value)
        {
            if (value == null || value == DBNull.Value)
                return "";

            try
            {
                return value.ToString();
            }
            catch (Exception)
            {
                return "";
            }
        }

        public static string ToDateString(object value)
        {
            if (value == null || value == DBNull.Value)
                return "";

            string s = value.ToString();
            try
            {
                s = DateTime.Parse(s).ToShortDateString();
                return s;
            }
            catch (Exception)
            {
                return "";
            }
        }

        public static string SqlString(object value)
        {
            if (value == DBNull.Value || value == null)
                return "null";
            string s = value.ToString().TrimEnd();
            if (s == string.Empty)
                return "null";
            return "'" + s.Replace("'", "''") + "'";
        }

        public static string SqlStringList(string value, string delimiter)
        {
            if (delimiter == string.Empty)
                delimiter = ",";
            value = SqlString(value);
            value = value.Replace(delimiter, "'" + delimiter + "'");
            return value;
        }

        public static bool ToBoolean(object value)
        {
            if (value == DBNull.Value || value == null)
                return false;
            string s = value.ToString().ToLower();
            if (s == string.Empty)
                return false;
            s = s.Substring(0, 1);
            //1, true, on, yes
            if (s == "1" || s == "t" || s == "o" || s == "y")
                return true;
            return false;
        }

        public static string SqlBoolean(object value)
        {
            if (value == DBNull.Value || value == null)
                return "0";
            string s = value.ToString().ToLower();
            if (s == string.Empty)
                return "0";
            s = s.Substring(0, 1);
            //1, true, on, yes
            if (s == "1" || s == "t" || s == "o" || s == "y")
                return "1";
            return "0";
        }

        public static string ToTrueFalse(object value)
        {
            if (value == DBNull.Value || value == null)
                return "";
            string s = value.ToString().ToLower();
            if (s == string.Empty)
                return "";
            s = s.Substring(0, 1);
            //1, true, on, yes
            if (s == "1" || s == "t" || s == "o" || s == "y")
                return "true";
            return "false";
        }

        public static void ExportGridToExcel(Infragistics.Win.UltraWinGrid.UltraGrid uwg, string fileName)
        {
            Infragistics.Win.UltraWinGrid.ExcelExport.UltraGridExcelExporter exporter = new Infragistics.Win.UltraWinGrid.ExcelExport.UltraGridExcelExporter();
            exporter.BeginExport += new Infragistics.Win.UltraWinGrid.ExcelExport.BeginExportEventHandler(exporter_BeginExport);
            exporter.Export(uwg, fileName);
        }

        static void exporter_BeginExport(object sender, Infragistics.Win.UltraWinGrid.ExcelExport.BeginExportEventArgs e)
        {
            for (int i = 0; i < e.Layout.Bands[0].Columns.Count; i++)
            {
                e.Layout.Bands[0].Columns[i].CellAppearance.BackColor = System.Drawing.Color.White;
            }
        }

        public static string TabFileName(string path, string fileName)
        {
            SaveFileDialog ofd1 = new SaveFileDialog();
            ofd1.InitialDirectory = path;
            ofd1.FileName = fileName;
            ofd1.Filter = "Tab files (*.tab)|*.tab|All files (*.*)|*.*";
            ofd1.RestoreDirectory = true;
            if (ofd1.ShowDialog() == DialogResult.OK)
            {
                return ofd1.FileName;
            }
            return string.Empty;
        }

        public static string ExcelFileName(string path, string fileName, bool overWritePrompt)
        {
            SaveFileDialog ofd1 = new SaveFileDialog();
            ofd1.InitialDirectory = path;
            ofd1.FileName = fileName;
            ofd1.Filter = "Excel files (*.xls)|*.xls|All files (*.*)|*.*";
            ofd1.RestoreDirectory = true;
            ofd1.OverwritePrompt = overWritePrompt;
            if (ofd1.ShowDialog() == DialogResult.OK)
            {
                return ofd1.FileName;
            }
            return string.Empty;
        }

        public static void OpenAssociatedFile(string fn)
        {
            System.Diagnostics.Process objDocProcess = new System.Diagnostics.Process();
            objDocProcess.EnableRaisingEvents = false;
            try
            {
                objDocProcess.StartInfo.FileName = fn;
                objDocProcess.Start();
            }
            catch (Exception ex)
            {
                System.Windows.Forms.MessageBox.Show(ex.Message);
            }
        }

        public static void ExportGridToTab(Infragistics.Win.UltraWinGrid.UltraGrid uwg, string fn)
        {
            System.Text.StringBuilder sb = new System.Text.StringBuilder("");
            int cols = uwg.Rows[0].Band.Columns.Count;
            int lastCol = 0;

            for (int i = 0; i < cols; i++)
            {
                if (uwg.Rows[0].Band.Columns[i].Hidden == false)
                    lastCol = i;
            }

            for (int i = 0; i <= lastCol; i++)
            {
                if (uwg.Rows[0].Band.Columns[i].Hidden == false)
                {
                    sb.Append(uwg.Rows[0].Band.Columns[i].Header.Caption);
                    if (i == lastCol)
                    {
                        sb.Append("\r\n");
                    }
                    else
                    {
                        sb.Append("\t");
                    }
                }
            }

            for (int r = 0; r < uwg.Rows.Count; r++)
            {
                for (int i = 0; i <= lastCol; i++)
                {
                    if (uwg.Rows[0].Band.Columns[i].Hidden == false)
                    {
                        sb.Append(uwg.Rows[r].Cells[i].Text.ToString());
                        if (i == lastCol)
                        {
                            sb.Append("\r\n");
                        }
                        else
                        {
                            sb.Append("\t");
                        }
                    }
                }
            }

            System.IO.StreamWriter sw = new System.IO.StreamWriter(fn);
            sw.Write(sb.ToString());
            sw.Flush();
            sw.Close();
        }
    }
}
