﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;
using CCPM.Data;

namespace CCPM
{
    public partial class GridEdit : Form
    {
        private string tableName = "";
        private string titleName = "";
        private string[] sFilterKey ;
        private string[] sUpdateKey ;
        private DataSet dsGrid = null;
        public UltraGridBand band;
        private bool blnDataDirty = false;

        public string TableName
        {
            get { return tableName; }
            set 
            {   tableName = value;
                LoadGrid();
            }
        }

        public string TitleName
        {
            get { return titleName; }
            set { titleName = value; }
        }


        public GridEdit()
        {
            InitializeComponent();
        }

        public GridEdit(string table)
        {
            InitializeComponent();
            tableName = table;
            LoadGrid();
        }
        public GridEdit(string table, string title, bool bReadOnly, bool bAdd, bool bDelete, string [] selectFilterKey, string [] updateKey)
        {
            InitializeComponent();
            tableName = table;
            sFilterKey = selectFilterKey;
            sUpdateKey = updateKey;
            titleName = title;
            btnAdd.Visible = bAdd;
            btnDelete.Visible = bDelete;
            btnSave.Visible = !bReadOnly;
            LoadGrid();
        }

        public void ColumnHide(int index)
        {
            band.Columns[index].Hidden = true;
        }

        public void ColumnHide(string key)
        {
            band.Columns[key].Hidden = true;
        }

        public void ColumnWidth(int index, int value)
        {
            band.Columns[index].Width = value;
        }

        public void ColumnCaption(int index, string value)
        {
            band.Columns[index].Header.Caption = value;
        }

        public void ColumnDisable(int index)
        {
             band.Columns[index].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
             band.Columns[index].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
             band.Columns[index].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
             band.Columns[index].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;
        }

        public void ColumnMoney(int index)
        {
            band.Columns[index].Format = GlobalSettings.MoneyFormat;
            band.Columns[index].MaskInput = "-nnnnnnnnnnn.nn";
            band.Columns[index].CellAppearance.TextHAlign = HAlign.Right;
            
        }

        public void ColumnCheckBox(int index)
        {
            band.Columns[index].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.CheckBox;
        }

        private void LoadGrid()
        {
            band = uwgEdit.DisplayLayout.Bands[0];
            switch (tableName)
            {
                case "ProjectRegion":
                    {                        
                        lblTitle.Text = "Manage Project Regions";
                        this.Text = lblTitle.Text;
                        dsGrid = CCPM.Data.ProjectData.ProjectRegionSelect();
                        uwgEdit.DataSource = dsGrid;
                        uwgEdit.DataBind();
                        ColumnHide(0);
                        ColumnWidth(1, 200);
                        ColumnCaption(2, "Active");
                        ColumnWidth(3, 200);
                        ColumnCaption(3, "Regional Manager");
                        ColumnHide("DirtyFlag");

                        DataSet dsProjectStaff = ProjectData.ProjectStaffList();
                        if (uwgEdit.DisplayLayout.ValueLists.Count == 0)
                            uwgEdit.DisplayLayout.ValueLists.Add("Name");
                        for (int i = 0; i < dsProjectStaff.Tables[0].Rows.Count; i++)
                        {
                            Infragistics.Win.ValueListItem listItem1 = new Infragistics.Win.ValueListItem();
                            listItem1.DataValue = dsProjectStaff.Tables[0].Rows[i].ItemArray.GetValue(0);
                            listItem1.DisplayText = (string)dsProjectStaff.Tables[0].Rows[i].ItemArray.GetValue(1);
                            uwgEdit.DisplayLayout.ValueLists["Name"].ValueListItems.Add(listItem1);
                        }
                        band.Layout.ValueLists["Name"].DisplayStyle = Infragistics.Win.ValueListDisplayStyle.DisplayText;
                        band.Columns["RegionalManagerId"].ValueList = uwgEdit.DisplayLayout.ValueLists["Name"];


                        break;
                    }
                case "ProjectContractsManagers" :
                    {
                        this.Text = "Change Contract Managers for Project ";
                        lblTitle.Text = this.Text + titleName;
                        string contractManagerName = sUpdateKey[1].ToString();
                        lblInstructions.Text = "Check the 'Update' box for the contracts, which Contract Manager should be updated to " + contractManagerName;
                        LoadProjectContractsManagers();
                        break;
                    }
            }
            btnSave.Enabled = false;
            blnDataDirty = false;
        }

        private void LoadProjectContractsManagers()
        {
            int projectId = Convert.ToInt32(sFilterKey[0].ToString());
            dsGrid = CCPM.Data.ProjectData.ProjectContractsManagerSelect(projectId);
            uwgEdit.DataSource = dsGrid;
            uwgEdit.DataBind();
            ColumnHide(0);
            ColumnHide(1);
            ColumnWidth(2, 100);
            ColumnCaption(2, "Update");
            ColumnCheckBox(2);

            ColumnDisable(3);
            ColumnCaption(3, "Contract Manager");
            ColumnDisable(3);

            ColumnWidth(4, 150);
            ColumnCaption(4, "Contract Number");
            ColumnDisable(4);

            ColumnWidth(5, 150);
            ColumnCaption(5, "Status");
            ColumnDisable(5);

            ColumnWidth(6, 200);
            ColumnCaption(6, "Balance");
            ColumnMoney(6);
            ColumnDisable(6);

            ColumnHide("DirtyFlag");

        
        }

        private void uwgEdit_AfterCellUpdate(object sender, CellEventArgs e)
        {
            uwgEdit.ActiveRow.Cells["DirtyFlag"].Value = true;
            blnDataDirty = true;
            btnSave.Enabled = true;
        }

        private void btnAdd_Click(object sender, EventArgs e)
        {
            UltraGridRow addRow = band.AddNew();
            addRow.Cells["DirtyFlag"].Value = true;
            blnDataDirty = true;
            btnSave.Enabled = true;
        }

        private void SaveData()
        {
            if (!blnDataDirty)
                return;

            bool retVal = true;

            switch (tableName)
            {
                case "ProjectRegion":
                    {
                        retVal = ProjectRegionSave();
                        break;
                    }
                case "ProjectContractsManagers":
                    {
                        retVal = ProjectContractsManagersSave();
                        break;
                    }
            }
            if (retVal)
                LoadGrid();
        }

        private bool ProjectRegionSave()
        {
            foreach (UltraGridRow ugr in uwgEdit.Rows)
            {
                if ((bool)ugr.Cells["DirtyFlag"].Value)
                {
                    if (!ugr.Hidden)
                    {
                        if (ugr.Cells["Region"].Value.ToString() == string.Empty)
                        {
                            MessageBox.Show("Region is a required field.", "Missing data", MessageBoxButtons.OKCancel);
                            return false;
                        }
                    }
                }
            }

            foreach (UltraGridRow ugr in uwgEdit.Rows)
            {
                if ((bool)ugr.Cells["DirtyFlag"].Value)
                {
                    int regionid = GlobalCode.ToInt32(ugr.Cells["RegionId"].Value);
                    if (ugr.Hidden)
                    {
                        if (regionid > 0)
                        {
                            try
                            {
                                ProjectData.ProjectRegionDelete(regionid);
                            }
                            catch (Exception ex)
                            {
                                MessageBox.Show(ex.Message, "Row delete failure", MessageBoxButtons.OKCancel);
                                ugr.Hidden = false;
                                return false;
                            }
                        }
                    }
                    else
                    {
                        try
                        {
                            ProjectData.ProjectRegionSave(
                                regionid,
                                ugr.Cells["Region"].Value.ToString(),
                                GlobalCode.ToBoolean(ugr.Cells["IsActive"].Value),
                                GlobalCode.ToInt32(ugr.Cells["RegionalManagerId"].Value)
                                );
                        }
                        catch (Exception ex)
                        {
                            MessageBox.Show(ex.Message, "Row save failure", MessageBoxButtons.OKCancel);
                            return false;
                        }
                    }
                }
            }
            return true;
        }

        private bool ProjectContractsManagersSave()
        {
            string contractList = "";
            foreach (UltraGridRow ugr in uwgEdit.Rows)
            {
                if ((bool)ugr.Cells["DirtyFlag"].Value)
                {
                    if (ugr.Cells["IsUpdate"].Value.ToString() == "1")
                    {
                        contractList += "," + ugr.Cells["ContractId"].Value.ToString();
                    }
                }
            }
            if (contractList == "")
            {
                MessageBox.Show( "No records for update have been selected." + lblInstructions.Text ,"Update Failed", MessageBoxButtons.OK);
                return false;
            }
            contractList = contractList.Substring(1);

            try
            {
                int projectMangerId = Convert.ToInt32(sUpdateKey[0].ToString());
                ProjectData.ProjectContractsManagerUpdate(projectMangerId, contractList);
              }
            catch (Exception ex)
              {
                 MessageBox.Show(ex.Message, "Row update failure", MessageBoxButtons.OK);
                 return false;
                }
            return true;
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            SaveData();
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            uwgEdit.ActiveRow.Cells["DirtyFlag"].Value = true;
            uwgEdit.ActiveRow.Hidden = true;
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            this.Close();
        }

    }
}
