﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid; 

namespace CCPM
{
    public partial class GridFilter : Form
    {
        private UltraGrid uwg = null;
        private Label lbl = null;
        private int columnIndex = 0;
        private string columnHeader = "";
        private Label lblOn = null;

        public GridFilter()
        {
            InitializeComponent();
        }

        public GridFilter(UltraGrid uwGrid, Label lblFilter, Label lblFilterOn, string title)
        {

            this.InitializeComponent();
            lblTitle.Text = "Grid Filter:   " + title;

            uwg = uwGrid;
            lbl = lblFilter;
            lblOn = lblFilterOn;

            if (lbl.Text == string.Empty)
                gbxAndOr.Visible = false;

            UltraGridBand band = this.uwg.DisplayLayout.Bands[0];

            int cols = band.Columns.Count;
            string s = "";

            for (int i = 0; i < cols; i++)
            {
                if (band.Columns[i].Hidden == false)
                {
                    try
                    {
                        s = band.Columns[i].Header.Caption;
                        this.lstColumn.Items.Add(s);
                   }
                    catch (Exception) { }
                }
            }

            //FilterComparisionOperator.Contains;
            //FilterComparisionOperator.DoesNotContain;
            //FilterComparisionOperator.DoesNotEndWith;
            //FilterComparisionOperator.DoesNotStartWith;
            //FilterComparisionOperator.EndsWith;
            //FilterComparisionOperator.Equals;
            //FilterComparisionOperator.GreaterThan;
            //FilterComparisionOperator.GreaterThanOrEqualTo;
            //FilterComparisionOperator.LessThan;
            //FilterComparisionOperator.LessThanOrEqualTo;
            //FilterComparisionOperator.Like;
            //FilterComparisionOperator.NotEquals;
            //FilterComparisionOperator.NotLike;
            //FilterComparisionOperator.StartsWith;

            this.lstOperator.Items.Add("Contains");
            this.lstOperator.Items.Add("Ends With");
            this.lstOperator.Items.Add("Equals");
            this.lstOperator.Items.Add("Greater Than");
            this.lstOperator.Items.Add("Greater Than Or Equal To");
            this.lstOperator.Items.Add("Less Than");
            this.lstOperator.Items.Add("Less Than Or Equal To");
            this.lstOperator.Items.Add("Starts With");

            this.lstColumn.SelectedIndex = 0;
            this.lstOperator.SelectedIndex = 7;

        }

        private void btnOk_Click(object sender, EventArgs e)
        {
            if (ApplyFilter())
            {
                DialogResult = DialogResult.OK;
                this.Close();
            }
        }

        private bool ApplyFilter()
        {
            UltraGridBand band = this.uwg.DisplayLayout.Bands[0];
            string operatorText = "";
            Infragistics.Win.UltraWinGrid.FilterComparisionOperator fco;
            string filterText = "";

            operatorText = lstOperator.Text;
            filterText = txtValue.Text;

            if (columnHeader == string.Empty)
            {
                MessageBox.Show("Missing column!");
                lstColumn.Focus();
                return false;
            }

            // Set the row filter mode to AllRowsInBand so UltraGrid uses the filters added 
            // to UltraGridBand.ColumnFilters object. 
            band.Override.RowFilterMode = RowFilterMode.AllRowsInBand;

            //checked list box used
            if (clbValues.CheckedItems.Count > 0)
            {
                fco = FilterComparisionOperator.Equals;
                band.ColumnFilters[columnIndex].LogicalOperator = FilterLogicalOperator.Or;
                string s = "";
                foreach (string filter in clbValues.CheckedItems)
                {
                    band.ColumnFilters[columnIndex].FilterConditions.Add(fco, filter);
                    s += filter + ", ";
                }
                s = s.Substring(0, s.Length - 2);
                lbl.Text += columnHeader + " in (" + s + ")\n";
                lblOn.Text = "Filter On";

                clbValues.ClearSelected();
                for (int i = 0; i < clbValues.Items.Count; i++)
                    clbValues.SetItemChecked(i, false);

                uwg.ActiveRow = uwg.Rows[0];
                uwg.ActiveRowScrollRegion.ScrollRowIntoView(uwg.ActiveRow);

                return true;
            }


            if (filterText == string.Empty)
            {
                MessageBox.Show("Missing value!");
                txtValue.Focus();
                return false;
            }
           


            fco = FilterComparisionOperator.StartsWith;
            switch (operatorText)
            {
                case "Contains":
                    fco = FilterComparisionOperator.Contains;
                    break;
                case "Ends With":
                    fco = FilterComparisionOperator.EndsWith;
                    break;
                case "Equals":
                    fco = FilterComparisionOperator.Equals;
                    break;
                case "Greater Than":
                    fco = FilterComparisionOperator.GreaterThan;
                    break;
                case "Greater Than Or Equal To":
                    fco = FilterComparisionOperator.GreaterThanOrEqualTo;
                    break;
                case "Less Than":
                    fco = FilterComparisionOperator.LessThan;
                    break;
                case "Less Than Or Equal To":
                    fco = FilterComparisionOperator.LessThanOrEqualTo;
                    break;
                case "Starts With":
                    fco = FilterComparisionOperator.StartsWith;
                    break;
            }

            if (radAnd.Checked)
            {
                band.ColumnFilters[columnIndex].LogicalOperator = FilterLogicalOperator.And;
                if (lbl.Text.Length > 0)
                    lbl.Text += "AND ";
            }
            else
            {
                band.ColumnFilters[columnIndex].LogicalOperator = FilterLogicalOperator.Or;
                if (lbl.Text.Length > 0)
                    lbl.Text += "OR   ";
            }

            if (filterText.ToLower() == "null")
            {
                band.ColumnFilters[columnIndex].FilterConditions.Add(fco, null);
                band.ColumnFilters[columnIndex].LogicalOperator = FilterLogicalOperator.Or;
                band.ColumnFilters[columnIndex].FilterConditions.Add(fco, string.Empty);
                lbl.Text += columnHeader + " is " + filterText + "\n";
            }
            else if (filterText.ToLower() == "not null")
            {
                band.ColumnFilters[columnIndex].FilterConditions.Add(FilterComparisionOperator.GreaterThan, string.Empty);
                lbl.Text += columnHeader + " is " + filterText + "\n";
            }
            else
            {
                band.ColumnFilters[columnIndex].FilterConditions.Add(fco, filterText);
                lbl.Text += columnHeader + " " + operatorText + " '" + filterText + "'\n";
            }
            lblOn.Text = "Filter On";

            uwg.ActiveRow = uwg.Rows[0];
            uwg.ActiveRowScrollRegion.ScrollRowIntoView(uwg.ActiveRow);

            udtDate.Value = null;
            radFalse.Checked = false;
            radTrue.Checked = false;
            radNull.Checked = false;
            radNotNull.Checked = false;
            txtValue.Text = "";
            txtValue.Focus();
            gbxAndOr.Visible = true;
            return true;
        }

        private void btnApply_Click(object sender, EventArgs e)
        {
            ApplyFilter();
        }

        private void btnClear_Click(object sender, EventArgs e)
        {
            UltraGridBand band = this.uwg.DisplayLayout.Bands[0];

            band.ColumnFilters.ClearAllFilters();
            lblOn.Text = "";
            lbl.Text = "";

            uwg.ActiveRow = uwg.Rows[0];
            uwg.ActiveRowScrollRegion.ScrollRowIntoView(uwg.ActiveRow);
            txtValue.Text = "";
            udtDate.Value = null;
            radFalse.Checked = false;
            radTrue.Checked = false;
            radNull.Checked = false;
            radNotNull.Checked = false;
            txtValue.Focus();
            gbxAndOr.Visible = false;
        }

        private void lstColumn_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (lstColumn.SelectedIndex == -1)
                return;

            UltraGridBand band = this.uwg.DisplayLayout.Bands[0];

            columnHeader = lstColumn.Text;
            int index = -1;

            for (int i = 0; i < band.Columns.Count; i++)
            {
                if (band.Columns[i].Hidden == false)
                {
                    if (columnHeader == band.Columns[i].Header.Caption)
                    {
                        index = i;
                        break;
                    }
                }
            }
            columnIndex = index;
            SetListValues();
            txtValue.Focus();
        }

        private void SetListValues()
        {
            if (columnIndex == -1)
                return;

            System.Collections.SortedList sl = new System.Collections.SortedList();
            clbValues.Items.Clear();
            string s = "";
            foreach (UltraGridRow ugr in uwg.Rows)
            {
                s = ugr.Cells[columnIndex].Text.ToString();
                if (s != "")
                {
                    if (!sl.ContainsValue(s))
                        sl.Add(s, s);
                }
            }
            foreach (System.Collections.DictionaryEntry de in sl) 
            {
                clbValues.Items.Add(de.Value.ToString());
            }
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void txtValue_Enter(object sender, EventArgs e)
        {
            this.txtValue.SelectAll();
        }

        private void udtDate_ValueChanged(object sender, EventArgs e)
        {
            if (udtDate.Value != null)
                txtValue.Text = Convert.ToDateTime(udtDate.Value).ToString("MM/dd/yyyy");
        }

        private void radTrue_Click(object sender, EventArgs e)
        {
            if (radTrue.Checked)
                txtValue.Text = "true";
            lstOperator.SelectedIndex = 2;
            txtValue.Focus();
        }

        private void radFalse_Click(object sender, EventArgs e)
        {
            if (radFalse.Checked)
            {
                txtValue.Text = "false";
                lstOperator.SelectedIndex = 2;
            }
            txtValue.Focus();
        }

        private void radNull_Click(object sender, EventArgs e)
        {
            if (radNull.Checked)
                txtValue.Text = "null";
            lstOperator.SelectedIndex = 2;
            txtValue.Focus();
        }

        private void radNotNull_Click(object sender, EventArgs e)
        {
            if (radNotNull.Checked)
                txtValue.Text = "not null";
            lstOperator.SelectedIndex = 2;
            txtValue.Focus();
        }

        private void txtValue_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Enter)
            {
                ApplyFilter();
                if (DialogResult == DialogResult.OK)
                    this.Close();
            }
            if (e.KeyCode == Keys.Escape)
            {
                this.Close();
            }
        }

        private void lstOperator_SelectedIndexChanged(object sender, EventArgs e)
        {
            txtValue.Focus();
        }

        private void clbValues_ItemCheck(object sender, ItemCheckEventArgs e)
        {
            lstOperator.SelectedIndex = 0;
            txtValue.Text = "";
        }
    }
}
