using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using System.Diagnostics;
using CCPM.Data;
using WrapColumn;
using System.Reflection;

namespace CCPM.Links
{
	/// <summary>
	/// Summary description for LinkList.
	/// </summary>
	public class LinkList : System.Windows.Forms.UserControl
	{
		private int projectId;
		private System.Windows.Forms.DataGrid dgLinks;
		private System.Windows.Forms.DataGridTableStyle dataGridTableStyle1;
		private System.Windows.Forms.DataGridTextBoxColumn colFilePath;
		private System.Windows.Forms.DataGridTextBoxColumn colDescription;
		private System.Windows.Forms.ContextMenu contextMenu1;
		private System.Windows.Forms.MenuItem miAddLink;
		private DataSet linkListDataSet = null;
		private System.Windows.Forms.MenuItem miEditDescription;
		private System.Windows.Forms.MenuItem menuItem1;
		private System.Windows.Forms.MenuItem miDeleteLink;
        private MenuItem miAddFolder;
        private Button btnAddLink;
        private Button btnDeleteLink;
        private Button btnEditLinkDesc;
        private Button btnAddFolderLink;
		/// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		public int ProjectId
		{
			get{return projectId;}
			set{projectId = value;}
		}

		public LinkList(int projectId)
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			ProjectId = projectId;
			BindList();
			this.Load +=new EventHandler(LinkList_Load);
			this.ContextMenu = contextMenu1;
		}

		private void BindList()
		{
			linkListDataSet = ResourceData.LinkList(ProjectId);
			dgLinks.DataSource = this.linkListDataSet;
			dgLinks.DataMember = "Table";
		}
		/// <summary>
		/// Set up the Open button column and a WrapColumn column for the 
		/// Description field. Then add those columns to the ColumnStyles colleciton.
		/// </summary>
		private void SetModifiedColumns()
		{
			DataGridButton.DataGridButtonColumn buttonColStyle = null;
			buttonColStyle = new DataGridButton.DataGridButtonColumn(0); //pass the column#
			
			buttonColStyle.HeaderText =  string.Empty;
			buttonColStyle.MappingName = "Open";
			buttonColStyle.Width = 80;
			

			//hookup cellbutton handler...
			buttonColStyle.CellButtonClicked += 
				new DataGridButton.DataGridCellButtonClickEventHandler(HandleOpenButtonClick);
			
			//Add a WrapColumn column
			DataGridTextBoxColumnWrap descriptionColumn = new DataGridTextBoxColumnWrap();
			descriptionColumn.HeaderText = "Description";
			descriptionColumn.MappingName = "Description";
			descriptionColumn.NullText = string.Empty;
			descriptionColumn.Width = 425;

			DataGridColumnStyle[] dgColumns = new DataGridColumnStyle[] {
																			buttonColStyle,
																			this.colFilePath,
																			descriptionColumn};
																		

			this.dataGridTableStyle1.GridColumnStyles.Clear();
			this.dataGridTableStyle1.GridColumnStyles.AddRange(dgColumns);

			//hook the mouse handlers
			dgLinks.MouseDown += new MouseEventHandler(buttonColStyle.HandleMouseDown);
			dgLinks.MouseUp += new MouseEventHandler(buttonColStyle.HandleMouseUp);

		}

		private void AutoSizeGrid() 
		{ 
			int numRows = linkListDataSet.Tables[0].Rows.Count; 

			Graphics g = Graphics.FromHwnd(dgLinks.Handle); 
 
			StringFormat sf = new StringFormat(StringFormat.GenericTypographic); 
			SizeF descriptionSize; //description field
 
			// Since DataGridRows[] is not exposed directly by the DataGrid 
			// we use reflection to hack into it.. There is actually 
			// a method get_DataGridRows that returns the collection of rows; 
			// that is what we are doing here, and casting it to a System.Array 
			MethodInfo mi = dgLinks.GetType().GetMethod("get_DataGridRows", 
				BindingFlags.FlattenHierarchy | BindingFlags.IgnoreCase | BindingFlags.Instance 
				| BindingFlags.NonPublic | BindingFlags.Public | BindingFlags.Static); 
 

			System.Array dgra = (System.Array)mi.Invoke(dgLinks,null); 
 
			// Convert this to an ArrayList, little bit easier to deal with 
			// that way, plus we can strip out the newrow row. 
			ArrayList DataGridRows = new ArrayList(); 
			foreach (object dgrr in dgra) 
			{ 
				if (dgrr.ToString().EndsWith("DataGridRelationshipRow")==true) 
					DataGridRows.Add(dgrr); 
			} 

			// Now loop through all the rows in the grid 
			for (int i = 0; i < numRows; ++i) 
			{ 
				// Here we are telling it that the column width is set to 
				// 425. so descriptionSize will contain the Height it needs to be. 
				descriptionSize = g.MeasureString(dgLinks[i,2].ToString(),dgLinks.Font,425,sf); 
				int h = Convert.ToInt32(descriptionSize.Height); 
				// Little extra cellpadding space 
				h = h + 8;
				h = h > 8 ? h : 22; //account for empty field
				// Now we pick that row out of the DataGridRows[] Array 
				// that we have and set it's Height property to what we  
				// think it should be. 
				PropertyInfo pi = DataGridRows[i].GetType().GetProperty("Height"); 
				pi.SetValue(DataGridRows[i],h,null); 
				// I have read here that after you set the Height in this manner that you should 
				// Call the DataGrid Invalidate() method, but I haven't seen any prob with not calling it.. 
			} 
			g.Dispose(); 
 
		} 
 
		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.dgLinks = new System.Windows.Forms.DataGrid();
            this.dataGridTableStyle1 = new System.Windows.Forms.DataGridTableStyle();
            this.colFilePath = new System.Windows.Forms.DataGridTextBoxColumn();
            this.colDescription = new System.Windows.Forms.DataGridTextBoxColumn();
            this.contextMenu1 = new System.Windows.Forms.ContextMenu();
            this.miAddLink = new System.Windows.Forms.MenuItem();
            this.miAddFolder = new System.Windows.Forms.MenuItem();
            this.miEditDescription = new System.Windows.Forms.MenuItem();
            this.menuItem1 = new System.Windows.Forms.MenuItem();
            this.miDeleteLink = new System.Windows.Forms.MenuItem();
            this.btnAddLink = new System.Windows.Forms.Button();
            this.btnDeleteLink = new System.Windows.Forms.Button();
            this.btnEditLinkDesc = new System.Windows.Forms.Button();
            this.btnAddFolderLink = new System.Windows.Forms.Button();
            ((System.ComponentModel.ISupportInitialize)(this.dgLinks)).BeginInit();
            this.SuspendLayout();
            // 
            // dgLinks
            // 
            this.dgLinks.AllowSorting = false;
            this.dgLinks.DataMember = "";
            this.dgLinks.HeaderForeColor = System.Drawing.SystemColors.ControlText;
            this.dgLinks.Location = new System.Drawing.Point(0, 0);
            this.dgLinks.Name = "dgLinks";
            this.dgLinks.ReadOnly = true;
            this.dgLinks.Size = new System.Drawing.Size(893, 408);
            this.dgLinks.TabIndex = 1;
            this.dgLinks.TableStyles.AddRange(new System.Windows.Forms.DataGridTableStyle[] {
            this.dataGridTableStyle1});
            // 
            // dataGridTableStyle1
            // 
            this.dataGridTableStyle1.DataGrid = this.dgLinks;
            this.dataGridTableStyle1.GridColumnStyles.AddRange(new System.Windows.Forms.DataGridColumnStyle[] {
            this.colFilePath,
            this.colDescription});
            this.dataGridTableStyle1.HeaderForeColor = System.Drawing.SystemColors.ControlText;
            this.dataGridTableStyle1.MappingName = "Table";
            // 
            // colFilePath
            // 
            this.colFilePath.Format = "";
            this.colFilePath.FormatInfo = null;
            this.colFilePath.HeaderText = "Link";
            this.colFilePath.MappingName = "FilePath";
            this.colFilePath.Width = 205;
            // 
            // colDescription
            // 
            this.colDescription.Format = "";
            this.colDescription.FormatInfo = null;
            this.colDescription.HeaderText = "Description";
            this.colDescription.MappingName = "Description";
            this.colDescription.Width = 425;
            // 
            // contextMenu1
            // 
            this.contextMenu1.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
            this.miAddLink,
            this.miAddFolder,
            this.miEditDescription,
            this.menuItem1,
            this.miDeleteLink});
            // 
            // miAddLink
            // 
            this.miAddLink.Index = 0;
            this.miAddLink.Text = "Add Link";
            this.miAddLink.Click += new System.EventHandler(this.miAddLink_Click);
            // 
            // miAddFolder
            // 
            this.miAddFolder.Index = 1;
            this.miAddFolder.Text = "Add Folder Link";
            this.miAddFolder.Click += new System.EventHandler(this.miAddFolder_Click);
            // 
            // miEditDescription
            // 
            this.miEditDescription.Index = 2;
            this.miEditDescription.Text = "Edit Link Description";
            this.miEditDescription.Click += new System.EventHandler(this.miEditDescription_Click);
            // 
            // menuItem1
            // 
            this.menuItem1.Index = 3;
            this.menuItem1.Text = "-";
            // 
            // miDeleteLink
            // 
            this.miDeleteLink.Index = 4;
            this.miDeleteLink.Text = "Delete Link";
            this.miDeleteLink.Click += new System.EventHandler(this.miDeleteLink_Click);
            // 
            // btnAddLink
            // 
            this.btnAddLink.Location = new System.Drawing.Point(12, 423);
            this.btnAddLink.Name = "btnAddLink";
            this.btnAddLink.Size = new System.Drawing.Size(86, 23);
            this.btnAddLink.TabIndex = 2;
            this.btnAddLink.Text = "Add Link";
            this.btnAddLink.UseVisualStyleBackColor = true;
            this.btnAddLink.Click += new System.EventHandler(this.btnAddLink_Click);
            // 
            // btnDeleteLink
            // 
            this.btnDeleteLink.Location = new System.Drawing.Point(430, 423);
            this.btnDeleteLink.Name = "btnDeleteLink";
            this.btnDeleteLink.Size = new System.Drawing.Size(102, 23);
            this.btnDeleteLink.TabIndex = 3;
            this.btnDeleteLink.Text = "Delete Link";
            this.btnDeleteLink.UseVisualStyleBackColor = true;
            this.btnDeleteLink.Click += new System.EventHandler(this.btnDeleteLink_Click);
            // 
            // btnEditLinkDesc
            // 
            this.btnEditLinkDesc.Location = new System.Drawing.Point(256, 423);
            this.btnEditLinkDesc.Name = "btnEditLinkDesc";
            this.btnEditLinkDesc.Size = new System.Drawing.Size(156, 23);
            this.btnEditLinkDesc.TabIndex = 4;
            this.btnEditLinkDesc.Text = "Edit Link Description";
            this.btnEditLinkDesc.UseVisualStyleBackColor = true;
            this.btnEditLinkDesc.Click += new System.EventHandler(this.btnEditLinkDesc_Click);
            // 
            // btnAddFolderLink
            // 
            this.btnAddFolderLink.Location = new System.Drawing.Point(116, 423);
            this.btnAddFolderLink.Name = "btnAddFolderLink";
            this.btnAddFolderLink.Size = new System.Drawing.Size(121, 23);
            this.btnAddFolderLink.TabIndex = 5;
            this.btnAddFolderLink.Text = "Add Folder Link";
            this.btnAddFolderLink.UseVisualStyleBackColor = true;
            this.btnAddFolderLink.Click += new System.EventHandler(this.btnAddFolderLink_Click);
            // 
            // LinkList
            // 
            this.Controls.Add(this.btnAddFolderLink);
            this.Controls.Add(this.btnEditLinkDesc);
            this.Controls.Add(this.btnDeleteLink);
            this.Controls.Add(this.btnAddLink);
            this.Controls.Add(this.dgLinks);
            this.Name = "LinkList";
            this.Size = new System.Drawing.Size(951, 528);
            ((System.ComponentModel.ISupportInitialize)(this.dgLinks)).EndInit();
            this.ResumeLayout(false);

		}
		#endregion

		private void LinkList_Load(object sender, EventArgs e)
		{
			//SetOpenButtonColumn();
			//
			//SetGridWrapColumn();
			SetModifiedColumns();
			AutoSizeGrid();
		}
		
		private void HandleOpenButtonClick(object sender, DataGridButton.DataGridCellButtonClickEventArgs e)
		{
			DataRow dr = linkListDataSet.Tables[0].Rows[e.RowIndex];
			string filePath = dr["FilePath"].ToString();
//			if(filePath.IndexOf(":") > 1)// item is a Web resource

			try
			{
				Process.Start(filePath);
			}
			catch(Exception ex)
			{
				MessageBox.Show(string.Concat("An error occurred while processing the request! \nError message: ", ex.Message));
			}
				
		}

		public void miAddLink_Click(object sender, System.EventArgs e)
		{
			AddLink addLink = new AddLink(ProjectId);
            addLink.StartPosition = FormStartPosition.CenterParent;
			DialogResult dialogResult = addLink.ShowDialog(this);
			if(dialogResult == DialogResult.OK)
			{
				BindList();
			}
		}

		public void miEditDescription_Click(object sender, System.EventArgs e)
		{
			if(linkListDataSet.Tables[0].Rows.Count < 1) return;
			DataRow dr = this.linkListDataSet.Tables[0].Rows[dgLinks.CurrentRowIndex];
			string fileName = dr["FilePath"].ToString();
			string description = dr["Description"].ToString();
			int linkId = (int)dr["LinkId"];
            EditLinkDescription el = new EditLinkDescription(linkId, fileName, description);
            el.StartPosition = FormStartPosition.CenterParent;
			if(DialogResult.OK == el.ShowDialog(this))
			{
				this.BindList();
			}

		}

		public void miDeleteLink_Click(object sender, System.EventArgs e)
		{
			if(dgLinks.CurrentRowIndex == -1) return;
			DataRow dr = this.linkListDataSet.Tables[0].Rows[dgLinks.CurrentRowIndex];
			int linkId = (int)dr["LinkId"];

			if(DialogResult.OK == MessageBox.Show("You are about to delete a link! Are you sure you want to do this?", "Delete Link Confirmation", MessageBoxButtons.OKCancel, MessageBoxIcon.Stop))
			{
				ResourceData.LinkDelete(linkId);
				this.BindList();
			}
		}

        private void miAddFolder_Click(object sender, EventArgs e)
        {
            AddLink addLink = new AddLink(ProjectId, true);
            addLink.StartPosition = FormStartPosition.CenterParent;
            DialogResult dialogResult = addLink.ShowDialog(this);
            if (dialogResult == DialogResult.OK)
            {
                BindList();
            }
        }

        private void btnAddLink_Click(object sender, EventArgs e)
        {
            AddLink addLink = new AddLink(ProjectId);
            addLink.StartPosition = FormStartPosition.CenterParent;
            DialogResult dialogResult = addLink.ShowDialog(this);
            if (dialogResult == DialogResult.OK)
            {
                BindList();
            }
        }

        private void btnAddFolderLink_Click(object sender, EventArgs e)
        {
            AddLink addLink = new AddLink(ProjectId, true);
            addLink.StartPosition = FormStartPosition.CenterParent;
            DialogResult dialogResult = addLink.ShowDialog(this);
            if (dialogResult == DialogResult.OK)
            {
                BindList();
            }
        }

        private void btnEditLinkDesc_Click(object sender, EventArgs e)
        {
            if (linkListDataSet.Tables[0].Rows.Count < 1) return;
            DataRow dr = this.linkListDataSet.Tables[0].Rows[dgLinks.CurrentRowIndex];
            string fileName = dr["FilePath"].ToString();
            string description = dr["Description"].ToString();
            int linkId = (int)dr["LinkId"];
            EditLinkDescription el = new EditLinkDescription(linkId, fileName, description);
            el.StartPosition = FormStartPosition.CenterParent;
            if (DialogResult.OK == el.ShowDialog(this))
            {
                this.BindList();
            }
        }

        private void btnDeleteLink_Click(object sender, EventArgs e)
        {
            if (dgLinks.CurrentRowIndex == -1) return;
            DataRow dr = this.linkListDataSet.Tables[0].Rows[dgLinks.CurrentRowIndex];
            int linkId = (int)dr["LinkId"];

            if (DialogResult.OK == MessageBox.Show("You are about to delete a link! Are you sure you want to do this?", "Delete Link Confirmation", MessageBoxButtons.OKCancel, MessageBoxIcon.Stop))
            {
                ResourceData.LinkDelete(linkId);
                this.BindList();
            }
        }

	}
}
