USE [CCPM]
GO
/************************************************************************************************/
/***** Issue 2.62        add/update Contract Project Manager				    *****/
/***** 		  spls	introduced: ProjectContractsManagerSelect, 			    *****/
/***** 				    ProjectContractsManagerUpdate			    *****/
/***** 				  						     	    *****/
/***** Issue 2.52        QueryTool: add funding Item to the list for view vwContract1	    *****/
/***** 				  						     	    *****/
/***** Issue 2.54        QueryTool: change funding Item to display Fiscal year 		    *****/
/***** 			            in Contract Fund View (vwContract2)  		    *****/
/***** 				  						     	    *****/
/***** Issue 2.56        QueryTool: add fund Number to ProjectAll,   			    *****/
/***** 			            ProjectAll(not concatenated),	      		    *****/
/***** 			            ContractFund (vwContract2)	,	      		    *****/
/***** 			            ContractTotal			      		    *****/
/***** 											    *****/
/************************************************************************************************/


/************************************************************************************************/
/***** Issue 2.62        add/update Contract Project Manager				    *****/
/************************************************************************************************/


GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE  PROCEDURE [dbo].[ProjectContractsManagerSelect]
@ProjectId int
AS
BEGIN
	SELECT cd.ContractId, cd.ProjectManagerId, 0 as IsUpdate,
		ProjectManagerName = (select ps.[NAME] FROM ProjectStaff ps WHERE ps.ProjectManagerId = cd.ProjectManagerId) , 
		cd.ContractNumber, cs.StatusCode,  
		dbo.usfContractTotals(cd.ContractId, 'IB') AS ContractBalance, cast(0 as bit) as DirtyFlag
	FROM contractdetails cd 
	LEFT OUTER JOIN ContractStatus cs ON cd.ContractStatusId = cs.ContractStatusId 
	WHERE cd.ProjectId = @ProjectId
	ORDER BY (select ps.[NAME] FROM ProjectStaff ps WHERE ps.ProjectManagerId = cd.ProjectManagerId);

	 IF (@@error!=0)
		BEGIN
			RAISERROR  20002 'ProjectContractsManagerSelect: An error occurred '
			RETURN(1)    
		END
END

GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE PROCEDURE [dbo].[ProjectContractsManagerUpdate]
@ProjectManagerId int,
@ContractList nvarchar (1000)
AS
BEGIN 

	DECLARE @STR nvarchar (1000);

	SET @STR = 
	' UPDATE [ContractDetails]' +
	' SET [ProjectManagerId] = ' + CAST(@ProjectManagerId as varchar) +
	' WHERE ContractId IN ' +  '( ' + @ContractList + ' )'; 

	EXEC (@STR);

    IF (@@error!=0)
    BEGIN
        RAISERROR  20001 'ProjectContractsManagerUpdate: Update failed '
        RETURN(1)
    
    END
END 


/************************************************************************************************/
/***** Issue 2.52        QueryTool: add funding Item to the list for view vwContract1	    *****/
/***** Issue 2.56        QueryTool: add fund Number to Contract Total for view vwContract1  *****/
/************************************************************************************************/
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
/* =============================================
-- Description:	Returns comma delimited list of contract funding items
-- Test:		select dbo.usfContractFundingItems(319) 
-- =============================================
*/
CREATE FUNCTION [dbo].[usfContractFundingItems] 
(
	@ContractId int
)
RETURNS varchar(8000)
AS
BEGIN
	DECLARE @ResultVar varchar(8000)

	SET @ResultVar = ''

	declare  @t table (yr varchar(100)) 
	insert	@t (yr)
		SELECT DISTINCT dbo.usfFundingItem1(cf.FundID)
		FROM	ContractFunds cf
		LEFT JOIN ContractDetails cd on cd.ContractId = cf.ContractId
		WHERE	cd.ContractId = @ContractId
		ORDER BY dbo.usfFundingItem1(cf.FundID)

	SELECT @ResultVar = @ResultVar + yr + ', ' from @t

	IF (datalength(@ResultVar) > 2)
		SET @ResultVar = left(@ResultVar, datalength(@ResultVar) - 2)

	If (@ResultVar = '')
		SET @ResultVar = null

	RETURN @ResultVar

END
------------------------------2.56 Prereq --------------------

GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
/* =============================================
-- Description:	Returns comma delimited list of contract funding items
-- Test:		select dbo.usfContractFundNumber(319) 
-- =============================================
*/
CREATE FUNCTION [dbo].[usfContractFundNumbers] 
(
	@ContractId int
)
RETURNS varchar(8000)
AS
BEGIN
	DECLARE @ResultVar varchar(8000)

	SET @ResultVar = ''

	declare  @t table (c1 varchar(100)) 
	insert	@t (c1)
		SELECT DISTINCT fs.FundNumber
		FROM	ContractFunds cf
		LEFT JOIN ContractDetails cd on cd.ContractId = cf.ContractId
		LEFT JOIN FundingSource fs on fs.FundID = cf.FundID
		WHERE	cd.ContractId = @ContractId
		AND fs.Source is not null
		ORDER BY fs.FundNumber

	SELECT @ResultVar = @ResultVar + c1 + ', ' from @t

	IF (datalength(@ResultVar) > 2)
		SET @ResultVar = left(@ResultVar, datalength(@ResultVar) - 2)

	If (@ResultVar = '')
		SET @ResultVar = null

	RETURN @ResultVar

END
------------------------------ 2.52, 2.56 -------------------------


GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
-- select top 100 * from vwContract1
ALTER VIEW [dbo].[vwContract1]
AS
select Project.ProjectId
,	Project.FileNumber as Project_Number
,	Project.ProjectName as Project_Name
,	ProjectStatus.Status as Project_Status

,	ContractDetails.ContractId
,	ContractDetails.ContractNumber as Contract_Number
,	Organization.Organization as Grantee_or_Contractor
,	ContractDetails.ContractedAmount as Contracted_Amount
,	dbo.usfContractTotals(ContractDetails.ContractId , 'C') as Contracted_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'D') as Disencumbered_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'I') as Invoice_Gross_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'IA') as Invoice_Approved_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'IP') as Invoice_Paid_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'IW') as Invoice_Withholding_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'A') as Amendment_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'EU') as Unspent_Total

,	ContractStatus.StatusCode as Contract_Status
,	ContractType.TypeCode as Contract_Type
,	dbo.usfContractFundingItems(ContractDetails.ContractId) as Funding_Item
,   dbo.usfContractFundNumbers(ContractDetails.ContractId) as Fund_Number
,	ContractDetails.AreContractsConditionMet as Are_Contracts_Condition_Met
,	ContractDetails.IsMonitoringRequired as Is_Monitoring_Required
,	ContractDetails.IsRepaymentRequired as Is_Repayment_Required
,	ContractDetails.ExecutedDate as Executed_Date
,	ContractDetails.CompletedDate as Completed_Date
,	ContractDetails.TerminationDate as Termination_Date
,	ContractDetails.ClosedDate as Closed_Date
,	ContractDetails.Purpose
,	ContractDetails.BoxNumber as Box_Number
,	ContractDetails.ClosingRemarks as Closing_Remarks
,	ContractDetails.County
,	ProjectStaff.[Name] as Project_Contract_Manager
,	dbo.usfContractExpirationAlert(ContractDetails.ContractId) as Expiration_Alert
,	dbo.usfContractLiquidationAlert(ContractDetails.ContractId, null) as Liquidation_Alert

,	Contact.ContactFName as Contact_First_Name
,	Contact.ContactLName as Contact_Last_Name
,	OrgAddress.Address
,	OrgAddress.City   
,	OrgAddress.State
,	OrgAddress.Zip
,	Contact.ContactEmail as Contact_Email
,	Contact.ContactPhone as Contact_Phone
,	Contact.ContactFax as Contact_Fax

from	Project
inner join ProjectStatus on ProjectStatus.StatusId = Project.StatusId
inner join ContractDetails on ContractDetails.ProjectId = Project.ProjectId
left outer join Organization on Organization.OrgId = ContractDetails.GranteeId
left join ContractStatus on ContractStatus.ContractStatusId = ContractDetails.ContractStatusId
left join ContractType on ContractType.ContractTypeId = ContractDetails.ContractTypeId
left outer join ProjectStaff on ProjectStaff.ProjectManagerId = ContractDetails.ProjectManagerId
left outer join Contact on Contact.ContactId = ContractDetails.ContactPersonId
left outer join OrgAddress on OrgAddress.OrgAddressId = ContractDetails.OrgAddressId



/************************************************************************************************/
/***** Issue 2.56        QueryTool: add fund Number to ProjectAll   			    *****/
/************************************************************************************************/
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
-- select top 100 * from vwProjectAll
ALTER VIEW [dbo].[vwProjectAll]
AS

select Project.ProjectId
,	Project.FileNumber as Project_Number
,	Project.ProjectName as Project_Name
,	ProjectStatus.Status as Project_Status
,	Project.Summary as Project_Summary
,	Project.Description
,	Project.Latitude
,	Project.Longitude
,	Project.LocationDescription as Coordinates_Represent
,	Project.Acreage
,	Project.SquareMiles as Square_Miles
,	Project.TrailMiles as Non_CCT_Trail_Miles
,	Project.CCTmiles as CCT_Trail_Miles
,	Project.TrailLinearFeet as Trail_Linear_Feet
,	Project.StreamMiles as Stream_Miles
,	Project.StreamLinearFeet as Stream_Linear_Feet
,	Project.ProjectNotes as Project_Notes
,	Project.APNNumber as APN_Number
,	ProjectStaff.[Name] as Project_Manager_Primary

--,	dbo.usfProjectProjectManagerNames(Project.ProjectId) as ProjectManagers
,	dbo.usfProjectContractManagerNames(Project.ProjectId) as Project_Contract_Managers
,	dbo.usfProjectCountyNames(Project.ProjectId) as Counties
,	dbo.usfProjectRegionNames(Project.ProjectId) as Regions
,	dbo.usfProjectProjectTypes(Project.ProjectId) as Project_Types
,	dbo.usfProjectProgramTypes(Project.ProjectId) as Program_Types
,	dbo.usfProjectAssemblyDistricts(Project.ProjectId) as Assembly_Districts
,	dbo.usfProjectSenateDistricts(Project.ProjectId) as Senate_Districts
,	dbo.usfProjectCongressionalDistricts(Project.ProjectId) as Congressional_Districts
,	dbo.usfProjectContractNumbers(Project.ProjectId) as Contract_Numbers
,	dbo.usfProjectAuthorizationDates(Project.ProjectId) as Authorization_Dates
,	dbo.usfProjectAuthorizationTypes(Project.ProjectId) as Authorization_Types
,	dbo.usfProjectFundingSources(Project.ProjectId) as Funding_Sources_Short
,	dbo.usfProjectFundNumbers(Project.ProjectId) as Fund_Numbers
,	dbo.usfProjectFiscalYears(Project.ProjectId) as Fiscal_Years
,	dbo.usfProjectFundingItems(Project.ProjectId) as Funding_Items
,	dbo.usfProjectGrantees(Project.ProjectId) as Grantee_Contractors
,	dbo.usfProjectObjectiveNumbers(Project.ProjectId) as Strategic_Objective_Numbers
,	dbo.usfProjectObjectiveMeasurements(Project.ProjectId) as Strategic_Objective_Measurements
,	dbo.usfProjectFundLiquidDates(Project.ProjectId) as Liquidation_Dates


,	dbo.usfProjectTotals(Project.ProjectId, 'A') as Authorized_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'R') as Reserved_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'M') as Matching_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'G') as Reimburse_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'N') as Conservancy_Net_Amount
,	dbo.usfProjectTotals(Project.ProjectId, 'P') as Project_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'E') as Encumbered_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'EU') as Encumbered_Unspent_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'U') as Unencumbered_Total

from	Project
left outer join ProjectStatus on ProjectStatus.StatusId = Project.StatusId
left outer join ProjectStaff on ProjectStaff.ProjectManagerId = Project.CurrentPM

/************************************************************************************************/
/***** Issue 2.56        QueryTool: add fund Number to ProjectAll(not concatenated)	    *****/
/************************************************************************************************/

GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
ALTER VIEW [dbo].[vwProjectAll2]
AS
/*
**	Desc:	view of project, many joined tables, totals per project
**			used by Query Tool
**	By:		Bob Freeman, 3/28/2009  
**	Test	select top 100 * from vwProjectAll2 where ProjectId < 100 order by Project_Number
*/

select Project.ProjectId
,	Project.FileNumber as Project_Number
,	Project.ProjectName as Project_Name
,	ProjectStatus.Status as Project_Status
,	Project.Summary as Project_Summary
,	Project.Description
,	Project.Latitude
,	Project.Longitude
,	Project.LocationDescription as Coordinates_Represent
,	Project.Acreage
,	Project.SquareMiles as Square_Miles
,	Project.TrailMiles as Non_CCT_Trail_Miles
,	Project.CCTmiles as CCT_Trail_Miles
,	Project.TrailLinearFeet as Trail_Linear_Feet
,	Project.StreamMiles as Stream_Miles
,	Project.StreamLinearFeet as Stream_Linear_Feet
,	Project.ProjectNotes as Project_Notes
,	Project.APNNumber as APN_Number
,	ProjectStaff.[Name] as Project_Manager_Primary
,	ps2.[Name] as Project_Contract_Manager
,	ProjectCounty.[CountyName] as County
,	ProjectRegion.Region
,	ProjectType.ProjectType as Project_Type
,	ProjectProgramType.ProgramType as Program_Type
,	ProjectAssemblyDistrict.AssemblyDistrictNumber as Assembly_District
,	ProjectStateSenateDistrict.StateSenateDistrictNumber as Senate_District
,	ProjectCongressionalDistrict.CongressionalDistrictNumber as Congressional_District
,	ContractDetails.ContractNumber as Contract_Number
,	AuthorizationDetail.AuthorizationDate as Authorization_Date
,	AuthorizationType.AuthorizationType as Authorization_Type
,	FundingSource.FundNumber as Fund_Numbers
,	FundingSource.Source as Funding_Source
,	FiscalYear.Years as Fiscal_Year
,	dbo.usfFundingItem2(ReservEncumb.FundID) as Funding_Item
,	Organization.Organization as Grantee_Contractor
,	ProjectObjective.ObjectiveNumber as Strategic_Objective_Number
,	isnull(convert(varchar(20), Project_ProjectObjective.NumberOfUnits), '') + ' '
		+ isnull(ProjectObjective.UnitOfMeasurement, '')  as Strategic_Objective_Measurement
,	FundingSource.LiquidDate as Liquidation_Date

,	dbo.usfProjectTotals(Project.ProjectId, 'A') as Authorized_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'R') as Reserved_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'M') as Matching_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'G') as Reimburse_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'N') as Conservancy_Net_Amount
,	dbo.usfProjectTotals(Project.ProjectId, 'P') as Project_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'E') as Encumbered_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'EU') as Encumbered_Unspent_Total
,	dbo.usfProjectTotals(Project.ProjectId, 'U') as Unencumbered_Total

from	Project
left outer join ProjectStatus on ProjectStatus.StatusId = Project.StatusId
left outer join ProjectStaff on ProjectStaff.ProjectManagerId = Project.CurrentPM
left outer join ContractDetails on ContractDetails.ProjectId = Project.ProjectId
left outer join ProjectStaff ps2 on ps2.ProjectManagerId = ContractDetails.ProjectManagerId
left outer join Project_ProjectCounty on Project_ProjectCounty.ProjectId = Project.ProjectId
		left outer join ProjectCounty on ProjectCounty.CountyId = Project_ProjectCounty.ProjectCountyId 
left outer join Project_ProjectRegion on Project_ProjectRegion.ProjectId = Project.ProjectId
		left outer join ProjectRegion on ProjectRegion.RegionId = Project_ProjectRegion.ProjectRegionId
left outer join Project_ProjectType on Project_ProjectType.ProjectId = Project.ProjectId
		left join ProjectType on ProjectType.ProjectTypeId = Project_ProjectType.ProjectTypeId
left outer join Project_ProjectProgramType on Project_ProjectProgramType.ProjectId = Project.ProjectId
		left outer join ProjectProgramType on ProjectProgramType.ProgramTypeId = Project_ProjectProgramType.ProjectProgramTypeId
left outer join Project_AssemblyDistrict on Project_AssemblyDistrict.ProjectId = Project.ProjectId
		left outer join ProjectAssemblyDistrict on ProjectAssemblyDistrict.AssemblyDistrictId = Project_AssemblyDistrict.AssemblyDistrictId
left outer join Project_SenateDistrict on Project_SenateDistrict.ProjectId = Project.ProjectId
		left outer join ProjectStateSenateDistrict on ProjectStateSenateDistrict.StateSenateDistrictId = Project_SenateDistrict.SenateDistrictId
left outer join Project_CongressionalDistrict on Project_CongressionalDistrict.ProjectId = Project.ProjectId
		left outer join ProjectCongressionalDistrict on ProjectCongressionalDistrict.CongressionalDistrictId = Project_CongressionalDistrict.CongressionalDistrictId
left outer join AuthorizationDetail on AuthorizationDetail.ProjectId = Project.ProjectId
		left outer join AuthorizationType on AuthorizationType.AuthorizationTypeId = AuthorizationDetail.AuthorizationTypeId
		left outer join ReservEncumb on AuthorizationDetail.AuthorizationId = ReservEncumb.AuthorizationId
			left outer join FundingSource on FundingSource.FundId = ReservEncumb.FundId
				left outer join FiscalYear on FiscalYear.FiscalYearId = FundingSource.FiscalYearId
left outer join Org_ProjectRole on Org_ProjectRole.ProjectId = Project.ProjectId
		left outer join Organization on Organization.OrgID = Org_ProjectRole.OrgID and Org_ProjectRole.ProjectRoleId = 1
left outer join Project_ProjectObjective on Project_ProjectObjective.ProjectId = Project.ProjectId
		left outer join ProjectObjective on ProjectObjective.ObjectiveID =  Project_ProjectObjective.ObjectiveID


/************************************************************************************************/
/***** Issue 2.54        QueryTool: change funding Item to display Fiscal year 		    *****/
/***** Issue 2.56        QueryTool: add fund Number to ContractFund			    *****/
/************************************************************************************************/
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE FUNCTION [dbo].[usfFundNumber]
	(
	@FundID int = null
)
RETURNS varchar(100) AS
BEGIN
	DECLARE @retVal varchar(50)

	SET @retVal = 
         (SELECT 
			 FundNumber
        FROM FundingSource 
        WHERE FundID = @FundID) 
         
	RETURN @retVal

END
/**************************************/
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
ALTER VIEW [dbo].[vwContract2]
AS
/*
**	Desc:	view of project contracts and contract funds
**			used by Query Tool
**	By:		Bob Freeman, 3/28/2009  
**	Test	select top 100 * from vwContract2
*/

select Project.ProjectId
,	Project.FileNumber as Project_Number
,	Project.ProjectName as Project_Name
,	ProjectStatus.Status as Project_Status

,	ContractDetails.ContractId
,	ContractDetails.ContractNumber as Contract_Number
,	Organization.Organization as Grantee_or_Contractor
,	ContractDetails.ContractedAmount as Contracted_Amount
,	dbo.usfContractTotals(ContractDetails.ContractId , 'C') as Contracted_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'D') as Disencumbered_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'I') as Invoice_Gross_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'IA') as Invoice_Approved_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'IP') as Invoice_Paid_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'IW') as Invoice_Withholding_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'A') as Amendment_Total
,	dbo.usfContractTotals(ContractDetails.ContractId , 'EU') as Unspent_Total

,	ContractStatus.StatusCode as Contract_Status
,	ContractType.TypeCode as Contract_Type

,   	dbo.usfFundNumber(ContractFunds.FundID) as Fund_Number
,	dbo.usfFundingItem1(ContractFunds.FundID) as Funding_Item
,	ContractFunds.ContractedAmount as Fund_Contracted_Amount
,	ContractFunds.DisencumberAmount as Fund_Disencumber_Amount
,	dbo.usfContractFundTotals(ContractFunds.ContractId, ContractFunds.FundId, 'I') as Fund_Invoice_Gross
,	dbo.usfContractFundTotals(ContractFunds.ContractId, ContractFunds.FundId, 'IA') as Fund_Invoice_Approved
,	dbo.usfContractFundTotals(ContractFunds.ContractId, ContractFunds.FundId, 'P') as Fund_Invoice_Paid
,	dbo.usfContractFundTotals(ContractFunds.ContractId, ContractFunds.FundId, 'W') as Fund_Invoice_Withholding
,	dbo.usfContractFundTotals(ContractFunds.ContractId, ContractFunds.FundId, 'B') as Fund_Balance

,	ContractDetails.AreContractsConditionMet as Are_Contracts_Condition_Met
,	ContractDetails.IsMonitoringRequired as Is_Monitoring_Required
,	ContractDetails.IsRepaymentRequired as Is_Repayment_Required
,	ContractDetails.ExecutedDate as Executed_Date
,	ContractDetails.CompletedDate as Completed_Date
,	ContractDetails.TerminationDate as Termination_Date
,	ContractDetails.ClosedDate as Closed_Date
,	ContractDetails.Purpose
,	ContractDetails.BoxNumber as Box_Number
,	ContractDetails.ClosingRemarks as Closing_Remarks
,	ContractDetails.County
,	ProjectStaff.[Name] as Project_Contract_Manager
,	dbo.usfContractExpirationAlert(ContractFunds.ContractId) as Expiration_Alert
,	dbo.usfContractLiquidationAlert(ContractFunds.ContractId, ContractFunds.FundId) as Liquidation_Alert

,	Contact.ContactFName as Contact_First_Name
,	Contact.ContactLName as Contact_Last_Name
,	OrgAddress.Address
,	OrgAddress.City   
,	OrgAddress.State
,	OrgAddress.Zip
,	Contact.ContactEmail as Contact_Email
,	Contact.ContactPhone as Contact_Phone
,	Contact.ContactFax as Contact_Fax

from	Project
inner join ProjectStatus on ProjectStatus.StatusId = Project.StatusId
inner join ContractDetails on ContractDetails.ProjectId = Project.ProjectId
left outer join Organization on Organization.OrgId = ContractDetails.GranteeId
left join ContractStatus on ContractStatus.ContractStatusId = ContractDetails.ContractStatusId
left join ContractType on ContractType.ContractTypeId = ContractDetails.ContractTypeId
left outer join ProjectStaff on ProjectStaff.ProjectManagerId = ContractDetails.ProjectManagerId
left outer join ContractFunds on ContractFunds.ContractId = ContractDetails.ContractId
left outer join Contact on Contact.ContactId = ContractDetails.ContactPersonId
left outer join OrgAddress on OrgAddress.OrgAddressId = ContractDetails.OrgAddressId


/************************************************************************************************/
/************************************************************************************************/
