
/************************************************************************************************/
/***** 				  						     						*****/
/***** Issue 2.8   Reassigns invoices to a different fuding source	    *****/
/***** 				  						     						*****/
/***** Issue 2.14  Runs an update statement on all disencumber amounts for current data	*****/
/*****																					*****/
/***** 				  						     						                    *****/
/***** Issue 2.19  Added alert to sendallalerts	- AlertReservedNotEncumberedFunds           *****/
/*****																					    *****/
/***** 				  						     						                    *****/
/***** Issue 2.63  Added new Procedure ProjectPrimaryPMUpdate to update the primary project manager           *****/
/*****																					    *****/
/************************************************************************************************/
/***** Issue 2.8         Reassigns invoices to a different fuding source                     ****/
/************************************************************************************************/

CREATE PROCEDURE [dbo].[ContractFundInvoicesReassigned]
(
	@ContractId		int,
	@OriginalFundId	int,
	@NewFundId		int
)
	
AS
BEGIN

	DECLARE @augmentDisencumbered money

	-- reassigns all Invoices and Payments to the new Funding Source
			BEGIN TRAN
				DECLARE @errNum int, @retVal int
			
				UPDATE Invoice
				SET FundId = @NewFundId
				WHERE ContractID = @ContractId AND
					  FundID = @OriginalFundId
			
				--now we need to update the disencumbered amount to reflect the new invoice assignments
				--set ContractFunds DisencumberAmount = ContractedAmount when invoice is disencumber
				SET @augmentDisencumbered = 0
				
				select @augmentDisencumbered = SUM(COALESCE(Invoice.DisencumberAugment, 0) ) from Invoice where	ContractId = @ContractId and FundId = @NewFundId and disencumberAugment < 0

				IF (@augmentDisencumbered < 0)		
				BEGIN		
					UPDATE	ContractFunds
					SET		DisencumberAmount = @augmentDisencumbered
					WHERE	ContractId = @ContractId and FundId = @NewFundId
				END

				IF (@@error!=0)
				BEGIN
					RAISERROR  20001 'ContractFundInvoicePaymentsUpdate: Update failed '
					ROLLBACK TRAN
					RETURN(1)
			    
				END

    COMMIT TRAN
    SELECT @retVal as retVal
END


/************************************************************************************************/
/***** Issue 2.14         Updates disencumber amount for all contracts                       ****/
/***** Written by Richard DesLonde															 ****/
/************************************************************************************************/

UPDATE ContractFunds
SET DisencumberAmount = id.DisencumberAmount
FROM
	ContractFunds cf JOIN
	
	(SELECT ContractID, FundID, SUM(isNULL(Invoice.DisencumberAugment, 0)) AS DisencumberAmount 
	 FROM Invoice
	 WHERE disencumberAugment < 0
	 GROUP BY ContractID, FundID) id ON cf.ContractID = id.ContractID AND cf.FundID = id.FundID



/************************************************************************************************/
/***** Issue 2.19         Added alert for reserved not encumbered funds - AlertReservedNotEncumberedFunds   ****/
/***** Written by Richard DesLonde															 ****/
/************************************************************************************************/


ALTER PROCEDURE [dbo].[SendEmailAlerts]
(
	@AsOfDate datetime = null
,	@Alert varchar(30) = null
)	
AS
/*
**	Desc:		send email alert batch
**	By:			Bob Freeman, 1/21/2009
**	Test:		exec SendEmailAlerts @AsOfDate = '9/22/2008'
**				select dateadd(d, -30, '10/22/2008'), dateadd(d, -91, '10/22/2008')
*/
begin

declare	@msg varchar(max)
declare	@t table (msg varchar(1000))

if	(@AsOfDate is null)
	set	@AsOfDate = getdate()

set	@msg = 'Email Alerts as of ' + convert(varchar(10), @AsOfDate, 101) + char(13) + char(13)

if	(@Alert is null or @Alert = 'All')
	begin
	insert @t (msg)
		exec AlertContractCompletion @AsOfDate = @AsOfDate

	insert @t (msg)
		exec AlertContractLiquidation @AsOfDate = @AsOfDate

	insert @t (msg)
		exec AlertContractTermination @AsOfDate = @AsOfDate

	insert @t (msg)
		exec AlertContractMonitor @AsOfDate = @AsOfDate

	insert @t (msg)
		exec AlertPaymentDue @AsOfDate = @AsOfDate

	insert @t (msg)
		exec AlertPaymentOverDue @AsOfDate = @AsOfDate

	insert @t (msg)
		exec AlertReservedNotEncumberedFunds @AsOfDate = @AsOfDate

	end
else
	begin
	if	(@Alert = 'AlertContractCompletion')
		insert @t (msg) exec AlertContractCompletion @AsOfDate = @AsOfDate
	if	(@Alert = 'AlertContractLiquidation')
		insert @t (msg)	exec AlertContractLiquidation @AsOfDate = @AsOfDate
	if	(@Alert = 'AlertContractTermination')
		insert @t (msg)	exec AlertContractTermination @AsOfDate = @AsOfDate
	if	(@Alert = 'AlertContractMonitor')
		insert @t (msg)	exec AlertContractMonitor @AsOfDate = @AsOfDate
	if	(@Alert = 'AlertPaymentDue')
		insert @t (msg)	exec AlertPaymentDue @AsOfDate = @AsOfDate
	if	(@Alert = 'AlertPaymentOverDue')
		insert @t (msg)	exec AlertPaymentOverDue @AsOfDate = @AsOfDate
	if	(@Alert = 'AlertReservedNotEncumbered')
		insert @t (msg)	exec AlertReservedNotEncumberedFunds @AsOfDate = @AsOfDate

	end

select @msg = @msg + msg from @t


	EXEC msdb.dbo.sp_send_dbmail
		  @profile_name = 'CCPM3'
		, @recipients = 'kgoodnight@scc.ca.gov;bfreeman@kieferconsulting.com'
		, @subject = 'Coastal SendEmailAlerts'
		, @body = @msg


select @msg as msg

end


/************************************************************************************************/
/***** Issue 2.63        Added Procedure  ProjectPrimaryPMUpdate for updating primary PM     ****/
/***** Written by Richard DesLonde															 ****/
/************************************************************************************************/


CREATE      PROCEDURE [dbo].[ProjectPrimaryPMUpdate]
@CurrentPM int,
@ProjectId int
AS
begin
	--first make sure the PM is in the list of PMs on the project
	DECLARE @countCurrentPM int
	SELECT @countCurrentPM = count(*) FROM Project_ProjectManager WHERE ProjectId = @ProjectId AND ProjectManagerID = @CurrentPM

	IF(@countCurrentPM = 0)
	BEGIN
		INSERT Project_ProjectManager(ProjectID, ProjectManagerID)
		VALUES (@ProjectId, @CurrentPM)
	END

	--then update the current PM
	UPDATE Project
	SET CurrentPM = @CurrentPM
	WHERE ProjectId = @ProjectId 

end