USE [CCPMTest]
GO
/************************************************************************************************/
/***** Issue 2.9        add/update Notes  ; 	 					    *****/
/***** 		  spls	updates:FundingSourceInsert/FundingSourceUpdate/FundingSourceDetails*****/
/***** 				  						     	    *****/
/***** Issue 2.16 table FundingSource new default column IsActive     			    *****/
/***** 											    *****/
/***** Issue 2.14 spls updates: InvoiceDetailInsert, InvoiceDetailUpdate		    *****/
/***** 											    *****/	
/***** Issue 2.21 change Chapter field in FiscalYear 					    *****/
/*****            spls updates: FiscalYearUpdate, FiscalYearInsert    			    *****/
/*****            table       : FiscalYear column Chapter from int to varchar(4)            *****/
/***** 											    *****/
/***** Issue 2.23 spls updates: FundingSourceDupCheck					    *****/
/***** 		  added check for ReimbCode 						    *****/
/***** 											    *****/
/***** Issue 2.4 Introduce Unique Constraint(ContractId,FundId) in ContractFunds table      *****/
/***** 								    			    *****/															
/***** Issue 2.57 New Stored Procedure MatchingFundDeleteByReimbId			    *****/
/*****			   to remove Matching Fund by ReserveEncumb Id		  	    *****/
/***** Issue 2.57 Changed existing Procedre MatchingFundDelete - remove by matchingfundid   *****/
/***** 											    *****/
/***** Issue 2.58 spls updates: AmendmentUpdate, AmendmentInsert	    		    *****/
/*****            Update ContractDetail Date Executed and Status for Amendment 0   	    *****/
/***** 											    *****/
/***** Issue 2.60: Introduced Delete functionality on 					    *****/
/***** 						Project Type, Staff, and watersheds screens *****/
/***** 											    *****/
/***** Issue 2.61 Inactive Functionality to the Authorization Type administration page	    *****/
/***** 						Contract Type administration page	    *****/
/***** 						Monitor Outcome administration page	    *****/
/***** 						Relationship Type administration page	    *****/
/***** 											    *****/
/***** Issue 2.64,2.65 Table Project: add column Date Completed, IsWebSite		    *****/
/***** 			Reflect changes in sp: ProjectInsert, ProjectUpdate		    *****/
/***** 											    *****/
/************************************************************************************************/


/************************************************************************************************/
/***** Issue 2.9 Contracts/Fundings allow to add/update Notes       			    *****/
/************************************************************************************************/


/****** Object:  StoredProcedure [dbo].[AuthorizationDetailInsert]    Script Date: 03/14/2012 13:02:13 ******/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO


ALTER  PROCEDURE [dbo].[AuthorizationDetailInsert]
(
    @ProjectId               int,
    @AuthorizationTypeId     int,
    @AuthorizationDate       datetime,
    @AmountAuthorized        money,
	@Notes					 varchar (250),
    @UserID                  varchar(30)             = NULL)
AS
BEGIN
    BEGIN TRAN
    DECLARE @errNum int, @retVal int
    INSERT INTO AuthorizationDetail(ProjectId,
                                    AuthorizationTypeId,
                                    AuthorizationDate,
                                    AmountAuthorized,
									Notes,
                                    CreatedDt,
                                    CreatedBy,
                                    UpdatedDt,									
                                    UpdatedBy)
    VALUES(@ProjectId,
           @AuthorizationTypeId,
           @AuthorizationDate,
           @AmountAuthorized,
		   @Notes,
           getdate(),
           @UserID,
           getdate(),
           @UserID)
    SET @errNum = @@ERROR
    SET @retVal = @@IDENTITY	
    IF (@errNum!=0)
    BEGIN
        RAISERROR  20000 'AuthorizationDetailInsert: Insert failed '
        ROLLBACK TRAN
        RETURN(-1)
    
    END
    COMMIT TRAN
    SELECT @retVal as retVal
END


/*============================================================================*/
GO
/****** Object:  StoredProcedure [dbo].[AuthorizationDetailUpdate]    Script Date: 03/14/2012 13:08:12 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

ALTER PROCEDURE [dbo].[AuthorizationDetailUpdate]
(
    @AuthorizationId         int,
    @ProjectId               int,
    @AuthorizationTypeId     int,
    @AuthorizationDate       datetime,
    @AmountAuthorized        money,
	@Notes					 varchar(250),
    @UserID                  varchar(30)             = NULL)
AS
BEGIN
    BEGIN TRAN
    UPDATE AuthorizationDetail
       SET ProjectId                = @ProjectId,
           AuthorizationTypeId      = @AuthorizationTypeId,
           AuthorizationDate        = @AuthorizationDate,
           AmountAuthorized         = @AmountAuthorized,
		   Notes					= @Notes,
           UpdatedDt                = getdate(),
           UpdatedBy                = @UserID
     WHERE AuthorizationId = @AuthorizationId
    IF (@@error!=0)
    BEGIN
        RAISERROR  20001 'AuthorizationDetailUpdate: Update failed '
        ROLLBACK TRAN
        RETURN(1)
    
    END
    COMMIT TRAN
    RETURN(0)
END

GO

/************************************************************************************************/
/***** Issue 2.16 table FundingSource new default column IsActive     						*****/
/************************************************************************************************/

ALTER TABLE FundingSource
 ADD IsActive bit NOT NULL CONSTRAINT [DF_FundingSource_IsActive]  DEFAULT ((1))

/****** Object:  StoredProcedure [dbo].[FundingSourceInsert]    Script Date: 03/15/2012 01:59:29 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

/* 
 * PROCEDURE: FundingSourceInsert
 */
ALTER          PROCEDURE [dbo].[FundingSourceInsert]
(
    @FiscalYearID        int,
    @FYShort			 varchar(10)			 = NULL,
    @FundTitle           varchar(120),
    @OrgCode             varchar(10)             = NULL,
    @RefCode             varchar(10)             = NULL,
    @FundNumber          varchar(10)             = NULL,
    @ScheduleNum         varchar(10)             = NULL,
    @Description         varchar(80)             = NULL,
    @Source              varchar(80)             = NULL,
    @SubScheduleNum      varchar(10)             = NULL,
    @SubScheduleName     varchar(80)             = NULL,
    @Program             varchar(10)             = NULL,
    @Element             varchar(10)             = NULL,
    @Component           varchar(10)             = NULL,
    @ReimbCode           varchar(10)             = NULL,
    @EncumbExpDate       datetime                = NULL,
    @LiquidDate          datetime                = NULL,
    @AppropAmt           money                   = NULL,
    @Category            varchar(120)            = NULL,
    @UserID              varchar(30)             = NULL,
	@IsActive			 bit					 = 1)
AS
BEGIN
    DECLARE @errNum int, @FundID int
    IF (@EncumbExpDate = 'Jan  1 1901 12:00:00:000AM')
           SET @EncumbExpDate = NULL
    IF (@LiquidDate = 'Jan  1 1901 12:00:00:000AM')
       SET @LiquidDate = Null

    IF DATALENGTH(@FYShort)=0 SET @FYShort = NULL
    IF DATALENGTH(@FundTitle)=0 SET @FundTitle = NULL
    IF DATALENGTH(@OrgCode)=0 SET @OrgCode = NULL
    IF DATALENGTH(@RefCode)=0 SET @RefCode = NULL
    IF DATALENGTH(@FundNumber)=0 SET @FundNumber = NULL
    IF DATALENGTH(@ScheduleNum)=0 SET @ScheduleNum = NULL
    IF DATALENGTH(@Description)=0 SET @Description = NULL
    IF DATALENGTH(@Source)=0 SET @Source = NULL
    IF DATALENGTH(@SubScheduleNum)=0 SET @SubScheduleNum = NULL
    IF DATALENGTH(@Program)=0 SET @Program = NULL
    IF DATALENGTH(@Element)=0 SET @Element = NULL
    IF DATALENGTH(@Component)=0 SET @Component = NULL
    IF DATALENGTH(@ReimbCode)=0 SET @ReimbCode = NULL
    IF DATALENGTH(@Category)=0 SET @Category = NULL

    BEGIN TRAN
    INSERT INTO FundingSource(FiscalYearID,
			      FYShort,
                              FundTitle,
                              OrgCode,
                              RefCode,
                              FundNumber,
                              ScheduleNum,
                              Description,
                              Source,
                              SubScheduleNum,
                              SubScheduleName,
                              Program,
                              Element,
                              Component,
                              ReimbCode,
                              EncumbExpDate,
                              LiquidDate,
                              AppropAmt,
                              Category,
                              CreatedDt,
                              CreatedBy,
			      IsActive,
                              UpdatedDt,
                              UpdatedBy)
    VALUES(@FiscalYearID,
	   @FYShort,
           @FundTitle,
           @OrgCode,
           @RefCode,
           @FundNumber,
           @ScheduleNum,
           @Description,
           @Source,
           @SubScheduleNum,
           @SubScheduleName,
           @Program,
           @Element,
           @Component,
           @ReimbCode,
           @EncumbExpDate,
           @LiquidDate,
           @AppropAmt,
           @Category,
           getdate(),
           @UserID,
	   @IsActive,
           getdate(),
           @UserID)
    SET @errNum = @@error
    SET @FundID = @@IDENTITY 
    IF (@errNum!=0)
    BEGIN
        RAISERROR  20000 'FundingSourceInsert: Insert failed'
        ROLLBACK TRAN
        RETURN(-1)
    
    END
    COMMIT TRAN
    SELECT @FundID
END



GO
/****** Object:  StoredProcedure [dbo].[FundingSourceUpdate]    Script Date: 03/15/2012 02:04:00 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

/* 
 * PROCEDURE: FundingSourceUpdate
 */
ALTER     PROCEDURE [dbo].[FundingSourceUpdate]
(
    @FundID              int,
    @FiscalYearID        int,
	@FYShort			 varchar(10)			 = NULL,
    @FundTitle           varchar(120),
    @OrgCode             varchar(10)             = NULL,
    @RefCode             varchar(10)             = NULL,
    @FundNumber          varchar(10)             = NULL,
    @ScheduleNum         varchar(10)             = NULL,
    @Description         varchar(80)             = NULL,
    @Source              varchar(80)             = NULL,
    @SubScheduleNum      varchar(10)             = NULL,
    @SubScheduleName     varchar(80)             = NULL,
    @Program             varchar(10)             = NULL,
    @Element             varchar(10)             = NULL,
    @Component           varchar(10)             = NULL,
    @ReimbCode           varchar(10)             = NULL,
    @EncumbExpDate       datetime                = NULL,
    @LiquidDate          datetime                = NULL,
    @AppropAmt           money                   = NULL,
    @Category            varchar(120)            = NULL,
    @UserID              varchar(30)             = NULL,
	@IsActive			 bit					 = 1)
AS
BEGIN
    IF (@EncumbExpDate = 'Jan  1 1901 12:00:00:000AM')
           SET @EncumbExpDate = NULL
    IF (@LiquidDate = 'Jan  1 1901 12:00:00:000AM')
       SET @LiquidDate = Null

	IF DATALENGTH(@FYShort)=0 SET @FYShort = NULL
    IF DATALENGTH(@FundTitle)=0 SET @FundTitle = NULL
    IF DATALENGTH(@OrgCode)=0 SET @OrgCode = NULL
    IF DATALENGTH(@RefCode)=0 SET @RefCode = NULL
    IF DATALENGTH(@FundNumber)=0 SET @FundNumber = NULL
    IF DATALENGTH(@ScheduleNum)=0 SET @ScheduleNum = NULL
    IF DATALENGTH(@Description)=0 SET @Description = NULL
    IF DATALENGTH(@Source)=0 SET @Source = NULL
    IF DATALENGTH(@SubScheduleNum)=0 SET @SubScheduleName = NULL
    IF DATALENGTH(@Program)=0 SET @Program = NULL
    IF DATALENGTH(@Element)=0 SET @Element = NULL
    IF DATALENGTH(@Component)=0 SET @Component = NULL
    IF DATALENGTH(@ReimbCode)=0 SET @ReimbCode = NULL
    IF DATALENGTH(@Category)=0 SET @Category = NULL

    BEGIN TRAN
    UPDATE FundingSource
       SET FiscalYearID         = @FiscalYearID,
		   FYShort				= @FYShort,
           FundTitle            = @FundTitle,
           OrgCode              = @OrgCode,
           RefCode              = @RefCode,
           FundNumber           = @FundNumber,
           ScheduleNum          = @ScheduleNum,
           Description          = @Description,
           Source               = @Source,
           SubScheduleNum       = @SubScheduleNum,
           SubScheduleName      = @SubScheduleName,
           Program              = @Program,
           Element              = @Element,
           Component            = @Component,
           ReimbCode            = @ReimbCode,
           EncumbExpDate        = @EncumbExpDate,
           LiquidDate           = @LiquidDate,
           AppropAmt            = @AppropAmt,
           Category             = @Category,
		   IsActive				= @IsActive,
           UpdatedDt            = getdate(),
           UpdatedBy            = @UserID
     WHERE FundID = @FundID
    IF (@@error!=0)
    BEGIN
        RAISERROR  20001 'FundingSourceUpdate: Update Failed'
        ROLLBACK TRAN
        RETURN(1)
    
    END
    COMMIT TRAN
    RETURN(0)
END



GO
/****** Object:  StoredProcedure [dbo].[FundingSourceDetail]    Script Date: 03/15/2012 02:13:42 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

/* 
 * PROCEDURE: FundingSourceDetail
 */
ALTER  PROCEDURE [dbo].[FundingSourceDetail]
(
    @FundID              int)
AS
BEGIN
    SELECT FundID
         , FiscalYearID
		 , FYShort = COALESCE(FYShort,'')
         , FundTitle = COALESCE(FundTitle,'')
         , OrgCode = COALESCE(OrgCode,'')
         , RefCode = COALESCE(RefCode,'')
         , FundNumber = COALESCE(FundNumber,'')
         , ScheduleNum = COALESCE(ScheduleNum,'')
         , Description = COALESCE(Description,'')
         , Source = COALESCE(Source,'')
         , SubScheduleNum = COALESCE(SubScheduleNum,'')
         , SubScheduleName = COALESCE(SubScheduleName,'')
         , Program = COALESCE(Program,'')
         , Element = COALESCE(Element,'')
         , Component = COALESCE(Component,'')
         , ReimbCode = COALESCE(ReimbCode,'')
         , EncumbExpDate = COALESCE(EncumbExpDate,'1/1/1901')
         , LiquidDate = COALESCE(LiquidDate,'1/1/1901')
         , AppropAmt = COALESCE(AppropAmt,0)
         , Category = COALESCE(Category,'')
         , IsActive = COALESCE(IsActive,1)
     FROM FundingSource WHERE FundID = @FundID
   
    IF (@@error!=0)
    BEGIN
        RAISERROR  20002 'FundingSourceDetail: An error occurred '
        RETURN(1)    
    END
END



/************************************************************************************************/
/***** Issue 2.14 spls updates: InvoiceDetailInsert, InvoiceDetailUpdate		    *****/
/************************************************************************************************/
GO
/****** Object:  StoredProcedure [dbo].[InvoiceDetailInsert]    Script Date: 03/19/2012 15:08:45 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO


ALTER PROCEDURE [dbo].[InvoiceDetailInsert]
(
	@ContractId				int,
	@ReceivedDate			datetime,	
	@GrossInvoiceAmount		money,
	@IsFinal				varchar(10),
	@BillingPeriodStart		varchar(20),
	@InvoiceDate			datetime,
	@GrossAmountApproved	money,
	@NetPaymentAmount		money,
	@WithholdingPercent		money,
	@WithholdingAmount		money,
	@Balance				money,
     	@DateToProjManager		datetime,
	@ToAccountingDate		datetime,
    	@FromAccountingDate		datetime,
    	@ClaimScheduleNumber	varchar(50),
    	@ClaimScheduleDate		datetime,
    	@DisputeDateFromPM		datetime,
    	@Reason					varchar(500),
    	@DisputeDateMailedOut	datetime,
    	@IsDisputed				varchar(10),
	@FundId					int,
	@InvoiceNumber			varchar(50),
	@DisencumberAugment		money = 0
)
	
AS
BEGIN

    DECLARE @augmentDisencumbered money

    BEGIN TRAN
    DECLARE @errNum int, @retVal int
    INSERT INTO Invoice
	(	ContractId,
		ReceivedDate,
		GrossInvoiceAmount,
		IsFinal,
		BillingPeriodStart, 	
		InvoiceDate,
		GrossAmountApproved,
		NetPaymentAmount,
		WithholdingPercent,
		WithholdingAmount,
		Balance,
		ToProjectManagerDate,
		ToAccountingDate,
		FromAccountingDate,
		ClaimScheduleNumber,
		ClaimScheduleDate,
		DisputeDateFromPM,
		Reason,
		DisputeDateMailedOut,
		IsDisputed,
		FundId,
		InvoiceNumber,
		DisencumberAugment
	)
    VALUES
	(	@ContractId,
		@ReceivedDate,
		@GrossInvoiceAmount,
		@IsFinal,
		@BillingPeriodStart,
		@InvoiceDate,
		@GrossAmountApproved,
		@NetPaymentAmount,
		@WithholdingPercent,
		@WithholdingAmount,
		@Balance,
		@DateToProjManager,
		@ToAccountingDate,
		@FromAccountingDate,
		@ClaimScheduleNumber,
		@ClaimScheduleDate,
		@DisputeDateFromPM,
		@Reason,
		@DisputeDateMailedOut,
		@IsDisputed,
		@FundId,
		@InvoiceNumber,
		@DisencumberAugment
	)

    SET @errNum = @@ERROR
    SET @retVal = @@IDENTITY	
    IF (@errNum!=0)
    BEGIN
        RAISERROR  20000 'InvoiceDetailInsert: Insert failed '
        ROLLBACK TRAN
        RETURN(-1)
    
    END

	--set ContractFunds DisencumberAmount = ContractedAmount when invoice is disencumber
	SET @augmentDisencumbered = 0
	--IF exists (select * from Invoice where	ContractId = @ContractId and FundId = @FundId and disencumberAugment < 0)
	--BEGIN
		select @augmentDisencumbered = SUM(COALESCE(Invoice.DisencumberAugment, 0) ) from Invoice where ContractId = @ContractId and FundId = @FundId and disencumberAugment < 0
	--END

	IF (@augmentDisencumbered < 0)		
	BEGIN		
		UPDATE	ContractFunds 
		SET		DisencumberAmount = @augmentDisencumbered
		WHERE	ContractId = @ContractId and FundId = @FundId
	END


    COMMIT TRAN
    SELECT @retVal as retVal
END


GO
/****** Object:  StoredProcedure [dbo].[InvoiceDetailUpdate]    Script Date: 03/19/2012 17:57:22 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

ALTER PROCEDURE [dbo].[InvoiceDetailUpdate]
(
    @InvoiceID				int, 
    @ReceivedDate			datetime,
    @GrossInvoiceAmount     money,
    @IsFinal				varchar(10),
    @BillingPeriodStart		varchar(20),
    @InvoiceDate			datetime,
    @GrossAmountApproved	money,
    @NetPaymentAmount		money,
    @WithholdingPercent		money,
	@WithholdingAmount		money,
    @Balance				money,
    @DateToProjManager		datetime,
    @ToAccountingDate		datetime,
    @FromAccountingDate		datetime,
    @ClaimScheduleNumber	varchar(50),
    @ClaimScheduleDate		datetime,
    @DisputeDateFromPM		datetime,
    @Reason					varchar(500),
    @DisputeDateMailedOut	datetime,
    @IsDisputed				varchar(10),
    @FundId					int,
	@InvoiceNumber			varchar(50),
	@DisencumberAugment		money
) 
AS
BEGIN

    DECLARE @augmentDisencumbered money	
		   ,@contractId int 	

    BEGIN TRAN
    UPDATE Invoice
       SET ReceivedDate         = @ReceivedDate,
           GrossInvoiceAmount   = @GrossInvoiceAmount,
           IsFinal              = @IsFinal,
           BillingPeriodStart   = @BillingPeriodStart,
           InvoiceDate			= @InvoiceDate,
           GrossAmountApproved  = @GrossAmountApproved,
           NetPaymentAmount     = @NetPaymentAmount,
           WithholdingPercent   = @WithholdingPercent,
			WithholdingAmount	= @WithholdingAmount,
           Balance				= @Balance,
           ToProjectManagerDate = @DateToProjManager,
           ToAccountingDate		= @ToAccountingDate,
           FromAccountingDate	= @FromAccountingDate,
           ClaimScheduleNumber  = @ClaimScheduleNumber,
           ClaimScheduleDate	= @ClaimScheduleDate,
           DisputeDateFromPM	= @DisputeDateFromPM,
           Reason				= @Reason,
           DisputeDateMailedOut	= @DisputeDateMailedOut,
           IsDisputed				= @IsDisputed,
           FundId				= @FundId,  
		   InvoiceNumber		= @InvoiceNumber,         
			DisencumberAugment	= @DisencumberAugment
       WHERE InvoiceId = @InvoiceId       
    IF (@@error!=0)
    BEGIN
        RAISERROR  20001 'InvoiceUpdate: Update Failed'
        ROLLBACK TRAN
        RETURN(1)
    
    END


	--set ContractFunds DisencumberAmount = ContractedAmount when invoice is disencumber
	SET @augmentDisencumbered = 0
	--IF exists (select * from Invoice where	ContractId = @ContractId and FundId = @FundId and disencumberAugment < 0)
	--BEGIN
		select @augmentDisencumbered = SUM(COALESCE(Invoice.DisencumberAugment, 0) ) from Invoice where ContractId = @ContractId and FundId = @FundId and disencumberAugment < 0
	--END

	IF (@augmentDisencumbered < 0)		
	BEGIN		
		UPDATE	ContractFunds 
		SET		DisencumberAmount = @augmentDisencumbered
		WHERE	ContractId = @ContractId and FundId = @FundId
	END

    COMMIT TRAN
    RETURN(0)
END


GO

/************************************************************************************************/
/***** Issue 2.21 change Chapter field in FiscalYear table from int to varchar(4)	    *****/
/************************************************************************************************/

ALTER TABLE FiscalYear ALTER COLUMN Chapter varchar(4) NULL 

GO

/************************************************************************************************/
/***** Issue 2.21 spls updates: FiscalYearUpdate, FiscalYearInsert			    *****/
/************************************************************************************************/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
/* 
 * PROCEDURE: FiscalYearUpdate 
 */
ALTER  PROCEDURE [dbo].[FiscalYearUpdate]
(
    @FiscalYearID     int,
    @StartDate        datetime,
    @EndDate          datetime,
    @Chapter          varchar(4)             = NULL,
    @Years            varchar(25)            = NULL,
    @ChapterFY        varchar(10)            = NULL,
    @UserID           varchar(30)            = NULL
)
AS
BEGIN
    BEGIN TRAN
    IF @Chapter = '-1'
       SET @Chapter = NULL
    UPDATE FiscalYear
       SET StartDate         = @StartDate,
           EndDate           = @EndDate,
           Chapter           = @Chapter,
           Years             = @Years,
           ChapterFY         = @ChapterFY,
           UpdatedDt         = getdate(),
           UpdatedBy         = @UserID 
     WHERE FiscalYearID = @FiscalYearID
    IF (@@error!=0)
    BEGIN
        RAISERROR  20001 'FiscalYearUpdate: Update failed '
        ROLLBACK TRAN
        RETURN(1)
    
    END
    COMMIT TRAN
    RETURN(0)
END
GO
/************************************************************************************************/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
/* 
 * PROCEDURE: FiscalYearInsert
 */
ALTER  PROCEDURE [dbo].[FiscalYearInsert]
(
    @StartDate        datetime,
    @EndDate          datetime,
    @Chapter          varchar(4)                = NULL,
    @Years            varchar(25)            = NULL,
    @ChapterFY        varchar(10)            = NULL,
    @UserID           varchar(30)            = NULL
 )
AS
BEGIN
    DECLARE @errNum int, @FiscalYearID int
    BEGIN TRAN
    IF (@Chapter = '-1')
      SET @Chapter = NULL
    INSERT INTO FiscalYear(StartDate,
                           EndDate,
                           Chapter,
                           Years,
                           ChapterFY,
                           CreatedDt,
                           CreatedBy,
                           UpdatedDt,
                           UpdatedBy)
    VALUES(@StartDate,
           @EndDate,
           @Chapter,
           @Years,
           @ChapterFY,
           getdate(),
           @UserID,
           getdate(),
           @UserID)
    SET @errNum = @@ERROR
    SET @FiscalYearID = @@IDENTITY 
    
    IF (@errNum!=0)
    BEGIN
        RAISERROR  20000 'FiscalYearInsert: Insert failed.'
        ROLLBACK TRAN
        RETURN(-1)
    END
    COMMIT TRAN
    SELECT @FiscalYearID AS FiscalYearID
    RETURN 
END
GO


/************************************************************************************************/
/***** Issue 2.23 spls updates: FundingSourceDupCheck					    *****/
/************************************************************************************************/

GO
/****** Object:  StoredProcedure [dbo].[FundingSourceDupCheck]    Script Date: 03/22/2012 11:57:13 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
/* 
 * PROCEDURE: FundingSourceDupCheck
 */
ALTER   PROCEDURE [dbo].[FundingSourceDupCheck]
(
    @FundID              int, 
    @FiscalYearID        int,
    @OrgCode             varchar(10)             = NULL,
    @RefCode             varchar(10)             = NULL,
    @FundNumber          varchar(10)             = NULL,
    @ScheduleNum         varchar(10)             = NULL,
    @SubScheduleNum      varchar(10)             = NULL,
    @ReimbCode		     varchar(10)             = NULL)
AS
BEGIN
    -- Check for dups on both Add and Edit
    -- if @FundID passed as 0, this is an Add, else this is an edit
    -- returns 1 if Dup, 0 if no dup
    DECLARE @rowCount int, @DupFundID int, @retVal int 
    SET @retVal = 0
    IF (@FundID = 0)
        BEGIN 
          -- check for dup on Add
          SET @rowCount = (SELECT COUNT(*) FROM FundingSource WHERE 
            (FiscalYearID=@FiscalYearID) AND 
            (COALESCE(OrgCode,'')+COALESCE(RefCode,'')+ COALESCE(FundNumber,'')+COALESCE(ScheduleNum,'')+COALESCE(SubScheduleNum,'')+COALESCE(ReimbCode,'')) = 
            (COALESCE(@OrgCode,'')+COALESCE(@RefCode,'')+ COALESCE(@FundNumber,'')+COALESCE(@ScheduleNum,'')+COALESCE(@SubScheduleNum,'')+COALESCE(@ReimbCode,'')))
          IF (@rowCount<>0)
             SET @retVal = 1
        END 
    ELSE  
        BEGIN 
          -- check for dup on Edit
          SET @rowCount = (SELECT COUNT(*) FROM FundingSource WHERE 
            (FundID <> @FundID) AND 
            (FiscalYearID=@FiscalYearID) AND 
            (COALESCE(OrgCode,'')+COALESCE(RefCode,'')+ COALESCE(FundNumber,'')+COALESCE(ScheduleNum,'')+COALESCE(SubScheduleNum,'')+COALESCE(ReimbCode,'')) = 
            (COALESCE(@OrgCode,'')+COALESCE(@RefCode,'')+ COALESCE(@FundNumber,'')+COALESCE(@ScheduleNum,'')+COALESCE(@SubScheduleNum,'')+COALESCE(@ReimbCode,'')))
          IF (@rowCount<>0)
             SET @retVal = 1
        END 
 
    SELECT @retVal as retVal
END



/************************************************************************************************/
/***** Issue 2.4 Introduce Unique Constraint(ContractId,FundId) in ContractFunds table      *****/
/************************************************************************************************/

GO

ALTER TABLE ContractFunds
ADD CONSTRAINT [IX_ContractFunds1] UNIQUE NONCLUSTERED 
(
	[ContractId] ASC,
	[FundId] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]


/************************************************************************************************/
/***** Issue 2.57 New Stored Procedre to remove Matching Fund by ReserveEncumb Id	        *****/
/************************************************************************************************/
GO
/****** Object:  StoredProcedure [dbo].[MatchingFundDeleteByReimbId]    Script Date: 04/07/2012 09:10:11 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
/* 
 * PROCEDURE: [MatchingFundDeleteByReimbId] 
 */
CREATE  PROCEDURE [dbo].[MatchingFundDeleteByReimbId]
(
    @ReimbId                  int)
AS
BEGIN
    BEGIN TRAN

    DELETE
      FROM MatchingFund
     WHERE ReimbId = @ReimbId
     
    IF (@@error!=0)
    BEGIN
        RAISERROR  20002 'MatchingFundDeleteByReimbId: Delete failed '
        ROLLBACK TRAN
        RETURN(1)
    
    END
    COMMIT TRAN
    RETURN(0)
END


/************************************************************************************************/
/***** Issue 2.57 Changed existing Procedre MatchingFundDelete - remove by matchingfundid   *****/
/************************************************************************************************/

GO
/****** Object:  StoredProcedure [dbo].[MatchingFundDelete]    Script Date: 04/07/2012 12:12:12 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
/* 
 * PROCEDURE: MatchingFundDelete 
 */
ALTER  PROCEDURE [dbo].[MatchingFundDelete]
(
    @MatchingFundId                  int)
AS
BEGIN
    BEGIN TRAN

     DELETE
       FROM MatchingFund
       WHERE MatchingFundId = @MatchingFundId
    IF (@@error!=0)
    BEGIN
        RAISERROR  20002 'MatchingFundDelete: Delete failed '
        ROLLBACK TRAN
        RETURN(1)
    
    END
    COMMIT TRAN
    RETURN(0)
END

/************************************************************************************************/
/***** Issue 2.58 Update ContractDetail Date Executed and Status for Amendment 0   	    *****/
/************************************************************************************************/
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO


ALTER PROCEDURE [dbo].[AmendmentInsert]
(
	@ContractId		int,	
	@AmendmentNumber		varchar(50),
	@ReasonForAmendment		varchar(1000),
	@Amount		money,
	@ContractTypeId		int,
	@ExecutedDate		datetime	= NULL)
	
AS
BEGIN
    BEGIN TRAN
    DECLARE @errNum int, @retVal int
    INSERT INTO Amendments(ContractId,
						   AmendmentNumber,
						   Amount,
						   ReasonForAmendment, 	
						   ContractTypeId,
						   ExecutedDate)
    VALUES(@ContractId,
           @AmendmentNumber,
           @Amount,
           @ReasonForAmendment,
           @ContractTypeId,
           @ExecutedDate)
    SET @errNum = @@ERROR
    SET @retVal = @@IDENTITY	
    IF (@errNum!=0)
    BEGIN
        RAISERROR  20000 'AmendmentsDetailInsert: Insert failed '
        ROLLBACK TRAN
        RETURN(-1)
    END

    DECLARE @AmendmentId	int	;
    SET     @AmendmentId = SCOPE_IDENTITY();

		--update executed date if 0 record
		update	ContractDetails
		set		ExecutedDate = @ExecutedDate
		from	ContractDetails
		join	Amendments on Amendments.ContractId = ContractDetails.ContractId
				and Amendments.AmendmentId = @AmendmentId
				and Amendments.AmendmentNumber = '0'
		where	ContractDetails.ContractId = @ContractId
		
		--status to Active from Draft if 0 record
		update	ContractDetails
		set		ContractStatusId = 2
		from	ContractDetails
		join	Amendments on Amendments.ContractId = ContractDetails.ContractId
				and Amendments.AmendmentId = @AmendmentId
				and Amendments.AmendmentNumber = '0'
		where	ContractDetails.ContractId = @ContractId
		and		ContractDetails.ContractStatusId = 1
		and		ContractDetails.ExecutedDate is not null
		
    IF (@@error!=0)
    BEGIN
        RAISERROR  20001 'AmendmentsDetailInsert: Update for AmendmentNumber 0 failed '
        ROLLBACK TRAN
        RETURN(1)
    
    END

    COMMIT TRAN
    SELECT @retVal as retVal
END

GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

ALTER PROCEDURE [dbo].[AmendmentUpdate]
(
	@ContractId		int,	
    @AmendmentId	int,
    @AmendmentNumber		varchar(50),
	@ReasonForAmendment		varchar(1000),
	@Amount		money,
	@ContractTypeId		int,
	@ExecutedDate		datetime	= NULL)
AS
BEGIN
    BEGIN TRAN
    UPDATE Amendments
       SET AmendmentNumber          = @AmendmentNumber,
           ReasonForAmendment	    = @ReasonForAmendment,
           Amount					= @Amount,
           ContractTypeId           = @ContractTypeId,
           ExecutedDate             = @ExecutedDate
     WHERE AmendmentId = @AmendmentId
    IF (@@error!=0)
    BEGIN
        RAISERROR  20001 'AmendmentsUpdate: Update failed '
        ROLLBACK TRAN
        RETURN(1)
    
    END
	
		--update executed date if 0 record
		update	ContractDetails
		set		ExecutedDate = @ExecutedDate
		from	ContractDetails
		join	Amendments on Amendments.ContractId = ContractDetails.ContractId
				and Amendments.AmendmentId = @AmendmentId
				and Amendments.AmendmentNumber = '0'
		where	ContractDetails.ContractId = @ContractId
		
		--status to Active from Draft if 0 record
		update	ContractDetails
		set		ContractStatusId = 2
		from	ContractDetails
		join	Amendments on Amendments.ContractId = ContractDetails.ContractId
				and Amendments.AmendmentId = @AmendmentId
				and Amendments.AmendmentNumber = '0'
		where	ContractDetails.ContractId = @ContractId
		and		ContractDetails.ContractStatusId = 1
		and		ContractDetails.ExecutedDate is not null
		
    IF (@@error!=0)
    BEGIN
        RAISERROR  20001 'AmendmentsUpdate: Update for AmendmentNumber 0 failed '
        ROLLBACK TRAN
        RETURN(1)
    
    END

    COMMIT TRAN
    RETURN(0)
END
/************************************************************************************************/
/***** Issue 2.61 Inactive Functionality to the Authorization Type administration page	    *****/
/************************************************************************************************/

GO
-- Alter Table
ALTER TABLE dbo.AuthorizationType ADD IsActive bit NOT NULL 
	CONSTRAINT DF_AuthorizationType_IsActive  DEFAULT (1);


--Alter Procedure AuthorizationTypeUpdate 
GO
/****** Object:  StoredProcedure [dbo].[AuthorizationTypeUpdate]    Script Date: 04/07/2012 20:06:13 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
ALTER  PROCEDURE [dbo].[AuthorizationTypeUpdate]
@AuthorizationTypeId int,
@AuthorizationType varchar(50),
@IsActive bit
AS
begin
	UPDATE [AuthorizationType]
	SET AuthorizationType = @AuthorizationType
	, IsActive = @IsActive
	WHERE AuthorizationTypeId = @AuthorizationTypeId
end

--Alter Procedure AuthorizationTypeSelect 
GO
/****** Object:  StoredProcedure [dbo].[AuthorizationTypeSelect]    Script Date: 04/07/2012 19:59:14 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
ALTER PROCEDURE [dbo].[AuthorizationTypeSelect]
(	@IncludeInactive bit
)
AS
begin
IF @IncludeInactive = 1
	begin
	SELECT AuthorizationTypeID
	,	AuthorizationType
    ,	IsActive
	FROM AuthorizationType
	ORDER BY AuthorizationType
	end
ELSE
	begin
	SELECT AuthorizationTypeID
	,	AuthorizationType
    ,	IsActive
	FROM AuthorizationType
	WHERE isActive = 1
	ORDER BY AuthorizationType
	end

end

/************************************************************************************************/
/***** Issue 2.61 Inactive Functionality to the Contract Type administration page	    *****/
/************************************************************************************************/

GO
-- Alter Table
ALTER TABLE dbo.ContractType ADD IsActive bit NOT NULL 
	CONSTRAINT DF_ContractType_IsActive  DEFAULT (1);


--Alter Procedure ContractTypeUpdate 
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
ALTER PROCEDURE [dbo].[ContractTypeUpdate]
@ContractTypeId int,
@TypeCode varchar(50),
@IsActive bit
AS
begin
UPDATE ContractType
SET TypeCode = @TypeCode, IsActive = @IsActive
WHERE ContractTypeId = @ContractTypeId
end

--Alter Procedure ContractTypeSelect 
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
ALTER PROCEDURE [dbo].[ContractTypeSelect]
(	@IncludeInactive bit
)
AS
begin
IF @IncludeInactive = 1
	begin
	SELECT ContractTypeID
	,	TypeCode
    ,	IsActive
	FROM ContractType
	ORDER BY TypeCode
	end
ELSE
	begin
	SELECT ContractTypeID
	,	TypeCode
    ,	IsActive
	FROM ContractType
	WHERE isActive = 1
	ORDER BY TypeCode
	end

end

/************************************************************************************************/
/***** Issue 2.61 Inactive Functionality to the Monitor outcomes administration page	    *****/
/************************************************************************************************/

GO
-- Alter Table
ALTER TABLE dbo.MonitorOutcome ADD IsActive bit NOT NULL 
	CONSTRAINT DF_MonitorOutcome_IsActive  DEFAULT (1);


--Alter Procedure MonitorOutcomeUpdate 
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
ALTER PROCEDURE [dbo].[MonitorOutcomeUpdate]
@OutcomeId int,
@OutcomeCode varchar(50),
@IsActive bit
AS
begin
UPDATE [MonitorOutcome]
	SET OutcomeCode = @OutcomeCode
	, IsActive = @IsActive
	WHERE OutcomeId = @OutcomeId
end

--Alter Procedure MonitorOutcomeSelect 
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
ALTER PROCEDURE [dbo].[MonitorOutcomeSelect]
(	@IncludeInactive bit
)
AS
begin
IF @IncludeInactive = 1
	begin
	SELECT OutcomeID
	,	OutcomeCode
    ,	IsActive
	FROM MonitorOutcome
	ORDER BY OutcomeCode	
	end
ELSE
	begin
	SELECT OutcomeID
	,	OutcomeCode
    ,	IsActive
	FROM MonitorOutcome
	WHERE isActive = 1
	ORDER BY OutcomeCode	
	end

end


/************************************************************************************************/
/***** Issue 2.60: Introduced Delete functionality on 					    *****/
/************************************************************************************************/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE PROCEDURE [dbo].[ProjectTypeDelete]
@ProjectTypeId int

AS
BEGIN

	declare @msg varchar(100)

	if exists (select * from Project_ProjectType where ProjectTypeId = @ProjectTypeId)
	BEGIN
		select	@msg = 'The project type ' + ProjectType + ' can''t be deleted.  It is being used in projects.' + char(13)
		from	ProjectType
		where	ProjectTypeId =@ProjectTypeId
		 RAISERROR(@msg, 16, 1)
		 RETURN(0)
	END

  BEGIN TRAN 
	DELETE 
		FROM ProjectType
		WHERE ProjectTypeId = @ProjectTypeId

    IF (@@error!=0)
    BEGIN
        RAISERROR  20002 'ProjectTypeDelete: Delete failed '
        ROLLBACK TRAN
        RETURN(1)
    
    END
    COMMIT TRAN
    RETURN(0)
END

GO

GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE PROCEDURE [dbo].[ProjectWatershedDelete]
@WatershedId int

AS
BEGIN
	declare @msg varchar(100)

	if exists (select * from Project_ProjectWatershed where WatershedId = @WatershedId)
	BEGIN
		select	@msg = 'The project type ' + Watershed + ' can''t be deleted.  It is being used in projects.' + char(13)
		from	ProjectWatershed
		where	WatershedId =@WatershedId
		 RAISERROR(@msg, 16, 1)
		 RETURN(0)
	END

  BEGIN TRAN 
	DELETE 
		FROM ProjectWatershed
		WHERE WatershedId =@WatershedId

    IF (@@error!=0)
    BEGIN
        RAISERROR  20002 'ProjectWatershedDelete: Delete failed '
        ROLLBACK TRAN
        RETURN(1)
    
    END
    COMMIT TRAN
    RETURN(0)
END


GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE PROCEDURE [dbo].[ProjectStaffDelete]
@ProjectManagerId int

AS
BEGIN

  BEGIN TRAN 
	if exists (select * from ProjectStaff_StaffRole where ProjectManagerId = @ProjectManagerId )
	BEGIN
		DELETE	
		FROM	ProjectStaff_StaffRole
		WHERE	ProjectManagerId =@ProjectManagerId
	END

	DELETE 
		FROM ProjectStaff
		WHERE ProjectManagerId =@ProjectManagerId

    IF (@@error!=0)
    BEGIN
        RAISERROR  20002 'ProjectStaffDelete: Delete failed '
        ROLLBACK TRAN
        RETURN(1)
    
    END
    COMMIT TRAN
    RETURN(0)
END



/************************************************************************************************/
/***** Issue 2.61 Inactive Functionality to the Relationship Type administration page	    *****/
/************************************************************************************************/

GO
-- Alter Table
ALTER TABLE dbo.RelType ADD IsActive bit NOT NULL 
	CONSTRAINT DF_RelType_IsActive  DEFAULT (1);


--Alter Procedure RelTypeUpdate 
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
ALTER PROCEDURE [dbo].[RelTypeUpdate]
@RelTypeId int,
@RelType varchar(50),
@IsActive bit
AS
begin
	UPDATE [RelType]
	SET RelType = @RelType
	, IsActive = @IsActive
	WHERE RelTypeId = @RelTypeId
end

--Alter Procedure RelTypeSelect
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
ALTER PROCEDURE [dbo].[RelTypeSelect]
(	@IncludeInactive bit
,	@ProjectId int = null
)
AS
begin
IF @IncludeInactive = 1
	begin
	SELECT RelTypeID
	,	RelType
    ,	IsActive
	FROM RelType
	ORDER BY RelType
	end
ELSE
	begin
	if	(@ProjectId > 0)
		begin
		SELECT RelTypeID
		,	RelType
		,	IsActive
		FROM RelType
		WHERE isActive = 1
		or	RelTypeID in (select RelTypeId from relatedProject where ProjectId = @ProjectId)
		ORDER BY RelType
		end
	else
		begin
		SELECT RelTypeID
		,	RelType
		,	IsActive
		FROM RelType
		WHERE isActive = 1
		ORDER BY RelType
		end
	end

end

/************************************************************************************************/
/***** Issue 2.64,2.65 Table Project: add column Date COmpleted, IsWebSite		    *****/
/***** Reflect changes in sp: ProjectInsert, ProjectUpdate 				    *****/
/************************************************************************************************/
GO
ALTER TABLE [dbo].[Project] ADD DateCompleted [datetime] NULL
GO
ALTER TABLE [dbo].[Project] ADD IsWebsite [bit] NOT NULL  DEFAULT ((0))
GO
GO
/****** Object:  StoredProcedure [dbo].[ProjectInsert]    ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

ALTER   PROCEDURE [dbo].[ProjectInsert]
@FileNumber varchar(100),
@ProjectName nvarchar(200),
@Summary nvarchar(1000),
@Description nvarchar(4000),
@Latitude float,
@Longitude float,
@Acreage float,
@SquareMiles float,
@TrailMiles float,
@TrailLinearFeet float,
@StreamMiles float,
@StreamLinearFeet float,
@APNNumber nvarchar(100),
@CoastalTrailMiles float,
@CoastalTrailLinearFeet float,
@CurrentPM int = NULL,
@ProjectNotes nvarchar(4000),
@LocationDescription varchar(100),
@DateCompleted datetime = NULL,
@IsWebsite bit = 0
AS
begin
SET TRANSACTION ISOLATION LEVEL REPEATABLE READ
INSERT Project
(	FileNumber
,	ProjectName
,	Summary
,	[Description]
,	Latitude
,	Longitude
,	Acreage
,	SquareMiles
,	TrailMiles
,	TrailLinearFeet
,	StreamMiles
,	StreamLinearFeet
,	ProjectNotes
,	APNNumber
,	CCTmiles
,	CCTLinearFeet
,	CurrentPM
,	LocationDescription
,	DateCompleted
,	IsWebsite 
)
VALUES
(	@FileNumber
,	@ProjectName
,	@Summary
,	@Description
,	@Latitude
,	@Longitude
,	@Acreage
,	@SquareMiles
,	@TrailMiles
,	@TrailLinearFeet
,	@StreamMiles
,	@StreamLinearFeet
,	@ProjectNotes
,	@APNNumber
,	@CoastalTrailMiles
,	@CoastalTrailLinearFeet
,	@CurrentPM
,	@LocationDescription 
,	@DateCompleted
,	@IsWebsite 
)

SELECT @@IDENTITY AS ProjectId
end

GO
GO
/****** Object:  StoredProcedure [dbo].[ProjectUpdate]   ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

ALTER      PROCEDURE [dbo].[ProjectUpdate]
@FileNumber varchar(100),
@ProjectName nvarchar(200),
@StatusId int,
@StatusDate datetime,
@Summary nvarchar(1000),
@Description nvarchar(4000),
@Latitude decimal(18,6),
@Longitude decimal(18,6),
@Acreage float,
@SquareMiles float,
@TrailMiles float,
@TrailLinearFeet float,
@StreamMiles float,
@StreamLinearFeet float,
@ProjectNotes nvarchar(4000),
@APNNumber nvarchar(100),
@CoastalTrailMiles float,
@CoastalTrailLinearFeet float,
@CurrentPM int,
@ProjectId int,
@LastModified datetime,
@LocationDescription varchar(100),
@DateCompleted datetime = NULL,
@IsWebsite bit = 0
AS
begin
UPDATE Project
SET FileNumber = @FileNumber
,	ProjectName = @ProjectName
,	StatusId = @StatusId
,	StatusDate = @StatusDate
,	Summary = @Summary
,	[Description] = @Description
,	Latitude = @Latitude
,	Longitude = @Longitude
,	Acreage = @Acreage
,	SquareMiles = @SquareMiles
,	TrailMiles = @TrailMiles
,	TrailLinearFeet = @TrailLinearFeet
,	StreamMiles = @StreamMiles
,	StreamLinearFeet = @StreamLinearFeet
,	ProjectNotes = @ProjectNotes
,	LastModified = GETDATE()
,	APNNumber = @APNNumber
,	CCTmiles = @CoastalTrailMiles
,	CCTLinearFeet = @CoastalTrailLinearFeet
,	CurrentPM = @CurrentPM
,	LocationDescription = @LocationDescription
,	DateCompleted = @DateCompleted
,	IsWebsite = @IsWebsite
WHERE ProjectId = @ProjectId 
AND LastModified = @LastModified

end


/************************************************************************************************/



/************************************************************************************************/
