using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Data.SqlClient;
using System.Data.SqlTypes;
using System.Windows.Forms;
using Infragistics.Shared; 
using Infragistics.Win; 
using Infragistics.Win.UltraWinGrid; 
using CCPM.Data;
using Microsoft.ApplicationBlocks.Data;

namespace CCPM.Project
{
	/// <summary>
	/// DirtyFlag values:
	///    0 = database row not edited
	///    1 = database row edited by user
	///    2 = database row marked as deleted
	///    3 = new row added by user
	/// </summary>
	public class Authorizations : System.Windows.Forms.UserControl
	{
		#region Fields
        
        private DataSet dsProjectMatchingFunds;
        private DataSet dsAllOrgs;
        private DataSet dsProject;
        private DataRow drProject;

		private DataSet dsProjectAuthorizations;
		private DataSet dsAuthReservations;
		private DataSet dsAuthTypes;
		private DataSet dsFundingSource;
        private DataSet dsReimbType;
		
		private bool blnGridDirty = false;
		private bool blnGridResDirty = false;
        private bool blnGridMatchDirty = false;

        decimal reservedTotal = 0;

		private System.Windows.Forms.Button btnDelete;
		private System.Windows.Forms.Button btnSave;
		private System.Windows.Forms.Button btnCancel;
		private System.Windows.Forms.Button btnAdd;
		private System.Windows.Forms.Label lblTotalConservany;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.GroupBox grpTotals;
		private System.Windows.Forms.TextBox txtNetSCC;
		private System.Windows.Forms.TextBox txtTotalMatchingFunds;
		private System.Windows.Forms.Label lblTotalMatchingFunds;
		private System.Windows.Forms.TextBox txtProjectCosts;

        private Infragistics.Win.UltraWinGrid.UltraGrid uwgAuthorizations;
        private Infragistics.Win.UltraWinGrid.UltraDropDown uddFundingSource;
        private Infragistics.Win.UltraWinGrid.UltraDropDown uddOrgSource;
        private System.Windows.Forms.Button btnAddRes;
		private System.Windows.Forms.Button btnDeleteRes;
		private System.Windows.Forms.Button btnSaveRes;
		private System.Windows.Forms.Button btnCancelRes;
        private System.Windows.Forms.Label lblInstructions;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.TextBox txtAmtReserved;
        private System.Windows.Forms.TextBox txtAmtAuthorized;
		//#endregion

        //private Infragistics.Win.UltraWinGrid.UltraGrid uwgReservations;
        private Button btnRefresh;
        private Button btnNewMatch;
        private UltraGrid uwgMatchingFunds;
        private Button btnCancelMatch;
        private Button btnSaveMatch;
        private Button btnDeleteMatch;
        private Button btnAddMatch;
        private UltraGrid uwgReservations;
        private Label label4;
        private TextBox txtStatus;
        private Label label5;
        private TextBox txtAmountEncumb;
        private Panel panel1;
        private Label label7;
        private Label label6;
        private Label label8;
        private TextBox txtAmountReserved;
        private Button btnShowAll;        
        private IContainer components;
        #endregion
        int pid = 0;

        public Authorizations()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();
            uwgReservations.DisplayLayout.Override.WrapHeaderText = Infragistics.Win.DefaultableBoolean.True;
            pid = GlobalSettings.projectId;
            dsProject = ProjectData.GetProject(GlobalSettings.projectId);
            drProject = dsProject.Tables["Project"].Rows[0];

            //FormInits();
			this.lblInstructions.Text = "Use Tab to navigate between cells within a row. " + 
                                   "Click 'Save' to refresh Totals after changes. \n" +
                                   "Match funds with a reimbursable or repayment feature should be added via the Reservations section above.";

			//-----------------------------------------------------------------------------
			// Create the Authorizations dataset and bind to a value list
            dsAuthTypes = ProjectFundingData.GetAuthTypeSelectionList();
            uwgAuthorizations.DisplayLayout.ValueLists.Add("AuthTypes");
            for (int i = 0; i < dsAuthTypes.Tables[0].Rows.Count; i++)
            {
                Infragistics.Win.ValueListItem ListItem = new Infragistics.Win.ValueListItem();
                ListItem.DataValue = dsAuthTypes.Tables[0].Rows[i].ItemArray.GetValue(0);
                ListItem.DisplayText = (string) dsAuthTypes.Tables[0].Rows[i].ItemArray.GetValue(1);
                uwgAuthorizations.DisplayLayout.ValueLists["AuthTypes"].ValueListItems.Add (ListItem);
            } 
            
            // Reimburse/Repyment Type dataset anad binding
            dsReimbType = ProjectFundingData.GetReimbTypeSelectionList();
            uwgReservations.DisplayLayout.ValueLists.Add("ReimbType");
            for (int i = 0; i < dsReimbType.Tables[0].Rows.Count; i++)
            {
                Infragistics.Win.ValueListItem ListItem = new Infragistics.Win.ValueListItem();
                ListItem.DataValue = dsReimbType.Tables[0].Rows[i].ItemArray.GetValue(0);
                ListItem.DisplayText = (string)dsReimbType.Tables[0].Rows[i].ItemArray.GetValue(1);
                uwgReservations.DisplayLayout.ValueLists["ReimbType"].ValueListItems.Add(ListItem);
            }

            uwgMatchingFunds.InitializeLayout+=new InitializeLayoutEventHandler(uwgMatchingFunds_InitializeLayout);
            LoadOrgs();

            uwgMatchingFunds.DisplayLayout.ValueLists.Add("ReimbType");
            for (int i = 0; i < dsReimbType.Tables[0].Rows.Count; i++)
            {
                Infragistics.Win.ValueListItem ListItem = new Infragistics.Win.ValueListItem();
                ListItem.DataValue = dsReimbType.Tables[0].Rows[i].ItemArray.GetValue(0);
                ListItem.DisplayText = (string)dsReimbType.Tables[0].Rows[i].ItemArray.GetValue(1);
                uwgMatchingFunds.DisplayLayout.ValueLists["ReimbType"].ValueListItems.Add(ListItem);
            }

            LoadGridOrganization();
            LoadGridFS();
			LoadGridAuth();
			LoadGridRes();
            LoadMatching();
			LoadTotals();
            SetButtons();            
		}

        private void LoadOrgs()
        {
            dsAllOrgs = ProjectFundingData.GetOrgList();
            try
            {
                uwgMatchingFunds.DisplayLayout.ValueLists.Remove("Organization");
            } catch(Exception e) {}

            uwgMatchingFunds.DisplayLayout.ValueLists.Add("Organization");
            for (int i = 0; i < dsAllOrgs.Tables[0].Rows.Count; i++)
            {
                Infragistics.Win.ValueListItem ListItem = new Infragistics.Win.ValueListItem();
                ListItem.DataValue = dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(0);
                ListItem.DisplayText = (string)dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(1);
                uwgMatchingFunds.DisplayLayout.ValueLists["Organization"].ValueListItems.Add(ListItem);
            }

        }

        private void FormInits()
        {

            // Create the objectives dataset and bind to a value list
            //uwgMatchingFunds.DisplayLayout.ValueLists.Add("Orgs");

            //dsAllOrgs = ProjectFundingData.GetOrgSelectionList();
            //for (int i = 0; i < dsAllOrgs.Tables[0].Rows.Count; i++)
            //{
            //    Infragistics.Win.ValueListItem ListItem = new Infragistics.Win.ValueListItem();
            //    ListItem.DataValue = dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(0);
            //    ListItem.DisplayText = (string)dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(1);
            //    uwgMatchingFunds.DisplayLayout.ValueLists["Orgs"].ValueListItems.Add(ListItem);
            //}

            // Initialize the grid with data
            LoadMatching();
            LoadTotals();
        }

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
        ///        
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		public bool GridDirty
		{
			get
			{
				if (blnGridDirty | blnGridResDirty)
					return(true);
				else
					return(false);
			}
		}

		private void LoadGridAuth()
		{			
            //Create the project objectives dataset and bind to the grid
			dsProjectAuthorizations = ProjectFundingData.GetProjectAuthorizations(GlobalSettings.projectId);
			uwgAuthorizations.DataSource = dsProjectAuthorizations.Tables[0];
            uwgAuthorizations.DataBind();
		}

        // Load Matching Fund grid
        private void LoadMatching()
        {
            //Create the project objectives dataset and bind to the grid
            dsProjectMatchingFunds = ProjectFundingData.GetProjectMatchingFunds(GlobalSettings.projectId);
            uwgMatchingFunds.DataSource = dsProjectMatchingFunds.Tables[0];
            uwgMatchingFunds.DataBind();
        }

		private void LoadGridRes()
		{
			// get auth id
			int AuthorizationId = 0;
			if (uwgAuthorizations.Rows.Count>0)
			{
				UltraGridRow authRow = this.uwgAuthorizations.ActiveRow;
				try 
				{
					AuthorizationId = Convert.ToInt32(authRow.Cells["AuthorizationId"].Value);
				}
				catch
				{
					AuthorizationId = 0;
				}
			}
			dsAuthReservations = ProjectFundingData.GetAuthReservations(AuthorizationId, pid);
			uwgReservations.DataSource = dsAuthReservations.Tables[0];
			uwgReservations.DataBind();
	    }

		private void LoadGridFS()
		{
			//Create the funding source dataset and bind to the (dropdown list) grid
			dsFundingSource = ProjectFundingData.GetFundSelectionList(true);
			uddFundingSource.DataSource = dsFundingSource.Tables[0];
			uddFundingSource.ValueMember="FundID";
			uddFundingSource.DisplayMember = "FundingItem";
            uddFundingSource.DisplayLayout.Bands[0].SortedColumns.Add("FundingItem", false);
			uddFundingSource.DataBind();
			//uwgReservations.DataBind();
			//uwgAuthorizations.DisplayLayout.AutoFitColumns = true;
        }

        private void LoadGridOrganization()
        {
            //Create the organization source dataset and bind to the (dropdown list) grid
            uddOrgSource.DataSource = dsAllOrgs.Tables[0];
            uddOrgSource.ValueMember = "OrgID";
            uddOrgSource.DisplayMember = "Organization";
            uddOrgSource.DataBind();
        }

       private void uwgAuthorizations_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
		{
			//e.Layout.Bands[0].HeaderVisible = false;

			// AuthorizationId
			e.Layout.Bands[0].Columns[0].Hidden = true;

			// AuthorizationTypeId
			e.Layout.Bands[0].Columns[1].Width = 100;
			e.Layout.Bands[0].Columns[1].Header.Caption = "Authorized By";
			e.Layout.Bands[0].Columns[1].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDownList;
			e.Layout.Bands[0].Columns[1].ValueList = uwgAuthorizations.DisplayLayout.ValueLists["AuthTypes"];
			e.Layout.ValueLists["AuthTypes"].DisplayStyle = Infragistics.Win.ValueListDisplayStyle.DisplayText;
			e.Layout.Bands[0].Columns["AuthorizationTypeId"].ValueList = uwgAuthorizations.DisplayLayout.ValueLists["AuthTypes"];

			// AuthorizationDate
			e.Layout.Bands[0].Columns[2].Width = 100;
			e.Layout.Bands[0].Columns[2].Header.Caption = "Date Authorized";
			e.Layout.Bands[0].Columns[2].Format = "MM/dd/yyyy";

			// ADS 8-Nov-2007 - Added new column
			// AmountAuthorized
			e.Layout.Bands[0].Columns[3].Width = 120;
			e.Layout.Bands[0].Columns[3].Header.Caption = "Amount Authorized";
            e.Layout.Bands[0].Columns[3].Format = "$#,##0.00";     //"$#,##0.00";	// #,##0
            e.Layout.Bands[0].Columns[3].MaskInput = "nnnnnnnnnnn.nn";
			e.Layout.Bands[0].Columns[3].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
			//e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
			e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;


            e.Layout.Bands[0].Columns[4].Hidden = true;
			// Dirty Flag
			e.Layout.Bands[0].Columns[5].Hidden = true;

			//e.Layout.ActiveRow.Appearance.BackColor = Color.Yellow;

           // Added new column Notes
            e.Layout.Bands[0].Columns[6].Width = 200;
            e.Layout.Bands[0].Columns[6].Header.Caption = "Notes";
       
       }

        private void uwgMatchingFunds_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            //e.Layout.Bands[0].Header.Appearance.BackColor = Color.Ivory;
            e.Layout.Bands[0].Columns[0].Hidden = true;

            e.Layout.Bands[0].Columns[1].Width = 400;
            e.Layout.Bands[0].Columns[1].Header.Caption = "Matching Fund Source";
            e.Layout.Bands[0].Columns[1].CellActivation = Infragistics.Win.UltraWinGrid.Activation.AllowEdit;
            e.Layout.Bands[0].Columns[1].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDownList;
            e.Layout.Bands[0].Columns[1].ValueList = uddOrgSource;

            //e.Layout.Bands[0].Columns[1].ValueList = uwgMatchingFunds.DisplayLayout.ValueLists["Organization"];
            //e.Layout.Bands[0].Columns[1].SortIndicator = SortIndicator.Ascending;
            //e.Layout.ValueLists["Organization"].DisplayStyle = Infragistics.Win.ValueListDisplayStyle.DisplayText;
            e.Layout.Bands[0].Columns[1].SortIndicator = SortIndicator.Ascending;
            
            

            e.Layout.Bands[0].Columns[2].Width = 140;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Category";
            //e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
            e.Layout.Bands[0].Columns[2].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

            e.Layout.Bands[0].Columns[3].Width = 110;
            e.Layout.Bands[0].Columns[3].Header.Caption = "Amount";
            e.Layout.Bands[0].Columns[3].Format = "$#,##0.00";
            e.Layout.Bands[0].Columns[3].MaskInput = "nnnnnnnnn.nn";
            e.Layout.Bands[0].Columns[3].MinValue = 0;
            e.Layout.Bands[0].Columns[3].MaxValue = 999999999;
            e.Layout.Bands[0].Columns[3].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;

            e.Layout.Bands[0].Columns[4].Width = 110;
            e.Layout.Bands[0].Columns[4].Header.Caption = "Reimb/Repayment";
            e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[4].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDownList;
            e.Layout.Bands[0].Columns[4].ValueList = uwgMatchingFunds.DisplayLayout.ValueLists["ReimbType"];
            e.Layout.ValueLists["ReimbType"].DisplayStyle = Infragistics.Win.ValueListDisplayStyle.DisplayText;
            e.Layout.Bands[0].Columns[4].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;

            // OrgID
            e.Layout.Bands[0].Columns[5].Hidden = true;
            //DirtyFlag
            e.Layout.Bands[0].Columns[6].Hidden = true;
            //ReimbId
            e.Layout.Bands[0].Columns[7].Hidden = true;

        }
		private void uwgReservations_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
		{

            // ReservEncumbID
			e.Layout.Bands[0].Columns[0].Hidden = true;
           
			// AuthorizationID
			e.Layout.Bands[0].Columns[1].Hidden = true;
         
            // FundingItem (dropdown list)
			e.Layout.Bands[0].Columns[2].Width = 140;
			e.Layout.Bands[0].Columns[2].Header.Caption = "Funding Item";
            e.Layout.Bands[0].Columns[2].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDownList;
            e.Layout.Bands[0].Columns[2].ValueList = uddFundingSource;

			// Source
			e.Layout.Bands[0].Columns[3].Width = 130;
			e.Layout.Bands[0].Columns[3].Header.Caption = "Source/Nickname";
			//e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
			e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.Disabled;
			e.Layout.Bands[0].Columns[3].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
			e.Layout.Bands[0].Columns[3].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
			e.Layout.Bands[0].Columns[3].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

			// Years
			e.Layout.Bands[0].Columns[4].Width = 70;
			e.Layout.Bands[0].Columns[4].Header.Caption = "FY";
			e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
			e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.Disabled;
			e.Layout.Bands[0].Columns[4].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
			e.Layout.Bands[0].Columns[4].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
			e.Layout.Bands[0].Columns[4].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

			// ReserveDate
			e.Layout.Bands[0].Columns[5].Width = 100;
			e.Layout.Bands[0].Columns[5].Header.Caption = "Reserve Date";
			e.Layout.Bands[0].Columns[5].Format = "MM/dd/yyyy";

			// EncumbExpDate
			e.Layout.Bands[0].Columns[6].Width = 100;
			e.Layout.Bands[0].Columns[6].Header.Caption = "Encumber By";
			e.Layout.Bands[0].Columns[6].Format = "MM/dd/yyyy";
			e.Layout.Bands[0].Columns[6].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
			e.Layout.Bands[0].Columns[6].CellActivation = Infragistics.Win.UltraWinGrid.Activation.Disabled;
			e.Layout.Bands[0].Columns[6].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
			e.Layout.Bands[0].Columns[6].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
			e.Layout.Bands[0].Columns[6].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

			// LiquidDate
			e.Layout.Bands[0].Columns[7].Width = 70;
			e.Layout.Bands[0].Columns[7].Header.Caption = "Spend By";
			e.Layout.Bands[0].Columns[7].Format = "MM/dd/yyyy";
			e.Layout.Bands[0].Columns[7].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
			e.Layout.Bands[0].Columns[7].CellActivation = Infragistics.Win.UltraWinGrid.Activation.Disabled;
			e.Layout.Bands[0].Columns[7].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
			e.Layout.Bands[0].Columns[7].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
			e.Layout.Bands[0].Columns[7].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

			// Amount
			e.Layout.Bands[0].Columns[8].Width = 100;
			e.Layout.Bands[0].Columns[8].Header.Caption = "Reserved Amount";
			e.Layout.Bands[0].Columns[8].Format = "$###,###,##0.00";	// #,##0.##
            e.Layout.Bands[0].Columns[8].MaskInput = "nnnnnnnnnnn.nn";
			e.Layout.Bands[0].Columns[8].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;

            //ReimbTypeId (dropdown list)
            e.Layout.Bands[0].Columns[9].Width = 120;
            e.Layout.Bands[0].Columns[9].Header.Caption = "Reimb/Repayment";
            e.Layout.Bands[0].Columns[9].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDownList;
            e.Layout.Bands[0].Columns[9].ValueList = uwgReservations.DisplayLayout.ValueLists["ReimbType"];
            e.Layout.ValueLists["ReimbType"].DisplayStyle = Infragistics.Win.ValueListDisplayStyle.DisplayText;

            //organization list
            //e.Layout.Bands[0].Columns[10].Width = 120;
            e.Layout.Bands[0].Columns[10].Header.Caption = "Organization";
            e.Layout.Bands[0].Columns[10].Hidden = true;
            e.Layout.Bands[0].Columns[10].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
            
            //Amount to be reimbursed
            e.Layout.Bands[0].Columns[11].Width = 100;
            e.Layout.Bands[0].Columns[11].Header.Caption = "Total Amt to be Reimb/Repaid";
            e.Layout.Bands[0].Columns[11].Format = "$###,###,##0.00";	// #,##0.##
            e.Layout.Bands[0].Columns[11].MaskInput = "nnnnnnnnn.nn";
            e.Layout.Bands[0].Columns[11].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;

            //// FundID
            e.Layout.Bands[0].Columns[12].Hidden = true;

            //// DirtyFlag
            e.Layout.Bands[0].Columns[13].Hidden = true;

            ////HasContract
            e.Layout.Bands[0].Columns[14].Hidden = true;
           
        
        }

		private void uwgGrantReimbs_InitializeLayout( object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e )
		{
			e.Layout.Bands[0].Columns[0].Hidden = true;
			e.Layout.Bands[0].Columns[1].Hidden = true;

            //e.Layout.Bands[0].Columns[2].Width = 70;
            //e.Layout.Bands[0].Columns[2].Header.Caption = "Reimburse";
			
            //e.Layout.Bands[0].Columns[3].Width = 75;
            //e.Layout.Bands[0].Columns[3].Header.Caption = "Amount";
            //e.Layout.Bands[0].Columns[3].Format = "$###,###,##0.00";	// #,##0.##
            //// e.Layout.Bands[0].Columns[3].MaskInput = "nnn,nnn,nnn.nn";
            //e.Layout.Bands[0].Columns[3].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;

			//e.Layout.Bands[0].Columns[4].Width = 190;
			//e.Layout.Bands[0].Columns[4].Header.Caption = "Source";

			e.Layout.Bands[0].Columns[5].Hidden = true;
		}

		private void uddFundingSource_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
		{
			e.Layout.Bands[0].Columns[0].Hidden = true;

            e.Layout.Bands[0].Columns[1].Width = 65;
            e.Layout.Bands[0].Columns[1].Header.Caption = "FY";

            e.Layout.Bands[0].Columns[2].Width = 183;
			e.Layout.Bands[0].Columns[2].Header.Caption = "Funding Item";
            e.Layout.Bands[0].Columns[2].SortIndicator = SortIndicator.Ascending;
			e.Layout.Bands[0].Columns[3].Width = 165;
			e.Layout.Bands[0].Columns[3].Header.Caption = "Source/Nickname";

			e.Layout.Bands[0].Columns[4].Width = 225;
			e.Layout.Bands[0].Columns[4].Header.Caption = "Program Name";

			e.Layout.Bands[0].Columns[5].Width = 140;
			e.Layout.Bands[0].Columns[5].Header.Caption = "SubAccount";

			e.Layout.Bands[0].Columns[6].Hidden = true;
			
			e.Layout.Bands[0].Columns[7].Hidden = true;
			
			// Source
			e.Layout.Bands[0].Columns[8].Hidden = true;

            //Is Active
            e.Layout.Bands[0].Columns[9].Width = 60;
            e.Layout.Bands[0].Columns[9].Header.Caption = "IsActive";
            e.Layout.Bands[0].Columns[9].Hidden = true;


            //filter row
            e.Layout.Override.AllowRowFiltering = Infragistics.Win.DefaultableBoolean.True;
            e.Layout.Override.FilterClearButtonLocation = FilterClearButtonLocation.Row;
            e.Layout.Override.FilterUIType = Infragistics.Win.UltraWinGrid.FilterUIType.FilterRow;
            e.Layout.Override.FilterOperatorDefaultValue = FilterOperatorDefaultValue.Contains;

            //column sorting
            e.Layout.Override.HeaderClickAction = HeaderClickAction.SortMulti;
        }

        private void uwgMatchingFunds_CellListSelect(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e)
        {           
            //int SelectedItemIndex = this.uwgMatchingFunds.DisplayLayout.ValueLists["Orgs"].SelectedIndex;
            //string OrgID = this.uwgMatchingFunds.DisplayLayout.ValueLists["Orgs"].ValueListItems[SelectedItemIndex].DataValue.ToString();

            // Set the id for the selected Organization into the row
            //this.uwgMatchingFunds.ActiveRow.Cells["OrgID"].Value = OrgID;

            // If this was a an existing row then set the dirty flag accordingly
            //if (this.uwgMatchingFunds.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
            //    this.uwgMatchingFunds.ActiveRow.Cells["DirtyFlag"].Value = "1";

            //blnGridMatchDirty = true;

            // Set the Organization Type column with the value associated to the selected org
            //string OrgID = uwgMatchingFunds.ActiveRow.Cells["OrgID"].Value.ToString();
            //for (int i = 0; i < dsAllOrgs.Tables[0].Rows.Count; i++)
            //{
            //    if (OrgID == dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(0).ToString())
            //    {
            //        this.uwgMatchingFunds.ActiveRow.Cells["OrganizationType"].Value =
            //            dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(2);
            //    }
            //}
        }
        
        private void uwgMatchingFunds_AfterRowActivate(object sender, System.EventArgs e)
        {           
            SetButtons();           
        }
        
		private void uwgAuthorizations_CellListSelect(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e) 
		{
			// If this was a an existing row then set the dirty flag accordingly
			if (this.uwgAuthorizations.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
				this.uwgAuthorizations.ActiveRow.Cells["DirtyFlag"].Value = "1";
			
			blnGridDirty = true;
		}

		private void uwgAuthorizations_AfterCellUpdate(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e) 
		{ 
			// If editing an existing row then set the dirty flag to edit mode for this row
			// Note: TotalAmount is a calculated column which gets refreshed when the reservations grid 
			//       is changed. 
			if (e.Cell.Column.Key!="TotalAmount")
			{
				if (this.uwgAuthorizations.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
					this.uwgAuthorizations.ActiveRow.Cells["DirtyFlag"].Value = "1";
				blnGridDirty = true;
				SetButtons();
				// get a handle to the main form so we can enable / disable the menus
				Form1 f = (Form1) this.ParentForm.MdiParent;
				f.DisableMenusAll();
			}
//			else
//			{
//				// When we change TotalAmount, we don't what the grid to go into edit mode
//				// This is a work-around for that problem. 
//				this.LoadGridAuth();
//				int rowIndex = this.uwgAuthorizations.ActiveRow.Index;
//				this.uwgAuthorizations.ActiveRow = this.uwgAuthorizations.Rows[rowIndex];            
//			}
		}

		private void uwgAuthorizations_AfterRowActivate(object sender, System.EventArgs e) 
		{ 
			//this.uwgAuthorizations.ActiveRow.Appearance.BackColor = Color.Yellow;
			SetButtons();
			LoadGridRes();
		}

		private void uwgReservations_CellListSelect(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e) 
		{
            if (this.uwgReservations.ActiveRow.Cells["FundingItem"].IsActiveCell)
            {
                int contractCount = GlobalCode.ToInt32(this.uwgReservations.ActiveRow.Cells["ContractCount"].Text);
                if (contractCount >0)
                {
                    string contracts = "a contract";
                    if (contractCount > 1)
                        contracts = "multiple contracts";

                    MessageBox.Show("Funding Item is used in " + contracts +  " associated with the project. Funding Item can not be changed.","Change Funding Source ",MessageBoxButtons.OK, MessageBoxIcon.Warning);
                    e.Cell.CancelUpdate();
                    return;
                }

                //do not allow to select funds that are no longer active
                if (ProjectFundingData.IsFundingSourceActive(GlobalCode.ToInt32(this.uddFundingSource.SelectedRow.Cells["FundID"].Value)) == false)
                {
                    MessageBox.Show("Funding Source is no longer Active.", "Change Funding Source ", MessageBoxButtons.OK, MessageBoxIcon.Warning);
                    e.Cell.CancelUpdate();
                    return;                
                }

            }

            if (this.uwgReservations.ActiveRow.Cells[9].IsActiveCell)
            {
                string reimb = this.uwgReservations.ActiveRow.Cells[9].Text;
                if (reimb != "")
                {
                    decimal amt = GlobalCode.ToDecimal(this.uwgReservations.ActiveRow.Cells["Amount"].Text);
                    if (amt == 0)
                    {
                        MessageBox.Show("Please enter an amount first");
                        e.Cell.CancelUpdate();
                        return;
                    }
                    OrganizationPicker op = new OrganizationPicker();
                    op.MyParentForm = this;
                    op.Amount = amt;
                    if (op.ShowDialog() == DialogResult.OK)
                    {
                        LoadOrgs();
                        UltraGridRow addRow = uwgMatchingFunds.DisplayLayout.Bands[0].AddNew();
                        uwgReservations.ActiveRow.Cells[10].Activate();
                        uwgReservations.ActiveRow.Cells[10].Value = op.OrgID;
                        uwgReservations.ActiveRow.Cells[11].Value = op.Amount;
                        addRow.Cells["DirtyFlag"].Value = "3";
                        blnGridResDirty = false;
                        SaveReservations();
                    }
                    else
                    {
                        e.Cell.CancelUpdate();
                    }
                }
            }
            
            try
			{             
                // set the non-editable related fields in Res grid, based on selected Funding Item
				int	FundID = Convert.ToInt32(this.uddFundingSource.SelectedRow.Cells["FundID"].Value); 	
				string Years = this.uddFundingSource.SelectedRow.Cells["Years"].Value.ToString();
				string Source = this.uddFundingSource.SelectedRow.Cells["Source"].Value.ToString();
				DateTime EncumbExpDate = Convert.ToDateTime(this.uddFundingSource.SelectedRow.Cells["EncumbExpDate"].Value);
				DateTime LiquidDate = Convert.ToDateTime(this.uddFundingSource.SelectedRow.Cells["LiquidDate"].Value);

				this.uwgReservations.ActiveRow.Cells["FundID"].Value = FundID;
				this.uwgReservations.ActiveRow.Cells["Years"].Value = Years;
				this.uwgReservations.ActiveRow.Cells["Source"].Value = Source;
				this.uwgReservations.ActiveRow.Cells["EncumbExpDate"].Value = EncumbExpDate;
				this.uwgReservations.ActiveRow.Cells["LiquidDate"].Value = LiquidDate;
			}
			catch
			{
				// catch will be triggered when a cell other than the Fund Item selection list is changed
			}

				// If this was a an existing row then set the dirty flag accordingly
				
		}

       
		private void uwgReservations_AfterCellUpdate(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e) 
		{
            try
            {

                if (uwgReservations.ActiveRow.Cells["Amount"].IsInEditMode == true)
                {
                    DataSet ds = null;
                    DataRow dr = null;
                    decimal totalFundingSourceAmount = 0;
                    decimal totalContractedAmount = 0;

                    // Gets the total contracted amount for the funding source for that particular project
                    DataSet ds1 = SqlHelper.ExecuteDataset(GlobalSettings.ConnectionString, CommandType.Text, "SELECT isnull(sum(cf.ContractedAmount),0) FROM ContractFunds cf INNER JOIN ContractDetails cd ON cf.ContractId = cd.ContractId WHERE (FundId = " + Convert.ToInt32(uwgReservations.ActiveRow.Cells["FundId"].Value) + " and ProjectId = " + Convert.ToInt32(pid) + ")");
                    if (ds1.Tables[0].Rows.Count > 0)
                    {
                        DataRow dr1 = ds1.Tables[0].Rows[0];
                        totalContractedAmount = GlobalCode.ToDecimal(dr1[0]);
                    }
                    else
                    {
                        totalContractedAmount = 0;
                    }

                    // Gets the sum of existing reservations for the funding source for that particular project
                    totalFundingSourceAmount = ProjectFundingData.GetProjectFundAmount(Convert.ToInt32(pid), Convert.ToInt32(uwgReservations.ActiveRow.Cells["FundId"].Value), Convert.ToInt32(uwgReservations.ActiveRow.Cells["AuthorizationId"].Value));                    
                    foreach (UltraGridRow ugr in uwgReservations.Rows)
                    {
                        if (GlobalCode.ToInt32(ugr.Cells["FundId"].Value) == GlobalCode.ToInt32(uwgReservations.ActiveRow.Cells["FundId"].Value))
                            totalFundingSourceAmount += GlobalCode.ToDecimal(ugr.Cells["Amount"].Value);
                    }

                    //do not allow to reduce the amount of the reservation to an amount less than the sum of all contracted funds
                    if (totalFundingSourceAmount < totalContractedAmount)
                    {
                        MessageBox.Show("The amount you entered for this funding source (" + uwgReservations.ActiveRow.Cells["FundingItem"].Value  + ")\n\nbrings the sum of reservations (" + totalFundingSourceAmount.ToString(GlobalSettings.MoneyFormat) + ") to be less than the sum amount contracted (" + totalContractedAmount.ToString(GlobalSettings.MoneyFormat) + ").\n " +
                                        "Please correct the Reserved Amount.", "Data entry error");
                        uwgReservations.ActiveRow.Cells["Amount"].Value = GlobalCode.ToDecimal(uwgReservations.ActiveRow.Cells["Amount"].OriginalValue);
                        uwgReservations.ActiveRow.Cells["Amount"].CancelUpdate();
                        return;
                    
                    }
                }

                // If editing an existing row then set the dirty flag to edit mode for this row
                if (this.uwgReservations.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                    this.uwgReservations.ActiveRow.Cells["DirtyFlag"].Value = "1";

                if (this.uwgReservations.ActiveRow.Cells["GrantAmount"].IsActiveCell == true)
                    if (this.uwgReservations.ActiveRow.Cells["ReimbTypeId"].Text == string.Empty)
                    {
                        DialogResult intDiagResult = MessageBox.Show("For 'Total Amt to be Reimb/Repaid' change the selection of Reimb/Repayment type is required.", "Required", 
					MessageBoxButtons.OK, MessageBoxIcon.Warning);
                    }
                blnGridResDirty = true;
                SetButtons();
                // get a handle to the main form so we can enable / disable the menus
                //Form1 f = (Form1) this.ParentForm.MdiParent;
                //f.DisableMenusAll();

                this.uwgAuthorizations.ActiveRow.Appearance.BackColorDisabled = Color.DarkBlue;
                this.uwgAuthorizations.ActiveRow.Appearance.ForeColorDisabled = Color.White;
            }
            catch (Exception ex)
            { }
		}

		private void uwgReservations_AfterRowActivate(object sender, System.EventArgs e) 
		{
            //Infragistics.Win.ToolTip t1;
            //t1.Show("hello \n how r u??");
            SetButtons();
           
		}

		private void btnDelete_Click(object sender, System.EventArgs e)
		{            
			// Get the row to delete. In this case we will use the active row. 
			UltraGridRow row = this.uwgAuthorizations.ActiveRow;

			if ( null != row ) 
			{
				DialogResult intDiagResult = MessageBox.Show("Do you want to delete this Authorization and related Reservations, and save all other pending changes?","Delete Row", 
					MessageBoxButtons.YesNo, MessageBoxIcon.Question);
				if (intDiagResult == DialogResult.Yes)
				{
					// if the row is a database row then mark it for deletion and hide it in the grid
					if (row.Cells["DirtyFlag"].Value.ToString() == "0")
					{
						row.Hidden = true;
						row.Cells["DirtyFlag"].Value = "2";
						blnGridDirty = true;
					}
						// else it was added by the user and not saved to the database - delete it from the grid
					else
					{
						row.Delete(false);
					}
					// set the active row to first (non-hidden) row
                    SaveAuthorization(0);
					GridManager.FirstButtonHandler(uwgAuthorizations);
					
					// MAR 2005-03-28 - added Save (remove SetButtons)
					
					LoadGridRes();   // reload Res grid as we may have deleted child records
                    LoadMatching();
                    LoadTotals();
				}
			} 
			else 
			{ 
				// If there is no active row, then prompt the user to select one. 
				MessageBox.Show( "Please select a single row to delete." ); 
			} 
		} 

		private void SetButtons()
		{
			if (blnGridDirty == false & blnGridResDirty==false)
			{
				// no edits have been made on either grid

				this.uwgAuthorizations.Enabled = true;
				this.btnAdd.Enabled = true;
				this.btnDelete.Enabled = true;
				this.btnCancel.Enabled = false;
				this.btnSave.Enabled = false;	
		//		this.btnReservEncumb.Enabled = true;

				this.uwgReservations.Enabled = true;
				this.btnAddRes.Enabled = true;
				this.btnDeleteRes.Enabled = true;
				this.btnCancelRes.Enabled = false;
				this.btnSaveRes.Enabled = false;

                //this.btnSaveMatch.Enabled = false;
                //this.btnAddMatch.Enabled = false;
                this.btnSaveMatch.Enabled = false;
                this.btnCancelMatch.Enabled = false;
                this.btnNewMatch.Enabled = true;
                this.btnRefresh.Enabled = true;
			}
			else if (blnGridDirty == true)
			{
				// we're in edit mode on the Authorizations grid

				this.uwgAuthorizations.Enabled = true;
				this.btnAdd.Enabled = true;
				this.btnDelete.Enabled = true;
				this.btnCancel.Enabled = true;
				this.btnSave.Enabled = true;
			//	this.btnReservEncumb.Enabled = true;

				this.uwgReservations.Enabled = false;
				this.btnAddRes.Enabled = false;
				this.btnDeleteRes.Enabled = false;
				this.btnCancelRes.Enabled = false;
				this.btnSaveRes.Enabled = false;

                
			}
			else if (blnGridResDirty == true)
			{
				// we're in edit mode on the Reservations grid

				this.uwgAuthorizations.Enabled = false;
				this.btnAdd.Enabled = false;
				this.btnDelete.Enabled = false;
				this.btnCancel.Enabled = false;
				this.btnSave.Enabled = false;

				this.uwgReservations.Enabled = true;
				this.btnAddRes.Enabled = true;
				this.btnDeleteRes.Enabled = true;
				this.btnCancelRes.Enabled = true;
				this.btnSaveRes.Enabled = true;
			}

            if (blnGridMatchDirty == true)
            {
                this.uwgMatchingFunds.Enabled = true;
                this.btnSaveMatch.Enabled = true;
                this.btnCancelMatch.Enabled = true;
                //this.btnNewMatch.Enabled = false;
                this.btnRefresh.Enabled = false;
            }
            if (this.uwgAuthorizations.ActiveRow == null)
            {
                this.btnDelete.Enabled = false;
                this.btnAddRes.Enabled = false;
            }

			if (this.uwgAuthorizations.ActiveRow == null)
				this.btnDelete.Enabled = false;

            if (this.uwgMatchingFunds.ActiveRow == null)
                this.btnDeleteMatch.Enabled = false;
            else
                this.btnDeleteMatch.Enabled = true;
		}

		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			if (blnGridDirty == true)
			{
				DialogResult intDiagResult = MessageBox.Show("Data has changed - Do you want to cancel changes?","Cancel Changes", 
					MessageBoxButtons.YesNo, MessageBoxIcon.Question);
				if (intDiagResult == DialogResult.Yes)
				{
					LoadGridAuth();
					blnGridDirty = false;
					SetButtons();
					// get a handle to the main form so we can enable / disable the menus
					Form1 f = (Form1) this.ParentForm.MdiParent;
					f.EnableMenusAll();
				}
			}
		}

		private void btnAdd_Click(object sender, System.EventArgs e)
		{
			UltraGridRow addedRow = uwgAuthorizations.DisplayLayout.Bands[0].AddNew( );
			addedRow.Cells["AuthorizationDate"].Value = System.DateTime.Now;
			addedRow.Cells["DirtyFlag"].Value = "3";
			blnGridDirty = true;
			SetButtons();
		}

		private void btnSave_Click(object sender, System.EventArgs e)
		{
			int rowNum = Convert.ToInt32(this.uwgAuthorizations.ActiveRow.Index); 
			SaveAuthorization(rowNum);
		}

		private void btnReservEncumb_Click(object sender, System.EventArgs e)
		{
			bool blnValidAuthRow = true;
			int rowNum = 0;
			try
			{
				rowNum = Convert.ToInt32(this.uwgAuthorizations.ActiveRow.Index); 
			}
			catch
			{
				blnValidAuthRow = false;
				MessageBox.Show("Please select a valid Authorization row",
					"Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);			
			}
			if (blnGridDirty==true)
				{
				 	SaveAuthorization(rowNum);	
				}
			// if validation for the above failed, blnGridDirty will still be True
			if (blnGridDirty==false & blnValidAuthRow==true)
			{
				this.uwgReservations.Focus();
				this.uwgAuthorizations.ActiveRow.Appearance.BackColorDisabled = Color.DarkBlue;
				this.uwgAuthorizations.ActiveRow.Appearance.ForeColorDisabled = Color.White;
				// add a new row 
				this.AddReservationRow();
				SetButtons();
			}
		}


		private void SaveAuthorization(int rowNum)
		{
			// Validate grid prior to update
			bool GridValid = true;
			int row;
			int retVal;
			string retMsg;

			for(int i = 0; i < uwgAuthorizations.Rows.Count; i++)
			{
				row = i + 1;
				if (uwgAuthorizations.Rows[i].Cells["AuthorizationTypeId"].Value.ToString() == "")
				{
					MessageBox.Show("Please select a valid 'Authorizated By' for row " + row.ToString(),
						"Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
					GridValid = false;
					break;
				}
				if (uwgAuthorizations.Rows[i].Cells["AuthorizationDate"].Value.ToString() == String.Empty)
				{
					MessageBox.Show("Authorization date required in row " + row.ToString(),
						"Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);

					GridValid = false;
					break;
				}

                decimal amt = GlobalCode.ToDecimal(uwgAuthorizations.Rows[i].Cells[3].Value);
                //if (amt == 0)
                //{
                //    MessageBox.Show("Authorization amount required in row " + row.ToString(),
                //        "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                //    GridValid = false;
                //    break;
                //}
                int id = GlobalCode.ToInt32(uwgAuthorizations.Rows[i].Cells["AuthorizationId"].Value);
                if (id > 0)
                {
                    decimal res = ProjectFundingData.GetAuthReservationTotal(id);
                    if (res > amt)
                    {
                        MessageBox.Show("Authorization amount (" + amt.ToString(GlobalSettings.MoneyFormat) + ") can't be less than reservation totals (" + res.ToString(GlobalSettings.MoneyFormat) + ").",
                            "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        GridValid = false;
                        break;
                    }
                }
			}
			
			// Perform updates
			if (GridValid == true)
			{
				// Iterate through each grid row and determine if an update is needed
				for(int i = 0; i < uwgAuthorizations.Rows.Count; i++)
				{
					switch (uwgAuthorizations.Rows[i].Cells["DirtyFlag"].Value.ToString())
					{
						case "1":
						{
							// updated
							retMsg = 
							ProjectFundingData.AuthorizationUpdate(
								Convert.ToInt32(uwgAuthorizations.Rows[i].Cells["AuthorizationId"].Value),
								GlobalSettings.projectId,
								Convert.ToInt32(uwgAuthorizations.Rows[i].Cells["AuthorizationTypeId"].Value), 
								Convert.ToDateTime(uwgAuthorizations.Rows[i].Cells["AuthorizationDate"].Value),
                                Convert.ToString(uwgAuthorizations.Rows[i].Cells["Notes"].Value),
                                GlobalCode.ToDecimal(uwgAuthorizations.Rows[i].Cells[3].Value));
							if (retMsg!="success")
								MessageBox.Show("Update failed in row " + (i+1).ToString(), "Database Error", 
									MessageBoxButtons.OK, MessageBoxIcon.Error);

							break;
						}
						case "2":
						{
							retMsg = ProjectFundingData.AuthorizationDelete(Convert.ToInt32(uwgAuthorizations.Rows[i].Cells["AuthorizationId"].Value));
							if (retMsg!="success")
								MessageBox.Show("Delete failed in row " + (i+1).ToString(), "Database Error", 
									MessageBoxButtons.OK, MessageBoxIcon.Error);

                            DbConnection dbConnection = DbConnection.GetDbConnection();
                            string connectionString = dbConnection.DbConnectionString;

                            //int retVal1 = SqlHelper.ExecuteNonQuery(connectionString, CommandType.Text, "delete from MatchingFunds mf INNER JOIN ReservEncumb re ON mf.ReimbId = re.ReservEncumbId where re.AuthorizationId = " + Convert.ToInt32(uwgAuthorizations.Rows[i].Cells["AuthorizationId"].Value));
                            //if (retVal1 == -1)
                            //{
                            //    MessageBox.Show("Deletion failed");
                            //}
							break;
						}
						case "3":
						{
							retVal = ProjectFundingData.AuthorizationInsert(GlobalSettings.projectId, 
								Convert.ToInt32(uwgAuthorizations.Rows[i].Cells["AuthorizationTypeId"].Value), 
								Convert.ToDateTime(uwgAuthorizations.Rows[i].Cells["AuthorizationDate"].Value),
                                GlobalCode.ToDecimal(uwgAuthorizations.Rows[i].Cells[3].Value),
                                Convert.ToString(uwgAuthorizations.Rows[i].Cells["Notes"].Value));
							if (retVal==-1)
								MessageBox.Show("Insert failed in row " + (i+1).ToString(), "Database Error", 
									MessageBoxButtons.OK, MessageBoxIcon.Error);

							break;
						}
					}
				}
				// Reset the dirty flag, reload the grid and reset the form buttons
				blnGridDirty = false;
				LoadGridAuth();
				if (rowNum!=0)
				{
					try 
					{
						this.uwgAuthorizations.ActiveRow = this.uwgAuthorizations.Rows[rowNum];
					}
					catch
					{
						//this.uwgAuthorizations.ActiveRow = this.uwgAuthorizations.Rows[0];
					}				    
				}
				LoadTotals();
				SetButtons();
				// get a handle to the main form so we can enable / disable the menus
				Form1 f = (Form1) this.ParentForm.MdiParent;
				f.EnableMenusAll();
                RefreshGeneralTab();
			}
		}

		private void pbFirst_Click(object sender, System.EventArgs e)
		{
			GridManager.FirstButtonHandler(uwgAuthorizations);
		}

		private void pbPrevious_Click(object sender, System.EventArgs e)
		{
			GridManager.PreviousButtonHandler(uwgAuthorizations);
		}

		private void pbNext_Click(object sender, System.EventArgs e)
		{
			GridManager.NextButtonHandler(uwgAuthorizations);
		}

		private void pbLast_Click(object sender, System.EventArgs e)
		{
			GridManager.LastButtonHandler(uwgAuthorizations);
		}

		public void LoadTotals()
		{
			this.txtNetSCC.Text = ProjectFundingData.GetFundTotal(GlobalSettings.projectId,"A").ToString("$###,###,###.00");	// #,###
			this.txtTotalMatchingFunds.Text = ProjectFundingData.GetFundTotal(GlobalSettings.projectId,"M").ToString("$###,###,###.00");	// #,###
			this.txtProjectCosts.Text = ProjectFundingData.GetFundTotal(GlobalSettings.projectId,"P").ToString("$###,###,###.00");		// #,###

			// ADS 7-Dec-2007 - 2.16 - Added new totals fields
			decimal authTotal = 0;
            reservedTotal = 0;
            decimal reimbTotal = 0;
            decimal totalMatch = 0;

            foreach (UltraGridRow row in this.uwgAuthorizations.Rows)
            {
                if (row.Cells[3].Value.ToString() != String.Empty)
                    authTotal += decimal.Parse(row.Cells[3].Value.ToString());
            }

            reimbTotal = ProjectFundingData.GetFundTotal(GlobalSettings.projectId, "G");
            reservedTotal = ProjectFundingData.GetFundTotal(GlobalSettings.projectId, "R");	


            foreach (UltraGridRow row in this.uwgMatchingFunds.Rows)
            {
                if (row.Cells[3].Value.ToString() != String.Empty)
                    totalMatch += decimal.Parse(row.Cells[3].Value.ToString());
            }
            
          
            decimal netscc = reservedTotal - reimbTotal;
            decimal projectCost = netscc + totalMatch;

            decimal amtEncumb = 0;
            amtEncumb = ProjectFundingData.GetFundTotal(GlobalSettings.projectId, "E");

			this.txtAmtAuthorized.Text = authTotal.ToString("$###,###,###.00");		// #,###  authTotal
			this.txtAmountReserved.Text = reservedTotal.ToString("$###,###,###.00");	// #,###
            this.txtAmtReserved.Text = reimbTotal.ToString("$###,###,###.00");	// #,###
            this.txtNetSCC.Text = netscc.ToString("$###,###,###.00");	// #,###
            this.txtTotalMatchingFunds.Text = totalMatch.ToString("$###,###,###.00");	// #,###
            this.txtProjectCosts.Text = projectCost.ToString("$###,###,###.00");	// #,###
            this.txtAmountEncumb.Text = amtEncumb.ToString("$###,###,###.00");

            string status = string.Empty;
            dsProject = ProjectData.GetProject(GlobalSettings.projectId);
            drProject = dsProject.Tables["Project"].Rows[0];
            switch ((int)drProject["StatusId"])
            {
                case 0:
                    status = "Active";
                    break;
                case 1:
                    status = string.Format("Inactive - Marked inactive on {0:d}", drProject["StatusDate"]);
                    break;
                case 2:
                    status = string.Format("Complete - Marked complete on {0:d}", drProject["StatusDate"]);
                    break;
                case 3:
                    status = string.Format("Closed - Marked closed on {0:d}", drProject["StatusDate"]);
                    break;
            }

            this.txtStatus.Text = status;

		}

		private void btnAddRes_Click(object sender, System.EventArgs e)
		{
			this.AddReservationRow();
		}

		private void AddReservationRow()
		{
			UltraGridRow authRow = this.uwgAuthorizations.ActiveRow;
			int AuthorizationId = 0;
			bool blnValidAuthRow = true;
			try
			{
				AuthorizationId = Convert.ToInt32(authRow.Cells["AuthorizationId"].Value);
			}
			catch
			{
				blnValidAuthRow = false;
				MessageBox.Show("Please select a valid Authorization row before adding a Reservation",
					"Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);			
			}
            
			if (blnValidAuthRow==true)
			{
				UltraGridRow addedRow = uwgReservations.DisplayLayout.Bands[0].AddNew( );
                addedRow.Cells["GrantAmount"].Value = "0";
                addedRow.Cells["AuthorizationId"].Value = AuthorizationId;
				addedRow.Cells["ReserveDate"].Value = System.DateTime.Now;
				addedRow.Cells["DirtyFlag"].Value = "3";
				blnGridResDirty = true;
				SetButtons();
                
			}
		}

		private void btnDeleteRes_Click(object sender, System.EventArgs e)
		{
			//delete active row
			UltraGridRow row = this.uwgReservations.ActiveRow;

			if ( null != row ) 
			{
                if (row.Cells["DirtyFlag"].Value.ToString() == "3")
                {
                    row.Delete();
                    return;
                }
                /*
                //do not allow to delete funding source if it is used in a contract associated with the project.
                int contractCount = GlobalCode.ToInt32(this.uwgReservations.ActiveRow.Cells["ContractCount"].Text);
                if (contractCount > 0)
                {
                    string contracts = "a contract";
                    if (contractCount > 1)
                        contracts = "multiple contracts";

                    MessageBox.Show("Funding Item is used in " + contracts + " associated with the project. Funding Item can not be deleted.", "Change Funding Source ", MessageBoxButtons.OK, MessageBoxIcon.Warning);
                    return;
                }
                */
                int fundid = GlobalCode.ToInt32(row.Cells["FundID"].Value);
                if (ProjectFundingData.HasContractFund(pid, fundid) == true)
                {
                    decimal contracted = ProjectFundingData.GetProjectContractFundAmount(pid, fundid);
                    decimal amt = GlobalCode.ToDecimal(row.Cells["Amount"].OriginalValue);
                    //other row with same fund
                    decimal fundAmt = 0;
                    decimal otherAmt = ProjectFundingData.GetProjectFundAmount(pid, (int)row.Cells["FundID"].Value, (int)row.Cells["AuthorizationId"].Value);
                    fundAmt += otherAmt;
                    foreach (UltraGridRow ugr in uwgReservations.Rows)
                    {
                        if (GlobalCode.ToInt32(ugr.Cells["FundId"].Value) == fundid)
                            fundAmt += GlobalCode.ToDecimal(ugr.Cells["Amount"].OriginalValue);
                    }
                    if (fundAmt != amt)     //multiple fund rows
                    {
                        //do not allow deleting negative balances
                        if ((fundAmt - contracted) < 0)
                        {
                            MessageBox.Show("This reservation cannot be deleted due to the negative balance of (" + (fundAmt - contracted).ToString(GlobalSettings.MoneyFormat) + ").",
                            "Delete failure !", MessageBoxButtons.OK, MessageBoxIcon.Error);
                            return;
                        }

                        if ((fundAmt - amt) < contracted)
                        {
                            string msg = "The contract amount (" + contracted.ToString(GlobalSettings.MoneyFormat) + ") for fund " +
                                ProjectFundingData.GetFundingItem(fundid) +
                                " can't be more than the remaining reserve amount total (" + (fundAmt - amt).ToString(GlobalSettings.MoneyFormat) + ").";
                            MessageBox.Show(msg, "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                            return;
                        }
                    }
                    else
                    {
                        MessageBox.Show("This reservation cannot be deleted because these funds are under contract. Row: " + (row.Index + 1),
                            "Delete failure !", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        return;
                    }
                }



				DialogResult intDiagResult = MessageBox.Show("Do you want to delete this Reservation, and save all other pending changes?","Delete Row", 
					MessageBoxButtons.YesNo, MessageBoxIcon.Question);
				if (intDiagResult == DialogResult.Yes)
				{
					// if the row is a database row then mark it for deletion and hide it in the grid
					if (row.Cells["DirtyFlag"].Value.ToString() == "0")
					{
						row.Hidden = true;
						row.Cells["DirtyFlag"].Value = "2";
						blnGridResDirty = true;
					}
						// else it was added by the user and not saved to the database - delete it from the grid
					else
					{
						row.Delete(false);
					}
					// set the active row to first (non-hidden) row
                    SaveReservations();
					GridManager.FirstButtonHandler(uwgReservations);
					
					// MAR 2005-03-28 - added Save (remove SetButtons)
					
				}
			} 
			else 
			{ 
				// If there is no active row, then prompt the user to select one. 
				MessageBox.Show( "Please select a single row to delete." ); 
			} 				
		}
		private void btnCancelRes_Click(object sender, System.EventArgs e)
		{
            
			if (blnGridResDirty == true)
			{
				DialogResult intDiagResult = MessageBox.Show("Data has changed - Do you want to cancel changes?","Cancel Changes", 
					MessageBoxButtons.YesNo, MessageBoxIcon.Question);
				if (intDiagResult == DialogResult.Yes)
				{
					LoadGridRes();
					blnGridResDirty = false;
					SetButtons();
					// get a handle to the main form so we can enable / disable the menus
					Form1 f = (Form1) this.ParentForm.MdiParent;
					f.EnableMenusAll();
					uwgAuthorizations.ActiveRow.Appearance.BackColorDisabled = Color.Empty; 
					uwgAuthorizations.ActiveRow.Appearance.ForeColorDisabled = Color.Empty;
				}
			}		
		}
		private void btnSaveRes_Click(object sender, System.EventArgs e)
		{
			SaveReservations();
		}

		private void SaveReservations()
		{
			int row;
			int retVal;
            int retVal1;
			string retMsg;
            string retMsg1;

            // Validate grid
            for (int i = 0; i < uwgReservations.Rows.Count; i++)
			{
				row = i + 1;

                if (uwgReservations.Rows[i].Cells["DirtyFlag"].Value.ToString() == "2")
                    continue;

                if (uwgReservations.Rows[i].Cells["FundID"].Value.ToString() == "")
				{
					MessageBox.Show("Please select a valid Funding Item for row " + row.ToString(),
						"Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
					return;
				}
				if (uwgReservations.Rows[i].Cells["ReserveDate"].Value.ToString() == String.Empty)
				{
					MessageBox.Show("Reserve date required in row " + row.ToString(),
						"Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }

                decimal amt = GlobalCode.ToDecimal(uwgReservations.Rows[i].Cells["Amount"].Value);
                if (amt == 0)
				{
					MessageBox.Show("Amount required in row " + row.ToString(), "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    return;
                }
                else
                {
                    //contract totals can't exceed amount
                    decimal contracted = ProjectFundingData.GetProjectContractFundAmount(pid, (int)uwgReservations.Rows[i].Cells["FundID"].Value);
                    decimal otherAmt = ProjectFundingData.GetProjectFundAmount(pid, (int)uwgReservations.Rows[i].Cells["FundID"].Value, (int)uwgReservations.Rows[i].Cells["AuthorizationId"].Value);
                    decimal fundAmt = amt + otherAmt;
                    for (int j = 0; j < uwgReservations.Rows.Count; j++)
                    {
                        if ((j != i) && (uwgReservations.Rows[j].Cells["FundId"].Value.ToString() == uwgReservations.Rows[i].Cells["FundId"].Value.ToString()))
                        {
                            fundAmt += GlobalCode.ToDecimal(uwgReservations.Rows[j].Cells["Amount"].Value);
                        }
                    }
                    if (fundAmt < contracted)
                    {
                        string msg = "The contract amount (" + contracted.ToString(GlobalSettings.MoneyFormat) + ") for fund " + 
                            ProjectFundingData.GetFundingItem(GlobalCode.ToInt32(uwgReservations.Rows[i].Cells["FundId"].Text)) + 
                            " exceeds the reserve amount total (" + fundAmt.ToString(GlobalSettings.MoneyFormat) + ").";
                        MessageBox.Show(msg , "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        return;
                    }
                }

                if (uwgReservations.Rows[i].Cells["ReimbTypeId"].Value.ToString() == "")
                {
                    uwgReservations.Rows[i].Cells[11].Value = 0;
                    uwgReservations.Rows[i].Cells[10].Value = 0;
                }
                else
                {
                    if (uwgReservations.Rows[i].Cells[10].Value.ToString() == "")
                    {
                        MessageBox.Show("Organization is required in row " + row.ToString(),
                            "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        return;
                    }
                    if (uwgReservations.Rows[i].Cells[11].Value.ToString() == String.Empty )
                    {                 
                        MessageBox.Show("Row " + row.ToString() + ": to change Reimb/Repayment amount, please use Matching Funds section below. \n\r\n\r " + 
                            "After changes in Matching Funds section are saved, Reimb/Repayment amount will be updated in funding reservation section automatically. \n\r" + 
                            "The entered Amount must be a valid numeric value. " ,
                        "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        return;
                    }
                    decimal reimbAmt = GlobalCode.ToDecimal(uwgReservations.Rows[i].Cells[11].Value);
                    if (reimbAmt > amt)
                    {
                        MessageBox.Show("Reimbursement amount can't be greater than the reserved amount in row " + row.ToString(),
                            "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                        return;
                    }
                }
			}

            reservedTotal = 0;
            foreach (UltraGridRow row1 in this.uwgReservations.Rows)
            {                
                if (row1.Cells[8].Value.ToString() == "" || row1.Cells[8].Value.ToString() == " ")
                {
                    row1.Cells[8].Value = 0;
                    blnGridResDirty = false;
                }
                reservedTotal += decimal.Parse(row1.Cells[8].Value.ToString());
            }
            UltraGridRow authRow = this.uwgAuthorizations.ActiveRow;
            decimal authorizedAmount = GlobalCode.ToDecimal(authRow.Cells[3].Value);
            if (reservedTotal > authorizedAmount)
            {
                MessageBox.Show("The sum of Reserved Amounts cannot exceed the Amount Authorized.");
                uwgReservations.ActiveRow.Cells[8].Value = uwgReservations.ActiveRow.Cells[8].OriginalValue;
                blnGridResDirty = false;
                return;
            }


            for (int i = 0; i < uwgReservations.Rows.Count; i++)
            {
                switch (uwgReservations.Rows[i].Cells["DirtyFlag"].Value.ToString())
                {
                    case "1":
                        {
                            // updated
                            if (uwgReservations.Rows[i].Cells["ReimbTypeId"].Value.ToString() == "")
                            {
                                retMsg = ProjectFundingData.ReservEncumbUpdate(
                                    Convert.ToInt32(uwgReservations.Rows[i].Cells["ReservEncumbId"].Value),
                                    Convert.ToInt32(uwgReservations.Rows[i].Cells["FundID"].Value),
                                    Convert.ToInt32(uwgReservations.Rows[i].Cells["AuthorizationId"].Value),
                                    Convert.ToDateTime(uwgReservations.Rows[i].Cells["ReserveDate"].Value),
                                    GlobalCode.ToDecimal(uwgReservations.Rows[i].Cells["Amount"].Value),
                                    GlobalCode.ToDecimal(uwgReservations.Rows[i].Cells["GrantAmount"].Value),
                                    Convert.ToString(uwgReservations.Rows[i].Cells["ReimbTypeId"].Value),
                                    Convert.ToString(uwgReservations.Rows[i].Cells["GrantSource"].Value));
                            }
                            else
                            {
                                retMsg = ProjectFundingData.ReservEncumbUpdate(
                                    Convert.ToInt32(uwgReservations.Rows[i].Cells["ReservEncumbId"].Value),
                                    Convert.ToInt32(uwgReservations.Rows[i].Cells["FundID"].Value),
                                    Convert.ToInt32(uwgReservations.Rows[i].Cells["AuthorizationId"].Value),
                                    Convert.ToDateTime(uwgReservations.Rows[i].Cells["ReserveDate"].Value),
                                    GlobalCode.ToDecimal(uwgReservations.Rows[i].Cells["Amount"].Value),
                                    GlobalCode.ToDecimal(uwgReservations.Rows[i].Cells["GrantAmount"].Value),
                                    Convert.ToString(uwgReservations.Rows[i].Cells["ReimbTypeId"].Value),
                                    Convert.ToString(uwgReservations.Rows[i].Cells["GrantSource"].Value));

                                //LoadGridRes();

                                int reId = Convert.ToInt32(this.uwgReservations.Rows[i].Cells[0].Value);

                                DbConnection dbConnection = DbConnection.GetDbConnection();
                                string connectionString = dbConnection.DbConnectionString;

                                DataSet ds1 = SqlHelper.ExecuteDataset(connectionString, CommandType.Text, "SELECT ReimbId, MatchingFundId FROM MatchingFund WHERE ReimbId = " + reId);
                                if (ds1.Tables[0].Rows.Count > 0)
                                {
                                    DataRow dr1 = ds1.Tables[0].Rows[0];
                                    int mid = Convert.ToInt32(dr1["MatchingFundId"]);
                                    retMsg1 = ProjectFundingData.MatchingFundUpdate(mid,
                                                 GlobalSettings.projectId,
                                                 Convert.ToInt32(uwgReservations.Rows[i].Cells[10].Value),
                                                 GlobalCode.ToDecimal(uwgReservations.Rows[i].Cells[11].Value),
                                                 uwgReservations.Rows[i].Cells["ReimbTypeId"].Value,
                                                 reId);

                                    if (retMsg != "success" && retMsg1 == "success")
                                        MessageBox.Show("Update failed in row " + (i + 1).ToString(), "Database Error",
                                            MessageBoxButtons.OK, MessageBoxIcon.Error);
                                }
                                else
                                {
                                    retVal1 = ProjectFundingData.MatchingFundInsert(GlobalSettings.projectId,
                                       Convert.ToInt32(uwgReservations.Rows[i].Cells[10].Value),
                                       GlobalCode.ToDecimal(uwgReservations.Rows[i].Cells[11].Value),
                                       Convert.ToInt32(uwgReservations.Rows[i].Cells["ReimbTypeId"].Value),
                                       reId);

                                    if (retMsg != "success" && retVal1 == -1)
                                        MessageBox.Show("Update failed in row " + (i + 1).ToString(), "Database Error",
                                            MessageBoxButtons.OK, MessageBoxIcon.Error);
                                }
                            }

                            break;
                        }
                    case "2":
                        {
                        //    retMsg = ProjectFundingData.ReservEncumbDelete(Convert.ToInt32(uwgReservations.Rows[i].Cells["ReservEncumbID"].Value));
                        //    if (retMsg != "success")
                        //        MessageBox.Show("Delete failed in row " + (i + 1).ToString(), "Database Error",
                        //            MessageBoxButtons.OK, MessageBoxIcon.Error);

                        //    if (uwgReservations.Rows[i].Cells["ReimbTypeId"].Value.ToString() == "")
                        //    {

                        //    }
                        //    else
                        //    {
                        //        retMsg1 = ProjectFundingData.MatchingFundDelete(Convert.ToInt32(uwgReservations.Rows[i].Cells["ReservEncumbID"].Value));
                        //        if (retMsg != "success" && retMsg1 != "success")
                        //            MessageBox.Show("Update failed in row " + (i + 1).ToString(), "Database Error",
                        //                MessageBoxButtons.OK, MessageBoxIcon.Error);
                        //    }
                        //    //LoadGridRes();
                        //    break;

                            if (uwgReservations.Rows[i].Cells["ReimbTypeId"].Value.ToString() != "")
                            {

                                DialogResult intDiagResult = MessageBox.Show("Deleting reservation row for Funding Item " + Convert.ToString(uwgReservations.Rows[i].Cells["FundingItem"].Value) + " will also delete the associated Matching Funds. Do you want to continue?", "Delete Row",
                                MessageBoxButtons.YesNo, MessageBoxIcon.Question);

                                if (intDiagResult==DialogResult.No)
                                   return;
                                else
                                {
                                    retMsg = ProjectFundingData.MatchingFundDeleteByReimbId(Convert.ToInt32(uwgReservations.Rows[i].Cells["ReservEncumbID"].Value));
                                    if (retMsg != "success")
                                    {
                                        MessageBox.Show("Delete failed in row " + (i + 1).ToString() + " for Funding Item " + Convert.ToString(uwgReservations.Rows[i].Cells["FundingItem"].Value), "Database Error",
                                            MessageBoxButtons.OK, MessageBoxIcon.Error);
                                        return;
                                    }
                                }
                            }

                            retMsg = ProjectFundingData.ReservEncumbDelete(Convert.ToInt32(uwgReservations.Rows[i].Cells["ReservEncumbID"].Value));
                            if (retMsg != "success")
                                MessageBox.Show("Delete failed in row " + (i + 1).ToString(), "Database Error",
                                    MessageBoxButtons.OK, MessageBoxIcon.Error);


                            break;

                        }
                    case "3":
                        {
                            if (uwgReservations.Rows[i].Cells["ReimbTypeId"].Value.ToString() == "")
                            {
                                retVal = ProjectFundingData.ReservEncumbInsert(
                                Convert.ToInt32(uwgReservations.Rows[i].Cells["FundID"].Value),
                                Convert.ToInt32(uwgReservations.Rows[i].Cells["AuthorizationId"].Value),
                                Convert.ToDateTime(uwgReservations.Rows[i].Cells["ReserveDate"].Value),
                                GlobalCode.ToDecimal(uwgReservations.Rows[i].Cells["Amount"].Value),
                                GlobalCode.ToDecimal(uwgReservations.Rows[i].Cells[11].Value),
                                uwgReservations.Rows[i].Cells["ReimbTypeId"].Value,
                                Convert.ToString(uwgReservations.Rows[i].Cells[10].Value));

                                if (retVal == -1)
                                    MessageBox.Show("Insert failed in row " + (i + 1).ToString(), "Database Error",
                                        MessageBoxButtons.OK, MessageBoxIcon.Error);

                                //LoadGridRes();
                            }
                            else
                            {
                                retVal = ProjectFundingData.ReservEncumbInsert(
                               Convert.ToInt32(uwgReservations.Rows[i].Cells["FundID"].Value),
                               Convert.ToInt32(uwgReservations.Rows[i].Cells["AuthorizationId"].Value),
                               Convert.ToDateTime(uwgReservations.Rows[i].Cells["ReserveDate"].Value),
                               GlobalCode.ToDecimal(uwgReservations.Rows[i].Cells["Amount"].Value),
                               GlobalCode.ToDecimal(uwgReservations.Rows[i].Cells[11].Value),
                               uwgReservations.Rows[i].Cells["ReimbTypeId"].Value,
                               Convert.ToString(uwgReservations.Rows[i].Cells[10].Value));

                                //LoadGridRes();

                                int reId = retVal;     //Convert.ToInt32(this.uwgReservations.Rows[i].Cells[0].Value);
                                retVal1 = ProjectFundingData.MatchingFundInsert(GlobalSettings.projectId,
                                    Convert.ToInt32(uwgReservations.Rows[i].Cells[10].Value),
                                    GlobalCode.ToDecimal(uwgReservations.Rows[i].Cells[11].Value),
                                    Convert.ToInt32(uwgReservations.Rows[i].Cells["ReimbTypeId"].Value),
                                    reId);

                                if (retVal == -1 && retVal1 == -1)
                                    MessageBox.Show("Insert failed in row " + (i + 1).ToString(), "Database Error",
                                        MessageBoxButtons.OK, MessageBoxIcon.Error);
                            }

                            break;
                        }
                }
            }
            // Reset the dirty flag, reload the grid and reset the form buttons
            blnGridResDirty = false;
            blnGridMatchDirty = false;
            //LoadGridAuth();
            LoadGridRes();
            LoadMatching();
            // need to update the total in Auth grid
            LoadTotals();
            //LoadAuthTotal();
            SetButtons();
            // get a handle to the main form so we can enable / disable the menus
            Form1 f = (Form1)this.ParentForm.MdiParent;
            f.EnableMenusAll();
            ProjectForm pf = (ProjectForm)this.ParentForm;
            pf.RefreshProjectPage();
            Point p = new Point(0, 0);
            this.AutoScrollPosition = p;
            this.uwgAuthorizations.ActiveRow.Appearance.BackColorDisabled = Color.Empty;
            this.uwgAuthorizations.ActiveRow.Appearance.ForeColorDisabled = Color.Empty;
            RefreshGeneralTab();
        }

        private void RefreshGeneralTab()
        {
            ProjectForm pf = (ProjectForm)this.ParentForm;
            pf.RefreshProjectPage();
        }

		private void LoadAuthTotal()
		{
			// update calculated amount in the current authorization grid row
			// this is called after a Save of reservations grid
			int AuthorizationId = Convert.ToInt32(this.uwgAuthorizations.ActiveRow.Cells["AuthorizationId"].Value); 
			//this.uwgAuthorizations.ActiveRow.Cells["TotalAmount"].Value = ProjectFundingData.GetAuthorizationTotal(AuthorizationId);

			// When we change TotalAmount, we don't what the grid to go into edit mode
			// This is a work-around for that problem. 
			int rowIndex = this.uwgAuthorizations.ActiveRow.Index;
			//this.LoadGridAuth();
			this.uwgAuthorizations.ActiveRow = this.uwgAuthorizations.Rows[rowIndex];            
		}

		private void pbFirstRes_Click(object sender, System.EventArgs e)
		{
			GridManager.FirstButtonHandler(uwgReservations);
		}

		private void pbPreviousRes_Click(object sender, System.EventArgs e)
		{
			GridManager.PreviousButtonHandler(uwgReservations);	
		}

		private void pbNextRes_Click(object sender, System.EventArgs e)
		{
			GridManager.NextButtonHandler(uwgReservations);	
		}

		private void pbLastRes_Click(object sender, System.EventArgs e)
		{
			GridManager.LastButtonHandler(uwgReservations);		
		}

		public void FundingSaveReminderMsg()
		{
			string msg = "Changes have been made on the Funding screen. Please save or cancel your changes.";
			DialogResult intDiagResult = MessageBox.Show(this,msg, "Data Changed", MessageBoxButtons.OK, MessageBoxIcon.Warning);
		}


		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            Infragistics.Win.UltraWinGrid.UltraGridBand ultraGridBand1 = new Infragistics.Win.UltraWinGrid.UltraGridBand("", -1);
            Infragistics.Win.Appearance appearance1 = new Infragistics.Win.Appearance();
            this.btnDelete = new System.Windows.Forms.Button();
            this.btnSave = new System.Windows.Forms.Button();
            this.btnCancel = new System.Windows.Forms.Button();
            this.btnAdd = new System.Windows.Forms.Button();
            this.uwgAuthorizations = new Infragistics.Win.UltraWinGrid.UltraGrid();
            this.uddFundingSource = new Infragistics.Win.UltraWinGrid.UltraDropDown();
            this.lblTotalConservany = new System.Windows.Forms.Label();
            this.txtNetSCC = new System.Windows.Forms.TextBox();
            this.txtTotalMatchingFunds = new System.Windows.Forms.TextBox();
            this.lblTotalMatchingFunds = new System.Windows.Forms.Label();
            this.txtProjectCosts = new System.Windows.Forms.TextBox();
            this.label2 = new System.Windows.Forms.Label();
            this.grpTotals = new System.Windows.Forms.GroupBox();
            this.label6 = new System.Windows.Forms.Label();
            this.panel1 = new System.Windows.Forms.Panel();
            this.label8 = new System.Windows.Forms.Label();
            this.txtAmountReserved = new System.Windows.Forms.TextBox();
            this.label1 = new System.Windows.Forms.Label();
            this.label3 = new System.Windows.Forms.Label();
            this.txtAmtReserved = new System.Windows.Forms.TextBox();
            this.txtAmtAuthorized = new System.Windows.Forms.TextBox();
            this.txtAmountEncumb = new System.Windows.Forms.TextBox();
            this.label5 = new System.Windows.Forms.Label();
            this.label4 = new System.Windows.Forms.Label();
            this.txtStatus = new System.Windows.Forms.TextBox();
            this.btnAddRes = new System.Windows.Forms.Button();
            this.btnDeleteRes = new System.Windows.Forms.Button();
            this.btnSaveRes = new System.Windows.Forms.Button();
            this.btnCancelRes = new System.Windows.Forms.Button();
            this.lblInstructions = new System.Windows.Forms.Label();
            this.uwgReservations = new Infragistics.Win.UltraWinGrid.UltraGrid();
            this.btnRefresh = new System.Windows.Forms.Button();
            this.btnNewMatch = new System.Windows.Forms.Button();
            this.btnCancelMatch = new System.Windows.Forms.Button();
            this.btnSaveMatch = new System.Windows.Forms.Button();
            this.btnDeleteMatch = new System.Windows.Forms.Button();
            this.btnAddMatch = new System.Windows.Forms.Button();
            this.uwgMatchingFunds = new Infragistics.Win.UltraWinGrid.UltraGrid();
            this.label7 = new System.Windows.Forms.Label();
            this.btnShowAll = new System.Windows.Forms.Button();
            this.uddOrgSource = new Infragistics.Win.UltraWinGrid.UltraDropDown();
            ((System.ComponentModel.ISupportInitialize)(this.uwgAuthorizations)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.uddFundingSource)).BeginInit();
            this.grpTotals.SuspendLayout();
            this.panel1.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.uwgReservations)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.uwgMatchingFunds)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.uddOrgSource)).BeginInit();
            this.SuspendLayout();
            // 
            // btnDelete
            // 
            this.btnDelete.Enabled = false;
            this.btnDelete.Location = new System.Drawing.Point(114, 169);
            this.btnDelete.Name = "btnDelete";
            this.btnDelete.Size = new System.Drawing.Size(64, 24);
            this.btnDelete.TabIndex = 23;
            this.btnDelete.Text = "Delete";
            this.btnDelete.Click += new System.EventHandler(this.btnDelete_Click);
            // 
            // btnSave
            // 
            this.btnSave.Enabled = false;
            this.btnSave.Location = new System.Drawing.Point(200, 169);
            this.btnSave.Name = "btnSave";
            this.btnSave.Size = new System.Drawing.Size(64, 24);
            this.btnSave.TabIndex = 24;
            this.btnSave.Text = "Save";
            this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
            // 
            // btnCancel
            // 
            this.btnCancel.Enabled = false;
            this.btnCancel.Location = new System.Drawing.Point(285, 169);
            this.btnCancel.Name = "btnCancel";
            this.btnCancel.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.btnCancel.Size = new System.Drawing.Size(64, 24);
            this.btnCancel.TabIndex = 25;
            this.btnCancel.Text = "Cancel";
            this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
            // 
            // btnAdd
            // 
            this.btnAdd.Location = new System.Drawing.Point(28, 169);
            this.btnAdd.Name = "btnAdd";
            this.btnAdd.Size = new System.Drawing.Size(64, 24);
            this.btnAdd.TabIndex = 22;
            this.btnAdd.Text = "Add";
            this.btnAdd.Click += new System.EventHandler(this.btnAdd_Click);
            // 
            // uwgAuthorizations
            // 
            this.uwgAuthorizations.Cursor = System.Windows.Forms.Cursors.Hand;
            this.uwgAuthorizations.Font = new System.Drawing.Font("Arial", 8F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.uwgAuthorizations.Location = new System.Drawing.Point(18, 16);
            this.uwgAuthorizations.Name = "uwgAuthorizations";
            this.uwgAuthorizations.Size = new System.Drawing.Size(557, 147);
            this.uwgAuthorizations.TabIndex = 28;
            this.uwgAuthorizations.Text = "AUTHORIZATIONS";
            this.uwgAuthorizations.AfterCellUpdate += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgAuthorizations_AfterCellUpdate);
            this.uwgAuthorizations.CellListSelect += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgAuthorizations_CellListSelect);
            this.uwgAuthorizations.KeyDown += new System.Windows.Forms.KeyEventHandler(this.uwgAuthorizations_KeyDown);
            this.uwgAuthorizations.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(this.uwgAuthorizations_InitializeLayout);
            this.uwgAuthorizations.AfterRowActivate += new System.EventHandler(this.uwgAuthorizations_AfterRowActivate);
            // 
            // uddFundingSource
            // 
            this.uddFundingSource.Font = new System.Drawing.Font("Arial", 8F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.uddFundingSource.Location = new System.Drawing.Point(352, 329);
            this.uddFundingSource.Name = "uddFundingSource";
            this.uddFundingSource.Size = new System.Drawing.Size(424, 57);
            this.uddFundingSource.TabIndex = 50;
            this.uddFundingSource.Visible = false;
            this.uddFundingSource.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(this.uddFundingSource_InitializeLayout);
            // 
            // lblTotalConservany
            // 
            this.lblTotalConservany.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblTotalConservany.Location = new System.Drawing.Point(5, 107);
            this.lblTotalConservany.Name = "lblTotalConservany";
            this.lblTotalConservany.Size = new System.Drawing.Size(208, 16);
            this.lblTotalConservany.TabIndex = 34;
            this.lblTotalConservany.Text = "Net Conservancy Contribution";
            // 
            // txtNetSCC
            // 
            this.txtNetSCC.BackColor = System.Drawing.Color.White;
            this.txtNetSCC.Enabled = false;
            this.txtNetSCC.Location = new System.Drawing.Point(218, 102);
            this.txtNetSCC.Name = "txtNetSCC";
            this.txtNetSCC.Size = new System.Drawing.Size(104, 21);
            this.txtNetSCC.TabIndex = 35;
            this.txtNetSCC.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // txtTotalMatchingFunds
            // 
            this.txtTotalMatchingFunds.BackColor = System.Drawing.Color.White;
            this.txtTotalMatchingFunds.Enabled = false;
            this.txtTotalMatchingFunds.Location = new System.Drawing.Point(229, 196);
            this.txtTotalMatchingFunds.Name = "txtTotalMatchingFunds";
            this.txtTotalMatchingFunds.Size = new System.Drawing.Size(104, 21);
            this.txtTotalMatchingFunds.TabIndex = 37;
            this.txtTotalMatchingFunds.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // lblTotalMatchingFunds
            // 
            this.lblTotalMatchingFunds.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblTotalMatchingFunds.Location = new System.Drawing.Point(16, 201);
            this.lblTotalMatchingFunds.Name = "lblTotalMatchingFunds";
            this.lblTotalMatchingFunds.Size = new System.Drawing.Size(208, 16);
            this.lblTotalMatchingFunds.TabIndex = 36;
            this.lblTotalMatchingFunds.Text = "Total Match incl. Reimb/Repayments";
            // 
            // txtProjectCosts
            // 
            this.txtProjectCosts.BackColor = System.Drawing.Color.White;
            this.txtProjectCosts.Enabled = false;
            this.txtProjectCosts.Location = new System.Drawing.Point(229, 222);
            this.txtProjectCosts.Name = "txtProjectCosts";
            this.txtProjectCosts.Size = new System.Drawing.Size(104, 21);
            this.txtProjectCosts.TabIndex = 39;
            this.txtProjectCosts.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // label2
            // 
            this.label2.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label2.Location = new System.Drawing.Point(16, 227);
            this.label2.Name = "label2";
            this.label2.Size = new System.Drawing.Size(160, 16);
            this.label2.TabIndex = 38;
            this.label2.Text = "Total Project Cost";
            // 
            // grpTotals
            // 
            this.grpTotals.Controls.Add(this.label6);
            this.grpTotals.Controls.Add(this.panel1);
            this.grpTotals.Controls.Add(this.txtTotalMatchingFunds);
            this.grpTotals.Controls.Add(this.label2);
            this.grpTotals.Controls.Add(this.lblTotalMatchingFunds);
            this.grpTotals.Controls.Add(this.txtProjectCosts);
            this.grpTotals.Controls.Add(this.label4);
            this.grpTotals.Controls.Add(this.txtStatus);
            this.grpTotals.Location = new System.Drawing.Point(600, 10);
            this.grpTotals.Name = "grpTotals";
            this.grpTotals.Size = new System.Drawing.Size(376, 254);
            this.grpTotals.TabIndex = 40;
            this.grpTotals.TabStop = false;
            this.grpTotals.Text = "Projected Project Totals";
            // 
            // label6
            // 
            this.label6.AutoSize = true;
            this.label6.Location = new System.Drawing.Point(2, 36);
            this.label6.Name = "label6";
            this.label6.Size = new System.Drawing.Size(352, 15);
            this.label6.TabIndex = 64;
            this.label6.Text = "Note: Please see the contract details for up-to-date information.";
            // 
            // panel1
            // 
            this.panel1.BorderStyle = System.Windows.Forms.BorderStyle.Fixed3D;
            this.panel1.Controls.Add(this.label8);
            this.panel1.Controls.Add(this.txtAmountReserved);
            this.panel1.Controls.Add(this.label1);
            this.panel1.Controls.Add(this.lblTotalConservany);
            this.panel1.Controls.Add(this.txtNetSCC);
            this.panel1.Controls.Add(this.label3);
            this.panel1.Controls.Add(this.txtAmtReserved);
            this.panel1.Controls.Add(this.txtAmtAuthorized);
            this.panel1.Controls.Add(this.txtAmountEncumb);
            this.panel1.Controls.Add(this.label5);
            this.panel1.Location = new System.Drawing.Point(9, 54);
            this.panel1.Name = "panel1";
            this.panel1.Size = new System.Drawing.Size(337, 136);
            this.panel1.TabIndex = 63;
            // 
            // label8
            // 
            this.label8.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label8.Location = new System.Drawing.Point(5, 27);
            this.label8.Name = "label8";
            this.label8.Size = new System.Drawing.Size(160, 16);
            this.label8.TabIndex = 42;
            this.label8.Text = "Total Amount Reserved";
            // 
            // txtAmountReserved
            // 
            this.txtAmountReserved.BackColor = System.Drawing.Color.White;
            this.txtAmountReserved.Enabled = false;
            this.txtAmountReserved.Location = new System.Drawing.Point(218, 24);
            this.txtAmountReserved.Name = "txtAmountReserved";
            this.txtAmountReserved.Size = new System.Drawing.Size(104, 21);
            this.txtAmountReserved.TabIndex = 43;
            this.txtAmountReserved.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // label1
            // 
            this.label1.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label1.Location = new System.Drawing.Point(5, 3);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(160, 16);
            this.label1.TabIndex = 36;
            this.label1.Text = "Total Amount Authorized";
            // 
            // label3
            // 
            this.label3.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label3.Location = new System.Drawing.Point(5, 80);
            this.label3.Name = "label3";
            this.label3.Size = new System.Drawing.Size(191, 16);
            this.label3.TabIndex = 38;
            this.label3.Text = "Total amount to be Reimb/Repaid";
            // 
            // txtAmtReserved
            // 
            this.txtAmtReserved.BackColor = System.Drawing.Color.White;
            this.txtAmtReserved.Enabled = false;
            this.txtAmtReserved.Location = new System.Drawing.Point(218, 75);
            this.txtAmtReserved.Name = "txtAmtReserved";
            this.txtAmtReserved.Size = new System.Drawing.Size(104, 21);
            this.txtAmtReserved.TabIndex = 39;
            this.txtAmtReserved.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // txtAmtAuthorized
            // 
            this.txtAmtAuthorized.BackColor = System.Drawing.Color.White;
            this.txtAmtAuthorized.Enabled = false;
            this.txtAmtAuthorized.Location = new System.Drawing.Point(218, -2);
            this.txtAmtAuthorized.Name = "txtAmtAuthorized";
            this.txtAmtAuthorized.Size = new System.Drawing.Size(104, 21);
            this.txtAmtAuthorized.TabIndex = 37;
            this.txtAmtAuthorized.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // txtAmountEncumb
            // 
            this.txtAmountEncumb.BackColor = System.Drawing.Color.White;
            this.txtAmountEncumb.Enabled = false;
            this.txtAmountEncumb.Location = new System.Drawing.Point(218, 49);
            this.txtAmountEncumb.Name = "txtAmountEncumb";
            this.txtAmountEncumb.Size = new System.Drawing.Size(104, 21);
            this.txtAmountEncumb.TabIndex = 41;
            this.txtAmountEncumb.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // label5
            // 
            this.label5.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label5.Location = new System.Drawing.Point(5, 52);
            this.label5.Name = "label5";
            this.label5.Size = new System.Drawing.Size(160, 16);
            this.label5.TabIndex = 40;
            this.label5.Text = "Total Amount Encumbered";
            // 
            // label4
            // 
            this.label4.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label4.Location = new System.Drawing.Point(18, 19);
            this.label4.Name = "label4";
            this.label4.Size = new System.Drawing.Size(86, 21);
            this.label4.TabIndex = 38;
            this.label4.Text = "Project Status";
            // 
            // txtStatus
            // 
            this.txtStatus.BackColor = System.Drawing.Color.White;
            this.txtStatus.Enabled = false;
            this.txtStatus.Location = new System.Drawing.Point(108, 15);
            this.txtStatus.Name = "txtStatus";
            this.txtStatus.Size = new System.Drawing.Size(224, 21);
            this.txtStatus.TabIndex = 39;
            this.txtStatus.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // btnAddRes
            // 
            this.btnAddRes.Location = new System.Drawing.Point(22, 432);
            this.btnAddRes.Name = "btnAddRes";
            this.btnAddRes.Size = new System.Drawing.Size(103, 24);
            this.btnAddRes.TabIndex = 42;
            this.btnAddRes.Text = "Reserve Funds";
            this.btnAddRes.Click += new System.EventHandler(this.btnAddRes_Click);
            // 
            // btnDeleteRes
            // 
            this.btnDeleteRes.Location = new System.Drawing.Point(154, 432);
            this.btnDeleteRes.Name = "btnDeleteRes";
            this.btnDeleteRes.Size = new System.Drawing.Size(64, 24);
            this.btnDeleteRes.TabIndex = 43;
            this.btnDeleteRes.Text = "Delete";
            this.btnDeleteRes.Click += new System.EventHandler(this.btnDeleteRes_Click);
            // 
            // btnSaveRes
            // 
            this.btnSaveRes.Enabled = false;
            this.btnSaveRes.Location = new System.Drawing.Point(246, 432);
            this.btnSaveRes.Name = "btnSaveRes";
            this.btnSaveRes.Size = new System.Drawing.Size(64, 24);
            this.btnSaveRes.TabIndex = 44;
            this.btnSaveRes.Text = "Save";
            this.btnSaveRes.Click += new System.EventHandler(this.btnSaveRes_Click);
            // 
            // btnCancelRes
            // 
            this.btnCancelRes.Enabled = false;
            this.btnCancelRes.Location = new System.Drawing.Point(338, 432);
            this.btnCancelRes.Name = "btnCancelRes";
            this.btnCancelRes.Size = new System.Drawing.Size(64, 24);
            this.btnCancelRes.TabIndex = 45;
            this.btnCancelRes.Text = "Cancel";
            this.btnCancelRes.Click += new System.EventHandler(this.btnCancelRes_Click);
            // 
            // lblInstructions
            // 
            this.lblInstructions.Font = new System.Drawing.Font("Arial", 7.75F);
            this.lblInstructions.ForeColor = System.Drawing.Color.Green;
            this.lblInstructions.Location = new System.Drawing.Point(20, 473);
            this.lblInstructions.Name = "lblInstructions";
            this.lblInstructions.Size = new System.Drawing.Size(886, 24);
            this.lblInstructions.TabIndex = 51;
            this.lblInstructions.Text = "lblInstructions";
            // 
            // uwgReservations
            // 
            this.uwgReservations.Cursor = System.Windows.Forms.Cursors.Hand;
            this.uwgReservations.Font = new System.Drawing.Font("Arial", 8F);
            this.uwgReservations.Location = new System.Drawing.Point(14, 279);
            this.uwgReservations.Name = "uwgReservations";
            this.uwgReservations.Size = new System.Drawing.Size(962, 147);
            this.uwgReservations.TabIndex = 41;
            this.uwgReservations.Text = "RESERVATION OF FUNDS";
            this.uwgReservations.MouseDown += new System.Windows.Forms.MouseEventHandler(this.uwgReservations_MouseDown);
            this.uwgReservations.AfterCellUpdate += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgReservations_AfterCellUpdate);
            this.uwgReservations.CellListSelect += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgReservations_CellListSelect);
            this.uwgReservations.KeyDown += new System.Windows.Forms.KeyEventHandler(this.uwgReservations_KeyDown);
            this.uwgReservations.BeforeCellListDropDown += new Infragistics.Win.UltraWinGrid.CancelableCellEventHandler(this.uwgReservations_BeforeCellListDropDown);
            this.uwgReservations.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(this.uwgReservations_InitializeLayout);
            this.uwgReservations.AfterRowActivate += new System.EventHandler(this.uwgReservations_AfterRowActivate);
            // 
            // btnRefresh
            // 
            this.btnRefresh.Enabled = false;
            this.btnRefresh.Location = new System.Drawing.Point(755, 658);
            this.btnRefresh.Name = "btnRefresh";
            this.btnRefresh.Size = new System.Drawing.Size(76, 24);
            this.btnRefresh.TabIndex = 61;
            this.btnRefresh.Text = "Refresh";
            this.btnRefresh.Click += new System.EventHandler(this.btnRefresh_Click);
            // 
            // btnNewMatch
            // 
            this.btnNewMatch.Font = new System.Drawing.Font("Arial", 8F);
            this.btnNewMatch.Location = new System.Drawing.Point(442, 658);
            this.btnNewMatch.Name = "btnNewMatch";
            this.btnNewMatch.Size = new System.Drawing.Size(143, 24);
            this.btnNewMatch.TabIndex = 60;
            this.btnNewMatch.Text = "Add New Organization";
            this.btnNewMatch.Click += new System.EventHandler(this.btnNewMatch_Click);
            // 
            // btnCancelMatch
            // 
            this.btnCancelMatch.Enabled = false;
            this.btnCancelMatch.Location = new System.Drawing.Point(338, 658);
            this.btnCancelMatch.Name = "btnCancelMatch";
            this.btnCancelMatch.Size = new System.Drawing.Size(76, 24);
            this.btnCancelMatch.TabIndex = 58;
            this.btnCancelMatch.Text = "Cancel";
            this.btnCancelMatch.Click += new System.EventHandler(this.btnCancelMatch_Click);
            // 
            // btnSaveMatch
            // 
            this.btnSaveMatch.Enabled = false;
            this.btnSaveMatch.Location = new System.Drawing.Point(234, 658);
            this.btnSaveMatch.Name = "btnSaveMatch";
            this.btnSaveMatch.Size = new System.Drawing.Size(76, 24);
            this.btnSaveMatch.TabIndex = 57;
            this.btnSaveMatch.Text = "Save";
            this.btnSaveMatch.Click += new System.EventHandler(this.btnSaveMatch_Click);
            // 
            // btnDeleteMatch
            // 
            this.btnDeleteMatch.Enabled = false;
            this.btnDeleteMatch.Location = new System.Drawing.Point(130, 658);
            this.btnDeleteMatch.Name = "btnDeleteMatch";
            this.btnDeleteMatch.Size = new System.Drawing.Size(76, 24);
            this.btnDeleteMatch.TabIndex = 56;
            this.btnDeleteMatch.Text = "Delete";
            this.btnDeleteMatch.Click += new System.EventHandler(this.btnDeleteMatch_Click);
            // 
            // btnAddMatch
            // 
            this.btnAddMatch.Location = new System.Drawing.Point(26, 658);
            this.btnAddMatch.Name = "btnAddMatch";
            this.btnAddMatch.Size = new System.Drawing.Size(76, 24);
            this.btnAddMatch.TabIndex = 55;
            this.btnAddMatch.Text = "Add";
            this.btnAddMatch.Click += new System.EventHandler(this.btnAddMatch_Click);
            // 
            // uwgMatchingFunds
            // 
            this.uwgMatchingFunds.Cursor = System.Windows.Forms.Cursors.Hand;
            appearance1.BackColor = System.Drawing.SystemColors.Info;
            ultraGridBand1.Header.Appearance = appearance1;
            this.uwgMatchingFunds.DisplayLayout.BandsSerializer.Add(ultraGridBand1);
            this.uwgMatchingFunds.Font = new System.Drawing.Font("Arial", 8F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.uwgMatchingFunds.Location = new System.Drawing.Point(14, 500);
            this.uwgMatchingFunds.Name = "uwgMatchingFunds";
            this.uwgMatchingFunds.Size = new System.Drawing.Size(958, 152);
            this.uwgMatchingFunds.TabIndex = 59;
            this.uwgMatchingFunds.Text = "MATCHING FUNDS";
            this.uwgMatchingFunds.AfterCellUpdate += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgMatchingFunds_AfterCellUpdate_1);
            this.uwgMatchingFunds.KeyDown += new System.Windows.Forms.KeyEventHandler(this.uwgMatchingFunds_KeyDown);
            this.uwgMatchingFunds.BeforeCellListDropDown += new Infragistics.Win.UltraWinGrid.CancelableCellEventHandler(this.uwgMatchingFunds_BeforeCellListDropDown);
            this.uwgMatchingFunds.CellChange += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgMatchingFunds_CellChange);
            // 
            // label7
            // 
            this.label7.AutoSize = true;
            this.label7.Location = new System.Drawing.Point(15, 259);
            this.label7.Name = "label7";
            this.label7.Size = new System.Drawing.Size(416, 15);
            this.label7.TabIndex = 63;
            this.label7.Text = "Note: You must first select an authorization and then click Reserve Funds.";
            // 
            // btnShowAll
            // 
            this.btnShowAll.Location = new System.Drawing.Point(432, 432);
            this.btnShowAll.Name = "btnShowAll";
            this.btnShowAll.Size = new System.Drawing.Size(143, 24);
            this.btnShowAll.TabIndex = 45;
            this.btnShowAll.Text = "Show All Reservations";
            this.btnShowAll.Click += new System.EventHandler(this.btnShowAll_Click);
            // 
            // uddOrgSource
            // 
            this.uddOrgSource.Font = new System.Drawing.Font("Arial", 8F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.uddOrgSource.Location = new System.Drawing.Point(352, 532);
            this.uddOrgSource.Name = "uddOrgSource";
            this.uddOrgSource.Size = new System.Drawing.Size(424, 57);
            this.uddOrgSource.TabIndex = 64;
            this.uddOrgSource.Visible = false;
            this.uddOrgSource.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(this.uddOrgSource_InitializeLayout);
            // 
            // Authorizations
            // 
            this.AutoScroll = true;
            this.Controls.Add(this.uwgReservations);
            this.Controls.Add(this.uddFundingSource);
            this.Controls.Add(this.uwgMatchingFunds);
            this.Controls.Add(this.uddOrgSource);
            this.Controls.Add(this.btnShowAll);
            this.Controls.Add(this.label7);
            this.Controls.Add(this.btnRefresh);
            this.Controls.Add(this.btnNewMatch);
            this.Controls.Add(this.btnCancelMatch);
            this.Controls.Add(this.btnSaveMatch);
            this.Controls.Add(this.btnDeleteMatch);
            this.Controls.Add(this.btnAddMatch);
            this.Controls.Add(this.lblInstructions);
            this.Controls.Add(this.btnAddRes);
            this.Controls.Add(this.btnDeleteRes);
            this.Controls.Add(this.btnSaveRes);
            this.Controls.Add(this.btnCancelRes);
            this.Controls.Add(this.uwgAuthorizations);
            this.Controls.Add(this.grpTotals);
            this.Controls.Add(this.btnAdd);
            this.Controls.Add(this.btnDelete);
            this.Controls.Add(this.btnSave);
            this.Controls.Add(this.btnCancel);
            this.Font = new System.Drawing.Font("Arial", 9F);
            this.Name = "Authorizations";
            this.Size = new System.Drawing.Size(1000, 730);
            ((System.ComponentModel.ISupportInitialize)(this.uwgAuthorizations)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.uddFundingSource)).EndInit();
            this.grpTotals.ResumeLayout(false);
            this.grpTotals.PerformLayout();
            this.panel1.ResumeLayout(false);
            this.panel1.PerformLayout();
            ((System.ComponentModel.ISupportInitialize)(this.uwgReservations)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.uwgMatchingFunds)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.uddOrgSource)).EndInit();
            this.ResumeLayout(false);
            this.PerformLayout();

		}
		#endregion       

        private void btnDeleteMatch_Click(object sender, EventArgs e)
        {
            // Get the row to delete. In this case we will use the active row. 
            UltraGridRow row = this.uwgMatchingFunds.ActiveRow;

            if (null != row)
            {
                DialogResult intDiagResult;
                if (row.Cells[4].Value.ToString() == string.Empty)
                {
                    intDiagResult = MessageBox.Show("Do you want to delete this row and save all other pending changes?", "Delete Row",
                        MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                }
                else
                {
                    intDiagResult = MessageBox.Show("Deleting this row will remove the Reimbursement/Repayment information from the linked reservation. This may require you to update that reservation. Do you want to continue?", "Delete Row",
                        MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                }
                if (intDiagResult == DialogResult.Yes)
                {
                    // if the row is a database row then mark it for deletion and hide it in the grid
                    if (row.Cells["DirtyFlag"].Value.ToString() == "0")
                    {
                        row.Hidden = true;
                        row.Cells["DirtyFlag"].Value = "2";
                        blnGridMatchDirty = true;
                    }
                    // else it was added by the user and not saved to the database - delete it from the grid
                    else
                    {
                        row.Delete(false);
                    }
                    SaveMatching();
                    // set the active row to first (non-hidden) row
                    GridManager.FirstButtonHandler(uwgMatchingFunds);

                    // MAR 2005-03-28 - added Save (remove SetButtons)
                    
                }
            }
            else
            {
                // If there is no active row, then prompt the user to select one. 
                MessageBox.Show("Please select a single row to delete.");
            } 
        }

        private void btnCancelMatch_Click(object sender, EventArgs e)
        {
            if (blnGridMatchDirty == true)
            {
                DialogResult intDiagResult = MessageBox.Show("Data has changed - Do you want to cancel changes?", "Cancel Changes",
                    MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (intDiagResult == DialogResult.Yes)
                {
                    LoadMatching();
                    blnGridMatchDirty = false;
                    SetButtons();
                    // get a handle to the main form so we can enable / disable the menus
                    Form1 f = (Form1)this.ParentForm.MdiParent;
                    f.EnableMenusAll();
                }
            }
        }

        private void btnAddMatch_Click(object sender, EventArgs e)
        {
            UltraGridRow addedRow = uwgMatchingFunds.DisplayLayout.Bands[0].AddNew();
            addedRow.Cells["DollarAmount"].Value = "0";
            addedRow.Cells["DirtyFlag"].Value = "3";
            blnGridMatchDirty = true;
            SetButtons();
        }

        private void btnSaveMatch_Click(object sender, EventArgs e)
        {
            SaveMatching();
        }

        private void SaveMatching()
        {
            // Validate grid prior to update
            bool GridValid = true;
            int row;
            int retVal;
            int reId = 0;
            
            string retMsg = "success";
            string retMsg1 = "success";
        
            for (int i = 0; i < uwgMatchingFunds.Rows.Count; i++)
            {
                row = i + 1;
                if (uwgMatchingFunds.Rows[i].Cells["OrgId"].Value.ToString() == "")
                {
                    MessageBox.Show("Please select a valid organization for row " + row.ToString(),
                        "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    GridValid = false;
                    break;
                }
                if (uwgMatchingFunds.Rows[i].Cells["DollarAmount"].Value.ToString() == String.Empty)
                {
                    MessageBox.Show("Amount must be a numeric value in row " + row.ToString(),
                        "Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);

                    GridValid = false;
                    break;
                }
                if (uwgMatchingFunds.Rows[i].Cells["DirtyFlag"].Value.ToString() == "1")
                {
                    reId = GlobalCode.ToInt32(uwgMatchingFunds.Rows[i].Cells["ReimbId"].Value);
                    if (reId != 0)
                    {
                        if (DialogResult.OK != MessageBox.Show("This will change the Reimb/Repayment information in the reservation. Continue?", "Warning", MessageBoxButtons.OKCancel))
                        {
                            GridValid = false;
                            break;
                        }
                        //matching amount must be less than grant amount
                        decimal amt = ProjectFundingData.GetReserveEncumbAmount(reId);
                        if (GlobalCode.ToDecimal(uwgMatchingFunds.Rows[i].Cells["DollarAmount"].Value) > amt)
                        {
                            MessageBox.Show("The amount should not be greater than reserved amount", "Data Entry Error", MessageBoxButtons.OK);
                            GridValid = false;
                            break;
                        }
                    }
                }
            }

            // Perform updates
            if (GridValid == true)
            {
                // Iterate through each grid row and determine if an update is needed
                for (int i = 0; i < uwgMatchingFunds.Rows.Count; i++)
                {
                    reId = GlobalCode.ToInt32(uwgMatchingFunds.Rows[i].Cells["ReimbId"].Value);
                    switch (uwgMatchingFunds.Rows[i].Cells["DirtyFlag"].Value.ToString())
                    {
                        case "1":
                            {
                                decimal amt = GlobalCode.ToDecimal(uwgMatchingFunds.Rows[i].Cells["DollarAmount"].Value);
                                // update 
                                retMsg = ProjectFundingData.MatchingFundUpdate(
                                        Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells["MatchingFundID"].Value),
                                        GlobalSettings.projectId,
                                        Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells["OrgID"].Value),
                                        amt,
                                        uwgMatchingFunds.Rows[i].Cells["ReimbTypeId"].Value,
                                        reId );
                                if (reId != 0)
                                    ProjectFundingData.ReserveEncumbGrantAmountUpdate(reId, amt);

                                if (retMsg != "success")
                                    MessageBox.Show("Update failed in row " + (i + 1).ToString(), "Database Error",
                                        MessageBoxButtons.OK, MessageBoxIcon.Error);
                                break;
                            }
                        case "2":
                            {
                                // delete
                                retMsg = ProjectFundingData.MatchingFundDelete(Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells["MatchingFundId"].Value));
                                if (retMsg != "success")
                                    MessageBox.Show("Delete failed in row " + (i + 1).ToString(), "Database Error",
                                         MessageBoxButtons.OK, MessageBoxIcon.Error);

                                if (reId > 0)
                                {
                                    SqlHelper.ExecuteNonQuery(GlobalSettings.ConnectionString, CommandType.Text, "UPDATE ReservEncumb SET ReimbTypeId = null, GrantAmount = 0 WHERE ReservEncumbId = " + reId);
                                }
                                //ContactData.OrgContactRemove(GlobalSettings.projectId, Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells["OrgID"].Value));
                                //ProjectForm fm = (ProjectForm)this.ParentForm;
                                //fm.RefreshContacts();
                                //if (retVal1 == -1)
                                //{
                                //    MessageBox.Show("Deletion Failed", "Error", MessageBoxButtons.OK);
                                //}
                                break;
                            }
                        case "3":
                            {
                                // insert
                                //"0= MatchingFundId, 1=OrgID, 2=OrganizationType, 3=DollarAmount, 4=ReimbTypeId, 5=OrgID, 6=DirtyFlag, 7=ReimbId
                                if (reId == 0)
                                {
                                    retVal = ProjectFundingData.MatchingFundInsert(GlobalSettings.projectId,
                                        Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells["OrgID"].Value),
                                        GlobalCode.ToDecimal(uwgMatchingFunds.Rows[i].Cells["DollarAmount"].Value),
                                        uwgMatchingFunds.Rows[i].Cells["ReimbTypeId"].Value,
                                        reId);

                                    DataSet ds = SqlHelper.ExecuteDataset(GlobalSettings.ConnectionString, CommandType.Text, "select * from Org_ProjectRole where (ProjectId = " + GlobalSettings.projectId + " and OrgId = " + Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells[1].Value) + ")");
                                    if (ds.Tables[0].Rows.Count == 0)
                                    {
                                        int retVal1 = SqlHelper.ExecuteNonQuery(GlobalSettings.ConnectionString, CommandType.Text, "INSERT INTO Org_ProjectRole(ProjectId,OrgId,ProjectRoleId) values(" + GlobalSettings.projectId + "," + Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells[1].Value) + ", 2)");
                                    }
                                    ProjectForm fm = (ProjectForm)this.ParentForm;
                                    fm.RefreshContacts();
                                    if (retVal == -1)
                                        MessageBox.Show("Insert failed in row " + (i + 1).ToString(), "Database Error",
                                            MessageBoxButtons.OK, MessageBoxIcon.Error);
                                }
                                else
                                {
                                    retVal = ProjectFundingData.MatchingFundInsert(GlobalSettings.projectId,
                                        Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells["OrgID"].Value),
                                        GlobalCode.ToDecimal(uwgMatchingFunds.Rows[i].Cells["DollarAmount"].Value),
                                        uwgMatchingFunds.Rows[i].Cells["ReimbTypeId"].Value,
                                        reId);

                                    DataSet ds = SqlHelper.ExecuteDataset(GlobalSettings.ConnectionString, CommandType.Text, "select * from Org_ProjectRole where (ProjectId = " + GlobalSettings.projectId + " and OrgId = " + Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells[1].Value) + ")");
                                    if (ds.Tables[0].Rows.Count == 0)
                                    {
                                        int retVal1 = SqlHelper.ExecuteNonQuery(GlobalSettings.ConnectionString, CommandType.Text, "INSERT INTO Org_ProjectRole(ProjectId,OrgId,ProjectRoleId) values(" + GlobalSettings.projectId + "," + Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells[1].Value) + ", 2)");
                                    }
                                    ProjectForm fm = (ProjectForm)this.ParentForm;
                                    fm.RefreshContacts();
                                    if (retVal == -1)
                                        MessageBox.Show("Insert failed in row " + (i + 1).ToString(), "Database Error",
                                            MessageBoxButtons.OK, MessageBoxIcon.Error);
                                }
                                break;
                            }
                    }
                }
                // Reset the dirty flag, reload the grid and reset the form buttons
                blnGridMatchDirty = false;
                LoadMatching();
                LoadGridRes();
                LoadTotals();
                SetButtons();
                // get a handle to the main form so we can enable / disable the menus
                Form1 f = (Form1)this.ParentForm.MdiParent;
                f.EnableMenusAll();
                RefreshGeneralTab();
            }
        }
        private void pbFirstMatch_Click(object sender, System.EventArgs e)
        {
            GridManager.FirstButtonHandler(uwgMatchingFunds);
        }

        private void pbPreviousMatch_Click(object sender, System.EventArgs e)
        {
            GridManager.PreviousButtonHandler(uwgMatchingFunds);
        }

        private void pbNextMatch_Click(object sender, System.EventArgs e)
        {
            GridManager.NextButtonHandler(uwgMatchingFunds);
        }

        private void pbLastMatch_Click(object sender, System.EventArgs e)
        {
            GridManager.LastButtonHandler(uwgMatchingFunds);
        }

        public void MatchingFundsSaveReminderMsg()
        {
            string msg = "Changes have been made on the Matching Funds screen. Please save or cancel your changes.";
            DialogResult intDiagResult = MessageBox.Show(this, msg, "Data Changed", MessageBoxButtons.OK, MessageBoxIcon.Warning);
        }

        private void btnNewMatch_Click(object sender, EventArgs e)
        {
            uwgReservations.Enabled = true;
            Project.Organizations frmOrgs = new Project.Organizations(true);
            Form1 fm = (Form1)((this.ParentForm).MdiParent);

            string msg = "This will add a new organization to the Master Organization List-have you confirmed that it\ndoes not already exist ?";
            DialogResult intDiagResult = MessageBox.Show(msg, "Confirm",
                MessageBoxButtons.YesNoCancel, MessageBoxIcon.Question);
            if (intDiagResult == DialogResult.Yes)
            {
                CCPM.Contact.NewOrganization no = new CCPM.Contact.NewOrganization(0, "insert","projectfunding");
                fm.OpenForm(no, "New Organization");
            }
            else if (intDiagResult == DialogResult.No)
            {
                CCPM.Contact.LinkOrg lo = new CCPM.Contact.LinkOrg(0);
                fm.OpenForm(lo, "Link Organization");
            }
            LoadOrgs();
            LoadMatching();
        }

        private void btnRefresh_Click(object sender, EventArgs e)
        {
            //uwgMatchingFunds.DisplayLayout.ValueLists.Remove("Orgs");
            LoadOrgs();
            FormInits();
            // Initialize the grid with data
            LoadGridFS();

            // Initialize the grids with data
            LoadGridAuth();
            LoadGridRes();
            LoadMatching();
            LoadTotals();
            
        }

        
        private void uwgMatchingFunds_CellChange(object sender, CellEventArgs e)
        {
            string ReimbType = "";
            if (uwgReservations.Rows.Count > 0)
            {
                UltraGridRow resRow = this.uwgReservations.ActiveRow;
                try
                {
                    ReimbType = resRow.Cells["ReimbTypeId"].Value.ToString();
                }
                catch
                {
                    ReimbType = "";
                }
            }

            if (ReimbType == "")
            {
                if (uwgMatchingFunds.ActiveRow.Cells[4].Text == "True")
                {
                    MessageBox.Show("Please select the Reimb/Repay type and enter a Total Amt to be Reimb/Repay", "Data Entry Error", MessageBoxButtons.OKCancel);
                    uwgMatchingFunds.InitializeLayout += new InitializeLayoutEventHandler(uwgMatchingFunds_InitializeLayout);
                    LoadMatching();
                    blnGridMatchDirty = false;
                    uwgReservations.Enabled = true;
                }
            }

            //set org type
            if (uwgMatchingFunds.ActiveCell.Column.Key == "OrgID")
            {
                string org = uwgMatchingFunds.ActiveRow.Cells["OrgID"].Text;
                if (org != "")
                {
                    for (int i = 0; i < dsAllOrgs.Tables[0].Rows.Count; i++)
                    {
                        if (org == dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(1).ToString())
                        {
                            uwgMatchingFunds.ActiveRow.Cells["OrganizationType"].Value = dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(2);
                            break;
                        }
                    }
                }
            }

        }        

        private void uwgMatchingFunds_AfterCellUpdate_1(object sender, CellEventArgs e)
        {
           if (this.uwgMatchingFunds.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
                this.uwgMatchingFunds.ActiveRow.Cells["DirtyFlag"].Value = "1";
            blnGridMatchDirty = true;


            SetButtons();
            // get a handle to the main form so we can enable / disable the menus
            Form1 f = (Form1)this.ParentForm.MdiParent;
            f.DisableMenusAll();
        }

        private void uwgReservations_MouseDown(object sender, MouseEventArgs e)
        {
            if (uwgReservations.Rows.Count == 0)
                return;

            Infragistics.Win.ToolTip t1 = new Infragistics.Win.ToolTip(uwgReservations);
            if (uwgReservations.ActiveRow.Cells[9].IsInEditMode == true)
            {
               t1.ToolTipText = "Make one of the following selections if all or part of the Conservancys original grant/contract \n" +
                                 "will be recouped via one of the following mechanisms, otherwise leave it blank. \n" + 
                                "\nRepayable grant/Loan  a grant from the Conservancy that the grantee will repay. \n" +
                                "Federal grant/funds  a federal agency will reimburse the Conservancy for a grant made to a grantee. \n" +
                                "State grant/funds  a state agency will reimburse the Conservancy for a grant made to a grantee. \n" +
                                "NGO grant/funds  funds from a private entity that the Conservancy passes on to a grantee.";
                
                //Point p = new Point(900, 500);
               Point p = new Point(1000, 220);
                t1.Show(p,true);
            }           
        }

        //allow user to tab off of last grid cell
        private void uwgAuthorizations_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Tab)
            {
                if (uwgAuthorizations.ActiveRow.Index  == uwgAuthorizations.Rows.Count -1)
                {
                    if (uwgAuthorizations.ActiveCell.Column.Index == 6) {
                        e.SuppressKeyPress = true;
                        this.btnAdd.Focus();
                    }
                }
            }
        }

        //allow user to tab out of reservations grid
        private void uwgReservations_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Tab)
            {
                if (uwgReservations.ActiveRow.Index == uwgReservations.Rows.Count - 1)
                {
                    if (uwgReservations.ActiveCell.Column.Index == 11)
                    {
                        e.SuppressKeyPress = true;
                        this.btnAddRes.Focus();
                    }
                }
            }
        }

        //allow user to tab out of matching funds grid
        private void uwgMatchingFunds_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Tab)
            {
                if (uwgMatchingFunds.ActiveRow.Index == uwgMatchingFunds.Rows.Count - 1)
                {
                    if (uwgMatchingFunds.ActiveCell.Column.Index == 4)
                    {
                        e.SuppressKeyPress = true;
                        this.btnAddMatch.Focus();
                    }
                }
            }

        }

        private void btnShowAll_Click(object sender, EventArgs e)
        {
            GridSelect gs = new GridSelect();
            gs.lblTitle.Text = "All Project Reservations";
            gs.Width = 1200;
            gs.btnSelectAll.Visible = false;
            gs.btnOK.Visible = false;
            DataSet ds = ProjectFundingData.GetReservations(pid);
            gs.uwgSelect.DataSource = ds;
            gs.uwgSelect.DataBind();
            gs.ColumnWidth(0, 140);
            gs.ColumnWidth(1, 180);
            gs.ColumnWidth(2, 80);
            //gs.band.Columns[7].Format = "$###,###,##0.00";
            gs.band.Columns[7].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
            gs.band.Columns[9].Format = "$###,###,##0.00";
            gs.band.Columns[9].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
            gs.ShowDialog();

        }

        private void uwgReservations_BeforeCellListDropDown(object sender, CancelableCellEventArgs e)
        {
            if (uwgReservations.ActiveRow.Cells[2].IsActiveCell)
            {
                string item = uwgReservations.ActiveCell.Value.ToString();
                if (item != string.Empty)
                {
                    for (int i = 0; i < uddFundingSource.Rows.Count; i++)
                    {
                        if (item == uddFundingSource.Rows[i].Cells["FundingItem"].Value.ToString())
                        {
                            
                            uddFundingSource.Rows[i].Selected = true;
                            uddFundingSource.Rows[i].Activated = true;
                            break;
                        }
                    }
                    //uwgReservations.ActiveCell.Value = item;
                }
            }
            blnGridResDirty = false;
        }

        private void uddOrgSource_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            e.Layout.Bands[0].Columns[0].Hidden = true;

            e.Layout.Bands[0].Columns[1].Width = 415;
            e.Layout.Bands[0].Columns[1].Header.Caption = "Organization";

            e.Layout.Bands[0].Columns[2].Width = 183;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Organization Type";

            //filter row
            e.Layout.Override.AllowRowFiltering = Infragistics.Win.DefaultableBoolean.True;
            e.Layout.Override.FilterClearButtonLocation = FilterClearButtonLocation.Row;
            e.Layout.Override.FilterUIType = Infragistics.Win.UltraWinGrid.FilterUIType.FilterRow;
            e.Layout.Override.FilterOperatorDefaultValue = FilterOperatorDefaultValue.Contains;

            //column sorting
            e.Layout.Override.HeaderClickAction = HeaderClickAction.SortMulti;

        }

        private void uwgMatchingFunds_BeforeCellListDropDown(object sender, CancelableCellEventArgs e)
        {
            if (uwgMatchingFunds.ActiveRow.Cells[2].IsActiveCell)
            {
                string item = uwgMatchingFunds.ActiveCell.Value.ToString();
                if (item != string.Empty)
                {
                    for (int i = 0; i < uddOrgSource.Rows.Count; i++)
                    {
                        if (item == uddOrgSource.Rows[i].Cells["Organization"].Value.ToString())
                        {

                            uddOrgSource.Rows[i].Selected = true;
                            uddOrgSource.Rows[i].Activated = true;
                            break;
                        }
                    }
                }
            }
            blnGridResDirty = false;
        }
    }
}
