﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using CCPM.Data;
using CCPM.Contact;
using Microsoft.ApplicationBlocks.Data;
using Infragistics.Win.UltraWinGrid;

namespace CCPM.Project
{
    public partial class Contacts : Form
    {
        private bool blnViewOnly = false;

        public Contacts()
        {
            InitializeComponent();
            uwgContacts.DisplayLayout.Override.WrapHeaderText = Infragistics.Win.DefaultableBoolean.True;
            LoadContacts();
            SetSecurity();
        }

        private void LoadContacts()
        {
            DataSet cds = ContactData.GetContacts();
            uwgContacts.DataSource = cds;
            uwgContacts.DataBind();

            if (uwgContacts.Rows.Count < 1)
            {
                btnContactRemove.Enabled = false;
                btnEditContact.Enabled = false;
            }
            else
            {
                uwgContacts.Rows[0].Selected = true;
                if (!blnViewOnly)
                {
                    btnContactRemove.Enabled = true;
                    btnEditContact.Enabled = true;
                }
            }
        }

        private void SetSecurity()
        {
            if (GlobalSettings.IsAdministrator)
            { }
            else
            {
                blnViewOnly = true;
                btnAdd.Enabled = false;
                btnContactRemove.Enabled = false;
                btnEditContact.Text = "View";
            }
        }

        private void uwgContacts_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
        {
            e.Layout.Bands[0].Columns[0].Header.Caption = "Remove Contact";
            e.Layout.Bands[0].Columns[0].Hidden = true;
            e.Layout.Bands[0].Columns[0].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.Button;
            e.Layout.Bands[0].Columns[0].ButtonDisplayStyle = Infragistics.Win.UltraWinGrid.ButtonDisplayStyle.Always;

            e.Layout.Bands[0].Columns[1].Width = 110;
            e.Layout.Bands[0].Columns[1].Header.Caption = "Full Name";
            e.Layout.Bands[0].Columns[1].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[2].Width = 150;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Job Title";
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[3].Width = 100;
            e.Layout.Bands[0].Columns[3].Header.Caption = "Contact Phone";
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[4].Width = 100;
            e.Layout.Bands[0].Columns[4].Header.Caption = "Contact Cell Phone";
            e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[5].Width = 100;
            e.Layout.Bands[0].Columns[5].Header.Caption = "Contact Fax";
            e.Layout.Bands[0].Columns[5].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[6].Width = 150;
            e.Layout.Bands[0].Columns[6].Header.Caption = "Contact Email";
            e.Layout.Bands[0].Columns[6].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[7].Width = 200;
            e.Layout.Bands[0].Columns[7].Header.Caption = "Organization";
            e.Layout.Bands[0].Columns[7].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            //ContactId
            e.Layout.Bands[0].Columns[8].Hidden = true;


            //filter row
            e.Layout.Override.AllowRowFiltering = Infragistics.Win.DefaultableBoolean.True;
            e.Layout.Override.FilterClearButtonLocation = FilterClearButtonLocation.Row;
            e.Layout.Override.FilterUIType = Infragistics.Win.UltraWinGrid.FilterUIType.FilterRow;
            e.Layout.Override.FilterOperatorDefaultValue = FilterOperatorDefaultValue.Contains;

            //column sorting
            e.Layout.Override.HeaderClickAction = HeaderClickAction.SortMulti;  

        }

        private void btnAdd_Click(object sender, EventArgs e)
        {
            int contactId = 0;
            int orgID = 0;
            CreateContact cc = new CreateContact(contactId, "insert", orgID, "admin");
            Form1 fm = (Form1)this.MdiParent;
            fm.OpenForm(cc, "Create Contact");
            
            LoadContacts();
        }

        private void btnEditContact_Click(object sender, EventArgs e)
        {
            Form1 fm = (Form1)this.MdiParent;

            if (uwgContacts.ActiveRow.Cells[8].Value == System.DBNull.Value ) return;
            CreateContact cc = new CreateContact(Convert.ToInt32(uwgContacts.ActiveRow.Cells[8].Value), "update", 0,"admin");
            if (blnViewOnly)
            {
                fm.OpenForm(cc, "View Contact");
            }
            else
            {
                DialogResult intRslt = MessageBox.Show("BE CAREFUL about making changes! Any changes to this contact will affect all other project linked to it.",
                                "Edit Contact Warning", MessageBoxButtons.OKCancel);
                if (intRslt == DialogResult.OK)
                {
                    fm.OpenForm(cc, "Edit Contact");
                }
            }

        }

        private void btnContactRemove_Click(object sender, EventArgs e)
        {
            for (int i = 0; i < uwgContacts.Rows.Count; i++)
            {
                if (uwgContacts.Rows[i].Selected == true)
                {
                    DataSet ds = ProjectData.ContactProjects(Convert.ToInt32(uwgContacts.Rows[i].Cells["ContactId"].Value));
                    if (ds.Tables[0].Rows.Count > 0)
                    {
                        string msg = "Contact " + uwgContacts.Rows[i].Cells["FullName"].Value.ToString() + " can't be removed because it is linked to the following project(s): \n\n ";
                        foreach (DataRow dr in ds.Tables[0].Rows)
                        {
                            msg += dr["FileNumber"] + "\n";
                        }
                        MessageBox.Show(msg, "Remove Contact Warning", MessageBoxButtons.OK);
                        return;
                    }
                }
                if (uwgContacts.Rows[i].Selected == true)
                {
                    try
                    {
                        ContactData.OrgContactDelete(Convert.ToInt32(uwgContacts.Rows[i].Cells["ContactId"].Value));
                    }
                    catch (Exception ex)
                    {
                        MessageBox.Show(ex.Message, "Delete Contact Failure!", MessageBoxButtons.OK);
                    }
                }
            }
            LoadContacts();
        }

        private void btnRefresh_Click(object sender, EventArgs e)
        {
            LoadContacts();
        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void Contacts_Activated(object sender, EventArgs e)
        {
            LoadContacts();
        }
    }
}
