using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Windows.Forms;
using Infragistics.Shared; 
using Infragistics.Win; 
using Infragistics.Win.UltraWinGrid; 
using CCPM.Data;

namespace CCPM.Project
{
	/// <summary>
	/// Summary description for Organization.
	/// </summary>
	public class FiscalYear : System.Windows.Forms.Form
	{
		private DataSet dsFiscalYears;
		// private DataSet dsOrgTypes;
		private bool blnGridDirty = false;
		private bool autoLaunchAdd = false;
		private System.Windows.Forms.PictureBox pbLast;
		private System.Windows.Forms.PictureBox pbPrevious;
		private System.Windows.Forms.PictureBox pbFirst;
		private System.Windows.Forms.Button btnCancel;
		private System.Windows.Forms.Button btnSave;
		private System.Windows.Forms.Button btnDelete;
		private System.Windows.Forms.Button btnAdd;
		private System.Windows.Forms.PictureBox pbNext;
		private System.Windows.Forms.Label lblInstructions;
		private Infragistics.Win.UltraWinGrid.UltraGrid uwgFiscalYears;
		
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public FiscalYear()
		{
			FormInits();
		}
		public FiscalYear(bool launchAdd)
		{
			// this constructor called by project MatchingFunds page ('Add Funding Source' button)
			FormInits();
			if (launchAdd)
			{
				autoLaunchAdd = true;
				AddGrid();
			}
		}

		private void FormInits()
		{
			InitializeComponent();

			// Initialize the grid with data
			LoadGrid();
			SetButtons();
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}
		private void LoadGrid()
		{
			//Create the project objectives dataset and bind to the grid
			dsFiscalYears = FiscalYearData.GetFiscalYears();
			uwgFiscalYears.DataSource = dsFiscalYears.Tables[0];
			uwgFiscalYears.DataBind();
		}

		private void uwgFiscalYears_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
		{
			// FiscalYearID
			e.Layout.Bands[0].Columns[0].Hidden = true;

			e.Layout.Bands[0].Columns[1].Header.Caption = "Years";
			e.Layout.Bands[0].Columns[1].Width = 100;
	
			e.Layout.Bands[0].Columns[2].Header.Caption = "Start Date";
			e.Layout.Bands[0].Columns[2].Width = 100;

			e.Layout.Bands[0].Columns[3].Header.Caption = "End Date";
			e.Layout.Bands[0].Columns[3].Width = 100;

			e.Layout.Bands[0].Columns[4].Header.Caption = "Chapter";
			e.Layout.Bands[0].Columns[4].Width = 100;
			//e.Layout.Bands[0].Columns[4].Format = "###0";
			//e.Layout.Bands[0].Columns[4].MaskInput = "nnnn";
			//e.Layout.Bands[0].Columns[4].MinValue = 1;
			//e.Layout.Bands[0].Columns[4].MaxValue = 9999;
            e.Layout.Bands[0].Columns[4].MaxLength = 4;
            e.Layout.Bands[0].Columns[4].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;


			e.Layout.Bands[0].Columns[5].Header.Caption = "Chapter/FY";
			e.Layout.Bands[0].Columns[5].Width = 100;

			e.Layout.Bands[0].Columns[6].Hidden = true;
		}

		private void uwgFiscalYears_AfterCellUpdate(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e) 
		{ 
			// If editing an existing row then set the dirty flag to edit mode for this row
			if (this.uwgFiscalYears.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
				this.uwgFiscalYears.ActiveRow.Cells["DirtyFlag"].Value = "1";
			blnGridDirty = true;
			SetButtons();
		}

		private void uwgFiscalYears_AfterRowActivate(object sender, System.EventArgs e) 
		{ 
			SetButtons();
		}

		private void btnDelete_Click(object sender, System.EventArgs e)
		{ 
 
			// Get the row to delete. In this case we will use the active row. 
			UltraGridRow row = this.uwgFiscalYears.ActiveRow;

			if ( null != row ) 
			{ 
				DialogResult intDiagResult = MessageBox.Show("Do you want to delete this row and save all other pending changes?","Delete Row", 
					MessageBoxButtons.YesNo, MessageBoxIcon.Question);
				if (intDiagResult == DialogResult.Yes)
				{
					// if the row is a database row then mark it for deletion and hide it in the grid
					if (row.Cells["DirtyFlag"].Value.ToString() == "0")
					{
						row.Hidden = true;
						row.Cells["DirtyFlag"].Value = "2";
						blnGridDirty = true;
					}
						// else it was added by the user and not saved to the database - delete it from the grid
					else
					{
						row.Delete(false);
					}
					// set the active row to first (non-hidden) row
					GridManager.FirstButtonHandler(uwgFiscalYears);
					
					// MAR 2005-03-28 - added Save (remove SetButtons)
					SaveGrid();
				}
			} 
			else 
			{ 
				// If there is no active row, then prompt the user to select one. 
				MessageBox.Show( "Please select a single row to delete." ); 
			} 
		} 

		private void SetButtons()
		{
			if (blnGridDirty == true)
			{
				this.btnSave.Enabled = true;
				this.btnCancel.Enabled = true;
			}
			else
			{
				this.btnSave.Enabled = false;
				this.btnCancel.Enabled = false;
			}

			if (this.uwgFiscalYears.ActiveRow == null)
				this.btnDelete.Enabled = false;
			else
				this.btnDelete.Enabled = true;

		}

		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			if (blnGridDirty == true)
			{
				DialogResult intDiagResult = MessageBox.Show("Data has changed - Do you want to cancel changes?","Cancel Changes", 
					MessageBoxButtons.YesNo, MessageBoxIcon.Question);
				if (intDiagResult == DialogResult.Yes)
				{
					this.LoadGrid();
					blnGridDirty = false;
					SetButtons();
				}
			}
			if (autoLaunchAdd)
				this.Close(); 

		}

		private void btnAdd_Click(object sender, System.EventArgs e)
		{
			AddGrid();
		}
		private void AddGrid()
		{
			UltraGridRow addedRow = uwgFiscalYears.DisplayLayout.Bands[0].AddNew( );
			addedRow.Cells["DirtyFlag"].Value = "3";
			blnGridDirty = true;
			SetButtons();
		}

		private void btnSave_Click(object sender, System.EventArgs e)
		{
			SaveGrid();
		}

		private void SaveGrid()
		{
			// Validate grid prior to update
			bool GridValid = true;
			int row;
			int retVal;
			string retMsg;
			string Chapter;
			for(int i = 0; i < uwgFiscalYears.Rows.Count; i++)
			{
				row = i + 1;
				if (uwgFiscalYears.Rows[i].Cells["Years"].Value.ToString() == "")
				{
					MessageBox.Show("Please enter Years for row " + row.ToString(),
						"Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
					GridValid = false;
					break;
				}
				if (uwgFiscalYears.Rows[i].Cells["StartDate"].Value.ToString() == String.Empty)
				{
					MessageBox.Show("Start date required in row " + row.ToString(),
						"Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);

					GridValid = false;
					break;
				}
				if (uwgFiscalYears.Rows[i].Cells["EndDate"].Value.ToString() == String.Empty)
				{
					MessageBox.Show("End date required in row " + row.ToString(),
						"Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);

					GridValid = false;
					break;
				}
			}
			
			// Perform updates
			if (GridValid == true)
			{
				// Iterate through each grid row and determine if an update is needed
				for(int i = 0; i < uwgFiscalYears.Rows.Count; i++)
				{
					switch (uwgFiscalYears.Rows[i].Cells["DirtyFlag"].Value.ToString())
					{
						case "1":
						{
							if (uwgFiscalYears.Rows[i].Cells["Chapter"].Value.ToString() == String.Empty)
								Chapter = "-1";
							else
                                Chapter =uwgFiscalYears.Rows[i].Cells["Chapter"].Value.ToString(); // no longer integer
                                //Chapter = Convert.ToInt32(uwgFiscalYears.Rows[i].Cells["Chapter"].Value);

							// update
							retMsg = FiscalYearData.FiscalYearUpdate(
								Convert.ToInt32(uwgFiscalYears.Rows[i].Cells["FiscalYearID"].Value),
								Convert.ToDateTime(uwgFiscalYears.Rows[i].Cells["StartDate"].Value),
								Convert.ToDateTime(uwgFiscalYears.Rows[i].Cells["EndDate"].Value),
								Chapter,
								uwgFiscalYears.Rows[i].Cells["Years"].Value.ToString(),
								uwgFiscalYears.Rows[i].Cells["ChapterFY"].Value.ToString()
								);
                                							
							if (retMsg!="success")
								MessageBox.Show("Update failed in row " + (i+1).ToString(), "Database Error", 
									MessageBoxButtons.OK, MessageBoxIcon.Error);

							break;
						}
						case "2":
						{
							// delete
							retMsg = FiscalYearData.FiscalYearDelete(Convert.ToInt32(uwgFiscalYears.Rows[i].Cells["FiscalYearID"].Value));
							if (retMsg!="success")
								MessageBox.Show("Unable to delete. References to this Fiscal Year exist. ", "Database Error", 
									MessageBoxButtons.OK, MessageBoxIcon.Error);

							break;
						}
						case "3":
						{
							// insert
							if (uwgFiscalYears.Rows[i].Cells["Chapter"].Value.ToString() == String.Empty)
								Chapter = "-1";
							else
								Chapter = uwgFiscalYears.Rows[i].Cells["Chapter"].Value.ToString(); //no longer an int 
                                //Chapter = Convert.ToInt32(uwgFiscalYears.Rows[i].Cells["Chapter"].Value);

							retVal = FiscalYearData.FiscalYearInsert(
								Convert.ToDateTime(uwgFiscalYears.Rows[i].Cells["StartDate"].Value),
								Convert.ToDateTime(uwgFiscalYears.Rows[i].Cells["EndDate"].Value),
								Chapter,
								uwgFiscalYears.Rows[i].Cells["Years"].Value.ToString(),
								uwgFiscalYears.Rows[i].Cells["ChapterFY"].Value.ToString()
								);
							if (retVal==-1)
								MessageBox.Show("Insert failed in row " + (i+1).ToString() + ". Possible duplicate.", "Database Error", 
									MessageBoxButtons.OK, MessageBoxIcon.Error);
							break;
						}
					}
				}
				// Reset the dirty flag, reload the grid and reset the form buttons
				blnGridDirty = false;
				LoadGrid();
				SetButtons();
				if (autoLaunchAdd)
					this.Close(); 
			}
		}

		private void pbFirst_Click(object sender, System.EventArgs e)
		{
			GridManager.FirstButtonHandler(uwgFiscalYears);
		}

		private void pbPrevious_Click(object sender, System.EventArgs e)
		{
			GridManager.PreviousButtonHandler(uwgFiscalYears);
		}

		private void pbNext_Click(object sender, System.EventArgs e)
		{
			GridManager.NextButtonHandler(uwgFiscalYears);
		}

		private void pbLast_Click(object sender, System.EventArgs e)
		{
			GridManager.LastButtonHandler(uwgFiscalYears);
		}

		private void form_Exit(object sender, System.ComponentModel.CancelEventArgs e)
		{
			if (blnGridDirty == true)
			{
				// If edits were made then display a dialog box to the user
				DialogResult intDiagResult = MessageBox.Show("Changes have been made on the " +
					"Fiscal Year screen.  Do you want to discard these changes?", "", 
					MessageBoxButtons.YesNo, MessageBoxIcon.Question);
				// If the user wants to save the changes cancel the close
				if (intDiagResult == DialogResult.No)
				{
					e.Cancel = true;
				}
			}
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(FiscalYear));
            this.pbLast = new System.Windows.Forms.PictureBox();
            this.pbPrevious = new System.Windows.Forms.PictureBox();
            this.pbNext = new System.Windows.Forms.PictureBox();
            this.pbFirst = new System.Windows.Forms.PictureBox();
            this.uwgFiscalYears = new Infragistics.Win.UltraWinGrid.UltraGrid();
            this.btnCancel = new System.Windows.Forms.Button();
            this.btnSave = new System.Windows.Forms.Button();
            this.btnDelete = new System.Windows.Forms.Button();
            this.btnAdd = new System.Windows.Forms.Button();
            this.lblInstructions = new System.Windows.Forms.Label();
            ((System.ComponentModel.ISupportInitialize)(this.pbLast)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.pbPrevious)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.pbNext)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.pbFirst)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.uwgFiscalYears)).BeginInit();
            this.SuspendLayout();
            // 
            // pbLast
            // 
            this.pbLast.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.pbLast.Image = ((System.Drawing.Image)(resources.GetObject("pbLast.Image")));
            this.pbLast.Location = new System.Drawing.Point(498, 406);
            this.pbLast.Name = "pbLast";
            this.pbLast.Size = new System.Drawing.Size(32, 24);
            this.pbLast.TabIndex = 52;
            this.pbLast.TabStop = false;
            this.pbLast.Click += new System.EventHandler(this.pbLast_Click);
            // 
            // pbPrevious
            // 
            this.pbPrevious.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.pbPrevious.Image = ((System.Drawing.Image)(resources.GetObject("pbPrevious.Image")));
            this.pbPrevious.Location = new System.Drawing.Point(414, 406);
            this.pbPrevious.Name = "pbPrevious";
            this.pbPrevious.Size = new System.Drawing.Size(32, 24);
            this.pbPrevious.TabIndex = 51;
            this.pbPrevious.TabStop = false;
            this.pbPrevious.Click += new System.EventHandler(this.pbPrevious_Click);
            // 
            // pbNext
            // 
            this.pbNext.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.pbNext.Image = ((System.Drawing.Image)(resources.GetObject("pbNext.Image")));
            this.pbNext.Location = new System.Drawing.Point(456, 406);
            this.pbNext.Name = "pbNext";
            this.pbNext.Size = new System.Drawing.Size(32, 24);
            this.pbNext.TabIndex = 50;
            this.pbNext.TabStop = false;
            this.pbNext.Click += new System.EventHandler(this.pbNext_Click);
            // 
            // pbFirst
            // 
            this.pbFirst.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.pbFirst.Image = ((System.Drawing.Image)(resources.GetObject("pbFirst.Image")));
            this.pbFirst.Location = new System.Drawing.Point(372, 406);
            this.pbFirst.Name = "pbFirst";
            this.pbFirst.Size = new System.Drawing.Size(32, 24);
            this.pbFirst.TabIndex = 49;
            this.pbFirst.TabStop = false;
            this.pbFirst.Click += new System.EventHandler(this.pbFirst_Click);
            // 
            // uwgFiscalYears
            // 
            this.uwgFiscalYears.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.uwgFiscalYears.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.uwgFiscalYears.Location = new System.Drawing.Point(49, 14);
            this.uwgFiscalYears.Name = "uwgFiscalYears";
            this.uwgFiscalYears.Size = new System.Drawing.Size(537, 362);
            this.uwgFiscalYears.TabIndex = 48;
            this.uwgFiscalYears.AfterCellUpdate += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgFiscalYears_AfterCellUpdate);
            this.uwgFiscalYears.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(this.uwgFiscalYears_InitializeLayout);
            this.uwgFiscalYears.AfterRowActivate += new System.EventHandler(this.uwgFiscalYears_AfterRowActivate);
            // 
            // btnCancel
            // 
            this.btnCancel.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.btnCancel.Enabled = false;
            this.btnCancel.Location = new System.Drawing.Point(298, 406);
            this.btnCancel.Name = "btnCancel";
            this.btnCancel.Size = new System.Drawing.Size(64, 24);
            this.btnCancel.TabIndex = 47;
            this.btnCancel.Text = "Cancel";
            this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
            // 
            // btnSave
            // 
            this.btnSave.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.btnSave.Enabled = false;
            this.btnSave.Location = new System.Drawing.Point(224, 406);
            this.btnSave.Name = "btnSave";
            this.btnSave.Size = new System.Drawing.Size(64, 24);
            this.btnSave.TabIndex = 46;
            this.btnSave.Text = "Save";
            this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
            // 
            // btnDelete
            // 
            this.btnDelete.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.btnDelete.Enabled = false;
            this.btnDelete.Location = new System.Drawing.Point(150, 406);
            this.btnDelete.Name = "btnDelete";
            this.btnDelete.Size = new System.Drawing.Size(64, 24);
            this.btnDelete.TabIndex = 45;
            this.btnDelete.Text = "Delete";
            this.btnDelete.Click += new System.EventHandler(this.btnDelete_Click);
            // 
            // btnAdd
            // 
            this.btnAdd.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.btnAdd.Location = new System.Drawing.Point(76, 406);
            this.btnAdd.Name = "btnAdd";
            this.btnAdd.Size = new System.Drawing.Size(64, 24);
            this.btnAdd.TabIndex = 44;
            this.btnAdd.Text = "Add";
            this.btnAdd.Click += new System.EventHandler(this.btnAdd_Click);
            // 
            // lblInstructions
            // 
            this.lblInstructions.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.lblInstructions.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblInstructions.ForeColor = System.Drawing.Color.Green;
            this.lblInstructions.Location = new System.Drawing.Point(80, 384);
            this.lblInstructions.Name = "lblInstructions";
            this.lblInstructions.Size = new System.Drawing.Size(320, 16);
            this.lblInstructions.TabIndex = 53;
            this.lblInstructions.Text = "Use Tab or Shift+Tab to navigate between cells within a row.";
            // 
            // FiscalYear
            // 
            this.AcceptButton = this.btnSave;
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(640, 444);
            this.Controls.Add(this.lblInstructions);
            this.Controls.Add(this.pbLast);
            this.Controls.Add(this.pbPrevious);
            this.Controls.Add(this.pbNext);
            this.Controls.Add(this.pbFirst);
            this.Controls.Add(this.uwgFiscalYears);
            this.Controls.Add(this.btnCancel);
            this.Controls.Add(this.btnSave);
            this.Controls.Add(this.btnDelete);
            this.Controls.Add(this.btnAdd);
            this.Name = "FiscalYear";
            this.Text = "Fiscal Years";
            this.Load += new System.EventHandler(this.FiscalYear_Load);
            this.Closing += new System.ComponentModel.CancelEventHandler(this.form_Exit);
            ((System.ComponentModel.ISupportInitialize)(this.pbLast)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.pbPrevious)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.pbNext)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.pbFirst)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.uwgFiscalYears)).EndInit();
            this.ResumeLayout(false);

		}
		#endregion

        private void FiscalYear_Load(object sender, EventArgs e)
        {

        }

	}
}
