using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Windows.Forms;
using Infragistics.Shared; 
using Infragistics.Win; 
using Infragistics.Win.UltraWinGrid; 
using CCPM.Data;

namespace CCPM.Project
{
	/// <summary>
	/// Summary description for ManageObjective.
	/// </summary>
	public class ManageObjective : System.Windows.Forms.Form
	{
		private DataSet dsObjectives;
		private bool blnGridDirty = false;

		private System.Windows.Forms.PictureBox pbLast;
		private System.Windows.Forms.PictureBox pbPrevious;
		private System.Windows.Forms.PictureBox pnNext;
		private System.Windows.Forms.PictureBox pbFirst;
		private Infragistics.Win.UltraWinGrid.UltraGrid uwgObjectives;
		private System.Windows.Forms.Button btnCancel;
		private System.Windows.Forms.Button btnSave;
		private System.Windows.Forms.Button btnDelete;
		private System.Windows.Forms.Button btnAdd;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public ManageObjective()
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			// Initialize the grid with data
			LoadGrid();
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}
		private void LoadGrid()
		{
			//Create the project objectives dataset and bind to the grid
			dsObjectives = ProjectObjectiveData.GetObjectives();
			uwgObjectives.DataSource = dsObjectives.Tables[0];
			uwgObjectives.DataBind();
            uwgObjectives.DisplayLayout.AutoFitStyle = AutoFitStyle.ResizeAllColumns;
		}

		private void uwgObjectives_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
		{
			e.Layout.Bands[0].Columns[0].Hidden = true;
			e.Layout.Bands[0].Columns[1].Header.Caption = "Objective Long Name";
			e.Layout.Bands[0].Columns[1].MaskInput = "A&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&";
			e.Layout.Bands[0].Columns[2].Header.Caption = "Objective Short Name";
			e.Layout.Bands[0].Columns[2].MaskInput = "A&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&";
			e.Layout.Bands[0].Columns[3].Header.Caption = "Objective Number";
			e.Layout.Bands[0].Columns[3].Width = 35;
			e.Layout.Bands[0].Columns[3].MaskInput = "A&&&&&&&&&";
			e.Layout.Bands[0].Columns[4].Header.Caption = "Unit of Measurement";
			e.Layout.Bands[0].Columns[4].Width = 40;
			e.Layout.Bands[0].Columns[4].MaskInput = "A&&&&&&&&&&&&&&&&&&&&&&&&";
			e.Layout.Bands[0].Columns[5].Header.Caption = "Target";
			e.Layout.Bands[0].Columns[5].Width = 20;
			e.Layout.Bands[0].Columns[5].MaskInput = "#9999999";
			e.Layout.Bands[0].Columns[5].MinValue = 0;
			e.Layout.Bands[0].Columns[5].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
			e.Layout.Bands[0].Columns[5].MaxValue = 99999999;
			e.Layout.Bands[0].Columns[6].Header.Caption = "Sort Order";
			e.Layout.Bands[0].Columns[6].Width = 25;
			e.Layout.Bands[0].Columns[6].MaskInput = "#99";
			e.Layout.Bands[0].Columns[6].MinValue = 1;
			e.Layout.Bands[0].Columns[6].MaxValue = 999;
			e.Layout.Bands[0].Columns[6].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;

            e.Layout.Bands[0].Columns[7].Header.Caption = "Plan Year";
            e.Layout.Bands[0].Columns[7].Width = 35;
            e.Layout.Bands[0].Columns[7].MaskInput = "A&&&&&&&&&";

            e.Layout.Bands[0].Columns[8].Header.Caption = "Is Active";
			e.Layout.Bands[0].Columns[8].Width = 20;
			e.Layout.Bands[0].Columns[8].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.CheckBox;
			e.Layout.Bands[0].Columns[9].Hidden = true;
		}

		private void uwgObjectives_AfterCellUpdate(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e) 
		{ 
			// If editing an existing row then set the dirty flag to edit mode for this row
			if (this.uwgObjectives.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
				this.uwgObjectives.ActiveRow.Cells["DirtyFlag"].Value = "1";
			blnGridDirty = true;
			SetButtons();
		}

		private void uwgObjectives_AfterRowActivate(object sender, System.EventArgs e) 
		{ 
			SetButtons();
		}

		private void btnDelete_Click(object sender, System.EventArgs e)
		{ 
			// Get the row to delete. In this case we will use the active row. 
			UltraGridRow row = this.uwgObjectives.ActiveRow;

			if ( null != row ) 
			{ 
				DialogResult intDiagResult = MessageBox.Show("Do you want to delete this row?","Delete Row", 
					MessageBoxButtons.YesNo);
				if (intDiagResult == DialogResult.Yes)
				{
					// if the row is a database row then mark it for deletion and hide it in the grid
					if (row.Cells["DirtyFlag"].Value.ToString() == "0")
					{
						row.Hidden = true;
						row.Cells["DirtyFlag"].Value = "2";
						blnGridDirty = true;
					}
						// else it was added by the user and not saved to the database - delete it from the grid
					else
					{
						row.Delete(false);
					}
					// set the active row to first (non-hidden) row
					MoveFirst();
					SetButtons();
				}
			} 
			else 
			{ 
				// If there is no active row, then prompt the user to select one. 
				MessageBox.Show( "Please select a single row to delete." ); 
			} 
		} 

		private void SetButtons()
		{
			if (blnGridDirty == true)
			{
				this.btnSave.Enabled = true;
				this.btnCancel.Enabled = true;
			}
			else
			{
				this.btnSave.Enabled = false;
				this.btnCancel.Enabled = false;
			}

			if (this.uwgObjectives.ActiveRow == null)
				this.btnDelete.Enabled = false;
			else
				this.btnDelete.Enabled = true;
		}

		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			if (blnGridDirty == true)
			{
				DialogResult intDiagResult = MessageBox.Show("Data has changed - Do you want to cancel changes?","Cancel Changes", 
					MessageBoxButtons.YesNo);
				if (intDiagResult == DialogResult.Yes)
				{
					this.LoadGrid();
					blnGridDirty = false;
					SetButtons();
				}
			}
		}

		private void btnAdd_Click(object sender, System.EventArgs e)
		{
			UltraGridRow addedRow = uwgObjectives.DisplayLayout.Bands[0].AddNew( );
			addedRow.Cells["IsActive"].Value = 1;
			addedRow.Cells["DirtyFlag"].Value = "3";
			addedRow.Cells["Target"].Value = 0;
			blnGridDirty = true;
			SetButtons();
		}

		private void btnSave_Click(object sender, System.EventArgs e)
		{
			// Validate grid prior to update
			bool GridValid = true;
			int row;
			for(int i = 0; i < uwgObjectives.Rows.Count; i++)
			{
				row = i + 1;
				if (uwgObjectives.Rows[i].Cells["ObjectiveLongName"].Value.ToString() == String.Empty)
				{
					MessageBox.Show("Objective Long Name cannot be blank in row " + row.ToString());
					GridValid = false;
					break;
				}
				if (uwgObjectives.Rows[i].Cells["ObjectiveShortName"].Value.ToString() == String.Empty)
				{
					MessageBox.Show("Objective Short Name cannot be blank in row " + row.ToString());
					GridValid = false;
					break;
				}
				if (uwgObjectives.Rows[i].Cells["ObjectiveNumber"].Value.ToString() == String.Empty)
				{
					MessageBox.Show("Objective Number cannot be blank in row " + row.ToString());
					GridValid = false;
					break;
				}
				if (uwgObjectives.Rows[i].Cells["UnitofMeasurement"].Value.ToString() == String.Empty)
				{
					MessageBox.Show("Unit of Measure cannot be blank in row " + row.ToString());
					GridValid = false;
					break;
				}
				if (uwgObjectives.Rows[i].Cells["Target"].Value.ToString() == String.Empty)
				{
					MessageBox.Show("Target cannot be blank in row " + row.ToString());
					GridValid = false;
					break;
				}
				if (uwgObjectives.Rows[i].Cells["SortOrder"].Value.ToString() == String.Empty)
				{
					MessageBox.Show("Sort Order cannot be blank in row " + row.ToString());
					GridValid = false;
					break;
				}
			}
			
			// Perform updates
			if (GridValid == true)
			{
				// Iterate through each grid row and determine if an update is needed
				for(int i = 0; i < uwgObjectives.Rows.Count; i++)
				{
					switch (uwgObjectives.Rows[i].Cells["DirtyFlag"].Value.ToString())
					{
						case "1":
						{
							ProjectObjectiveData.ObjectiveUpdate(
								Convert.ToInt32(uwgObjectives.Rows[i].Cells["ObjectiveID"].Value),
								uwgObjectives.Rows[i].Cells["ObjectiveLongName"].Value.ToString(),
								uwgObjectives.Rows[i].Cells["ObjectiveShortName"].Value.ToString(),
								uwgObjectives.Rows[i].Cells["ObjectiveNumber"].Value.ToString(),
								uwgObjectives.Rows[i].Cells["UnitOfMeasurement"].Value.ToString(),
								Convert.ToInt32(uwgObjectives.Rows[i].Cells["Target"].Value),
								Convert.ToInt32(uwgObjectives.Rows[i].Cells["SortOrder"].Value),
								Convert.ToInt32(uwgObjectives.Rows[i].Cells["IsActive"].Value),
                                uwgObjectives.Rows[i].Cells["PlanYear"].Value.ToString()   );
							break;
						}
						case "2":
						{
							ProjectObjectiveData.ObjectiveDelete(
								Convert.ToInt32(uwgObjectives.Rows[i].Cells["ObjectiveID"].Value));
							break;
						}
						case "3":
						{
							ProjectObjectiveData.ObjectiveInsert(
								uwgObjectives.Rows[i].Cells["ObjectiveLongName"].Value.ToString(),
								uwgObjectives.Rows[i].Cells["ObjectiveShortName"].Value.ToString(),
								uwgObjectives.Rows[i].Cells["ObjectiveNumber"].Value.ToString(),
								uwgObjectives.Rows[i].Cells["UnitOfMeasurement"].Value.ToString(),
								Convert.ToInt32(uwgObjectives.Rows[i].Cells["Target"].Value),
								Convert.ToInt32(uwgObjectives.Rows[i].Cells["SortOrder"].Value),
								Convert.ToInt32(uwgObjectives.Rows[i].Cells["IsActive"].Value),
                                uwgObjectives.Rows[i].Cells["PlanYear"].Value.ToString()   );
							break;
						}
					}
				}
				// Reset the dirty flag, reload the grid and reset the form buttons
				blnGridDirty = false;
				LoadGrid();
				SetButtons();
			}
		}

		private void pbFirst_Click(object sender, System.EventArgs e)
		{
			MoveFirst();
		}

		private void pbPrevious_Click(object sender, System.EventArgs e)
		{
			int i = uwgObjectives.ActiveRow.Index - 1;
			while (i >= 0) 
			{
				if (uwgObjectives.Rows[i].Hidden != true)
				{
					uwgObjectives.ActiveRow = uwgObjectives.Rows[i];
					break;
				}
				else
					i--;
			}
		}

		private void pbNext_Click(object sender, System.EventArgs e)
		{
			int i = uwgObjectives.ActiveRow.Index + 1;
			while (i <= uwgObjectives.Rows.Count - 1) 
			{
				if (uwgObjectives.Rows[i].Hidden != true)
				{
					uwgObjectives.ActiveRow = uwgObjectives.Rows[i];
					break;
				}
				else
					i++;
			}
		}

		private void pbLast_Click(object sender, System.EventArgs e)
		{
			int i = uwgObjectives.Rows.Count - 1;
			uwgObjectives.ActiveRow = uwgObjectives.Rows[i];
			while (uwgObjectives.Rows[i].Hidden == true)
			{
				i--;
				uwgObjectives.ActiveRow = uwgObjectives.Rows[i];
			}
		}

		private void MoveFirst()
		{
			uwgObjectives.ActiveRow = uwgObjectives.Rows[0];
			int i = 0;
			while (uwgObjectives.Rows[i].Hidden == true)
			{
				i++;
				uwgObjectives.ActiveRow = uwgObjectives.Rows[i];
			}
		}

		private void form_Exit(object sender, System.ComponentModel.CancelEventArgs e)
		{
			if (blnGridDirty == true)
			{
				// If edits were made then display a dialog box to the user
				DialogResult intDiagResult = MessageBox.Show("Changes have been made on the " +
					"Manage Objectives screen.  Do you want to discard these changes?", "", 
					MessageBoxButtons.YesNo);
				// If the user wants to save the changes cancel the close
				if (intDiagResult == DialogResult.No)
				{
					e.Cancel = true;
				}
			}
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ManageObjective));
			this.pbLast = new System.Windows.Forms.PictureBox();
			this.pbPrevious = new System.Windows.Forms.PictureBox();
			this.pnNext = new System.Windows.Forms.PictureBox();
			this.pbFirst = new System.Windows.Forms.PictureBox();
			this.uwgObjectives = new Infragistics.Win.UltraWinGrid.UltraGrid();
			this.btnCancel = new System.Windows.Forms.Button();
			this.btnSave = new System.Windows.Forms.Button();
			this.btnDelete = new System.Windows.Forms.Button();
			this.btnAdd = new System.Windows.Forms.Button();
			((System.ComponentModel.ISupportInitialize)(this.uwgObjectives)).BeginInit();
			this.SuspendLayout();
			// 
			// pbLast
			// 
			this.pbLast.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.pbLast.Image = ((System.Drawing.Image)(resources.GetObject("pbLast.Image")));
			this.pbLast.Location = new System.Drawing.Point(848, 528);
			this.pbLast.Name = "pbLast";
			this.pbLast.Size = new System.Drawing.Size(32, 24);
			this.pbLast.TabIndex = 43;
			this.pbLast.TabStop = false;
			this.pbLast.Click += new System.EventHandler(this.pbLast_Click);
			// 
			// pbPrevious
			// 
			this.pbPrevious.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.pbPrevious.Image = ((System.Drawing.Image)(resources.GetObject("pbPrevious.Image")));
			this.pbPrevious.Location = new System.Drawing.Point(736, 528);
			this.pbPrevious.Name = "pbPrevious";
			this.pbPrevious.Size = new System.Drawing.Size(32, 24);
			this.pbPrevious.TabIndex = 42;
			this.pbPrevious.TabStop = false;
			this.pbPrevious.Click += new System.EventHandler(this.pbPrevious_Click);
			// 
			// pnNext
			// 
			this.pnNext.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.pnNext.Image = ((System.Drawing.Image)(resources.GetObject("pnNext.Image")));
			this.pnNext.Location = new System.Drawing.Point(792, 528);
			this.pnNext.Name = "pnNext";
			this.pnNext.Size = new System.Drawing.Size(32, 24);
			this.pnNext.TabIndex = 41;
			this.pnNext.TabStop = false;
			this.pnNext.Click += new System.EventHandler(this.pbNext_Click);
			// 
			// pbFirst
			// 
			this.pbFirst.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
			this.pbFirst.Image = ((System.Drawing.Image)(resources.GetObject("pbFirst.Image")));
			this.pbFirst.Location = new System.Drawing.Point(680, 528);
			this.pbFirst.Name = "pbFirst";
			this.pbFirst.Size = new System.Drawing.Size(32, 24);
			this.pbFirst.TabIndex = 40;
			this.pbFirst.TabStop = false;
			this.pbFirst.Click += new System.EventHandler(this.pbFirst_Click);
			// 
			// uwgObjectives
			// 
			this.uwgObjectives.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom) 
				| System.Windows.Forms.AnchorStyles.Left) 
				| System.Windows.Forms.AnchorStyles.Right)));
			this.uwgObjectives.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.uwgObjectives.Location = new System.Drawing.Point(0, 0);
			this.uwgObjectives.Name = "uwgObjectives";
			this.uwgObjectives.Size = new System.Drawing.Size(896, 512);
			this.uwgObjectives.TabIndex = 39;
			this.uwgObjectives.Text = "Objectives";
			this.uwgObjectives.AfterRowActivate += new System.EventHandler(this.uwgObjectives_AfterRowActivate);
			this.uwgObjectives.AfterCellUpdate += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgObjectives_AfterCellUpdate);
			this.uwgObjectives.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(this.uwgObjectives_InitializeLayout);
			// 
			// btnCancel
			// 
			this.btnCancel.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnCancel.Enabled = false;
			this.btnCancel.Location = new System.Drawing.Point(256, 528);
			this.btnCancel.Name = "btnCancel";
			this.btnCancel.Size = new System.Drawing.Size(64, 24);
			this.btnCancel.TabIndex = 37;
			this.btnCancel.Text = "Cancel";
			this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
			// 
			// btnSave
			// 
			this.btnSave.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnSave.Enabled = false;
			this.btnSave.Location = new System.Drawing.Point(176, 528);
			this.btnSave.Name = "btnSave";
			this.btnSave.Size = new System.Drawing.Size(64, 24);
			this.btnSave.TabIndex = 36;
			this.btnSave.Text = "Save";
			this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
			// 
			// btnDelete
			// 
			this.btnDelete.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnDelete.Enabled = false;
			this.btnDelete.Location = new System.Drawing.Point(96, 528);
			this.btnDelete.Name = "btnDelete";
			this.btnDelete.Size = new System.Drawing.Size(64, 24);
			this.btnDelete.TabIndex = 35;
			this.btnDelete.Text = "Delete";
			this.btnDelete.Click += new System.EventHandler(this.btnDelete_Click);
			// 
			// btnAdd
			// 
			this.btnAdd.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)));
			this.btnAdd.Location = new System.Drawing.Point(16, 528);
			this.btnAdd.Name = "btnAdd";
			this.btnAdd.Size = new System.Drawing.Size(64, 24);
			this.btnAdd.TabIndex = 34;
			this.btnAdd.Text = "Add";
			this.btnAdd.Click += new System.EventHandler(this.btnAdd_Click);
			// 
			// ManageObjective
			// 
			this.AcceptButton = this.btnSave;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(896, 557);
			this.Controls.Add(this.pbLast);
			this.Controls.Add(this.pbPrevious);
			this.Controls.Add(this.pnNext);
			this.Controls.Add(this.pbFirst);
			this.Controls.Add(this.uwgObjectives);
			this.Controls.Add(this.btnCancel);
			this.Controls.Add(this.btnSave);
			this.Controls.Add(this.btnDelete);
			this.Controls.Add(this.btnAdd);
			this.Name = "ManageObjective";
			this.Text = "Manage Objective";
			this.Closing += new System.ComponentModel.CancelEventHandler(this.form_Exit);
			((System.ComponentModel.ISupportInitialize)(this.uwgObjectives)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

	}
}
