using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using Infragistics.Shared; 
using Infragistics.Win; 
using Infragistics.Win.UltraWinGrid; 
using CCPM.Data;

namespace CCPM.Project
{
	/// <summary>
	/// DirtyFlag values:
	///    0 = database row not edited
	///    1 = database row edited by user
	///    2 = database row marked as deleted
	///    3 = new row added by user
	/// </summary>
	public class MatchingFunds : System.Windows.Forms.UserControl
	{
		private DataSet dsProjectMatchingFunds;
		private DataSet dsAllOrgs;
		private bool blnGridDirty = false;

		private System.Windows.Forms.Button btnDelete;
		private System.Windows.Forms.Button btnSave;
		private System.Windows.Forms.Button btnCancel;
		private System.Windows.Forms.Button btnAdd;
		private Infragistics.Win.UltraWinGrid.UltraGrid uwgMatchingFunds;
		private System.Windows.Forms.Label lblTotalConservany;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.GroupBox grpTotals;
		private System.Windows.Forms.TextBox txtTotalAuthorized;
		private System.Windows.Forms.TextBox txtTotalMatchingFunds;
		private System.Windows.Forms.Label lblTotalMatchingFunds;
		private System.Windows.Forms.TextBox txtProjectCosts;
		private System.Windows.Forms.Label lblInstructions;
		private System.Windows.Forms.Button btnAddOrg;
		private System.Windows.Forms.Button btnRefresh;
		/// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		public MatchingFunds()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();
			FormInits();
		}
		private void FormInits()
		{

			// Create the objectives dataset and bind to a value list
			uwgMatchingFunds.DisplayLayout.ValueLists.Add("Orgs");

			dsAllOrgs = ProjectFundingData.GetOrgSelectionList();
			for(int i = 0; i < dsAllOrgs.Tables[0].Rows.Count; i++)
			{
				Infragistics.Win.ValueListItem ListItem = new Infragistics.Win.ValueListItem();
				ListItem.DataValue = dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(0);
				ListItem.DisplayText = (string) dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(1);
				uwgMatchingFunds.DisplayLayout.ValueLists["Orgs"].ValueListItems.Add (ListItem);
			}

			// Initialize the grid with data
			LoadGrid();
			LoadTotals();
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		public bool GridDirty
		{
			get
			{
				return(blnGridDirty);
			}
		}

		private void LoadGrid()
		{
			//Create the project objectives dataset and bind to the grid
			dsProjectMatchingFunds = ProjectFundingData.GetProjectMatchingFunds(GlobalSettings.projectId);
			uwgMatchingFunds.DataSource = dsProjectMatchingFunds.Tables[0];
			uwgMatchingFunds.DataBind();
			//uwgMatchingFunds.DisplayLayout.AutoFitColumns = true;
		}
		public void LoadTotals()
		{
			this.txtTotalAuthorized.Text = ProjectFundingData.GetFundTotal(GlobalSettings.projectId,"A").ToString("$#,###");
			this.txtTotalMatchingFunds.Text = ProjectFundingData.GetFundTotal(GlobalSettings.projectId,"M").ToString("$#,###");
			this.txtProjectCosts.Text = ProjectFundingData.GetFundTotal(GlobalSettings.projectId,"P").ToString("$#,###");
		}

		private void uwgMatchingFunds_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
		{
		    //e.Layout.Bands[0].Header.Appearance.BackColor = Color.Ivory;
			e.Layout.Bands[0].Columns[0].Hidden = true;

			e.Layout.Bands[0].Columns[1].Width = 300;
			e.Layout.Bands[0].Columns[1].Header.Caption = "Matching Fund Source";
			e.Layout.Bands[0].Columns[1].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDownList;
			e.Layout.Bands[0].Columns[1].ValueList = uwgMatchingFunds.DisplayLayout.ValueLists["Orgs"];
			e.Layout.ValueLists["Orgs"].DisplayStyle = Infragistics.Win.ValueListDisplayStyle.DisplayText;
			e.Layout.Bands[0].Columns["OrgID"].ValueList = uwgMatchingFunds.DisplayLayout.ValueLists["Orgs"];

			e.Layout.Bands[0].Columns[2].Width = 130;
			e.Layout.Bands[0].Columns[2].Header.Caption = "Category";
			//e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
			e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.Disabled;
			e.Layout.Bands[0].Columns[2].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
			e.Layout.Bands[0].Columns[2].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
			e.Layout.Bands[0].Columns[2].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;

			e.Layout.Bands[0].Columns[3].Width = 100;
			e.Layout.Bands[0].Columns[3].Header.Caption = "Amount";
			e.Layout.Bands[0].Columns[3].Format = "$#,##0";
			e.Layout.Bands[0].Columns[3].MaskInput = "nnn,nnn,nnn";
			e.Layout.Bands[0].Columns[3].MinValue = 0;
			e.Layout.Bands[0].Columns[3].MaxValue = 999999999;
			e.Layout.Bands[0].Columns[3].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;

			e.Layout.Bands[0].Columns[4].Hidden = true;
		}

		private void uwgMatchingFunds_CellListSelect(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e) 
		{
			int SelectedItemIndex = this.uwgMatchingFunds.DisplayLayout.ValueLists["Orgs"].SelectedIndex;
			string OrgID = this.uwgMatchingFunds.DisplayLayout.ValueLists["Orgs"].ValueListItems[SelectedItemIndex].DataValue.ToString();

			// Set the id for the selected Organization into the row
			this.uwgMatchingFunds.ActiveRow.Cells["OrgID"].Value = OrgID;

			// If this was a an existing row then set the dirty flag accordingly
			if (this.uwgMatchingFunds.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
				this.uwgMatchingFunds.ActiveRow.Cells["DirtyFlag"].Value = "1";
			
			blnGridDirty = true;

			// Set the Organization Type column with the value associated to the selected org
			for(int i = 0; i < dsAllOrgs.Tables[0].Rows.Count; i++)
			{
				if (OrgID == dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(0).ToString())
				{
					this.uwgMatchingFunds.ActiveRow.Cells["OrganizationType"].Value = 
						dsAllOrgs.Tables[0].Rows[i].ItemArray.GetValue(2);
				}
			}
		}

		private void uwgMatchingFunds_AfterCellUpdate(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e) 
		{ 
			// If editing an existing row then set the dirty flag to edit mode for this row
			if (this.uwgMatchingFunds.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
				this.uwgMatchingFunds.ActiveRow.Cells["DirtyFlag"].Value = "1";
			blnGridDirty = true;
			SetButtons();
			// get a handle to the main form so we can enable / disable the menus
			Form1 f = (Form1) this.ParentForm.MdiParent;
			f.DisableMenusAll();
		}

		private void uwgMatchingFunds_AfterRowActivate(object sender, System.EventArgs e) 
		{ 
			SetButtons();
		}

		private void btnDelete_Click(object sender, System.EventArgs e)
		{ 
 
			// Get the row to delete. In this case we will use the active row. 
			UltraGridRow row = this.uwgMatchingFunds.ActiveRow;

			if ( null != row ) 
			{ 
				DialogResult intDiagResult = MessageBox.Show("Do you want to delete this row and save all other pending changes?","Delete Row", 
					MessageBoxButtons.YesNo, MessageBoxIcon.Question);
				if (intDiagResult == DialogResult.Yes)
				{
					// if the row is a database row then mark it for deletion and hide it in the grid
					if (row.Cells["DirtyFlag"].Value.ToString() == "0")
					{
						row.Hidden = true;
						row.Cells["DirtyFlag"].Value = "2";
						blnGridDirty = true;
					}
						// else it was added by the user and not saved to the database - delete it from the grid
					else
					{
						row.Delete(false);
					}
					// set the active row to first (non-hidden) row
					GridManager.FirstButtonHandler(uwgMatchingFunds);
					
					// MAR 2005-03-28 - added Save (remove SetButtons)
					SaveGrid();
				}
			} 
			else 
			{ 
				// If there is no active row, then prompt the user to select one. 
				MessageBox.Show( "Please select a single row to delete." ); 
			} 
		} 

		private void SetButtons()
		{
			if (blnGridDirty == true)
			{
				this.btnSave.Enabled = true;
				this.btnCancel.Enabled = true;
				this.btnAddOrg.Enabled = false;
				this.btnRefresh.Enabled = false;
			}
			else
			{
				this.btnSave.Enabled = false;
				this.btnCancel.Enabled = false;
				this.btnAddOrg.Enabled = true;
				this.btnRefresh.Enabled = true;
			}

			if (this.uwgMatchingFunds.ActiveRow == null)
				this.btnDelete.Enabled = false;
			else
				this.btnDelete.Enabled = true;
		}

		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			if (blnGridDirty == true)
			{
				DialogResult intDiagResult = MessageBox.Show("Data has changed - Do you want to cancel changes?","Cancel Changes", 
					MessageBoxButtons.YesNo, MessageBoxIcon.Question);
				if (intDiagResult == DialogResult.Yes)
				{
					this.LoadGrid();
					blnGridDirty = false;
					SetButtons();
					// get a handle to the main form so we can enable / disable the menus
					Form1 f = (Form1) this.ParentForm.MdiParent;
					f.EnableMenusAll();
				}
			}
		}

		private void btnAdd_Click(object sender, System.EventArgs e)
		{
			UltraGridRow addedRow = uwgMatchingFunds.DisplayLayout.Bands[0].AddNew( );
			addedRow.Cells["DollarAmount"].Value = "0";
			addedRow.Cells["DirtyFlag"].Value = "3";
			blnGridDirty = true;
			SetButtons();
		}

		private void btnSave_Click(object sender, System.EventArgs e)
		{
			SaveGrid();
		}

		private void SaveGrid()
		{
			// Validate grid prior to update
			bool GridValid = true;
			int row;
			int retVal;
			string retMsg;
			for(int i = 0; i < uwgMatchingFunds.Rows.Count; i++)
			{
				row = i + 1;
				if (uwgMatchingFunds.Rows[i].Cells["OrgID"].Value.ToString() == "")
				{
					MessageBox.Show("Please select a valid Funding Source for row " + row.ToString(),
						"Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
					GridValid = false;
					break;
				}
				if (uwgMatchingFunds.Rows[i].Cells["DollarAmount"].Value.ToString() == String.Empty)
				{
					MessageBox.Show("Amount must be a numeric value in row " + row.ToString(),
						"Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);

					GridValid = false;
					break;
				}
			}
			
			// Perform updates
			if (GridValid == true)
			{
				// Iterate through each grid row and determine if an update is needed
				for(int i = 0; i < uwgMatchingFunds.Rows.Count; i++)
				{
					switch (uwgMatchingFunds.Rows[i].Cells["DirtyFlag"].Value.ToString())
					{
						case "1":
						{
							// update
                            //LoadGridRes();

                            //int reId = Convert.ToInt32(this.uwgReservations.Rows[i].Cells[0].Value);

                            //retMsg = ProjectFundingData.MatchingFundUpdate(
                            //    Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells["MatchingFundID"].Value),
                            //    GlobalSettings.projectId,
                            //    Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells["OrgID"].Value), 
                            //    Convert.ToDecimal(uwgMatchingFunds.Rows[i].Cells["DollarAmount"].Value));
                            //if (retMsg!="success")
                            //    MessageBox.Show("Update failed in row " + (i+1).ToString(), "Database Error", 
                            //        MessageBoxButtons.OK, MessageBoxIcon.Error);

							break;
						}
						case "2":
						{
							// delete
							retMsg = ProjectFundingData.MatchingFundDelete(Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells["MatchingFundId"].Value));
							if (retMsg!="success")
							   MessageBox.Show("Delete failed in row " + (i+1).ToString(), "Database Error", 
							     	MessageBoxButtons.OK, MessageBoxIcon.Error);

							break;
						}
						case "3":
						{
							// insert
                            //retVal = ProjectFundingData.MatchingFundInsert(GlobalSettings.projectId, 
                            //    Convert.ToInt32(uwgMatchingFunds.Rows[i].Cells["OrgID"].Value), 
                            //    Convert.ToDecimal(uwgMatchingFunds.Rows[i].Cells["DollarAmount"].Value));
                            //if (retVal==-1)
                            //    MessageBox.Show("Insert failed in row " + (i+1).ToString(), "Database Error", 
                            //        MessageBoxButtons.OK, MessageBoxIcon.Error);
                            break;
						}
					}
				}
				// Reset the dirty flag, reload the grid and reset the form buttons
				blnGridDirty = false;
				LoadGrid();
				LoadTotals();
				SetButtons();
				// get a handle to the main form so we can enable / disable the menus
				Form1 f = (Form1) this.ParentForm.MdiParent;
				f.EnableMenusAll();
			}
		}

		private void pbFirst_Click(object sender, System.EventArgs e)
		{
			GridManager.FirstButtonHandler(uwgMatchingFunds);
		}

		private void pbPrevious_Click(object sender, System.EventArgs e)
		{
			GridManager.PreviousButtonHandler(uwgMatchingFunds);
		}

		private void pbNext_Click(object sender, System.EventArgs e)
		{
			GridManager.NextButtonHandler(uwgMatchingFunds);
		}

		private void pbLast_Click(object sender, System.EventArgs e)
		{
			GridManager.LastButtonHandler(uwgMatchingFunds);
		}

		public void MatchingFundsSaveReminderMsg()
		{
			string msg = "Changes have been made on the Matching Funds screen. Please save or cancel your changes.";
			DialogResult intDiagResult = MessageBox.Show(this,msg, "Data Changed", MessageBoxButtons.OK, MessageBoxIcon.Warning);
		}

		private void btnAddOrg_Click(object sender, System.EventArgs e)
		{
			Project.Organizations frmOrgs = new Project.Organizations(true);
	
			DialogResult intDiagResult = MessageBox.Show("Have you checked to make sure the organization is not already on the Matching Fund Source drop down list?","Confirm", 
				MessageBoxButtons.YesNo, MessageBoxIcon.Question);
			if (intDiagResult == DialogResult.Yes)
			{
				//frmOrgs.Show();	
				frmOrgs.ShowDialog();
				this.LoadGrid();
			}
		}

		private void btnRefresh_Click(object sender, System.EventArgs e)
		{
			// Refresh is used after the 'Add Fund Source' was used to add a new org
			// need to reload the org dropdown list
			uwgMatchingFunds.DisplayLayout.ValueLists.Remove("Orgs");
			FormInits();		
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            Infragistics.Win.UltraWinGrid.UltraGridBand ultraGridBand1 = new Infragistics.Win.UltraWinGrid.UltraGridBand("", -1);
            Infragistics.Win.Appearance appearance1 = new Infragistics.Win.Appearance();
            this.btnDelete = new System.Windows.Forms.Button();
            this.btnSave = new System.Windows.Forms.Button();
            this.btnCancel = new System.Windows.Forms.Button();
            this.btnAdd = new System.Windows.Forms.Button();
            this.uwgMatchingFunds = new Infragistics.Win.UltraWinGrid.UltraGrid();
            this.lblTotalConservany = new System.Windows.Forms.Label();
            this.txtTotalAuthorized = new System.Windows.Forms.TextBox();
            this.txtTotalMatchingFunds = new System.Windows.Forms.TextBox();
            this.lblTotalMatchingFunds = new System.Windows.Forms.Label();
            this.txtProjectCosts = new System.Windows.Forms.TextBox();
            this.label2 = new System.Windows.Forms.Label();
            this.grpTotals = new System.Windows.Forms.GroupBox();
            this.btnAddOrg = new System.Windows.Forms.Button();
            this.lblInstructions = new System.Windows.Forms.Label();
            this.btnRefresh = new System.Windows.Forms.Button();
            ((System.ComponentModel.ISupportInitialize)(this.uwgMatchingFunds)).BeginInit();
            this.grpTotals.SuspendLayout();
            this.SuspendLayout();
            // 
            // btnDelete
            // 
            this.btnDelete.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.btnDelete.Enabled = false;
            this.btnDelete.Location = new System.Drawing.Point(96, 241);
            this.btnDelete.Name = "btnDelete";
            this.btnDelete.Size = new System.Drawing.Size(76, 31);
            this.btnDelete.TabIndex = 23;
            this.btnDelete.Text = "Delete";
            this.btnDelete.Click += new System.EventHandler(this.btnDelete_Click);
            // 
            // btnSave
            // 
            this.btnSave.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.btnSave.Enabled = false;
            this.btnSave.Location = new System.Drawing.Point(176, 241);
            this.btnSave.Name = "btnSave";
            this.btnSave.Size = new System.Drawing.Size(76, 31);
            this.btnSave.TabIndex = 24;
            this.btnSave.Text = "Save";
            this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
            // 
            // btnCancel
            // 
            this.btnCancel.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.btnCancel.Enabled = false;
            this.btnCancel.Location = new System.Drawing.Point(256, 241);
            this.btnCancel.Name = "btnCancel";
            this.btnCancel.Size = new System.Drawing.Size(76, 31);
            this.btnCancel.TabIndex = 25;
            this.btnCancel.Text = "Cancel";
            this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
            // 
            // btnAdd
            // 
            this.btnAdd.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.btnAdd.Location = new System.Drawing.Point(16, 241);
            this.btnAdd.Name = "btnAdd";
            this.btnAdd.Size = new System.Drawing.Size(76, 31);
            this.btnAdd.TabIndex = 22;
            this.btnAdd.Text = "Add";
            this.btnAdd.Click += new System.EventHandler(this.btnAdd_Click);
            // 
            // uwgMatchingFunds
            // 
            this.uwgMatchingFunds.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.uwgMatchingFunds.Cursor = System.Windows.Forms.Cursors.Hand;
            appearance1.BackColor = System.Drawing.SystemColors.Info;
            ultraGridBand1.Header.Appearance = appearance1;
            this.uwgMatchingFunds.DisplayLayout.BandsSerializer.Add(ultraGridBand1);
            this.uwgMatchingFunds.Font = new System.Drawing.Font("Arial", 8F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.uwgMatchingFunds.Location = new System.Drawing.Point(18, 8);
            this.uwgMatchingFunds.Name = "uwgMatchingFunds";
            this.uwgMatchingFunds.Size = new System.Drawing.Size(566, 200);
            this.uwgMatchingFunds.TabIndex = 28;
            this.uwgMatchingFunds.Text = "MATCHING FUNDS";
            this.uwgMatchingFunds.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(this.uwgMatchingFunds_InitializeLayout);
            this.uwgMatchingFunds.CellListSelect += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgMatchingFunds_CellListSelect);
            this.uwgMatchingFunds.AfterCellUpdate += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgMatchingFunds_AfterCellUpdate);
            this.uwgMatchingFunds.AfterRowActivate += new System.EventHandler(this.uwgMatchingFunds_AfterRowActivate);
            // 
            // lblTotalConservany
            // 
            this.lblTotalConservany.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.lblTotalConservany.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblTotalConservany.Location = new System.Drawing.Point(10, 35);
            this.lblTotalConservany.Name = "lblTotalConservany";
            this.lblTotalConservany.Size = new System.Drawing.Size(213, 16);
            this.lblTotalConservany.TabIndex = 34;
            this.lblTotalConservany.Text = "Total Conservancy Contribution";
            // 
            // txtTotalAuthorized
            // 
            this.txtTotalAuthorized.BackColor = System.Drawing.Color.White;
            this.txtTotalAuthorized.Enabled = false;
            this.txtTotalAuthorized.Location = new System.Drawing.Point(224, 21);
            this.txtTotalAuthorized.Name = "txtTotalAuthorized";
            this.txtTotalAuthorized.Size = new System.Drawing.Size(107, 21);
            this.txtTotalAuthorized.TabIndex = 35;
            this.txtTotalAuthorized.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // txtTotalMatchingFunds
            // 
            this.txtTotalMatchingFunds.BackColor = System.Drawing.Color.White;
            this.txtTotalMatchingFunds.Enabled = false;
            this.txtTotalMatchingFunds.Location = new System.Drawing.Point(224, 48);
            this.txtTotalMatchingFunds.Name = "txtTotalMatchingFunds";
            this.txtTotalMatchingFunds.Size = new System.Drawing.Size(107, 21);
            this.txtTotalMatchingFunds.TabIndex = 37;
            this.txtTotalMatchingFunds.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // lblTotalMatchingFunds
            // 
            this.lblTotalMatchingFunds.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.lblTotalMatchingFunds.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblTotalMatchingFunds.Location = new System.Drawing.Point(10, 62);
            this.lblTotalMatchingFunds.Name = "lblTotalMatchingFunds";
            this.lblTotalMatchingFunds.Size = new System.Drawing.Size(160, 16);
            this.lblTotalMatchingFunds.TabIndex = 36;
            this.lblTotalMatchingFunds.Text = "Total Matching Funds";
            // 
            // txtProjectCosts
            // 
            this.txtProjectCosts.BackColor = System.Drawing.Color.White;
            this.txtProjectCosts.Enabled = false;
            this.txtProjectCosts.Location = new System.Drawing.Point(224, 75);
            this.txtProjectCosts.Name = "txtProjectCosts";
            this.txtProjectCosts.Size = new System.Drawing.Size(107, 21);
            this.txtProjectCosts.TabIndex = 39;
            this.txtProjectCosts.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            // 
            // label2
            // 
            this.label2.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.label2.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label2.Location = new System.Drawing.Point(10, 89);
            this.label2.Name = "label2";
            this.label2.Size = new System.Drawing.Size(160, 16);
            this.label2.TabIndex = 38;
            this.label2.Text = "Total Project Costs";
            // 
            // grpTotals
            // 
            this.grpTotals.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.grpTotals.Controls.Add(this.txtTotalAuthorized);
            this.grpTotals.Controls.Add(this.txtTotalMatchingFunds);
            this.grpTotals.Controls.Add(this.lblTotalMatchingFunds);
            this.grpTotals.Controls.Add(this.label2);
            this.grpTotals.Controls.Add(this.txtProjectCosts);
            this.grpTotals.Controls.Add(this.lblTotalConservany);
            this.grpTotals.Location = new System.Drawing.Point(242, 304);
            this.grpTotals.Name = "grpTotals";
            this.grpTotals.Size = new System.Drawing.Size(337, 112);
            this.grpTotals.TabIndex = 40;
            this.grpTotals.TabStop = false;
            this.grpTotals.Text = "Project Totals";
            // 
            // btnAddOrg
            // 
            this.btnAddOrg.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.btnAddOrg.Font = new System.Drawing.Font("Arial", 8F);
            this.btnAddOrg.Location = new System.Drawing.Point(336, 241);
            this.btnAddOrg.Name = "btnAddOrg";
            this.btnAddOrg.Size = new System.Drawing.Size(76, 31);
            this.btnAddOrg.TabIndex = 41;
            this.btnAddOrg.Text = "Enter New Organization";
            this.btnAddOrg.Click += new System.EventHandler(this.btnAddOrg_Click);
            // 
            // lblInstructions
            // 
            this.lblInstructions.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.lblInstructions.Font = new System.Drawing.Font("Arial", 7.75F);
            this.lblInstructions.ForeColor = System.Drawing.Color.Green;
            this.lblInstructions.Location = new System.Drawing.Point(11, 440);
            this.lblInstructions.Name = "lblInstructions";
            this.lblInstructions.Size = new System.Drawing.Size(571, 16);
            this.lblInstructions.TabIndex = 42;
            this.lblInstructions.Text = "Use Tab to navigate between cells within a row. Click \'Save\' to refresh Project T" +
                "otals after changes.";
            this.lblInstructions.Click += new System.EventHandler(this.lblInstructions_Click);
            // 
            // btnRefresh
            // 
            this.btnRefresh.Anchor = System.Windows.Forms.AnchorStyles.None;
            this.btnRefresh.Enabled = false;
            this.btnRefresh.Location = new System.Drawing.Point(416, 241);
            this.btnRefresh.Name = "btnRefresh";
            this.btnRefresh.Size = new System.Drawing.Size(76, 31);
            this.btnRefresh.TabIndex = 43;
            this.btnRefresh.Text = "Refresh";
            this.btnRefresh.Click += new System.EventHandler(this.btnRefresh_Click);
            // 
            // MatchingFunds
            // 
            this.Controls.Add(this.btnRefresh);
            this.Controls.Add(this.lblInstructions);
            this.Controls.Add(this.btnAddOrg);
            this.Controls.Add(this.grpTotals);
            this.Controls.Add(this.uwgMatchingFunds);
            this.Controls.Add(this.btnCancel);
            this.Controls.Add(this.btnSave);
            this.Controls.Add(this.btnDelete);
            this.Controls.Add(this.btnAdd);
            this.Font = new System.Drawing.Font("Arial", 9F);
            this.Name = "MatchingFunds";
            this.Size = new System.Drawing.Size(763, 467);
            this.Load += new System.EventHandler(this.MatchingFunds_Load);
            ((System.ComponentModel.ISupportInitialize)(this.uwgMatchingFunds)).EndInit();
            this.grpTotals.ResumeLayout(false);
            this.grpTotals.PerformLayout();
            this.ResumeLayout(false);

		}
		#endregion

		private void lblInstructions_Click(object sender, System.EventArgs e)
		{
		
		}

        private void MatchingFunds_Load(object sender, EventArgs e)
        {

        }



	}
}
