using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Windows.Forms;
using Infragistics.Shared; 
using Infragistics.Win; 
using Infragistics.Win.UltraWinGrid; 
using CCPM.Data;
using CCPM.Contact;
using Microsoft.ApplicationBlocks.Data;

namespace CCPM.Project
{
	/// <summary>
	/// Summary description for Organization.
	/// </summary>
	public class Organizations : System.Windows.Forms.Form
	{
		private DataSet dsOrgs;
		private DataSet dsOrgTypes;
		private bool blnGridDirty = false;
        private bool autoLaunchAdd = false;
        private string formActDisplay = "admin";

        int OrgAddressId = 0;
        int OrgId = 0;
        private Label label3;
        private Button btnEditContact;
        private Button btnLinkContact;
        private Button btnEditOrg;
        private Button btnLinkOrg;
        private UltraGrid uwgOrg;
        private UltraGrid uwgContacts;
		
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
        private UltraGrid uwgOrgAddress;
        private Button btnRefresh;
        private Button btnRemove;
        private Label label1;
        private Button btnAdd;
        private Button btnContactRemove;
        private Button btnAddressRemove;
        private Button btnAddAddress;
        private Button btnEditAddress;
        bool blnDataDirty = false;
        private Button btnLink;
        private Label label10;
        private Label label2;
        private Label label4;
        private Button btnEditOrgAddress;
        private Button btnLinkOrgAddressToProject;
        private TextBox txtTopOrganizationAddressNotes;
        private Label label5;
        private System.Windows.Forms.ContextMenu contextMenu1;
		public Organizations()
		{
			FormInits();
		}

		public Organizations(bool launchAdd)
		{
			// this constructor called by project MatchingFunds page ('Add Funding Source' button)
			FormInits();
			if (launchAdd)
			{
				autoLaunchAdd = true;
			
			}
		}

        public Organizations(string formDisplay, int? OrgId)
        {
            // this constructor called by project MatchingFunds page ('Add Funding Source' button)
            FormInits();
            if (formDisplay == "project")
            {
                formActDisplay = formDisplay;
                this.Text = "Link Organization to Project";

                if (GlobalSettings.projectId != 0)
                {
                    DataSet ds = ContractData.GetProjectNumber(GlobalSettings.projectId);
                    DataRow dr = ds.Tables[0].Rows[0];
                    label10.Text = "Link Organization to Project (" + dr["ProjectName"].ToString() + ")";

                    if (OrgId != null)
                    {
                        this.OrgId = OrgId.Value;
                    }
                }

            }
            else //default
                formActDisplay = "admin";
        }

		private void FormInits()
		{
			InitializeComponent();

            
            uwgOrg.DisplayLayout.Override.WrapHeaderText = Infragistics.Win.DefaultableBoolean.True;
            uwgContacts.DisplayLayout.Override.WrapHeaderText = Infragistics.Win.DefaultableBoolean.True;

			// Initialize the grid with data
			LoadGrid();
            LoadContacts();
            //SetContextMenu();
			
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		private void LoadGrid()
		{
			//Create the project objectives dataset and bind to the grid
			dsOrgs = OrganizationData.GetOrganizations();
			uwgOrg.DataSource = dsOrgs.Tables[0];
			uwgOrg.DataBind();

            if (uwgOrg.Rows.Count > 0)
            {
                //uwgOrg.Rows[0].Selected = true;
                if (OrgId != 0)
                {
                    for (int i = 0; i < uwgOrg.Rows.Count; i++)
                    {
                        if (Convert.ToInt32(uwgOrg.Rows[i].Cells[3].Value) == OrgId)
                        {
                            uwgOrg.Rows[i].Selected = true;
                            uwgOrg.Rows[i].Activated = true;
                        }
                    }

                }
                else
                {
                    uwgOrg.Rows[0].Selected = true;
                }
            }

            if (uwgOrg.Rows.Count > 0)
            {
                //uwgOrg.Rows[0].Selected = true;
                btnEditOrg.Enabled = true;
                btnRemove.Enabled = true;
                btnLinkContact.Enabled = true;
                btnAdd.Enabled = true;
                btnAddAddress.Enabled = true;
            }
            else
            {
                btnEditOrg.Enabled = false;
                btnRemove.Enabled = false;
                btnLinkContact.Enabled = false;
                btnAdd.Enabled = false;
                btnAddAddress.Enabled = false;
            }
		}

        public void LoadContacts()
        {
            DbConnection dbConnection = DbConnection.GetDbConnection();
            string connectionString = dbConnection.DbConnectionString;
            int orgId = 0;
            if (uwgOrg.Rows.Count < 1)
            {
                orgId = 0;
                btnEditContact.Enabled = false;
            }
            else
            {
                if (uwgOrg.ActiveRow.Cells[3].Value != System.DBNull.Value)
                {
                    orgId = Convert.ToInt32(uwgOrg.ActiveRow.Cells[3].Value);
                    btnEditContact.Enabled = true;
                }
            }
            DataSet cds = SqlHelper.ExecuteDataset(connectionString, CommandType.Text, "Select 'Remove Contact' as Button, ContactLName + ',  ' + ContactFName as FullName, ContactJobTitle, ContactPhone, ContactExtension, ContactCellPhone, ContactFax, ContactEmail, ContactID, oa.Address + ' ' + oa.City + ' ' + oa.State + ' ' + oa.Zip from Contact LEFT OUTER JOIN OrgAddress oa ON Contact.OrgAddressID = oa.OrgAddressID Where Contact.OrgID = " + orgId + " order by ContactLName, ContactFName" );  //ContactData.GetContactByOrganization(orgId);
            uwgContacts.DataSource = cds;
            uwgContacts.DataBind();

            if (uwgContacts.Rows.Count < 1)
            {
                btnEditContact.Enabled = false;
                btnContactRemove.Enabled = false;
            }
            else
            {
                uwgContacts.Rows[0].Selected = true;
                btnEditContact.Enabled = true;
                btnContactRemove.Enabled = true;
            }
        }

        public void LoadOrgAddress()
        {
            DbConnection dbConnection = DbConnection.GetDbConnection();
            string connectionString = dbConnection.DbConnectionString;
            int orgId = 0;
            if (uwgOrg.Rows.Count < 1)
            {
                orgId = 0;
            }
            else
            {
                if (uwgOrg.ActiveRow.Cells[3].Value != System.DBNull.Value)
                    orgId = Convert.ToInt32(uwgOrg.ActiveRow.Cells[3].Value);
            }
            DataSet cds = SqlHelper.ExecuteDataset(connectionString, CommandType.Text, "Select 'Remove Org Address' as Button, DepartmentOffice, Address, City, State, Zip, GeneralPhone, GeneralFax, OrgNotes, OrgAddressID, 0 AS DirtyFlag from OrgAddress Where OrgID = " + orgId);
            uwgOrgAddress.DataSource = cds;
            uwgOrgAddress.DataBind();

            if (uwgOrgAddress.Rows.Count < 1)
            {
                btnAddressRemove.Enabled = false;
                btnEditOrgAddress.Enabled = false;
            }
            else
            {
                uwgOrgAddress.Rows[0].Selected = true;
                btnAddressRemove.Enabled = true;
                btnEditOrgAddress.Enabled = true;

                //now get the address notes and put it in the box.
                txtTopOrganizationAddressNotes.Text = uwgOrgAddress.Rows[0].Cells["OrgNotes"].Value.ToString();
            }
        }
		

		private void form_Exit(object sender, System.ComponentModel.CancelEventArgs e)
		{
			if (blnGridDirty == true)
			{
				// If edits were made then display a dialog box to the user
				DialogResult intDiagResult = MessageBox.Show("Changes have been made on the " +
					"Organizations screen.  Do you want to discard these changes?", "", 
					MessageBoxButtons.YesNo, MessageBoxIcon.Question);
				// If the user wants to save the changes cancel the close
				if (intDiagResult == DialogResult.No)
				{
					e.Cancel = true;
				}
			}
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.label3 = new System.Windows.Forms.Label();
            this.btnEditContact = new System.Windows.Forms.Button();
            this.btnLinkContact = new System.Windows.Forms.Button();
            this.btnEditOrg = new System.Windows.Forms.Button();
            this.btnLinkOrg = new System.Windows.Forms.Button();
            this.uwgOrg = new Infragistics.Win.UltraWinGrid.UltraGrid();
            this.uwgContacts = new Infragistics.Win.UltraWinGrid.UltraGrid();
            this.uwgOrgAddress = new Infragistics.Win.UltraWinGrid.UltraGrid();
            this.btnRefresh = new System.Windows.Forms.Button();
            this.btnRemove = new System.Windows.Forms.Button();
            this.label1 = new System.Windows.Forms.Label();
            this.btnAdd = new System.Windows.Forms.Button();
            this.btnContactRemove = new System.Windows.Forms.Button();
            this.btnAddressRemove = new System.Windows.Forms.Button();
            this.btnAddAddress = new System.Windows.Forms.Button();
            this.btnEditAddress = new System.Windows.Forms.Button();
            this.btnLink = new System.Windows.Forms.Button();
            this.label10 = new System.Windows.Forms.Label();
            this.label2 = new System.Windows.Forms.Label();
            this.label4 = new System.Windows.Forms.Label();
            this.btnEditOrgAddress = new System.Windows.Forms.Button();
            this.btnLinkOrgAddressToProject = new System.Windows.Forms.Button();
            this.txtTopOrganizationAddressNotes = new System.Windows.Forms.TextBox();
            this.label5 = new System.Windows.Forms.Label();
            ((System.ComponentModel.ISupportInitialize)(this.uwgOrg)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.uwgContacts)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.uwgOrgAddress)).BeginInit();
            this.SuspendLayout();
            // 
            // label3
            // 
            this.label3.AutoSize = true;
            this.label3.Location = new System.Drawing.Point(12, 387);
            this.label3.Name = "label3";
            this.label3.Size = new System.Drawing.Size(377, 13);
            this.label3.TabIndex = 80;
            this.label3.Text = "Before clicking the buttons below, first select an organization in the grid above" +
                ".";
            // 
            // btnEditContact
            // 
            this.btnEditContact.Location = new System.Drawing.Point(355, 598);
            this.btnEditContact.Name = "btnEditContact";
            this.btnEditContact.Size = new System.Drawing.Size(102, 25);
            this.btnEditContact.TabIndex = 10;
            this.btnEditContact.Text = "Edit Contact";
            this.btnEditContact.UseVisualStyleBackColor = true;
            this.btnEditContact.Click += new System.EventHandler(this.btnEditContact_Click);
            // 
            // btnLinkContact
            // 
            this.btnLinkContact.Location = new System.Drawing.Point(15, 598);
            this.btnLinkContact.Name = "btnLinkContact";
            this.btnLinkContact.Size = new System.Drawing.Size(205, 25);
            this.btnLinkContact.TabIndex = 8;
            this.btnLinkContact.Text = "Link Contact to Organization";
            this.btnLinkContact.UseVisualStyleBackColor = true;
            this.btnLinkContact.Click += new System.EventHandler(this.btnLinkContact_Click);
            // 
            // btnEditOrg
            // 
            this.btnEditOrg.Location = new System.Drawing.Point(409, 403);
            this.btnEditOrg.Name = "btnEditOrg";
            this.btnEditOrg.Size = new System.Drawing.Size(135, 24);
            this.btnEditOrg.TabIndex = 5;
            this.btnEditOrg.Text = "Edit Organization";
            this.btnEditOrg.UseVisualStyleBackColor = true;
            this.btnEditOrg.Click += new System.EventHandler(this.btnEditOrg_Click);
            // 
            // btnLinkOrg
            // 
            this.btnLinkOrg.Location = new System.Drawing.Point(242, 403);
            this.btnLinkOrg.Name = "btnLinkOrg";
            this.btnLinkOrg.Size = new System.Drawing.Size(162, 24);
            this.btnLinkOrg.TabIndex = 4;
            this.btnLinkOrg.Text = "Add New Organization";
            this.btnLinkOrg.UseVisualStyleBackColor = true;
            this.btnLinkOrg.Click += new System.EventHandler(this.btnLinkOrg_Click);
            // 
            // uwgOrg
            // 
            this.uwgOrg.Cursor = System.Windows.Forms.Cursors.Hand;
            this.uwgOrg.Font = new System.Drawing.Font("Arial", 8F);
            this.uwgOrg.Location = new System.Drawing.Point(12, 67);
            this.uwgOrg.Name = "uwgOrg";
            this.uwgOrg.Size = new System.Drawing.Size(698, 319);
            this.uwgOrg.TabIndex = 2;
            this.uwgOrg.Text = "Organizations";
            this.uwgOrg.MouseDown += new System.Windows.Forms.MouseEventHandler(this.uwgOrg_MouseDown);
            this.uwgOrg.ClickCellButton += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgOrg_ClickCellButton);
            this.uwgOrg.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(this.uwgOrg_InitializeLayout);
            this.uwgOrg.AfterRowActivate += new System.EventHandler(this.uwgOrg_AfterRowActivate);
            // 
            // uwgContacts
            // 
            this.uwgContacts.Cursor = System.Windows.Forms.Cursors.Hand;
            this.uwgContacts.Font = new System.Drawing.Font("Arial", 8F);
            this.uwgContacts.Location = new System.Drawing.Point(12, 438);
            this.uwgContacts.Name = "uwgContacts";
            this.uwgContacts.Size = new System.Drawing.Size(940, 141);
            this.uwgContacts.TabIndex = 7;
            this.uwgContacts.Text = "Contacts";
            this.uwgContacts.ClickCellButton += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgContacts_ClickCellButton);
            this.uwgContacts.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(this.uwgContacts_InitializeLayout);
            // 
            // uwgOrgAddress
            // 
            this.uwgOrgAddress.Cursor = System.Windows.Forms.Cursors.Hand;
            this.uwgOrgAddress.Font = new System.Drawing.Font("Arial", 8F);
            this.uwgOrgAddress.Location = new System.Drawing.Point(13, 632);
            this.uwgOrgAddress.Name = "uwgOrgAddress";
            this.uwgOrgAddress.Size = new System.Drawing.Size(892, 127);
            this.uwgOrgAddress.TabIndex = 12;
            this.uwgOrgAddress.Text = "Organization Address";
            this.uwgOrgAddress.AfterCellUpdate += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgOrgAddress_AfterCellUpdate);
            this.uwgOrgAddress.Leave += new System.EventHandler(this.uwgOrgAddress_Leave);
            this.uwgOrgAddress.ClickCellButton += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgOrgAddress_ClickCellButton);
            this.uwgOrgAddress.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(this.uwgOrgAddress_InitializeLayout);
            // 
            // btnRefresh
            // 
            this.btnRefresh.Location = new System.Drawing.Point(307, 33);
            this.btnRefresh.Name = "btnRefresh";
            this.btnRefresh.Size = new System.Drawing.Size(97, 23);
            this.btnRefresh.TabIndex = 1;
            this.btnRefresh.Text = "Refresh";
            this.btnRefresh.UseVisualStyleBackColor = true;
            this.btnRefresh.Click += new System.EventHandler(this.btnRefresh_Click);
            // 
            // btnRemove
            // 
            this.btnRemove.Location = new System.Drawing.Point(548, 403);
            this.btnRemove.Name = "btnRemove";
            this.btnRemove.Size = new System.Drawing.Size(162, 24);
            this.btnRemove.TabIndex = 6;
            this.btnRemove.Text = "Delete Organization";
            this.btnRemove.UseVisualStyleBackColor = true;
            this.btnRemove.Click += new System.EventHandler(this.btnRemove_Click);
            // 
            // label1
            // 
            this.label1.AutoSize = true;
            this.label1.Location = new System.Drawing.Point(13, 582);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(350, 13);
            this.label1.TabIndex = 81;
            this.label1.Text = "Before clicking the buttons below, first select a contact in the grid above.";
            // 
            // btnAdd
            // 
            this.btnAdd.Location = new System.Drawing.Point(226, 598);
            this.btnAdd.Name = "btnAdd";
            this.btnAdd.Size = new System.Drawing.Size(123, 25);
            this.btnAdd.TabIndex = 9;
            this.btnAdd.Text = "Add New Contact";
            this.btnAdd.UseVisualStyleBackColor = true;
            this.btnAdd.Click += new System.EventHandler(this.btnAdd_Click);
            // 
            // btnContactRemove
            // 
            this.btnContactRemove.Location = new System.Drawing.Point(461, 598);
            this.btnContactRemove.Name = "btnContactRemove";
            this.btnContactRemove.Size = new System.Drawing.Size(182, 25);
            this.btnContactRemove.TabIndex = 11;
            this.btnContactRemove.Text = "Unlink Contact from Org";
            this.btnContactRemove.UseVisualStyleBackColor = true;
            this.btnContactRemove.Click += new System.EventHandler(this.btnContactRemove_Click);
            // 
            // btnAddressRemove
            // 
            this.btnAddressRemove.Location = new System.Drawing.Point(425, 781);
            this.btnAddressRemove.Name = "btnAddressRemove";
            this.btnAddressRemove.Size = new System.Drawing.Size(181, 23);
            this.btnAddressRemove.TabIndex = 14;
            this.btnAddressRemove.Text = "Remove Org Address";
            this.btnAddressRemove.UseVisualStyleBackColor = true;
            this.btnAddressRemove.Click += new System.EventHandler(this.btnAddressRemove_Click);
            // 
            // btnAddAddress
            // 
            this.btnAddAddress.Location = new System.Drawing.Point(235, 781);
            this.btnAddAddress.Name = "btnAddAddress";
            this.btnAddAddress.Size = new System.Drawing.Size(181, 23);
            this.btnAddAddress.TabIndex = 13;
            this.btnAddAddress.Text = "Add New Org Address";
            this.btnAddAddress.UseVisualStyleBackColor = true;
            this.btnAddAddress.Click += new System.EventHandler(this.btnAddAddress_Click);
            // 
            // btnEditAddress
            // 
            this.btnEditAddress.Location = new System.Drawing.Point(774, 781);
            this.btnEditAddress.Name = "btnEditAddress";
            this.btnEditAddress.Size = new System.Drawing.Size(146, 23);
            this.btnEditAddress.TabIndex = 15;
            this.btnEditAddress.Text = "Save Org Address";
            this.btnEditAddress.UseVisualStyleBackColor = true;
            this.btnEditAddress.Visible = false;
            this.btnEditAddress.Click += new System.EventHandler(this.btnEditAddress_Click);
            // 
            // btnLink
            // 
            this.btnLink.Location = new System.Drawing.Point(8, 403);
            this.btnLink.Name = "btnLink";
            this.btnLink.Size = new System.Drawing.Size(229, 24);
            this.btnLink.TabIndex = 3;
            this.btnLink.Text = "Link Organization to Project";
            this.btnLink.UseVisualStyleBackColor = true;
            this.btnLink.Click += new System.EventHandler(this.btnLink_Click);
            // 
            // label10
            // 
            this.label10.AutoSize = true;
            this.label10.Font = new System.Drawing.Font("Microsoft Sans Serif", 14F, ((System.Drawing.FontStyle)((System.Drawing.FontStyle.Bold | System.Drawing.FontStyle.Italic))), System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label10.ForeColor = System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(0)))), ((int)(((byte)(192)))));
            this.label10.Location = new System.Drawing.Point(10, 6);
            this.label10.Name = "label10";
            this.label10.Size = new System.Drawing.Size(387, 24);
            this.label10.TabIndex = 134;
            this.label10.Text = "Master Organization List   (Administrator)";
            // 
            // label2
            // 
            this.label2.AutoSize = true;
            this.label2.Location = new System.Drawing.Point(15, 763);
            this.label2.Name = "label2";
            this.label2.Size = new System.Drawing.Size(417, 13);
            this.label2.TabIndex = 135;
            this.label2.Text = "Before clicking the buttons below, first select an organization address in the gr" +
                "id above.";
            // 
            // label4
            // 
            this.label4.AutoSize = true;
            this.label4.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label4.Location = new System.Drawing.Point(12, 38);
            this.label4.Name = "label4";
            this.label4.Size = new System.Drawing.Size(278, 13);
            this.label4.TabIndex = 136;
            this.label4.Text = "To reload the page, click the REFRESH button:";
            // 
            // btnEditOrgAddress
            // 
            this.btnEditOrgAddress.Location = new System.Drawing.Point(618, 781);
            this.btnEditOrgAddress.Name = "btnEditOrgAddress";
            this.btnEditOrgAddress.Size = new System.Drawing.Size(144, 23);
            this.btnEditOrgAddress.TabIndex = 137;
            this.btnEditOrgAddress.Text = "Edit Org Address";
            this.btnEditOrgAddress.UseVisualStyleBackColor = true;
            this.btnEditOrgAddress.Click += new System.EventHandler(this.btnEditOrgAddress_Click);
            // 
            // btnLinkOrgAddressToProject
            // 
            this.btnLinkOrgAddressToProject.Location = new System.Drawing.Point(18, 780);
            this.btnLinkOrgAddressToProject.Name = "btnLinkOrgAddressToProject";
            this.btnLinkOrgAddressToProject.Size = new System.Drawing.Size(202, 24);
            this.btnLinkOrgAddressToProject.TabIndex = 138;
            this.btnLinkOrgAddressToProject.Text = "Link Org Address to Project";
            this.btnLinkOrgAddressToProject.UseVisualStyleBackColor = true;
            this.btnLinkOrgAddressToProject.Click += new System.EventHandler(this.btnLinkOrgAddressToProject_Click);
            // 
            // txtTopOrganizationAddressNotes
            // 
            this.txtTopOrganizationAddressNotes.BackColor = System.Drawing.Color.White;
            this.txtTopOrganizationAddressNotes.Location = new System.Drawing.Point(717, 101);
            this.txtTopOrganizationAddressNotes.Multiline = true;
            this.txtTopOrganizationAddressNotes.Name = "txtTopOrganizationAddressNotes";
            this.txtTopOrganizationAddressNotes.ReadOnly = true;
            this.txtTopOrganizationAddressNotes.Size = new System.Drawing.Size(235, 326);
            this.txtTopOrganizationAddressNotes.TabIndex = 139;
            // 
            // label5
            // 
            this.label5.AutoSize = true;
            this.label5.Location = new System.Drawing.Point(717, 82);
            this.label5.Name = "label5";
            this.label5.Size = new System.Drawing.Size(160, 13);
            this.label5.TabIndex = 140;
            this.label5.Text = "Top Organization Address Notes";
            // 
            // Organizations
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.AutoScroll = true;
            this.ClientSize = new System.Drawing.Size(1240, 835);
            this.Controls.Add(this.label5);
            this.Controls.Add(this.txtTopOrganizationAddressNotes);
            this.Controls.Add(this.btnLinkOrgAddressToProject);
            this.Controls.Add(this.btnEditOrgAddress);
            this.Controls.Add(this.label4);
            this.Controls.Add(this.label2);
            this.Controls.Add(this.label10);
            this.Controls.Add(this.btnLink);
            this.Controls.Add(this.btnEditAddress);
            this.Controls.Add(this.btnAddAddress);
            this.Controls.Add(this.btnAddressRemove);
            this.Controls.Add(this.btnContactRemove);
            this.Controls.Add(this.btnAdd);
            this.Controls.Add(this.btnLinkContact);
            this.Controls.Add(this.btnEditContact);
            this.Controls.Add(this.label1);
            this.Controls.Add(this.label3);
            this.Controls.Add(this.btnRemove);
            this.Controls.Add(this.btnRefresh);
            this.Controls.Add(this.uwgOrgAddress);
            this.Controls.Add(this.uwgOrg);
            this.Controls.Add(this.btnEditOrg);
            this.Controls.Add(this.btnLinkOrg);
            this.Controls.Add(this.uwgContacts);
            this.Name = "Organizations";
            this.Text = "Master Organization List";
            this.Activated += new System.EventHandler(this.Organizations_Activated);
            this.Closing += new System.ComponentModel.CancelEventHandler(this.form_Exit);
            this.KeyUp += new System.Windows.Forms.KeyEventHandler(this.Organizations_KeyUp);
            this.FormClosing += new System.Windows.Forms.FormClosingEventHandler(this.Organizations_FormClosing);
            ((System.ComponentModel.ISupportInitialize)(this.uwgOrg)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.uwgContacts)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.uwgOrgAddress)).EndInit();
            this.ResumeLayout(false);
            this.PerformLayout();

		}
		#endregion

        private void uwgOrg_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            e.Layout.Bands[0].Columns[0].Width = 80;
            e.Layout.Bands[0].Columns[0].Hidden = true;
            e.Layout.Bands[0].Columns[0].Header.Caption = "Remove Organization";
            e.Layout.Bands[0].Columns[0].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.Button;
            e.Layout.Bands[0].Columns[0].ButtonDisplayStyle = Infragistics.Win.UltraWinGrid.ButtonDisplayStyle.Always;

            e.Layout.Bands[0].Columns[1].Width = 200;
            e.Layout.Bands[0].Columns[1].Header.Caption = "Organization";
            e.Layout.Bands[0].Columns[1].CellActivation = Infragistics.Win.UltraWinGrid.Activation.ActivateOnly;

            e.Layout.Bands[0].Columns[2].Width = 150;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Organization Type";
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.ActivateOnly;

            // OrgID
            e.Layout.Bands[0].Columns[3].Hidden = true;
            //TaxID
            e.Layout.Bands[0].Columns[4].Width = 80;
            e.Layout.Bands[0].Columns[4].Header.Caption = "TaxID Number";
            e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            //SBE
            e.Layout.Bands[0].Columns[5].Width = 60;
            e.Layout.Bands[0].Columns[5].Header.Caption = "SBE";
            e.Layout.Bands[0].Columns[5].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[5].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.CheckBox;
            //DVBE
            e.Layout.Bands[0].Columns[6].Width = 60;
            e.Layout.Bands[0].Columns[6].Header.Caption = "DVBE";
            e.Layout.Bands[0].Columns[6].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[6].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.CheckBox;

            //filter row
            e.Layout.Override.AllowRowFiltering = Infragistics.Win.DefaultableBoolean.True;
            e.Layout.Override.FilterClearButtonLocation = FilterClearButtonLocation.Row;
            e.Layout.Override.FilterUIType = Infragistics.Win.UltraWinGrid.FilterUIType.FilterRow;
            e.Layout.Override.FilterOperatorDefaultValue = FilterOperatorDefaultValue.Contains;

            //column sorting
            e.Layout.Override.HeaderClickAction = HeaderClickAction.SortMulti;  
           
        }

        private void uwgContacts_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            e.Layout.Bands[0].Columns[0].Header.Caption = "Remove Contact";
            e.Layout.Bands[0].Columns[0].Hidden = true;
            e.Layout.Bands[0].Columns[0].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.Button;
            e.Layout.Bands[0].Columns[0].ButtonDisplayStyle = Infragistics.Win.UltraWinGrid.ButtonDisplayStyle.Always;

            e.Layout.Bands[0].Columns[1].Width = 110;
            e.Layout.Bands[0].Columns[1].Header.Caption = "Full Name";
            e.Layout.Bands[0].Columns[1].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[2].Width = 140;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Job Title";
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[3].Width = 100;
            e.Layout.Bands[0].Columns[3].Header.Caption = "Contact Phone";
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[4].Width = 60;
            e.Layout.Bands[0].Columns[4].Header.Caption = "Extension";
            e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[5].Width = 100;
            e.Layout.Bands[0].Columns[5].Header.Caption = "Cell Phone";
            e.Layout.Bands[0].Columns[5].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[6].Width = 100;
            e.Layout.Bands[0].Columns[6].Header.Caption = "Contact Fax";
            e.Layout.Bands[0].Columns[6].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[7].Width = 140;
            e.Layout.Bands[0].Columns[7].Header.Caption = "Contact Email";
            e.Layout.Bands[0].Columns[7].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            //ContactId
            e.Layout.Bands[0].Columns[8].Hidden = true;

            e.Layout.Bands[0].Columns[9].Width = 150;
            e.Layout.Bands[0].Columns[9].Header.Caption = "Address";
            e.Layout.Bands[0].Columns[9].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            //filter row
            e.Layout.Override.AllowRowFiltering = Infragistics.Win.DefaultableBoolean.True;
            e.Layout.Override.FilterClearButtonLocation = FilterClearButtonLocation.Row;
            e.Layout.Override.FilterUIType = Infragistics.Win.UltraWinGrid.FilterUIType.FilterRow;
            e.Layout.Override.FilterOperatorDefaultValue = FilterOperatorDefaultValue.Contains;

            //column sorting
            e.Layout.Override.HeaderClickAction = HeaderClickAction.SortMulti;

        }

        private void uwgOrg_AfterRowActivate(object sender, EventArgs e)
        {
            if (uwgOrg.ActiveRow.Cells[3].Value == System.DBNull.Value) return;

            LoadContacts();
            LoadOrgAddress();

            DataSet ds = ContactData.GetOrganizationData(Convert.ToInt32(uwgOrg.ActiveRow.Cells[3].Value));
            if (ds.Tables[0].Rows.Count > 0)
            {
                DataRow dr = ds.Tables[0].Rows[0];
               
            }
        }

        private void btnLinkOrg_Click(object sender, EventArgs e)
        {
                int orgID = 0;
                if (formActDisplay == "project")
                {
                    DialogResult diarslt = MessageBox.Show("Confirm that organization is not already on master list.",
                                                            "New Organization Warning", MessageBoxButtons.OK);
                }
                //if (diarslt == DialogResult.Yes)
                //{
                    NewOrganization no = new NewOrganization(orgID, "insert", "admin");
                    Form1 fm = (Form1)this.MdiParent;
                    fm.OpenForm(no, "Link Organization");
                //}
        }

        private void btnLinkOrgToProject()
        {
            //int contactId = 0;
            string roles = "";

            for (int i = 0; i < uwgOrg.Rows.Count; i++)
            {
                if (uwgOrg.Rows[i].Selected == true || uwgOrg.Rows[i].Activated == true)
                {
                    int orgid = (int)uwgOrg.Rows[i].Cells[3].Value;
                    if (ProjectData.OrgHasProjectRole(orgid, GlobalSettings.projectId) == false)
                    {
                        roles = ProjectRoles(uwgOrg.Rows[i].Cells[1].Text);
                        if (roles == string.Empty)
                            return;
                        ProjectData.OrgProjectRoleInsert(orgid, GlobalSettings.projectId, roles);
                    }

                    for (int j = 0; j < uwgOrgAddress.Rows.Count; j++)
                    {
                        if (uwgOrgAddress.Rows[j].Selected == true)
                        {
                            DataSet ds1 = SqlHelper.ExecuteDataset(GlobalSettings.ConnectionString, CommandType.Text, "select * from Org_Project_Address where (ProjectId = " + GlobalSettings.projectId + " and OrgId = " + Convert.ToInt32(uwgOrg.Rows[i].Cells[3].Value) + " and OrgAddressId = " + Convert.ToInt32(uwgOrgAddress.Rows[j].Cells["OrgAddressID"].Value) + ")");
                            if (ds1.Tables[0].Rows.Count == 0)
                            {
                                int retVal = SqlHelper.ExecuteNonQuery(GlobalSettings.ConnectionString, CommandType.Text, "INSERT INTO Org_Project_Address(ProjectId,OrgId,OrgAddressId) values(" + GlobalSettings.projectId + "," + Convert.ToInt32(uwgOrg.Rows[i].Cells[3].Value) + "," + Convert.ToInt32(uwgOrgAddress.Rows[j].Cells["OrgAddressID"].Value) + ")");
                            }
                        }
                    }
                }

            }
            

            OpenContact(GlobalSettings.projectId);
            this.Close();        
        }

        public void OpenContact(int projectId)
        {
            Form1 mainForm = (Form1)this.MdiParent;
            mainForm.OpenProject(GlobalSettings.projectId, ProjectData.GetProjectName(GlobalSettings.projectId));

            CCPM.Project.ProjectForm projectForm = null;
            mainForm.GetCurrentProject(out projectForm);
            projectForm.RefreshContacts();
            projectForm.SetTabIndex(1);

        }
        private string ProjectRoles(string orgname)
        {
            string retVal = "";
            DialogResult dr;
            GridSelect gs = new GridSelect();
            gs.lblTitle.Text = "Select One or More Project Roles";
            gs.Text = "Linking Organization:  " + orgname;
            gs.DataSet(ProjectData.GetProjectRoles());
            gs.ColumnHide(0);
            gs.ColumnWidth(1, 300);
            gs.ColumnName(1, "Project Role");
            dr = gs.ShowDialog();
            if (dr == DialogResult.OK)
                retVal = gs.SelectedKeys(0, false);
            return retVal;
        }

        private void btnLinkContact_Click(object sender, EventArgs e)
        {
            if (uwgOrg.ActiveRow.Cells[3].Value == System.DBNull.Value) return;

            LinkContact lc = new LinkContact(Convert.ToInt32(uwgOrg.ActiveRow.Cells[3].Value),"admin");
            Form1 fm = (Form1)(this.MdiParent);
            fm.OpenForm(lc, "Link Contact");
        }

        private void btnEditContact_Click(object sender, EventArgs e)
        {

            if (uwgContacts.ActiveRow.Cells["ContactId"].Value == System.DBNull.Value) return;

            DialogResult intRslt = MessageBox.Show("BE CAREFUL about making changes! Any changes to this contact will affect all other project linked to it.",
                            "Edit Contact Warning", MessageBoxButtons.OKCancel);
            if (intRslt == DialogResult.OK)
            {
                CreateContact cc = new CreateContact(Convert.ToInt32(uwgContacts.ActiveRow.Cells["ContactId"].Value), "update", 0,"admin");
                cc.Text = "Edit Contact";
                Form1 fm = (Form1)(this.MdiParent);
                fm.OpenForm(cc, "Edit Contact");

            }
        }

        private void btnEditOrg_Click(object sender, EventArgs e)
        {
            if (uwgOrg.ActiveRow.Cells[3].Value == System.DBNull.Value) return;

            DialogResult intRslt = MessageBox.Show("BE CAREFUL about making changes! Any changes to this organization will affect all other project linked to it.",
                            "Edit Organization Warning", MessageBoxButtons.OKCancel);
            if (intRslt == DialogResult.OK)
            {
                NewOrganization no = new NewOrganization(Convert.ToInt32(uwgOrg.ActiveRow.Cells[3].Value), "update", "admin");
                no.Text = "Edit Organization";
                Form1 fm = (Form1)(this.MdiParent);
                fm.OpenForm(no, "Edit Organization");
            }
        }

        public void RemoveOrg()
        {
            if (uwgOrg.ActiveRow.Cells[3].Value == System.DBNull.Value) return;

            DbConnection dbConnection = DbConnection.GetDbConnection();
            string connectionString = dbConnection.DbConnectionString;
            //DialogResult dr = MessageBox.Show(
            //   "You are about to remove the selected organization ? ", "Remove Organization Warning", MessageBoxButtons.OKCancel);
            //if (dr == DialogResult.OK)
            {
                int retVal = SqlHelper.ExecuteNonQuery(connectionString, CommandType.Text, "delete from Organization where OrgID = " + Convert.ToInt32(uwgOrg.ActiveRow.Cells[3].Value));
            }
        }

        private void uwgOrg_ClickCellButton(object sender, CellEventArgs e)
        {
            RemoveOrg();
            LoadGrid();
            LoadContacts();
            LoadOrgAddress();
        }

        public void SetContextMenu()
        {
           
                contextMenu1 = new System.Windows.Forms.ContextMenu();

                MenuItem miAddExisting = new System.Windows.Forms.MenuItem();
                miAddExisting.Index = 0;
                miAddExisting.Text = "Add Existing Organization";

                MenuItem miAddNew = new MenuItem();
                miAddNew.Visible = false;
                miAddNew.Text = "Add New Organization";
                miAddNew.Index = 1;

                MenuItem miClone = new MenuItem();
                miClone.Visible = false;
                miClone.Text = "Clone Contact";
                miClone.Index = 2;

                MenuItem miSpacer1 = new MenuItem();
                miSpacer1.Text = "-";
                miSpacer1.Index = 3;

                MenuItem miEdit = new MenuItem();
                miEdit.Text = "Edit Organization";
                miEdit.Index = 4;

                MenuItem miSpacer2 = new MenuItem();
                miSpacer2.Text = "-";
                miSpacer2.Index = 5;

                MenuItem miRemove = new MenuItem();
                miRemove.Visible = false;
                miRemove.Text = "Remove Contact";
                miRemove.Index = 6;

                MenuItem miRemove1 = new MenuItem();
                miRemove1.Text = "Remove Organization";
                miRemove1.Index = 7;

                MenuItem miSpacer3 = new MenuItem();
                miSpacer3.Text = "-";
                miSpacer3.Index = 8;

                MenuItem miRefresh = new MenuItem();
                miRefresh.Text = "Refresh";
                miRefresh.Index = 9;

                contextMenu1.MenuItems.AddRange(new MenuItem[] { miAddExisting, miAddNew, miClone, miSpacer1, miEdit, miSpacer2, miRemove, miRemove1, miSpacer3, miRefresh });

                uwgOrg.ContextMenu = contextMenu1;

                miAddExisting.Click += new EventHandler(miAddExisting_Click);
                miAddNew.Click += new EventHandler(miAddNew_Click);
                miEdit.Click += new EventHandler(miEdit_Click);
                miRemove1.Click += new EventHandler(miRemove1_Click);
                miRefresh.Click += new EventHandler(miRefresh_Click);
            
        }

        public void miRemove1_Click(object sender, EventArgs e)
        {

            RemoveOrg();
        }

        public void miRefresh_Click(object sender, EventArgs e)
        {
            LoadGrid();
            LoadContacts();
        }

        public void miAddExisting_Click(object sender, EventArgs e)
        {
            Form1 fm = (Form1)(this.MdiParent);
            LinkOrg lo = new LinkOrg(0);
            fm.OpenForm(lo, "Link Organization");
        }

        public void miAddNew_Click(object sender, EventArgs e)
        {
            CCPM.Project.ProjectForm projectForm = (CCPM.Project.ProjectForm)this.MdiParent;
            CCPM.Contact.ContactCreateOrUpdate contactCreateOrUpdate = new CCPM.Contact.ContactCreateOrUpdate();
            contactCreateOrUpdate.Location = new Point(0, 0);
            contactCreateOrUpdate.ProjectId = projectForm.ProjectId;
            contactCreateOrUpdate.ProjectName = projectForm.ProjectName;

            DialogResult dr = contactCreateOrUpdate.ShowDialog();
            if (dr == DialogResult.OK)
            {
                projectForm.GetMasterDetailControl.ContactId = contactCreateOrUpdate.ContactId;
                projectForm.RefreshContacts();
            }
        }

        public void miEdit_Click(object sender, EventArgs e)
        {
            //If there are no contacts listed then return.
            if (uwgContacts.Rows.Count < 1) return;
            if (uwgOrg.ActiveRow.Cells[3].Value == System.DBNull.Value) return;

            DialogResult intRslt = MessageBox.Show("BE CAREFUL about making changes! Any changes to this organization will affect all other project linked to it.\nIf you want to designate a new branch address for this organization, cancel and select the\nLink Organization to this Project button and follow the instructions. ",
                            "Edit Organization Warning", MessageBoxButtons.OKCancel);
            if (intRslt == DialogResult.OK)
            {
                NewOrganization no = new NewOrganization(Convert.ToInt32(uwgOrg.ActiveRow.Cells[3].Value), "update","admin");
                no.Text = "Edit Organization";
                Form1 fm = (Form1)(this.MdiParent);
                fm.OpenForm(no, "Edit Organization");
            }
        }

        private void uwgOrg_MouseDown(object sender, MouseEventArgs e)
        {
            //if (e.Button == MouseButtons.Right)
            //{
            //    Point mousePoint = new Point(e.X, e.Y);
            //    UIElement element = ((UltraGrid)sender).DisplayLayout.UIElement.ElementFromPoint(mousePoint);

            //    contextMenu1.Show(uwgOrg, mousePoint);
            //}
        }

        private void uwgContacts_ClickCellButton(object sender, CellEventArgs e)
        {
            DialogResult dr = MessageBox.Show(
                    "You are about to remove a contact linked with the selected organization !\n The organization information will remain. ?",
                    "Remove Contact Confirmation",
                    MessageBoxButtons.OKCancel,
                    MessageBoxIcon.Exclamation);
            if (dr == DialogResult.OK)
            {
                DbConnection dbConnection = DbConnection.GetDbConnection();
                string connectionString = dbConnection.DbConnectionString;
                int retVal = SqlHelper.ExecuteNonQuery(connectionString, CommandType.Text, "UPDATE Contact SET OrgID = NULL where ContactID = " + Convert.ToInt32(uwgContacts.ActiveRow.Cells[7].Value));
                LoadContacts();

            }
        }

        private void uwgOrgAddress_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            e.Layout.Bands[0].Columns[0].Width = 130;
            e.Layout.Bands[0].Columns[0].Hidden = true;
            e.Layout.Bands[0].Columns[0].Header.Caption = "Remove Org Address";
            e.Layout.Bands[0].Columns[0].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.Button;
            e.Layout.Bands[0].Columns[0].ButtonDisplayStyle = Infragistics.Win.UltraWinGrid.ButtonDisplayStyle.Always;

            e.Layout.Bands[0].Columns[1].Width = 190;
            e.Layout.Bands[0].Columns[1].Header.Caption = "Department/Office";
            e.Layout.Bands[0].Columns[1].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[2].Width = 160;
            e.Layout.Bands[0].Columns[2].Header.Caption = "Street";
            e.Layout.Bands[0].Columns[2].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[3].Width = 80;
            e.Layout.Bands[0].Columns[3].Header.Caption = "City";
            e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[4].Width = 80;
            e.Layout.Bands[0].Columns[4].Header.Caption = "State";
            e.Layout.Bands[0].Columns[4].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[5].Width = 80;
            e.Layout.Bands[0].Columns[5].Header.Caption = "Zip";
            e.Layout.Bands[0].Columns[5].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[6].Width = 100;
            e.Layout.Bands[0].Columns[6].Header.Caption = "Phone";
            e.Layout.Bands[0].Columns[6].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            e.Layout.Bands[0].Columns[7].Width = 100;
            e.Layout.Bands[0].Columns[7].Header.Caption = "Fax";
            e.Layout.Bands[0].Columns[7].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;

            //OrgNotes
            e.Layout.Bands[0].Columns["OrgNotes"].Hidden = true;

            //OrgAddressId
            e.Layout.Bands[0].Columns["OrgAddressID"].Hidden = true;
            //DirtyFlag
            e.Layout.Bands[0].Columns[9].Hidden = true;

            //filter row
            e.Layout.Override.AllowRowFiltering = Infragistics.Win.DefaultableBoolean.True;
            e.Layout.Override.FilterClearButtonLocation = FilterClearButtonLocation.Row;
            e.Layout.Override.FilterUIType = Infragistics.Win.UltraWinGrid.FilterUIType.FilterRow;
            e.Layout.Override.FilterOperatorDefaultValue = FilterOperatorDefaultValue.Contains;

            //column sorting
            e.Layout.Override.HeaderClickAction = HeaderClickAction.SortMulti;  


        }

        private void uwgOrgAddress_ClickCellButton(object sender, CellEventArgs e)
        {
            DbConnection dbConnection = DbConnection.GetDbConnection();
            string connectionString = dbConnection.DbConnectionString;
            DialogResult dr = MessageBox.Show(
               "You are about to remove the selected organization address ? ", "Remove Organization Address Warning", MessageBoxButtons.OKCancel);
            if (dr == DialogResult.OK)
            {
                int retVal = SqlHelper.ExecuteNonQuery(connectionString, CommandType.Text, "delete from OrgAddress where OrgAddressID = " + Convert.ToInt32(uwgOrgAddress.ActiveRow.Cells["OrgAddressID"].Value));
            }
            LoadOrgAddress();
        }

        private void btnRefresh_Click(object sender, EventArgs e)
        {
            LoadGrid();
            LoadContacts();
            LoadOrgAddress();
        }

        private void Organizations_Activated(object sender, EventArgs e)
        {
            LoadGrid();
            LoadContacts();
            LoadOrgAddress();
        }

        private void btnRemove_Click(object sender, EventArgs e)
        {
            for (int i = 0; i < uwgOrg.Rows.Count; i++)
            {
                if (uwgOrg.Rows[i].Selected == true)
                {
                    DataSet ds = ProjectData.OrganizationProjects(Convert.ToInt32(uwgOrg.Rows[i].Cells["OrgId"].Value));
                    if (ds.Tables[0].Rows.Count > 0)
                    {
                        string msg = uwgOrg.Rows[i].Cells["Organization"].Value.ToString() + " can't be deleted because it is linked to the following project(s): \n\n ";
                        foreach (DataRow dr in ds.Tables[0].Rows)
                        {
                            msg += dr["FileNumber"] + "\n";
                        }
                        MessageBox.Show(msg, "Delete Organization Warning", MessageBoxButtons.OK);
                        return;
                    }
                }
            }
            for (int i = 0; i < uwgOrg.Rows.Count; i++)
            {
                if (uwgOrg.Rows[i].Selected == true)
                {
                    try
                    {
                        ContactData.OrganizationDelete(Convert.ToInt32(uwgOrg.Rows[i].Cells["OrgId"].Value));
                    }
                    catch (Exception ex)
                    {
                        MessageBox.Show(ex.Message, "Delete Organization Failure!", MessageBoxButtons.OK);
                    }
                }
            }
            LoadGrid();
            LoadContacts();
            LoadOrgAddress();
        }

        private void btnContactRemove_Click(object sender, EventArgs e)
        {
            for (int i = 0; i < uwgContacts.Rows.Count; i++)
            {
                if (uwgContacts.Rows[i].Selected == true)
                {
                    DataSet ds = ProjectData.ContactProjects(Convert.ToInt32(uwgContacts.Rows[i].Cells["ContactId"].Value));
                    if (ds.Tables[0].Rows.Count > 0)
                    {
                        string msg = "Contact " + uwgContacts.Rows[i].Cells["FullName"].Value.ToString() + " can't be removed because it is linked to the following project(s): \n\n ";
                        foreach (DataRow dr in ds.Tables[0].Rows)
                        {
                            msg += dr["FileNumber"] + "\n";
                        }
                        MessageBox.Show(msg, "Remove Contact Warning", MessageBoxButtons.OK);
                        return;
                    }
                }
            }

            for (int i = 0; i < uwgContacts.Rows.Count; i++)
            {
                if (uwgContacts.Rows[i].Selected == true)
                {
                    try
                    {
                        ContactData.OrgContactUnlink(Convert.ToInt32(uwgContacts.Rows[i].Cells["ContactId"].Value));
                    }
                    catch (Exception ex)
                    {
                        MessageBox.Show(ex.Message, "Unlink Contact Failure!", MessageBoxButtons.OK);
                    }
                }
            }
            LoadContacts();
        }

        private void btnAdd_Click(object sender, EventArgs e)
        {
            if (uwgOrg.ActiveRow.Cells[3].Value == System.DBNull.Value) return;

            int contactId = 0;
            int orgID = Convert.ToInt32(uwgOrg.ActiveRow.Cells[3].Value);
            //DialogResult diarslt = MessageBox.Show("This will add a new contact to the Master Contact List-have you confirmed that it\ndoes not already exist ?",
            //                                        "New Contact Warning", MessageBoxButtons.YesNoCancel);
            //if (diarslt == DialogResult.Yes)
            //{
                CreateContact cc = new CreateContact(contactId, "addlink", orgID, "admin");
                Form1 fm = (Form1)this.MdiParent;
                fm.OpenForm(cc, "Create Contact");
            //}
            //else if (diarslt == DialogResult.No)
            //{
            //    //LinkContact lc = new LinkContact(orgID,"admin");
            //    //lc.MdiParent = this.MdiParent;
            //    //lc.Show();
            //    CCPM.Project.Contacts lc = new CCPM.Project.Contacts();
            //    //LinkContact lc = new LinkContact(OrgID, "admin");
            //    lc.MdiParent = this.MdiParent;
            //    lc.Show();
            //}
            LoadContacts();
        }

        private void btnAddressRemove_Click(object sender, EventArgs e)
        {
            for (int i = 0; i < uwgOrgAddress.Rows.Count; i++)
            {
                if (uwgOrgAddress.Rows[i].Selected == true)
                {
                    DbConnection dbConnection = DbConnection.GetDbConnection();
                    string connectionString = dbConnection.DbConnectionString;
                    int retVal = SqlHelper.ExecuteNonQuery(connectionString, CommandType.Text, "delete from OrgAddress where OrgAddressID = " + Convert.ToInt32(uwgOrgAddress.Rows[i].Cells["OrgAddressID"].Value));
                    //int retVal1 = SqlHelper.ExecuteNonQuery(connectionString, CommandType.Text, "UPDATE Contact SET OrgAddressID = NULL where OrgAddressID = " + Convert.ToInt32(uwgOrgAddress.Rows[i].Cells["OrgAddressID"].Value));
                }
            }
            LoadOrgAddress();
            LoadContacts();
        }

        private void btnAddAddress_Click(object sender, EventArgs e)
        {
            if (uwgOrg.ActiveRow.Cells[3].Value == System.DBNull.Value) return;

            GlobalSettings.projectId = 0;
            NewOrganization no = new NewOrganization(Convert.ToInt32(uwgOrg.ActiveRow.Cells[3].Value), "address","admin");
            Form1 fm = (Form1)this.MdiParent;
            fm.OpenForm(no, "Add Address");
            LoadOrgAddress();
            LoadContacts();
        }

        private void saveOrgAddressGrid()
        {
            DbConnection dbConnection = DbConnection.GetDbConnection();
            string connectionString = dbConnection.DbConnectionString;
            for (int i = 0; i < uwgOrgAddress.Rows.Count; i++)
            {
                if (uwgOrgAddress.Rows[i].Cells[9].Value.ToString() == "1")
                {

                    int retVal = SqlHelper.ExecuteNonQuery(connectionString, CommandType.Text, "UPDATE OrgAddress SET DepartmentOffice = '" + uwgOrgAddress.Rows[i].Cells[1].Value.ToString() +
                                                                                                "',Address = '" + uwgOrgAddress.Rows[i].Cells[2].Value.ToString() +
                                                                                                "',City = '" + uwgOrgAddress.Rows[i].Cells[3].Value.ToString() +
                                                                                                "',State = '" + uwgOrgAddress.Rows[i].Cells[4].Value.ToString() +
                                                                                                "',Zip = '" + uwgOrgAddress.Rows[i].Cells[5].Value.ToString() +
                                                                                                "',GeneralPhone = '" + uwgOrgAddress.Rows[i].Cells[6].Value.ToString() +
                                                                                                "',GeneralFax = '" + uwgOrgAddress.Rows[i].Cells[7].Value.ToString() +
                                                                                                "' where OrgAddressID = " + Convert.ToInt32(uwgOrgAddress.Rows[i].Cells["OrgAddressID"].Value));

                }
            }
            blnDataDirty = false;
            LoadOrgAddress();
        }

        private void uwgOrgAddress_AfterCellUpdate(object sender, CellEventArgs e)
        {
            if (uwgOrgAddress.ActiveRow.Cells[9].Value.ToString() == "0")
                uwgOrgAddress.ActiveRow.Cells[9].Value = "1";

            blnDataDirty = true;
        }

        private void btnEditAddress_Click(object sender, EventArgs e)
        {
            saveOrgAddressGrid();
            LoadContacts();
        }

        private void Organizations_FormClosing(object sender, FormClosingEventArgs e)
        {
            
        }

        private void uwgOrgAddress_Leave(object sender, EventArgs e)
        {
            //for (int i = 0; i < uwgOrgAddress.Rows.Count; i++)
            //{
            //    if (uwgOrgAddress.Rows[i].Cells[9].Value.ToString() == "1")
            //    {
            //        blnDataDirty = true;
            //    }
            //}
            //if (blnDataDirty == true)
            //{
            //    DialogResult diaRslt = MessageBox.Show("Data has been changed in Organization Address Grid. Do You want to save changes ?", "Data Change Warning", MessageBoxButtons.YesNo);
            //    if (diaRslt == DialogResult.Yes)
            //    {
            //        saveOrgAddressGrid();
            //        blnDataDirty = false;
            //    }
            //    else
            //    {
            //        blnDataDirty = false;
            //        LoadOrgAddress();
            //    }

            //}
        }

        private void btnLink_Click(object sender, EventArgs e)
        {
            if (formActDisplay == "project")
            {
                btnLinkOrgToProject();
            }
            else
            {
                if (uwgOrg.ActiveRow.Cells[3].Value == System.DBNull.Value) return;

                ProjectList pl = new ProjectList(Convert.ToInt32(uwgOrg.ActiveRow.Cells[3].Value));
                pl.ShowDialog();
            }
        }

        private void Organizations_KeyUp(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.F5)
            {
                LoadGrid();
                LoadContacts();
                LoadOrgAddress();
                
            }
        }

        private void btnEditOrgAddress_Click(object sender, EventArgs e)
        {
            if (uwgOrg.ActiveRow.Cells[3].Value == System.DBNull.Value || uwgOrgAddress.ActiveRow.Cells[8].Value == System.DBNull.Value) return;

            DialogResult intRslt = MessageBox.Show("BE CAREFUL about making changes! Any changes to this org address will affect all other project linked to it.",
                            "Edit Org Address Warning", MessageBoxButtons.OKCancel);
            if (intRslt == DialogResult.OK)
            {
                OrgAddressId = Convert.ToInt32(uwgOrgAddress.ActiveRow.Cells["OrgAddressID"].Value);
                OrgId = Convert.ToInt32(uwgOrg.ActiveRow.Cells[3].Value);
                NewOrganization no = new NewOrganization("update", "admin", OrgAddressId, OrgId);
                Form1 fm = (Form1)this.MdiParent;
                fm.OpenForm(no, "Edit Organization Address");
            }
        }

        private void btnLinkOrgAddressToProject_Click(object sender, EventArgs e)
        {
            string roles = "";

            for (int i = 0; i < uwgOrg.Rows.Count; i++)
            {
                //adds the organization to the project if it isn't already...need an org to associate the address with on the project!
                if (uwgOrg.Rows[i].Selected == true || uwgOrg.Rows[i].Activated == true)
                {
                    int orgid = (int)uwgOrg.Rows[i].Cells["OrgID"].Value;
                    if (ProjectData.OrgHasProjectRole(orgid, GlobalSettings.projectId) == false)
                    {
                        roles = ProjectRoles(uwgOrg.Rows[i].Cells[2].Text);
                        if (roles == string.Empty)
                            return;
                        ProjectData.OrgProjectRoleInsert(orgid, GlobalSettings.projectId, roles);
                    }

                    for (int j = 0; j < uwgOrgAddress.Rows.Count; j++)
                    {
                        if (uwgOrgAddress.Rows[j].Selected == true)
                        {
                            DataSet ds1 = SqlHelper.ExecuteDataset(GlobalSettings.ConnectionString, CommandType.Text, "select * from Org_Project_Address where (ProjectId = " + GlobalSettings.projectId + " and OrgId = " + Convert.ToInt32(uwgOrg.Rows[i].Cells["OrgID"].Value) + " and OrgAddressId = " + Convert.ToInt32(uwgOrgAddress.Rows[j].Cells["OrgAddressID"].Value) + ")");
                            if (ds1.Tables[0].Rows.Count == 0)
                            {
                                int retVal = SqlHelper.ExecuteNonQuery(GlobalSettings.ConnectionString, CommandType.Text, "INSERT INTO Org_Project_Address(ProjectId,OrgId,OrgAddressId) values(" + GlobalSettings.projectId + "," + Convert.ToInt32(uwgOrg.Rows[i].Cells["OrgID"].Value) + "," + Convert.ToInt32(uwgOrgAddress.Rows[j].Cells["OrgAddressID"].Value) + ")");
                            }
                        }
                    }
                }

            }

            OpenContact(GlobalSettings.projectId);
            this.Close();
        }

     

	}
}
