using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using CCPM .Data;
using System.Data;
using System.Text.RegularExpressions;
using Infragistics.Win.UltraWinGrid;
using System.Collections.Generic;

namespace CCPM.Project
{
	/// <summary>
	/// This form can be in two states; create a new Project and
	/// edit an existing project. Setting IsUpdateMode property to true
	/// puts the form in update mode and populates the controls with
	/// the current project information.
	/// This form might be better implemented as a series of 
	/// steps that group elements together.
    ///     
    /// 07.01.2014 - another state 'copy of an existing project' is introduced. 
    /// In this case the IsCopyMode property needs to be set to true. 
    /// The existing project info will be copied but the project name and # will not.
	/// </summary>
	public class ProjectCreateOrUpdate : System.Windows.Forms.Form
	{
		#region Member fields
		private System.Windows.Forms.Label lblFileNumber;
		private System.Windows.Forms.TextBox txtFileNumber;
		private System.Windows.Forms.ListBox lbStaff;
		private System.Windows.Forms.TextBox txtDescription;
		private System.Windows.Forms.Label lblStaff;
		private System.Windows.Forms.Label lblAttorney;
		private System.Windows.Forms.ListBox lbAttorney;
		private System.Windows.Forms.Label lblSummary;
		private System.Windows.Forms.TextBox txtSummary;
		private System.Windows.Forms.Label lblDescription;
		private System.EventHandler streamLinearFeetHandler = null;
		private System.EventHandler streamMilesHandler = null;
		private System.EventHandler trailLinearFeetHandler = null;
		private System.EventHandler trailMilesHandler = null;
		private System.EventHandler acreageHandler = null;
		private System.EventHandler squareMilesHandler = null;
        private bool saved = false;
        private IContainer components;
		
		private int projectId = 0;
        private int projectCopiedId = 0;
		private System.Windows.Forms.Label lblProgramType;
		private System.Windows.Forms.ListBox lbProgramType;
		private System.Windows.Forms.Label lblProjectType;
		private System.Windows.Forms.ListBox lbProjectType;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.RadioButton rbActive;
		private System.Windows.Forms.RadioButton rbInactive;
		private System.Windows.Forms.RadioButton rbComplete;
		private System.Windows.Forms.TextBox txtProjectName;
		private System.Windows.Forms.Label lblProjectName;
		private System.Windows.Forms.Label lblCity;
		private System.Windows.Forms.Label lblCounty;
		private System.Windows.Forms.ListBox lbCounty;
		private System.Windows.Forms.Label lblRegion;
		private System.Windows.Forms.ListBox lbRegion;
		private System.Windows.Forms.Label lblLatitude;
		private System.Windows.Forms.Label lblLongitude;
		private System.Windows.Forms.Label lblAssembly;
		private System.Windows.Forms.Label lblSenate;
		private System.Windows.Forms.Label lblCongressional;
		private System.Windows.Forms.ListBox lbCongressional;
		private System.Windows.Forms.ListBox lbAssembly;
		private System.Windows.Forms.ListBox lbSenate;
		private System.Windows.Forms.Label lblAcreage;
		private System.Windows.Forms.TextBox txtAcreage;
		private System.Windows.Forms.Label lblSquareMiles;
		private System.Windows.Forms.TextBox txtSquareMiles;
		private System.Windows.Forms.Label lblStreamMiles;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.Label lblTrailLinear;
		private System.Windows.Forms.Label lblNotes;
		private System.Windows.Forms.Button btnSave;
		private System.Windows.Forms.TextBox txtTrailMiles;
		private System.Windows.Forms.TextBox txtTrailLinearFeet;
		private System.Windows.Forms.TextBox txtStreamMiles;
		private System.Windows.Forms.TextBox txtStreamLinearFeet;
        private System.Windows.Forms.TextBox txtNotes;
		private Genghis.Windows.Forms.RequiredFieldValidator rfvName;
		private System.Windows.Forms.Button btnCancel;
		private bool isUpdateMode = false;
        private bool isCopyMode = false;
		private System.Windows.Forms.ContextMenu contextMenu1;
		private System.Windows.Forms.MenuItem miSave;
		private System.Windows.Forms.MenuItem miRefresh;
		private System.Windows.Forms.MenuItem menuItem3;
		private System.Windows.Forms.MenuItem miClose;
		private System.Windows.Forms.MenuItem menuItem5;
		private DateTime lastModified;
		private System.Windows.Forms.TextBox txtLatitude;
		private System.Windows.Forms.TextBox txtLongitude;
		private Genghis.Windows.Forms.RegularExpressionValidator revLatitude;
        private Genghis.Windows.Forms.RegularExpressionValidator revLongitude;
		private int parentProjectId = 0;
		private int currentStatus = 0;
		private System.Windows.Forms.ListBox lbCity;
		private Genghis.Windows.Forms.RequiredFieldValidator rfvProjectNumber;
		private Genghis.Windows.Forms.RegularExpressionValidator revProjectNumber;
		private Genghis.Windows.Forms.RangeValidator rvLatitude;
		private Genghis.Windows.Forms.RangeValidator rvLongitude;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.ListBox lbWatershed;
		private System.Windows.Forms.Label lblWatershed;
		private System.Windows.Forms.Label lblTrailMiles;
		private System.Windows.Forms.Label lblCoastalTrailMiles;
		private System.Windows.Forms.TextBox txtCCTmiles;
		private System.Windows.Forms.TextBox txtParcelNumber;
		private System.Windows.Forms.Label lblParcelNumber;
		private System.Windows.Forms.ComboBox cbCurrentPM;
		private System.Windows.Forms.Label label4;
        private System.Windows.Forms.Button btnNewProjectNumber;
        private TextBox txtCCTLinearFeet;
        private Label label6;
        private TextBox txtLocationDescription;
        private Label label7;
        private RadioButton rbClosed;
        private ToolTip toolTip1;
		private DateTime currentStatusDate = DateTime.MinValue;

		#endregion
        private Infragistics.Win.UltraWinEditors.UltraDateTimeEditor uwdtCompletionDate;
        private Label label8;
        private CheckBox chkIsWebSite;

		#region Properties
        public int ProjectCopiedId
        {
            get { return projectCopiedId; }
            set { projectCopiedId = value; }
        }
        public int ProjectId
		{
			get{return projectId;}
			set{projectId = value;}
		}
		public int ParentProjectId
		{
			get{return parentProjectId;}
			set{parentProjectId = value;}
		}
		public bool IsUpdateMode
		{
			get{return isUpdateMode;}
			set{isUpdateMode = value;}
		}
        public bool IsCopyMode
        {
            get { return isCopyMode; }
            set { isCopyMode = value; }
        }
		public int CurrentStatus
		{
			get{return currentStatus;}
			set{currentStatus = value;}
		}
		public DateTime CurrentStatusDate
		{
			get{return currentStatusDate;}
			set{currentStatusDate = value;}
		}

		#endregion

        private bool blnSkip = false;
        private Label lblDD1;
        private Label lblDD2;
        private Infragistics.Win.UltraWinGrid.UltraCombo DynamicDD1;
        private Infragistics.Win.UltraWinGrid.UltraCombo DynamicDD2;
        private ListBox DynamicLB1;
        private Label lblMultiselect1;
        private bool blnDataLoaded = false;


		public ProjectCreateOrUpdate()
		{
			
			InitializeComponent();

			this.Load += new System.EventHandler(this.ProjectCreateOrUpdate_Load);
			
		}


		private void SetUpdateDisplay()
		{
			DataSet dsProject = ProjectData.GetProject(ProjectId);
			DataRow drProject = dsProject.Tables["Project"].Rows[0];
			this.lastModified = (DateTime)drProject["LastModified"];
			this.Text = string.Concat("Update: " + (string)drProject["ProjectName"]);
			txtProjectName.Text = (string)drProject["ProjectName"];
			//Status
			CurrentStatus = (int)drProject["StatusId"];
			switch(CurrentStatus)
			{
				case 0 :
					rbActive.Checked = true;
					break;
				case 1 :
					rbInactive.Checked = true;
					break;
				case 2 :
					rbComplete.Checked = true;
					break;
                case 3:
                    rbClosed.Checked = true;
                    break;
            }

            //Website
            chkIsWebSite.Checked = (Boolean)drProject["IsWebsite"];
            //Status Date
			CurrentStatusDate = (DateTime)drProject["StatusDate"];
            //Completed Date
            uwdtCompletionDate.Value =  string.Format("{0:d}",drProject["DateCompleted"]);
            //File Number
			txtFileNumber.Text = (string)drProject["FileNumber"];
            //Dynamic Dropdown 1
            DynamicDD1.Text = (string)drProject["DynamicDD1"].ToString();
            //Dynamic Dropdown 2
            DynamicDD2.Text = (string)drProject["DynamicDD2"].ToString();
            
            //Staff
			
			foreach(DataRow drPM in dsProject.Tables["ProjectManager"].Rows)
			{
				int index = lbStaff.FindStringExact((string)drPM["Name"]);
				lbStaff.SetSelected(index, true);
			}
			
			if( drProject["CurrentPM"] != DBNull.Value )
			{
				// ADS 9-Nov-2007 - Set the current PM in the drop-down
				for( int pmIdx = 0; pmIdx < cbCurrentPM.Items.Count; pmIdx ++ )
				{
					if( (int)((DataRowView)cbCurrentPM.Items[pmIdx])["ProjectManagerID"] == (int)drProject["CurrentPM"] )
					{
						cbCurrentPM.SelectedIndex = pmIdx;
						break;
					}
				}
			}
			else
			{
				cbCurrentPM.SelectedIndex = -1;
			}

			//Attorney
			foreach(DataRow drPA in dsProject.Tables["ProjectAttorney"].Rows)
			{
				int index = lbAttorney.FindStringExact((string)drPA["Name"]);
				lbAttorney.SetSelected(index, true);
			}
			//Summary
			txtSummary.Text = (string)drProject["Summary"];
			//Description
			txtDescription.Text = (string)drProject["Description"];
			//Program Type
			foreach(DataRow drPPT in dsProject.Tables["ProjectProgramType"].Rows)
			{
				int index = lbProgramType.FindStringExact((string)drPPT["ProgramType"]);
				lbProgramType.SetSelected(index,true);
			}
			//Project Type
			foreach(DataRow drPT in dsProject.Tables["ProjectType"].Rows)
			{
				int index = lbProjectType.FindStringExact((string)drPT["ProjectType"]);
				lbProjectType.SetSelected(index, true);
			}
			
			//County
			foreach(DataRow drCounty in dsProject.Tables["ProjectCounty"].Rows)
			{
				int index = lbCounty.FindStringExact((string)drCounty["CountyName"]);
				lbCounty.SetSelected(index, true);
			}
			//City
			foreach(DataRow drCity in dsProject.Tables["ProjectCity"].Rows)
			{
				int index = lbCity.FindStringExact((string)drCity["CityName"]);
				lbCity.SetSelected(index, true);
			}
			//Region
			foreach(DataRow drRegion in dsProject.Tables["ProjectRegion"].Rows)
			{
				int index = lbRegion.FindStringExact((string)drRegion["Region"]);
				lbRegion.SetSelected(index, true);
			}
            // 2005-02-18 - added Watershed
			//Watershed
			foreach(DataRow drWatershed in dsProject.Tables["ProjectWatershed"].Rows)
			{
				int index = lbWatershed.FindStringExact((string)drWatershed["Watershed"]);
				lbWatershed.SetSelected(index, true);
			}

			//Latitude & Longitude
			string latitude = drProject["Latitude"].ToString();
			txtLatitude.Text =  latitude == "0" ? string.Empty : latitude;
			string longitude = drProject["longitude"].ToString();
			txtLongitude.Text = longitude == "0" ? string.Empty : longitude;
            txtLocationDescription.Text = drProject["LocationDescription"].ToString();
			//Assembly district
			foreach(DataRow drAssembly in dsProject.Tables["ProjectAssemblyDistrict"].Rows)
			{
				int index = lbAssembly.FindStringExact(drAssembly["AssemblyDistrictNumber"].ToString());
                if (index != ListBox.NoMatches)
                {
                    lbAssembly.SetSelected(index, true);
                }
			}
			//Senate district
			foreach(DataRow drSenate in dsProject.Tables["ProjectSenateDistrict"].Rows)
			{
				int index = lbSenate.FindStringExact(drSenate["SenateDistrictNumber"].ToString());
                if (index != ListBox.NoMatches)
                {
                    lbSenate.SetSelected(index, true);
                }
			}
			//Congressional district
			foreach(DataRow drCongress in dsProject.Tables["ProjectCongressionalDistrict"].Rows)
			{
				int index = lbCongressional.FindStringExact(drCongress["CongressionalDistrictNumber"].ToString());
                if (index != ListBox.NoMatches)
                {
                    lbCongressional.SetSelected(index, true);
                }
			}
            //DynamicMultiselect1
            foreach (DataRow drMultiSelect in dsProject.Tables["DynamicMultiSelect1"].Rows)
            {
                int index = DynamicLB1.FindStringExact((string)drMultiSelect["DisplayName"]);
                DynamicLB1.SetSelected(index, true);
            }
			//Land dimensions
			txtAcreage.Text = drProject["Acreage"].ToString();
            txtAcreage.Tag = txtAcreage.Text;
			txtSquareMiles.Text = drProject["SquareMiles"].ToString();
            txtSquareMiles.Tag = txtSquareMiles.Text;
			txtTrailMiles.Text = drProject["TrailMiles"].ToString();
			txtTrailLinearFeet.Text = drProject["TrailLinearFeet"].ToString();
			txtStreamMiles.Text = drProject["StreamMiles"].ToString();
			txtStreamLinearFeet.Text = drProject["StreamLinearFeet"].ToString();
			//Notes
			txtNotes.Text = drProject["ProjectNotes"].ToString();

			txtParcelNumber.Text = drProject["APNNumber"].ToString();
			txtCCTmiles.Text = drProject["CCTmiles"].ToString();
            //SetMilesFeet(txtCCTmiles, txtCCTLinearFeet, false);
            txtCCTLinearFeet.Text = drProject["CCTLinearFeet"].ToString();
		}

        private void SetCopyDisplay()
        {
            DataSet dsProject = ProjectData.GetProject(ProjectCopiedId);
            DataRow drProject = dsProject.Tables["Project"].Rows[0];
            this.lastModified = (DateTime)drProject["LastModified"];
            this.Text = string.Concat("Copy of : " + (string)drProject["ProjectName"]);
            txtProjectName.Text = string.Empty;
            //Status
            CurrentStatus = (int)drProject["StatusId"];
            switch (CurrentStatus)
            {
                case 0:
                    rbActive.Checked = true;
                    break;
                case 1:
                    rbInactive.Checked = true;
                    break;
                case 2:
                    rbComplete.Checked = true;
                    break;
                case 3:
                    rbClosed.Checked = true;
                    break;
            }

            //Website
            chkIsWebSite.Checked = (Boolean)drProject["IsWebsite"];
            //Status Date
            CurrentStatusDate = (DateTime)drProject["StatusDate"];
            //Completed Date
            uwdtCompletionDate.Value = string.Format("{0:d}", drProject["DateCompleted"]);
            //File Number
            txtFileNumber.Text = string.Empty;
            //Dynamic Dropdown 1
            DynamicDD1.Text = drProject["DynamicDD1"].ToString();
            //Dynamic Dropdown 2
            DynamicDD2.Text = (string)drProject["DynamicDD2"].ToString();

            //Staff

            foreach (DataRow drPM in dsProject.Tables["ProjectManager"].Rows)
            {
                int index = lbStaff.FindStringExact((string)drPM["Name"]);
                lbStaff.SetSelected(index, true);
            }

            if (drProject["CurrentPM"] != DBNull.Value)
            {
                // ADS 9-Nov-2007 - Set the current PM in the drop-down
                for (int pmIdx = 0; pmIdx < cbCurrentPM.Items.Count; pmIdx++)
                {
                    if ((int)((DataRowView)cbCurrentPM.Items[pmIdx])["ProjectManagerID"] == (int)drProject["CurrentPM"])
                    {
                        cbCurrentPM.SelectedIndex = pmIdx;
                        break;
                    }
                }
            }
            else
            {
                cbCurrentPM.SelectedIndex = -1;
            }

            //Attorney
            foreach (DataRow drPA in dsProject.Tables["ProjectAttorney"].Rows)
            {
                int index = lbAttorney.FindStringExact((string)drPA["Name"]);
                lbAttorney.SetSelected(index, true);
            }
            //Summary
            txtSummary.Text = (string)drProject["Summary"];
            //Description
            txtDescription.Text = (string)drProject["Description"];
            //Program Type
            foreach (DataRow drPPT in dsProject.Tables["ProjectProgramType"].Rows)
            {
                int index = lbProgramType.FindStringExact((string)drPPT["ProgramType"]);
                lbProgramType.SetSelected(index, true);
            }
            //Project Type
            foreach (DataRow drPT in dsProject.Tables["ProjectType"].Rows)
            {
                int index = lbProjectType.FindStringExact((string)drPT["ProjectType"]);
                lbProjectType.SetSelected(index, true);
            }

            //County
            foreach (DataRow drCounty in dsProject.Tables["ProjectCounty"].Rows)
            {
                int index = lbCounty.FindStringExact((string)drCounty["CountyName"]);
                lbCounty.SetSelected(index, true);
            }
            //City
            foreach (DataRow drCity in dsProject.Tables["ProjectCity"].Rows)
            {
                int index = lbCity.FindStringExact((string)drCity["CityName"]);
                lbCity.SetSelected(index, true);
            }
            //Region
            foreach (DataRow drRegion in dsProject.Tables["ProjectRegion"].Rows)
            {
                int index = lbRegion.FindStringExact((string)drRegion["Region"]);
                lbRegion.SetSelected(index, true);
            }
            // 2005-02-18 - added Watershed
            //Watershed
            foreach (DataRow drWatershed in dsProject.Tables["ProjectWatershed"].Rows)
            {
                int index = lbWatershed.FindStringExact((string)drWatershed["Watershed"]);
                lbWatershed.SetSelected(index, true);
            }

            //Latitude & Longitude
            string latitude = drProject["Latitude"].ToString();
            txtLatitude.Text = latitude == "0" ? string.Empty : latitude;
            string longitude = drProject["longitude"].ToString();
            txtLongitude.Text = longitude == "0" ? string.Empty : longitude;
            txtLocationDescription.Text = drProject["LocationDescription"].ToString();
            //Assembly district
            foreach (DataRow drAssembly in dsProject.Tables["ProjectAssemblyDistrict"].Rows)
            {
                int index = lbAssembly.FindStringExact(drAssembly["AssemblyDistrictNumber"].ToString());
                if (index != ListBox.NoMatches)
                {
                    lbAssembly.SetSelected(index, true);
                }
            }
            //Senate district
            foreach (DataRow drSenate in dsProject.Tables["ProjectSenateDistrict"].Rows)
            {
                int index = lbSenate.FindStringExact(drSenate["SenateDistrictNumber"].ToString());
                if (index != ListBox.NoMatches)
                {
                    lbSenate.SetSelected(index, true);
                }
            }
            //Congressional district
            foreach (DataRow drCongress in dsProject.Tables["ProjectCongressionalDistrict"].Rows)
            {
                int index = lbCongressional.FindStringExact(drCongress["CongressionalDistrictNumber"].ToString());
                if (index != ListBox.NoMatches)
                {
                    lbCongressional.SetSelected(index, true);
                }
            }
            //Land dimensions
            txtAcreage.Text = drProject["Acreage"].ToString();
            txtAcreage.Tag = txtAcreage.Text;
            txtSquareMiles.Text = drProject["SquareMiles"].ToString();
            txtSquareMiles.Tag = txtSquareMiles.Text;
            txtTrailMiles.Text = drProject["TrailMiles"].ToString();
            txtTrailLinearFeet.Text = drProject["TrailLinearFeet"].ToString();
            txtStreamMiles.Text = drProject["StreamMiles"].ToString();
            txtStreamLinearFeet.Text = drProject["StreamLinearFeet"].ToString();
            //Notes
            txtNotes.Text = drProject["ProjectNotes"].ToString();

            txtParcelNumber.Text = drProject["APNNumber"].ToString();
            txtCCTmiles.Text = drProject["CCTmiles"].ToString();
            //SetMilesFeet(txtCCTmiles, txtCCTLinearFeet, false);
            txtCCTLinearFeet.Text = drProject["CCTLinearFeet"].ToString();
        }


		private void PopulateLists()
		{
			// MAR 2005-07-12 - we only want to exclude inactive records when doing an Add
			//DataSet dsProjectRelated = ProjectData.GetProjectRelated();
			DataSet dsProjectRelated = null;
            //if (IsUpdateMode) 
            //{
            //    dsProjectRelated = ProjectData.GetProjectRelatedInactive();	
            //    ProjectData.GetProjectRelatedInactive();
            //}
            //else
            //{
            //
                //if copy mode is set then use the existing project id 
                if (IsCopyMode)
                    dsProjectRelated = ProjectData.GetProjectRelated(this.projectCopiedId);
                else
                    dsProjectRelated = ProjectData.GetProjectRelated(GlobalSettings.projectId);
                    //ProjectData.GetProjectRelated();
            //}
            //DD1
            DataSet ds = ProjectData.GetDynamicDropDown(DynamicDD1.Name);
            DynamicDD1.DataSource = ds.Tables[0];
            DynamicDD1.ValueMember = "Code";
            DynamicDD1.DisplayMember = "DisplayName";
            DynamicDD1.DropDownStyle = UltraComboStyle.DropDown;
            lblDD1.Text = ds.Tables[0].Rows.Count>1 ? ds.Tables[0].Rows[1]["LabelName"].ToString() : string.Empty ;
            //

            //DD2
            ds = ProjectData.GetDynamicDropDown(DynamicDD2.Name);
            DynamicDD2.DataSource = ds.Tables[0]; 
            DynamicDD2.ValueMember = "Code";
            DynamicDD2.DisplayMember = "DisplayName";
            DynamicDD2.DropDownStyle = UltraComboStyle.DropDown;
            lblDD2.Text = ds.Tables[0].Rows.Count > 1 ? ds.Tables[0].Rows[1]["LabelName"].ToString() : string.Empty;

            DataTable dtDynamicMultiSelect1 = ProjectData.GetDynamicMultiSelect("Project_ProjectDynamicMultiSelect1");
            DynamicLB1.DataSource = dtDynamicMultiSelect1;
            DynamicLB1.ValueMember = "Code";
            DynamicLB1.DisplayMember = "DisplayName";
            DynamicLB1.SelectionMode = SelectionMode.MultiSimple;
            DynamicLB1.ClearSelected();
            lblMultiselect1.Text = dtDynamicMultiSelect1.Rows.Count > 1 ? dtDynamicMultiSelect1.Rows[1]["LabelName"].ToString() : string.Empty;

			//Staff
			lbStaff.DataSource = dsProjectRelated.Tables["ProjectManager"];
			lbStaff.ValueMember = "ProjectManagerId";
			lbStaff.DisplayMember = "Name";
			lbStaff.ClearSelected();
			//Attorney
			lbAttorney.DataSource = dsProjectRelated.Tables["ProjectAttorney"];
			lbAttorney.ValueMember = "AttorneyId";
			lbAttorney.DisplayMember = "Name";
			lbAttorney.ClearSelected();
			//Program Type
			lbProgramType.DataSource = dsProjectRelated.Tables["ProjectProgramType"];
			lbProgramType.ValueMember = "ProgramTypeId";
			lbProgramType.DisplayMember = "ProgramType";
			lbProgramType.ClearSelected();
			//Project Type
			lbProjectType.DataSource = dsProjectRelated.Tables["ProjectType"];
			lbProjectType.ValueMember = "ProjectTypeId";
			lbProjectType.DisplayMember = "ProjectType";
			lbProjectType.ClearSelected();
			//County
			lbCounty.DataSource = dsProjectRelated.Tables["ProjectCounty"];
			lbCounty.DisplayMember = "CountyName";
			lbCounty.ValueMember = "CountyId";
			lbCounty.ClearSelected();
			//City
			lbCity.DataSource = dsProjectRelated;
			lbCity.DisplayMember = "ProjectCity.CityName";
			lbCity.ValueMember = "ProjectCity.CityId";
			lbCity.ClearSelected();
			//Region
			lbRegion.DataSource = dsProjectRelated.Tables["ProjectRegion"];
			lbRegion.DisplayMember = "Region";
			lbRegion.ValueMember = "RegionId";
			lbRegion.ClearSelected();

			//Watershed - MAR 2005-02-18 - added
			lbWatershed.DataSource = dsProjectRelated.Tables["Watershed"];
			lbWatershed.DisplayMember = "Watershed";
			lbWatershed.ValueMember = "WatershedID";
			lbWatershed.ClearSelected();

			//Congressional
			lbCongressional.DataSource = dsProjectRelated.Tables["ProjectCongressionalDistrict"];
			lbCongressional.DisplayMember = "CongressionalDistrictNumber";
			lbCongressional.ColumnWidth = 20;
			lbCongressional.ClearSelected();
			
			//Assembly
			lbAssembly.DataSource = dsProjectRelated.Tables["ProjectAssemblyDistrict"];
			lbAssembly.DisplayMember = "AssemblyDistrictNumber";
			lbAssembly.ColumnWidth = 20;
			lbAssembly.ClearSelected();
			
			//Senate
			lbSenate.DataSource = dsProjectRelated.Tables["ProjectStateSenateDistrict"];
			lbSenate.DisplayMember = "StateSenateDistrictNumber";
			lbSenate.ColumnWidth = 20;
			lbSenate.ClearSelected();

		}


		private bool UpdateOrInsertRecord()
		{
			// MAR 2005-02-07 - moved to validation section
//			if( ! ProjectData.ProjectFileNumberIsUnuique(txtFileNumber.Text, projectId))
//			{
//				MessageBox.Show("File number is not unique!\nPlease revise your input.",
//					"File Number Not Unique", MessageBoxButtons.OK, MessageBoxIcon.Error);
//				return false;
//			}

			bool result = true;

			IntegerList attorneyList = new IntegerList();
			foreach(DataRowView drv in lbAttorney.SelectedItems)
			{
				attorneyList.Add((int)drv["AttorneyId"]);
			}
			IntegerList countyList = new IntegerList();
			foreach(DataRowView drv in lbCounty.SelectedItems)
			{
				countyList.Add((int)drv["CountyId"]);
			}
			IntegerList cityList = new IntegerList();
			foreach(DataRowView drv in lbCity.SelectedItems)
			{
				cityList.Add((int)drv["CityId"]);
			}
			IntegerList staffList = new IntegerList();
			foreach(DataRowView drv in lbStaff.SelectedItems)
			{
				staffList.Add((int)drv["ProjectManagerId"]);
			}
			IntegerList programTypeList = new IntegerList();
			foreach(DataRowView drv in lbProgramType.SelectedItems)
			{
				programTypeList.Add((int)drv["ProgramTypeId"]);
			}
			IntegerList projectRegionList = new IntegerList();
			foreach(DataRowView drv in lbRegion.SelectedItems)
			{
				projectRegionList.Add((int)drv["RegionId"]);
			}
            // 2005-02-18 MAR - added
			IntegerList projectWatershedList = new IntegerList();
			foreach(DataRowView drv in lbWatershed.SelectedItems)
			{
				projectWatershedList.Add((int)drv["WatershedID"]);
			}

			IntegerList projectTypeList = new IntegerList();
			foreach(DataRowView drv in lbProjectType.SelectedItems)
			{
				projectTypeList.Add((int)drv["ProjectTypeId"]);
			}
			IntegerList assemblyList = new IntegerList();
			foreach(DataRowView drvAssembly in lbAssembly.SelectedItems)
			{
				assemblyList.Add((int)drvAssembly["AssemblyDistrictNumber"]);
			}
			IntegerList senateList = new IntegerList();
			foreach(DataRowView drvSenate in lbSenate.SelectedItems)
			{
				senateList.Add((int)drvSenate["StateSenateDistrictNumber"]);
			}
            IntegerList congressionalList = new IntegerList();
			foreach(DataRowView drvCongressional in lbCongressional.SelectedItems)
			{
				congressionalList.Add((int)drvCongressional["CongressionalDistrictNumber"]);
			}
            List<string> dynamicMultiSelectList = new List<string>();
            foreach (DataRowView drv in DynamicLB1.SelectedItems)
            {
                dynamicMultiSelectList.Add(drv["Code"].ToString());
            }
			//If the status has changed then we update the StatusDate to today's date
			int status = 0; //active
			DateTime statusDate = CurrentStatusDate;
			if(rbInactive.Checked)//inactive
			{
				status = 1;
				if(CurrentStatus != 1) statusDate = DateTime.Today;
			}
			else if(rbComplete.Checked)
			{
				status = 2;//complete
				if(CurrentStatus != 2) statusDate = DateTime.Today;
			}
            else if (rbClosed.Checked)
            {
                status = 3;//closed
                if (CurrentStatus != 3) statusDate = DateTime.Today;
            }
            //If longitude is a positive number multiply it by -1 to achieve a negative number.
			decimal longitude = ParseDecimal(txtLongitude.Text);
			if(longitude > 0) longitude =  decimal.Negate(longitude);

			// ADS 6-Dec-2007 - Added boilerplate (somtimes there is no selected PM)
			int CurrentPM = 0;
			
			if( cbCurrentPM.SelectedItem != null )
				CurrentPM = (int)(((DataRowView)cbCurrentPM.SelectedItem)["ProjectManagerID"]);

			if(IsUpdateMode)//Update project
			{
				result = ProjectData.UpdateProject(
					txtFileNumber.Text,
					txtProjectName.Text,
					status,
					statusDate,
					txtSummary.Text,
					txtDescription.Text,
					ParseDecimal(txtLatitude.Text),
					longitude,
					ParseDecimal(txtAcreage.Text),
					ParseDecimal(txtSquareMiles.Text),
					ParseDecimal(txtTrailMiles.Text),
					ParseDecimal(txtTrailLinearFeet.Text),
					ParseDecimal(txtStreamMiles.Text),
					ParseDecimal(txtStreamLinearFeet.Text),
					txtNotes.Text,
					attorneyList,
					countyList,
					cityList,
					staffList,
					programTypeList,
					projectRegionList,
					projectWatershedList,
					projectTypeList,
					assemblyList,
					senateList,
					congressionalList,
					txtParcelNumber.Text,
					ParseDecimal(txtCCTmiles.Text),
                    ParseDecimal(txtCCTLinearFeet.Text),
					CurrentPM,
					ProjectId,
					this.lastModified,
                    txtLocationDescription.Text,
                    uwdtCompletionDate.Value,
                    Convert.ToString(chkIsWebSite.Checked),
                    Convert.ToString(DynamicDD1.Value),
                    Convert.ToString(DynamicDD2.Value),
                    dynamicMultiSelectList
                    );
			}
			else //Insert new project
			{
				this.ProjectId = ProjectData.InsertProject(
					txtFileNumber.Text,
					txtProjectName.Text,
					txtSummary.Text,
					txtDescription.Text,
					ParseDecimal(txtLatitude.Text),
					longitude,
					ParseDecimal(txtAcreage.Text),
					ParseDecimal(txtSquareMiles.Text),
					ParseDecimal(txtTrailMiles.Text),
					ParseDecimal(txtTrailLinearFeet.Text),
					ParseDecimal(txtStreamMiles.Text),
					ParseDecimal(txtStreamLinearFeet.Text),
					txtNotes.Text,
					txtParcelNumber.Text,
					ParseDecimal(txtCCTmiles.Text),
                    ParseDecimal(txtCCTLinearFeet.Text),
					CurrentPM,
					attorneyList,
					countyList,
					cityList,
					staffList,
					programTypeList,
					projectRegionList,
					projectWatershedList,
					projectTypeList,
					assemblyList,
					senateList,
					congressionalList,
                    txtLocationDescription.Text,
                    uwdtCompletionDate.Value,
                    Convert.ToString(chkIsWebSite.Checked),
                    Convert.ToString(DynamicDD1.Value),
                    Convert.ToString(DynamicDD2.Value),
                    dynamicMultiSelectList
                    );
			}
					
			return result;
		}


		private decimal ParseDecimal(string input)
		{
			return input == string.Empty ? 0 : decimal.Parse(input);
		}


		private float ParseFloat(string input)
		{
			return input == string.Empty ? 0 : float.Parse(input);
		}


		private bool AreaIsValid(string input)
		{
			Regex regex = new Regex(@"^\d{0,16}(\.\d{0,2})?$");
			if(regex.IsMatch(input))
			{
				return true;
			}
			return false;
		}

		public string TrimString(string input)
		{
			if(this.AreaIsValid(input)) 
			{
				return input;
			}
			string wrkString = string.Empty;
			if(input.Length > 0)
			{
				wrkString =  TrimString(input.Remove((input.Length -1), 1));
			}

			return wrkString;
		
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}


		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.components = new System.ComponentModel.Container();
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(ProjectCreateOrUpdate));
            this.txtFileNumber = new System.Windows.Forms.TextBox();
            this.lblFileNumber = new System.Windows.Forms.Label();
            this.lblStaff = new System.Windows.Forms.Label();
            this.lbStaff = new System.Windows.Forms.ListBox();
            this.lblAttorney = new System.Windows.Forms.Label();
            this.lbAttorney = new System.Windows.Forms.ListBox();
            this.lblSummary = new System.Windows.Forms.Label();
            this.txtSummary = new System.Windows.Forms.TextBox();
            this.lblDescription = new System.Windows.Forms.Label();
            this.txtDescription = new System.Windows.Forms.TextBox();
            this.lblProgramType = new System.Windows.Forms.Label();
            this.lbProgramType = new System.Windows.Forms.ListBox();
            this.lblProjectType = new System.Windows.Forms.Label();
            this.lbProjectType = new System.Windows.Forms.ListBox();
            this.label1 = new System.Windows.Forms.Label();
            this.rbActive = new System.Windows.Forms.RadioButton();
            this.rbInactive = new System.Windows.Forms.RadioButton();
            this.rbComplete = new System.Windows.Forms.RadioButton();
            this.txtProjectName = new System.Windows.Forms.TextBox();
            this.lblProjectName = new System.Windows.Forms.Label();
            this.lblCity = new System.Windows.Forms.Label();
            this.lblCounty = new System.Windows.Forms.Label();
            this.lbCounty = new System.Windows.Forms.ListBox();
            this.lblRegion = new System.Windows.Forms.Label();
            this.lbRegion = new System.Windows.Forms.ListBox();
            this.lblLatitude = new System.Windows.Forms.Label();
            this.txtLatitude = new System.Windows.Forms.TextBox();
            this.lblLongitude = new System.Windows.Forms.Label();
            this.txtLongitude = new System.Windows.Forms.TextBox();
            this.lblAssembly = new System.Windows.Forms.Label();
            this.lblSenate = new System.Windows.Forms.Label();
            this.btnSave = new System.Windows.Forms.Button();
            this.lblCongressional = new System.Windows.Forms.Label();
            this.lbCongressional = new System.Windows.Forms.ListBox();
            this.lbAssembly = new System.Windows.Forms.ListBox();
            this.lbSenate = new System.Windows.Forms.ListBox();
            this.lblAcreage = new System.Windows.Forms.Label();
            this.txtAcreage = new System.Windows.Forms.TextBox();
            this.lblSquareMiles = new System.Windows.Forms.Label();
            this.txtSquareMiles = new System.Windows.Forms.TextBox();
            this.txtTrailMiles = new System.Windows.Forms.TextBox();
            this.txtTrailLinearFeet = new System.Windows.Forms.TextBox();
            this.txtStreamMiles = new System.Windows.Forms.TextBox();
            this.txtStreamLinearFeet = new System.Windows.Forms.TextBox();
            this.lblStreamMiles = new System.Windows.Forms.Label();
            this.label3 = new System.Windows.Forms.Label();
            this.lblTrailMiles = new System.Windows.Forms.Label();
            this.lblTrailLinear = new System.Windows.Forms.Label();
            this.txtNotes = new System.Windows.Forms.TextBox();
            this.lblNotes = new System.Windows.Forms.Label();
            this.rfvName = new Genghis.Windows.Forms.RequiredFieldValidator();
            this.btnCancel = new System.Windows.Forms.Button();
            this.contextMenu1 = new System.Windows.Forms.ContextMenu();
            this.miSave = new System.Windows.Forms.MenuItem();
            this.menuItem3 = new System.Windows.Forms.MenuItem();
            this.miRefresh = new System.Windows.Forms.MenuItem();
            this.menuItem5 = new System.Windows.Forms.MenuItem();
            this.miClose = new System.Windows.Forms.MenuItem();
            this.revLatitude = new Genghis.Windows.Forms.RegularExpressionValidator();
            this.revLongitude = new Genghis.Windows.Forms.RegularExpressionValidator();
            this.lbCity = new System.Windows.Forms.ListBox();
            this.rfvProjectNumber = new Genghis.Windows.Forms.RequiredFieldValidator();
            this.revProjectNumber = new Genghis.Windows.Forms.RegularExpressionValidator();
            this.rvLatitude = new Genghis.Windows.Forms.RangeValidator();
            this.rvLongitude = new Genghis.Windows.Forms.RangeValidator();
            this.label2 = new System.Windows.Forms.Label();
            this.label5 = new System.Windows.Forms.Label();
            this.lbWatershed = new System.Windows.Forms.ListBox();
            this.lblWatershed = new System.Windows.Forms.Label();
            this.lblCoastalTrailMiles = new System.Windows.Forms.Label();
            this.txtCCTmiles = new System.Windows.Forms.TextBox();
            this.txtParcelNumber = new System.Windows.Forms.TextBox();
            this.lblParcelNumber = new System.Windows.Forms.Label();
            this.cbCurrentPM = new System.Windows.Forms.ComboBox();
            this.label4 = new System.Windows.Forms.Label();
            this.btnNewProjectNumber = new System.Windows.Forms.Button();
            this.txtCCTLinearFeet = new System.Windows.Forms.TextBox();
            this.label6 = new System.Windows.Forms.Label();
            this.txtLocationDescription = new System.Windows.Forms.TextBox();
            this.label7 = new System.Windows.Forms.Label();
            this.rbClosed = new System.Windows.Forms.RadioButton();
            this.toolTip1 = new System.Windows.Forms.ToolTip(this.components);
            this.uwdtCompletionDate = new Infragistics.Win.UltraWinEditors.UltraDateTimeEditor();
            this.label8 = new System.Windows.Forms.Label();
            this.chkIsWebSite = new System.Windows.Forms.CheckBox();
            this.lblDD1 = new System.Windows.Forms.Label();
            this.lblDD2 = new System.Windows.Forms.Label();
            this.DynamicDD1 = new Infragistics.Win.UltraWinGrid.UltraCombo();
            this.DynamicDD2 = new Infragistics.Win.UltraWinGrid.UltraCombo();
            this.DynamicLB1 = new System.Windows.Forms.ListBox();
            this.lblMultiselect1 = new System.Windows.Forms.Label();
            ((System.ComponentModel.ISupportInitialize)(this.rfvName)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.revLatitude)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.revLongitude)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.rfvProjectNumber)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.revProjectNumber)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.rvLatitude)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.rvLongitude)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.uwdtCompletionDate)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.DynamicDD1)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.DynamicDD2)).BeginInit();
            this.SuspendLayout();
            // 
            // txtFileNumber
            // 
            this.txtFileNumber.Location = new System.Drawing.Point(752, 21);
            this.txtFileNumber.MaxLength = 50;
            this.txtFileNumber.Name = "txtFileNumber";
            this.txtFileNumber.Size = new System.Drawing.Size(236, 22);
            this.txtFileNumber.TabIndex = 2;
            // 
            // lblFileNumber
            // 
            this.lblFileNumber.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblFileNumber.Location = new System.Drawing.Point(667, 10);
            this.lblFileNumber.Name = "lblFileNumber";
            this.lblFileNumber.Size = new System.Drawing.Size(72, 32);
            this.lblFileNumber.TabIndex = 1;
            this.lblFileNumber.Text = "Project Number";
            this.lblFileNumber.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // lblStaff
            // 
            this.lblStaff.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblStaff.Location = new System.Drawing.Point(5, 113);
            this.lblStaff.Name = "lblStaff";
            this.lblStaff.Size = new System.Drawing.Size(87, 52);
            this.lblStaff.TabIndex = 2;
            this.lblStaff.Text = "Project Manager(s)";
            this.lblStaff.Click += new System.EventHandler(this.lblStaff_Click);
            // 
            // lbStaff
            // 
            this.lbStaff.ItemHeight = 16;
            this.lbStaff.Location = new System.Drawing.Point(82, 113);
            this.lbStaff.Name = "lbStaff";
            this.lbStaff.SelectionMode = System.Windows.Forms.SelectionMode.MultiSimple;
            this.lbStaff.Size = new System.Drawing.Size(226, 68);
            this.lbStaff.TabIndex = 11;
            this.lbStaff.SelectedIndexChanged += new System.EventHandler(this.lbStaff_SelectedIndexChanged);
            // 
            // lblAttorney
            // 
            this.lblAttorney.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblAttorney.Location = new System.Drawing.Point(667, 113);
            this.lblAttorney.Name = "lblAttorney";
            this.lblAttorney.Size = new System.Drawing.Size(64, 40);
            this.lblAttorney.TabIndex = 6;
            this.lblAttorney.Text = "Attorney";
            this.lblAttorney.Click += new System.EventHandler(this.lblAttorney_Click);
            // 
            // lbAttorney
            // 
            this.lbAttorney.ItemHeight = 16;
            this.lbAttorney.Location = new System.Drawing.Point(752, 113);
            this.lbAttorney.Name = "lbAttorney";
            this.lbAttorney.SelectionMode = System.Windows.Forms.SelectionMode.MultiSimple;
            this.lbAttorney.Size = new System.Drawing.Size(236, 68);
            this.lbAttorney.TabIndex = 13;
            this.lbAttorney.SelectedIndexChanged += new System.EventHandler(this.lbAttorney_SelectedIndexChanged);
            // 
            // lblSummary
            // 
            this.lblSummary.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblSummary.Location = new System.Drawing.Point(4, 201);
            this.lblSummary.Name = "lblSummary";
            this.lblSummary.Size = new System.Drawing.Size(90, 23);
            this.lblSummary.TabIndex = 8;
            this.lblSummary.Text = "Summary";
            this.lblSummary.Click += new System.EventHandler(this.lblSummary_Click);
            // 
            // txtSummary
            // 
            this.txtSummary.Location = new System.Drawing.Point(82, 192);
            this.txtSummary.MaxLength = 300;
            this.txtSummary.Multiline = true;
            this.txtSummary.Name = "txtSummary";
            this.txtSummary.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
            this.txtSummary.Size = new System.Drawing.Size(906, 31);
            this.txtSummary.TabIndex = 14;
            this.txtSummary.TextChanged += new System.EventHandler(this.txtSummary_TextChanged);
            // 
            // lblDescription
            // 
            this.lblDescription.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblDescription.Location = new System.Drawing.Point(4, 260);
            this.lblDescription.Name = "lblDescription";
            this.lblDescription.Size = new System.Drawing.Size(80, 23);
            this.lblDescription.TabIndex = 10;
            this.lblDescription.Text = "Description";
            this.lblDescription.Click += new System.EventHandler(this.lblDescription_Click);
            // 
            // txtDescription
            // 
            this.txtDescription.Location = new System.Drawing.Point(82, 248);
            this.txtDescription.MaxLength = 1968;
            this.txtDescription.Multiline = true;
            this.txtDescription.Name = "txtDescription";
            this.txtDescription.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
            this.txtDescription.Size = new System.Drawing.Size(906, 78);
            this.txtDescription.TabIndex = 15;
            this.txtDescription.TextChanged += new System.EventHandler(this.txtDescription_TextChanged);
            // 
            // lblProgramType
            // 
            this.lblProgramType.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblProgramType.Location = new System.Drawing.Point(4, 339);
            this.lblProgramType.Name = "lblProgramType";
            this.lblProgramType.Size = new System.Drawing.Size(90, 37);
            this.lblProgramType.TabIndex = 12;
            this.lblProgramType.Text = "Program \r\nType";
            this.lblProgramType.Click += new System.EventHandler(this.lblProgramType_Click);
            // 
            // lbProgramType
            // 
            this.lbProgramType.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lbProgramType.ItemHeight = 14;
            this.lbProgramType.Location = new System.Drawing.Point(82, 338);
            this.lbProgramType.Name = "lbProgramType";
            this.lbProgramType.SelectionMode = System.Windows.Forms.SelectionMode.MultiSimple;
            this.lbProgramType.Size = new System.Drawing.Size(226, 74);
            this.lbProgramType.TabIndex = 16;
            this.lbProgramType.SelectedIndexChanged += new System.EventHandler(this.lbProgramType_SelectedIndexChanged);
            // 
            // lblProjectType
            // 
            this.lblProjectType.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblProjectType.Location = new System.Drawing.Point(318, 339);
            this.lblProjectType.Name = "lblProjectType";
            this.lblProjectType.Size = new System.Drawing.Size(88, 38);
            this.lblProjectType.TabIndex = 14;
            this.lblProjectType.Text = "Project \r\nType";
            this.lblProjectType.Click += new System.EventHandler(this.lblProjectType_Click);
            // 
            // lbProjectType
            // 
            this.lbProjectType.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lbProjectType.ItemHeight = 14;
            this.lbProjectType.Location = new System.Drawing.Point(406, 339);
            this.lbProjectType.Name = "lbProjectType";
            this.lbProjectType.SelectionMode = System.Windows.Forms.SelectionMode.MultiSimple;
            this.lbProjectType.Size = new System.Drawing.Size(236, 74);
            this.lbProjectType.TabIndex = 17;
            this.lbProjectType.SelectedIndexChanged += new System.EventHandler(this.lbProjectType_SelectedIndexChanged);
            // 
            // label1
            // 
            this.label1.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label1.Location = new System.Drawing.Point(6, 46);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(48, 23);
            this.label1.TabIndex = 16;
            this.label1.Text = "Status";
            // 
            // rbActive
            // 
            this.rbActive.Location = new System.Drawing.Point(84, 44);
            this.rbActive.Name = "rbActive";
            this.rbActive.Size = new System.Drawing.Size(64, 24);
            this.rbActive.TabIndex = 3;
            this.rbActive.Text = "Active";
            // 
            // rbInactive
            // 
            this.rbInactive.Location = new System.Drawing.Point(156, 44);
            this.rbInactive.Name = "rbInactive";
            this.rbInactive.Size = new System.Drawing.Size(72, 24);
            this.rbInactive.TabIndex = 4;
            this.rbInactive.Text = "Inactive";
            // 
            // rbComplete
            // 
            this.rbComplete.Location = new System.Drawing.Point(228, 44);
            this.rbComplete.Name = "rbComplete";
            this.rbComplete.Size = new System.Drawing.Size(82, 24);
            this.rbComplete.TabIndex = 5;
            this.rbComplete.Text = "Complete";
            // 
            // txtProjectName
            // 
            this.txtProjectName.Location = new System.Drawing.Point(84, 17);
            this.txtProjectName.MaxLength = 100;
            this.txtProjectName.Name = "txtProjectName";
            this.txtProjectName.Size = new System.Drawing.Size(564, 22);
            this.txtProjectName.TabIndex = 1;
            // 
            // lblProjectName
            // 
            this.lblProjectName.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblProjectName.Location = new System.Drawing.Point(6, 9);
            this.lblProjectName.Name = "lblProjectName";
            this.lblProjectName.Size = new System.Drawing.Size(100, 30);
            this.lblProjectName.TabIndex = 20;
            this.lblProjectName.Text = "Project \r\nName";
            // 
            // lblCity
            // 
            this.lblCity.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblCity.Location = new System.Drawing.Point(318, 432);
            this.lblCity.Name = "lblCity";
            this.lblCity.Size = new System.Drawing.Size(56, 23);
            this.lblCity.TabIndex = 22;
            this.lblCity.Text = "City";
            this.lblCity.Click += new System.EventHandler(this.lblCity_Click);
            // 
            // lblCounty
            // 
            this.lblCounty.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblCounty.Location = new System.Drawing.Point(4, 424);
            this.lblCounty.Name = "lblCounty";
            this.lblCounty.Size = new System.Drawing.Size(64, 23);
            this.lblCounty.TabIndex = 24;
            this.lblCounty.Text = "County";
            this.lblCounty.Click += new System.EventHandler(this.lblCounty_Click);
            // 
            // lbCounty
            // 
            this.lbCounty.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lbCounty.ItemHeight = 14;
            this.lbCounty.Location = new System.Drawing.Point(82, 423);
            this.lbCounty.Name = "lbCounty";
            this.lbCounty.SelectionMode = System.Windows.Forms.SelectionMode.MultiSimple;
            this.lbCounty.Size = new System.Drawing.Size(226, 88);
            this.lbCounty.TabIndex = 20;
            this.lbCounty.SelectedIndexChanged += new System.EventHandler(this.lbCounty_SelectedIndexChanged);
            // 
            // lblRegion
            // 
            this.lblRegion.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblRegion.Location = new System.Drawing.Point(667, 525);
            this.lblRegion.Name = "lblRegion";
            this.lblRegion.Size = new System.Drawing.Size(87, 23);
            this.lblRegion.TabIndex = 26;
            this.lblRegion.Text = "Region";
            // 
            // lbRegion
            // 
            this.lbRegion.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lbRegion.ItemHeight = 14;
            this.lbRegion.Location = new System.Drawing.Point(772, 525);
            this.lbRegion.Name = "lbRegion";
            this.lbRegion.SelectionMode = System.Windows.Forms.SelectionMode.MultiSimple;
            this.lbRegion.Size = new System.Drawing.Size(216, 74);
            this.lbRegion.TabIndex = 25;
            // 
            // lblLatitude
            // 
            this.lblLatitude.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblLatitude.Location = new System.Drawing.Point(667, 340);
            this.lblLatitude.Name = "lblLatitude";
            this.lblLatitude.Size = new System.Drawing.Size(87, 23);
            this.lblLatitude.TabIndex = 28;
            this.lblLatitude.Text = "Latitude";
            this.lblLatitude.Click += new System.EventHandler(this.lblLatitude_Click);
            // 
            // txtLatitude
            // 
            this.txtLatitude.Location = new System.Drawing.Point(772, 340);
            this.txtLatitude.MaxLength = 9;
            this.txtLatitude.Name = "txtLatitude";
            this.txtLatitude.Size = new System.Drawing.Size(128, 22);
            this.txtLatitude.TabIndex = 18;
            this.txtLatitude.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.txtLatitude.TextChanged += new System.EventHandler(this.txtLatitude_TextChanged);
            // 
            // lblLongitude
            // 
            this.lblLongitude.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblLongitude.Location = new System.Drawing.Point(667, 377);
            this.lblLongitude.Name = "lblLongitude";
            this.lblLongitude.Size = new System.Drawing.Size(87, 23);
            this.lblLongitude.TabIndex = 30;
            this.lblLongitude.Text = "Longitude";
            this.lblLongitude.Click += new System.EventHandler(this.lblLongitude_Click);
            // 
            // txtLongitude
            // 
            this.txtLongitude.Location = new System.Drawing.Point(772, 377);
            this.txtLongitude.MaxLength = 11;
            this.txtLongitude.Name = "txtLongitude";
            this.txtLongitude.Size = new System.Drawing.Size(128, 22);
            this.txtLongitude.TabIndex = 19;
            this.txtLongitude.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.txtLongitude.TextChanged += new System.EventHandler(this.txtLongitude_TextChanged);
            // 
            // lblAssembly
            // 
            this.lblAssembly.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblAssembly.Location = new System.Drawing.Point(4, 610);
            this.lblAssembly.Name = "lblAssembly";
            this.lblAssembly.Size = new System.Drawing.Size(72, 40);
            this.lblAssembly.TabIndex = 32;
            this.lblAssembly.Text = "Assembly District";
            // 
            // lblSenate
            // 
            this.lblSenate.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblSenate.Location = new System.Drawing.Point(318, 610);
            this.lblSenate.Name = "lblSenate";
            this.lblSenate.Size = new System.Drawing.Size(88, 32);
            this.lblSenate.TabIndex = 33;
            this.lblSenate.Text = "State Senate District";
            // 
            // btnSave
            // 
            this.btnSave.Location = new System.Drawing.Point(436, 958);
            this.btnSave.Name = "btnSave";
            this.btnSave.Size = new System.Drawing.Size(75, 23);
            this.btnSave.TabIndex = 38;
            this.btnSave.Text = "Save";
            this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
            // 
            // lblCongressional
            // 
            this.lblCongressional.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblCongressional.Location = new System.Drawing.Point(669, 610);
            this.lblCongressional.Name = "lblCongressional";
            this.lblCongressional.Size = new System.Drawing.Size(104, 40);
            this.lblCongressional.TabIndex = 37;
            this.lblCongressional.Text = "Congressional District";
            // 
            // lbCongressional
            // 
            this.lbCongressional.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lbCongressional.ItemHeight = 14;
            this.lbCongressional.Location = new System.Drawing.Point(772, 610);
            this.lbCongressional.MultiColumn = true;
            this.lbCongressional.Name = "lbCongressional";
            this.lbCongressional.SelectionMode = System.Windows.Forms.SelectionMode.MultiSimple;
            this.lbCongressional.Size = new System.Drawing.Size(216, 102);
            this.lbCongressional.TabIndex = 28;
            this.lbCongressional.SelectedIndexChanged += new System.EventHandler(this.lbCongressional_SelectedIndexChanged);
            this.lbCongressional.Click += new System.EventHandler(this.lbCongressional_Click);
            // 
            // lbAssembly
            // 
            this.lbAssembly.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lbAssembly.ItemHeight = 14;
            this.lbAssembly.Location = new System.Drawing.Point(82, 610);
            this.lbAssembly.MultiColumn = true;
            this.lbAssembly.Name = "lbAssembly";
            this.lbAssembly.SelectionMode = System.Windows.Forms.SelectionMode.MultiSimple;
            this.lbAssembly.Size = new System.Drawing.Size(226, 102);
            this.lbAssembly.TabIndex = 26;
            this.lbAssembly.SelectedIndexChanged += new System.EventHandler(this.lbAssembly_SelectedIndexChanged);
            this.lbAssembly.Click += new System.EventHandler(this.lbAssembly_Click);
            // 
            // lbSenate
            // 
            this.lbSenate.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lbSenate.ItemHeight = 14;
            this.lbSenate.Location = new System.Drawing.Point(410, 610);
            this.lbSenate.MultiColumn = true;
            this.lbSenate.Name = "lbSenate";
            this.lbSenate.SelectionMode = System.Windows.Forms.SelectionMode.MultiSimple;
            this.lbSenate.Size = new System.Drawing.Size(236, 102);
            this.lbSenate.TabIndex = 27;
            this.lbSenate.SelectedIndexChanged += new System.EventHandler(this.lbSenate_SelectedIndexChanged);
            this.lbSenate.Click += new System.EventHandler(this.lbSenate_Click);
            // 
            // lblAcreage
            // 
            this.lblAcreage.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblAcreage.Location = new System.Drawing.Point(4, 829);
            this.lblAcreage.Name = "lblAcreage";
            this.lblAcreage.Size = new System.Drawing.Size(64, 23);
            this.lblAcreage.TabIndex = 44;
            this.lblAcreage.Text = "Acreage";
            // 
            // txtAcreage
            // 
            this.txtAcreage.Location = new System.Drawing.Point(82, 828);
            this.txtAcreage.MaxLength = 18;
            this.txtAcreage.Name = "txtAcreage";
            this.txtAcreage.Size = new System.Drawing.Size(128, 22);
            this.txtAcreage.TabIndex = 29;
            this.txtAcreage.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.txtAcreage.Leave += new System.EventHandler(this.txtAcreage_Leave);
            // 
            // lblSquareMiles
            // 
            this.lblSquareMiles.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblSquareMiles.Location = new System.Drawing.Point(233, 830);
            this.lblSquareMiles.Name = "lblSquareMiles";
            this.lblSquareMiles.Size = new System.Drawing.Size(96, 24);
            this.lblSquareMiles.TabIndex = 46;
            this.lblSquareMiles.Text = "Square Miles";
            // 
            // txtSquareMiles
            // 
            this.txtSquareMiles.Location = new System.Drawing.Point(325, 830);
            this.txtSquareMiles.MaxLength = 18;
            this.txtSquareMiles.Name = "txtSquareMiles";
            this.txtSquareMiles.Size = new System.Drawing.Size(128, 22);
            this.txtSquareMiles.TabIndex = 30;
            this.txtSquareMiles.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.txtSquareMiles.Leave += new System.EventHandler(this.txtSquareMiles_Leave);
            // 
            // txtTrailMiles
            // 
            this.txtTrailMiles.Location = new System.Drawing.Point(592, 867);
            this.txtTrailMiles.MaxLength = 18;
            this.txtTrailMiles.Name = "txtTrailMiles";
            this.txtTrailMiles.Size = new System.Drawing.Size(128, 22);
            this.txtTrailMiles.TabIndex = 35;
            this.txtTrailMiles.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.txtTrailMiles.Leave += new System.EventHandler(this.txtTrailMiles_Leave);
            // 
            // txtTrailLinearFeet
            // 
            this.txtTrailLinearFeet.Location = new System.Drawing.Point(860, 865);
            this.txtTrailLinearFeet.MaxLength = 18;
            this.txtTrailLinearFeet.Name = "txtTrailLinearFeet";
            this.txtTrailLinearFeet.Size = new System.Drawing.Size(128, 22);
            this.txtTrailLinearFeet.TabIndex = 36;
            this.txtTrailLinearFeet.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.txtTrailLinearFeet.Leave += new System.EventHandler(this.txtTrailLinearFeet_Leave);
            // 
            // txtStreamMiles
            // 
            this.txtStreamMiles.Location = new System.Drawing.Point(592, 832);
            this.txtStreamMiles.MaxLength = 18;
            this.txtStreamMiles.Name = "txtStreamMiles";
            this.txtStreamMiles.Size = new System.Drawing.Size(128, 22);
            this.txtStreamMiles.TabIndex = 31;
            this.txtStreamMiles.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.txtStreamMiles.Leave += new System.EventHandler(this.txtStreamMiles_Leave);
            // 
            // txtStreamLinearFeet
            // 
            this.txtStreamLinearFeet.Location = new System.Drawing.Point(860, 829);
            this.txtStreamLinearFeet.MaxLength = 18;
            this.txtStreamLinearFeet.Name = "txtStreamLinearFeet";
            this.txtStreamLinearFeet.Size = new System.Drawing.Size(128, 22);
            this.txtStreamLinearFeet.TabIndex = 32;
            this.txtStreamLinearFeet.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.txtStreamLinearFeet.Leave += new System.EventHandler(this.txtStreamLinearFeet_Leave);
            // 
            // lblStreamMiles
            // 
            this.lblStreamMiles.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblStreamMiles.Location = new System.Drawing.Point(496, 832);
            this.lblStreamMiles.Name = "lblStreamMiles";
            this.lblStreamMiles.Size = new System.Drawing.Size(98, 24);
            this.lblStreamMiles.TabIndex = 52;
            this.lblStreamMiles.Text = "Stream Miles";
            // 
            // label3
            // 
            this.label3.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label3.Location = new System.Drawing.Point(762, 830);
            this.label3.Name = "label3";
            this.label3.Size = new System.Drawing.Size(90, 27);
            this.label3.TabIndex = 53;
            this.label3.Text = "(Linear Feet)";
            // 
            // lblTrailMiles
            // 
            this.lblTrailMiles.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblTrailMiles.Location = new System.Drawing.Point(496, 859);
            this.lblTrailMiles.Name = "lblTrailMiles";
            this.lblTrailMiles.Size = new System.Drawing.Size(88, 32);
            this.lblTrailMiles.TabIndex = 54;
            this.lblTrailMiles.Text = "Other Trail Miles";
            // 
            // lblTrailLinear
            // 
            this.lblTrailLinear.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblTrailLinear.Location = new System.Drawing.Point(762, 866);
            this.lblTrailLinear.Name = "lblTrailLinear";
            this.lblTrailLinear.Size = new System.Drawing.Size(90, 24);
            this.lblTrailLinear.TabIndex = 55;
            this.lblTrailLinear.Text = "(Linear Feet)";
            // 
            // txtNotes
            // 
            this.txtNotes.Location = new System.Drawing.Point(82, 898);
            this.txtNotes.MaxLength = 4000;
            this.txtNotes.Multiline = true;
            this.txtNotes.Name = "txtNotes";
            this.txtNotes.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
            this.txtNotes.Size = new System.Drawing.Size(906, 54);
            this.txtNotes.TabIndex = 37;
            // 
            // lblNotes
            // 
            this.lblNotes.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblNotes.Location = new System.Drawing.Point(4, 907);
            this.lblNotes.Name = "lblNotes";
            this.lblNotes.Size = new System.Drawing.Size(88, 24);
            this.lblNotes.TabIndex = 57;
            this.lblNotes.Text = "Notes";
            // 
            // rfvName
            // 
            this.rfvName.ControlToValidate = this.txtProjectName;
            this.rfvName.ErrorMessage = "Project Name is required";
            this.rfvName.Icon = ((System.Drawing.Icon)(resources.GetObject("rfvName.Icon")));
            // 
            // btnCancel
            // 
            this.btnCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            this.btnCancel.Location = new System.Drawing.Point(580, 958);
            this.btnCancel.Name = "btnCancel";
            this.btnCancel.Size = new System.Drawing.Size(75, 23);
            this.btnCancel.TabIndex = 39;
            this.btnCancel.Text = "Cancel";
            // 
            // contextMenu1
            // 
            this.contextMenu1.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
            this.miSave,
            this.menuItem3,
            this.miRefresh,
            this.menuItem5,
            this.miClose});
            // 
            // miSave
            // 
            this.miSave.Index = 0;
            this.miSave.Text = "Save";
            this.miSave.Click += new System.EventHandler(this.miSave_Click);
            // 
            // menuItem3
            // 
            this.menuItem3.Index = 1;
            this.menuItem3.Text = "-";
            // 
            // miRefresh
            // 
            this.miRefresh.Index = 2;
            this.miRefresh.Text = "Refresh";
            this.miRefresh.Click += new System.EventHandler(this.miRefresh_Click);
            // 
            // menuItem5
            // 
            this.menuItem5.Index = 3;
            this.menuItem5.Text = "-";
            // 
            // miClose
            // 
            this.miClose.Index = 4;
            this.miClose.Text = "Close";
            this.miClose.Click += new System.EventHandler(this.miClose_Click);
            // 
            // revLatitude
            // 
            this.revLatitude.ControlToValidate = this.txtLatitude;
            this.revLatitude.ErrorMessage = "Please enter a decimal number with 2 places to the left of the decimal point and " +
                "up to 6 places to the right";
            this.revLatitude.Icon = ((System.Drawing.Icon)(resources.GetObject("revLatitude.Icon")));
            this.revLatitude.Required = false;
            this.revLatitude.ValidationExpression = "^\\d{2}(\\.\\d{1,6})?$";
            // 
            // revLongitude
            // 
            this.revLongitude.ControlToValidate = this.txtLongitude;
            this.revLongitude.ErrorMessage = "Please enter a decimal number with 3 places to the left of the decimal point and " +
                "up to 6 places to the right.";
            this.revLongitude.Icon = ((System.Drawing.Icon)(resources.GetObject("revLongitude.Icon")));
            this.revLongitude.Required = false;
            this.revLongitude.ValidationExpression = "^-?\\d{3}(\\.\\d{1,6})?$";
            // 
            // lbCity
            // 
            this.lbCity.CausesValidation = false;
            this.lbCity.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lbCity.ItemHeight = 14;
            this.lbCity.Location = new System.Drawing.Point(406, 424);
            this.lbCity.Name = "lbCity";
            this.lbCity.SelectionMode = System.Windows.Forms.SelectionMode.MultiSimple;
            this.lbCity.Size = new System.Drawing.Size(236, 88);
            this.lbCity.TabIndex = 21;
            this.lbCity.SelectedIndexChanged += new System.EventHandler(this.lbCity_SelectedIndexChanged);
            // 
            // rfvProjectNumber
            // 
            this.rfvProjectNumber.ControlToValidate = this.txtFileNumber;
            this.rfvProjectNumber.ErrorMessage = "Project Number is required";
            this.rfvProjectNumber.Icon = ((System.Drawing.Icon)(resources.GetObject("rfvProjectNumber.Icon")));
            // 
            // revProjectNumber
            // 
            this.revProjectNumber.ControlToValidate = this.txtFileNumber;
            this.revProjectNumber.ErrorMessage = "Please format project number as ##-###-##";
            this.revProjectNumber.Icon = ((System.Drawing.Icon)(resources.GetObject("revProjectNumber.Icon")));
            this.revProjectNumber.ValidationExpression = "^\\d{2}-\\d{3}-\\d{2}$";
            // 
            // rvLatitude
            // 
            this.rvLatitude.ControlToValidate = this.txtLatitude;
            this.rvLatitude.ErrorMessage = "Entry is out of range. Must be between 32.5 and 42.";
            this.rvLatitude.Icon = ((System.Drawing.Icon)(resources.GetObject("rvLatitude.Icon")));
            this.rvLatitude.MaximumValue = "42";
            this.rvLatitude.MinimumValue = "32.5";
            this.rvLatitude.Required = false;
            this.rvLatitude.Type = Genghis.Windows.Forms.ValidationDataType.Double;
            // 
            // rvLongitude
            // 
            this.rvLongitude.ControlToValidate = this.txtLongitude;
            this.rvLongitude.ErrorMessage = "Entry is out of range. Must be between -114.133333 and  -124.4";
            this.rvLongitude.Icon = ((System.Drawing.Icon)(resources.GetObject("rvLongitude.Icon")));
            this.rvLongitude.MaximumValue = "-114.133333";
            this.rvLongitude.MinimumValue = "-124.4";
            this.rvLongitude.Required = false;
            this.rvLongitude.Type = Genghis.Windows.Forms.ValidationDataType.Double;
            // 
            // label2
            // 
            this.label2.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label2.ForeColor = System.Drawing.Color.DarkGreen;
            this.label2.Location = new System.Drawing.Point(79, 229);
            this.label2.Name = "label2";
            this.label2.Size = new System.Drawing.Size(432, 16);
            this.label2.TabIndex = 59;
            this.label2.Text = "To start a new paragraph, hit CTRL and ENTER together";
            this.label2.Click += new System.EventHandler(this.label2_Click);
            // 
            // label5
            // 
            this.label5.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label5.ForeColor = System.Drawing.Color.DarkGreen;
            this.label5.Location = new System.Drawing.Point(746, 5);
            this.label5.Name = "label5";
            this.label5.Size = new System.Drawing.Size(232, 16);
            this.label5.TabIndex = 60;
            this.label5.Text = "Project Number format must be: ##-###-##";
            // 
            // lbWatershed
            // 
            this.lbWatershed.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lbWatershed.ItemHeight = 14;
            this.lbWatershed.Location = new System.Drawing.Point(82, 524);
            this.lbWatershed.Name = "lbWatershed";
            this.lbWatershed.SelectionMode = System.Windows.Forms.SelectionMode.MultiSimple;
            this.lbWatershed.Size = new System.Drawing.Size(226, 74);
            this.lbWatershed.TabIndex = 23;
            // 
            // lblWatershed
            // 
            this.lblWatershed.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblWatershed.Location = new System.Drawing.Point(4, 525);
            this.lblWatershed.Name = "lblWatershed";
            this.lblWatershed.Size = new System.Drawing.Size(80, 23);
            this.lblWatershed.TabIndex = 62;
            this.lblWatershed.Text = "Watershed";
            // 
            // lblCoastalTrailMiles
            // 
            this.lblCoastalTrailMiles.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblCoastalTrailMiles.Location = new System.Drawing.Point(4, 857);
            this.lblCoastalTrailMiles.Name = "lblCoastalTrailMiles";
            this.lblCoastalTrailMiles.Size = new System.Drawing.Size(88, 32);
            this.lblCoastalTrailMiles.TabIndex = 52;
            this.lblCoastalTrailMiles.Text = "CA Coastal Trail Miles";
            // 
            // txtCCTmiles
            // 
            this.txtCCTmiles.Location = new System.Drawing.Point(82, 864);
            this.txtCCTmiles.MaxLength = 18;
            this.txtCCTmiles.Name = "txtCCTmiles";
            this.txtCCTmiles.Size = new System.Drawing.Size(128, 22);
            this.txtCCTmiles.TabIndex = 33;
            this.txtCCTmiles.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.txtCCTmiles.Leave += new System.EventHandler(this.txtCCTmiles_Leave);
            // 
            // txtParcelNumber
            // 
            this.txtParcelNumber.Location = new System.Drawing.Point(406, 523);
            this.txtParcelNumber.MaxLength = 100;
            this.txtParcelNumber.Multiline = true;
            this.txtParcelNumber.Name = "txtParcelNumber";
            this.txtParcelNumber.Size = new System.Drawing.Size(240, 72);
            this.txtParcelNumber.TabIndex = 24;
            // 
            // lblParcelNumber
            // 
            this.lblParcelNumber.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblParcelNumber.Location = new System.Drawing.Point(318, 523);
            this.lblParcelNumber.Name = "lblParcelNumber";
            this.lblParcelNumber.Size = new System.Drawing.Size(80, 72);
            this.lblParcelNumber.TabIndex = 30;
            this.lblParcelNumber.Text = "APN/Parcel number(s)";
            // 
            // cbCurrentPM
            // 
            this.cbCurrentPM.DisplayMember = "Name";
            this.cbCurrentPM.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.cbCurrentPM.Location = new System.Drawing.Point(406, 113);
            this.cbCurrentPM.Name = "cbCurrentPM";
            this.cbCurrentPM.Size = new System.Drawing.Size(236, 24);
            this.cbCurrentPM.TabIndex = 12;
            this.cbCurrentPM.ValueMember = "ProjectManagerID";
            this.cbCurrentPM.SelectedIndexChanged += new System.EventHandler(this.cbCurrentPM_SelectedIndexChanged);
            // 
            // label4
            // 
            this.label4.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label4.Location = new System.Drawing.Point(318, 113);
            this.label4.Name = "label4";
            this.label4.Size = new System.Drawing.Size(88, 32);
            this.label4.TabIndex = 8;
            this.label4.Text = "Primary Manager";
            this.label4.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            this.label4.Click += new System.EventHandler(this.label4_Click);
            // 
            // btnNewProjectNumber
            // 
            this.btnNewProjectNumber.CausesValidation = false;
            this.btnNewProjectNumber.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.btnNewProjectNumber.Location = new System.Drawing.Point(778, 49);
            this.btnNewProjectNumber.Name = "btnNewProjectNumber";
            this.btnNewProjectNumber.Size = new System.Drawing.Size(184, 20);
            this.btnNewProjectNumber.TabIndex = 40;
            this.btnNewProjectNumber.TabStop = false;
            this.btnNewProjectNumber.Text = "Get New Project Number";
            this.btnNewProjectNumber.Click += new System.EventHandler(this.btnNewProjectNumber_Click);
            // 
            // txtCCTLinearFeet
            // 
            this.txtCCTLinearFeet.Location = new System.Drawing.Point(325, 865);
            this.txtCCTLinearFeet.MaxLength = 18;
            this.txtCCTLinearFeet.Name = "txtCCTLinearFeet";
            this.txtCCTLinearFeet.Size = new System.Drawing.Size(128, 22);
            this.txtCCTLinearFeet.TabIndex = 34;
            this.txtCCTLinearFeet.TextAlign = System.Windows.Forms.HorizontalAlignment.Right;
            this.txtCCTLinearFeet.Leave += new System.EventHandler(this.txtCCTLinearFeet_Leave);
            // 
            // label6
            // 
            this.label6.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label6.Location = new System.Drawing.Point(228, 867);
            this.label6.Name = "label6";
            this.label6.Size = new System.Drawing.Size(91, 24);
            this.label6.TabIndex = 65;
            this.label6.Text = "(Linear Feet)";
            // 
            // txtLocationDescription
            // 
            this.txtLocationDescription.Location = new System.Drawing.Point(772, 421);
            this.txtLocationDescription.MaxLength = 100;
            this.txtLocationDescription.Multiline = true;
            this.txtLocationDescription.Name = "txtLocationDescription";
            this.txtLocationDescription.Size = new System.Drawing.Size(216, 88);
            this.txtLocationDescription.TabIndex = 22;
            this.toolTip1.SetToolTip(this.txtLocationDescription, "Please enter 1-5 words that describe what the lat/long point represents. \r\n(e.g.," +
                    " culvert site, approximate center of property, park entrance, \r\ngeneric point fo" +
                    "r countywide project, etc.)\r\n");
            this.txtLocationDescription.TextChanged += new System.EventHandler(this.txtLocationDescription_TextChanged);
            // 
            // label7
            // 
            this.label7.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label7.Location = new System.Drawing.Point(667, 420);
            this.label7.Name = "label7";
            this.label7.Size = new System.Drawing.Size(87, 72);
            this.label7.TabIndex = 67;
            this.label7.Text = "Coordinates Represent";
            this.label7.Click += new System.EventHandler(this.label7_Click);
            // 
            // rbClosed
            // 
            this.rbClosed.Location = new System.Drawing.Point(316, 45);
            this.rbClosed.Name = "rbClosed";
            this.rbClosed.Size = new System.Drawing.Size(82, 24);
            this.rbClosed.TabIndex = 6;
            this.rbClosed.Text = "Closed";
            // 
            // uwdtCompletionDate
            // 
            this.uwdtCompletionDate.Location = new System.Drawing.Point(84, 75);
            this.uwdtCompletionDate.Name = "uwdtCompletionDate";
            this.uwdtCompletionDate.Size = new System.Drawing.Size(92, 24);
            this.uwdtCompletionDate.TabIndex = 8;
            this.uwdtCompletionDate.Value = null;
            this.uwdtCompletionDate.Enter += new System.EventHandler(this.uwdtCompletionDate_Enter);
            // 
            // label8
            // 
            this.label8.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label8.Location = new System.Drawing.Point(4, 69);
            this.label8.Name = "label8";
            this.label8.Size = new System.Drawing.Size(80, 37);
            this.label8.TabIndex = 69;
            this.label8.Text = "Date Completed";
            // 
            // chkIsWebSite
            // 
            this.chkIsWebSite.AutoSize = true;
            this.chkIsWebSite.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold);
            this.chkIsWebSite.Location = new System.Drawing.Point(406, 48);
            this.chkIsWebSite.Name = "chkIsWebSite";
            this.chkIsWebSite.RightToLeft = System.Windows.Forms.RightToLeft.No;
            this.chkIsWebSite.Size = new System.Drawing.Size(205, 20);
            this.chkIsWebSite.TabIndex = 7;
            this.chkIsWebSite.Text = "Include project on web map";
            this.chkIsWebSite.UseVisualStyleBackColor = true;
            // 
            // lblDD1
            // 
            this.lblDD1.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblDD1.ImageAlign = System.Drawing.ContentAlignment.TopLeft;
            this.lblDD1.Location = new System.Drawing.Point(4, 727);
            this.lblDD1.Name = "lblDD1";
            this.lblDD1.Size = new System.Drawing.Size(119, 40);
            this.lblDD1.TabIndex = 72;
            this.lblDD1.Text = "Dropdown 1";
            this.lblDD1.TextAlign = System.Drawing.ContentAlignment.TopRight;
            // 
            // lblDD2
            // 
            this.lblDD2.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblDD2.ImageAlign = System.Drawing.ContentAlignment.TopLeft;
            this.lblDD2.Location = new System.Drawing.Point(403, 727);
            this.lblDD2.Name = "lblDD2";
            this.lblDD2.Size = new System.Drawing.Size(88, 41);
            this.lblDD2.TabIndex = 73;
            this.lblDD2.Text = "Dropdown 2";
            this.lblDD2.TextAlign = System.Drawing.ContentAlignment.TopRight;
            // 
            // DynamicDD1
            // 
            this.DynamicDD1.AlwaysInEditMode = true;
            this.DynamicDD1.CheckedListSettings.CheckStateMember = "";
            this.DynamicDD1.ImeMode = System.Windows.Forms.ImeMode.Off;
            this.DynamicDD1.Location = new System.Drawing.Point(129, 727);
            this.DynamicDD1.MaxLength = 60;
            this.DynamicDD1.Name = "DynamicDD1";
            this.DynamicDD1.Size = new System.Drawing.Size(268, 25);
            this.DynamicDD1.TabIndex = 74;
            this.DynamicDD1.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(this.DynamicDD1_InitializeLayout);
            // 
            // DynamicDD2
            // 
            this.DynamicDD2.AlwaysInEditMode = true;
            this.DynamicDD2.CheckedListSettings.CheckStateMember = "";
            this.DynamicDD2.ImeMode = System.Windows.Forms.ImeMode.Off;
            this.DynamicDD2.Location = new System.Drawing.Point(499, 727);
            this.DynamicDD2.MaxLength = 60;
            this.DynamicDD2.Name = "DynamicDD2";
            this.DynamicDD2.Size = new System.Drawing.Size(149, 25);
            this.DynamicDD2.TabIndex = 10;
            this.DynamicDD2.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(this.DynamicDD2_InitializeLayout);
            // 
            // DynamicLB1
            // 
            this.DynamicLB1.ItemHeight = 16;
            this.DynamicLB1.Location = new System.Drawing.Point(772, 725);
            this.DynamicLB1.Name = "DynamicLB1";
            this.DynamicLB1.SelectionMode = System.Windows.Forms.SelectionMode.MultiSimple;
            this.DynamicLB1.Size = new System.Drawing.Size(218, 68);
            this.DynamicLB1.TabIndex = 76;
            // 
            // lblMultiselect1
            // 
            this.lblMultiselect1.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblMultiselect1.Location = new System.Drawing.Point(654, 725);
            this.lblMultiselect1.Name = "lblMultiselect1";
            this.lblMultiselect1.Size = new System.Drawing.Size(112, 40);
            this.lblMultiselect1.TabIndex = 75;
            this.lblMultiselect1.Text = "Multi-select 1";
            this.lblMultiselect1.TextAlign = System.Drawing.ContentAlignment.TopRight;
            // 
            // ProjectCreateOrUpdate
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(6, 15);
            this.AutoScroll = true;
            this.AutoSizeMode = System.Windows.Forms.AutoSizeMode.GrowAndShrink;
            this.CancelButton = this.btnCancel;
            this.ClientSize = new System.Drawing.Size(1026, 1058);
            this.ContextMenu = this.contextMenu1;
            this.Controls.Add(this.DynamicLB1);
            this.Controls.Add(this.lblMultiselect1);
            this.Controls.Add(this.DynamicDD2);
            this.Controls.Add(this.DynamicDD1);
            this.Controls.Add(this.lblDD2);
            this.Controls.Add(this.lblDD1);
            this.Controls.Add(this.chkIsWebSite);
            this.Controls.Add(this.label8);
            this.Controls.Add(this.uwdtCompletionDate);
            this.Controls.Add(this.rbClosed);
            this.Controls.Add(this.label7);
            this.Controls.Add(this.txtLocationDescription);
            this.Controls.Add(this.label6);
            this.Controls.Add(this.txtCCTLinearFeet);
            this.Controls.Add(this.btnNewProjectNumber);
            this.Controls.Add(this.cbCurrentPM);
            this.Controls.Add(this.lbWatershed);
            this.Controls.Add(this.lblWatershed);
            this.Controls.Add(this.label5);
            this.Controls.Add(this.label2);
            this.Controls.Add(this.lbCity);
            this.Controls.Add(this.btnCancel);
            this.Controls.Add(this.txtStreamLinearFeet);
            this.Controls.Add(this.txtFileNumber);
            this.Controls.Add(this.txtNotes);
            this.Controls.Add(this.txtStreamMiles);
            this.Controls.Add(this.txtTrailLinearFeet);
            this.Controls.Add(this.txtTrailMiles);
            this.Controls.Add(this.txtSquareMiles);
            this.Controls.Add(this.txtAcreage);
            this.Controls.Add(this.txtLongitude);
            this.Controls.Add(this.txtLatitude);
            this.Controls.Add(this.txtProjectName);
            this.Controls.Add(this.txtDescription);
            this.Controls.Add(this.txtSummary);
            this.Controls.Add(this.txtCCTmiles);
            this.Controls.Add(this.txtParcelNumber);
            this.Controls.Add(this.lblNotes);
            this.Controls.Add(this.lblTrailLinear);
            this.Controls.Add(this.lblTrailMiles);
            this.Controls.Add(this.label3);
            this.Controls.Add(this.lblStreamMiles);
            this.Controls.Add(this.lblSquareMiles);
            this.Controls.Add(this.lblAcreage);
            this.Controls.Add(this.lbSenate);
            this.Controls.Add(this.lbAssembly);
            this.Controls.Add(this.lbCongressional);
            this.Controls.Add(this.lblCongressional);
            this.Controls.Add(this.btnSave);
            this.Controls.Add(this.lblSenate);
            this.Controls.Add(this.lblAssembly);
            this.Controls.Add(this.lblLongitude);
            this.Controls.Add(this.lblLatitude);
            this.Controls.Add(this.lbRegion);
            this.Controls.Add(this.lblRegion);
            this.Controls.Add(this.lbCounty);
            this.Controls.Add(this.lblCounty);
            this.Controls.Add(this.lblCity);
            this.Controls.Add(this.lblProjectName);
            this.Controls.Add(this.rbComplete);
            this.Controls.Add(this.rbInactive);
            this.Controls.Add(this.rbActive);
            this.Controls.Add(this.label1);
            this.Controls.Add(this.lbProjectType);
            this.Controls.Add(this.lblProjectType);
            this.Controls.Add(this.lbProgramType);
            this.Controls.Add(this.lblProgramType);
            this.Controls.Add(this.lblDescription);
            this.Controls.Add(this.lblSummary);
            this.Controls.Add(this.lbAttorney);
            this.Controls.Add(this.lblAttorney);
            this.Controls.Add(this.lbStaff);
            this.Controls.Add(this.lblStaff);
            this.Controls.Add(this.lblFileNumber);
            this.Controls.Add(this.lblCoastalTrailMiles);
            this.Controls.Add(this.lblParcelNumber);
            this.Controls.Add(this.label4);
            this.Font = new System.Drawing.Font("Arial", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.Name = "ProjectCreateOrUpdate";
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
            this.Load += new System.EventHandler(this.ProjectCreateOrUpdate_Load_1);
            this.Closing += new System.ComponentModel.CancelEventHandler(this.ProjectCreateOrUpdate_Closing);
            ((System.ComponentModel.ISupportInitialize)(this.rfvName)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.revLatitude)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.revLongitude)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.rfvProjectNumber)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.revProjectNumber)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.rvLatitude)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.rvLongitude)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.uwdtCompletionDate)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.DynamicDD1)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.DynamicDD2)).EndInit();
            this.ResumeLayout(false);
            this.PerformLayout();

		}
		#endregion

		private void ProjectCreateOrUpdate_Load(object sender, System.EventArgs e)
		{
            blnDataLoaded = false;
            
            PopulateLists();

			if(IsUpdateMode) //Default for general info update.
			{
				SetUpdateDisplay();
			}
            else if (IsCopyMode)//Copy from selected project.
            {
                SetCopyDisplay(); 
                this.rbActive.Checked = true;

            }
			else//Default for new project.
			{
				this.rbActive.Checked = true;
			}
			
			this.Refresh();
            blnDataLoaded = true;

		}


		private void btnSave_Click(object sender, System.EventArgs e)
		{
			string msg = "Do you want to save changes?";
			//DialogResult doSave = MessageBox.Show("Click Yes to save; Click No to close without saving. ", "Do you want to save Changes?", MessageBoxButtons.YesNo, MessageBoxIcon.Warning);

			DialogResult doSave = MessageBox.Show(this, msg, "Save Confirmation", MessageBoxButtons.YesNo, MessageBoxIcon.Warning);
			if(doSave == DialogResult.Yes)
			{
				if(ValidateForm())
				{
					bool success = this.UpdateOrInsertRecord();
					if(success)
					{
						saved = true;
						// Returns OK result to calling routine, so that it knows to open
						// the project form with the newly added record. 
						this.DialogResult = DialogResult.OK;  
						this.Close();
					}
					else
					{
						// MAR 2005-02-01 added failure message
						MessageBox.Show(this, "The application was unable to successfully save the changes to the database.","Warning", MessageBoxButtons.OK,MessageBoxIcon.Error );
						//Concept rejected by CC; replaced by record locking
//						string message = string.Concat(
//							"Another user has updated this project since you opened it for editing! \n",
//							"Here are the steps to take: \n",
//							"1.You will not be able to save your work so if you have made substantial edits you may want to copy them to another program like Note Pad. \n",
//							"2.Right click the edit window and choose \"Refresh\" to view the changes made by the other user. Then make your updates as usual.\n",
//							"3.Close the edit window you are working with, right click the general information display and choose \"Refresh\" to view the changes made by the other user.");
//						MessageBox.Show(this, message, "Record has Chnaged!", MessageBoxButtons.OK);
					}
				}
				else
				{
					string errorMsg = "Some of the entries you made are not valid!\nIn your review of the form you will see\nred icons to the right of fields that\nhave invalid input.";
					MessageBox.Show(errorMsg, "Validation Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
				}
			}
		}

		// MAR 2005-02-01 - pulled valudation logic out of btnSave_Click()
		private bool ValidateForm()
		{
			// this is called by btnSave_Click() and ProjectCreateOrUpdate_Closing()

			bool isValid = true;

			//Validate the items lowest on the page first so that the last item that is found invalid will be the 
			//item highest on the form.
			//Prevent the form from scrolling down when controls get focus.
            this.VScroll = false;
            foreach (Control cntrl in this.Controls)
            {
                try
                {
                    if (cntrl.GetType() != typeof(RadioButton))
                    {
                        switch  (cntrl.Name)
                        {
                            case "txtAcerage":
                                break;
                            case "txtSquareMiles":
                                break;
                            case "txtStreamLinearFeet":
                                break;
                            case "txtStreamMiles": 
                                break;
                            case "txtTrailLinearFeet":
                                break; 
                            case "txtTrailMiles": 
                                break;
                            case "txtCCTmiles": 
                                break;
                            case "txtCCTLinearFeet": 
                                break;
                            case "": 
                                break;
                            default:
                                cntrl.Focus();
                                break;
                        }
                    }
                }
                catch { }
            }
            this.VScroll = true;

		
            //if(! rvLatitude.IsValid)
            //{
            //    txtLatitude.Focus();
            //    isValid = false;
            //}
            //if(! revLatitude.IsValid)
            //{
            //    txtLatitude.Focus();
            //    isValid = false;
            //}

            //if(! revLongitude.IsValid)
            //{
            //    txtLongitude.Focus();
            //    isValid = false;
            //}
            //if(! rvLongitude.IsValid)
            //{
            //    txtLongitude.Focus();
            //    isValid = false;
            //}
				
			if( ! rfvProjectNumber.IsValid)
			{
				txtFileNumber.Focus();
				isValid = false;
			}

			if( ! ProjectData.ProjectFileNumberIsUnuique(txtFileNumber.Text, projectId))
			{
				MessageBox.Show("Project number is not unique!\nPlease revise your input.",
					"Project Number Not Unique", MessageBoxButtons.OK, MessageBoxIcon.Error);				
				isValid = false;

				// MAR 2005-07-26 - this is a cludgy way to make the little red validator
				//                  icon show. 
				string wasFileNumber = txtFileNumber.Text;
				txtFileNumber.Text = txtFileNumber.Text + "?";
				txtFileNumber.Focus();
				this.SelectNextControl(this.txtFileNumber, true, true, true, true);
				txtFileNumber.Text = wasFileNumber;
			}

			if( ! revProjectNumber.IsValid)
			{
				txtFileNumber.Focus();
				isValid = false;
			}

			if(! rfvName.IsValid)
			{
				txtProjectName.Focus();
				isValid = false;
			}


			return isValid;
		}

		private void miSave_Click(object sender, System.EventArgs e)
		{
			btnSave_Click(this, EventArgs.Empty);
		}


		private void miRefresh_Click(object sender, System.EventArgs e)
		{
			this.SetUpdateDisplay();
		}


		private void miClose_Click(object sender, System.EventArgs e)
		{
			this.Close();
		}

		private void txtLongitude_TextChanged(object sender, System.EventArgs e)
		{
			//Mask input as a negative number
			//TODO: Unhook TextChanged event so it does not run twice if the condition is met.
			Regex regex = new Regex("^-.*");
			if( ! regex.IsMatch(txtLongitude.Text))
			{
				txtLongitude.Text = txtLongitude.Text.Insert(0, "-");
				txtLongitude.AppendText(string.Empty);
			}
		}
		//Prompt user to save incase they did not see the save button and assume they can close
		//the window to save their changes.
		private void ProjectCreateOrUpdate_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			if( ! saved)
			{

				DialogResult dialogResult = MessageBox.Show(this, "Do you want to save changes?", "Save Confirmation", MessageBoxButtons.YesNo , MessageBoxIcon.Warning);
				if(dialogResult == DialogResult.Yes)
				{
					//e.Cancel = true;
					//this.btnSave_Click(this.btnSave, EventArgs.Empty);
					if(ValidateForm())
					{
						bool success = this.UpdateOrInsertRecord();
						if(!success)
						{
							MessageBox.Show(this, "The application was unable to successfully save the changes to the database.","Warning", MessageBoxButtons.OK,MessageBoxIcon.Error );
						}
						else
						{
							this.DialogResult = DialogResult.OK;  

							//try
							//ProjectForm.RefreshProjectPage();
							//catch

						}
					}
					else
					{
						string errorMsg = "Some of the entries you made are not valid!\nIn your review of the form you will see\nred icons to the right of fields that\nhave invalid input.";
						MessageBox.Show(errorMsg, "Validation Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
						e.Cancel = true;
					}
				}
				else	// ADS 25-Jan-2008 - Added cancel dialog result
				{
					this.DialogResult= DialogResult.Cancel;
				}
			}
		}

		private void lbStaff_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			if( lbStaff.SelectedIndices.Count == 1 )
			{
				cbCurrentPM.Items.Clear();
				cbCurrentPM.Items.Add( lbStaff.Items[lbStaff.SelectedIndices[0]]);
				cbCurrentPM.SelectedIndex=0;
			}
			else if( lbStaff.SelectedIndices.Count > 1 )
			{
				string current = cbCurrentPM.Text;
				int selectedIdx = 0;

				cbCurrentPM.Items.Clear();

				for( int idx = 0; idx < lbStaff.SelectedIndices.Count; idx++ )
				{
					object item = lbStaff.Items[lbStaff.SelectedIndices[idx]];
					cbCurrentPM.Items.Add( item );

					if( lbStaff.GetItemText( item ) == current )
					{
						selectedIdx = idx;
					}
				}

				cbCurrentPM.SelectedIndex = selectedIdx;
			}
			else
			{
				cbCurrentPM.Items.Clear();
				cbCurrentPM.Text = string.Empty;
			}
		}

		private void btnNewProjectNumber_Click(object sender, System.EventArgs e)
		{
			string partA = DateTime.Now.Year.ToString().Substring( 2, 2 );
			int nextKey = ProjectData.GetNextProjectNumber();
		
			this.txtFileNumber.Text = string.Format( "{0}-{1:d3}-01", partA, nextKey );
		}

        private void txtCCTmiles_Leave(object sender, EventArgs e)
        {
            TextBoxNumeric((TextBox)sender);
            SetMilesFeet(txtCCTmiles, txtCCTLinearFeet, false);
        }

        private void SetMilesFeet(TextBox txtMile, TextBox txtFeet, bool isFeet)
        {
            decimal miles = 0;
            decimal feet = 0;
            if (isFeet)
            {
                feet = ParseDecimal(txtFeet.Text);
                miles = Math.Round((feet / 5280m), 2);
            }
            else
            {
                miles = ParseDecimal(txtMile.Text);
                feet = Math.Round((miles * 5280m), 2);
            }
            txtFeet.Text = feet.ToString("0.00");
            txtMile.Text = miles.ToString("0.00");
        }

        
        private void TextBoxNumeric(TextBox txt)
        {
            string patern = @"[^0-9\.]*";
            txt.Text = System.Text.RegularExpressions.Regex.Replace(txt.Text, patern, string.Empty);
        }

        private void txtCCTLinearFeet_Leave(object sender, EventArgs e)
        {
            TextBoxNumeric((TextBox)sender);
            SetMilesFeet(txtCCTmiles, txtCCTLinearFeet, true);
        }

        private void txtTrailLinearFeet_Leave(object sender, EventArgs e)
        {
            TextBoxNumeric((TextBox)sender);
            SetMilesFeet(txtTrailMiles, txtTrailLinearFeet, true);
        }

        private void txtTrailMiles_Leave(object sender, EventArgs e)
        {
            TextBoxNumeric((TextBox)sender);
            SetMilesFeet(txtTrailMiles, txtTrailLinearFeet, false);
        }

        private void txtStreamMiles_Leave(object sender, EventArgs e)
        {
            TextBoxNumeric((TextBox)sender);
            SetMilesFeet(txtStreamMiles, txtStreamLinearFeet, false);
        }

        private void txtStreamLinearFeet_Leave(object sender, EventArgs e)
        {
            TextBoxNumeric((TextBox)sender);
            SetMilesFeet(txtStreamMiles, txtStreamLinearFeet, true);
        }

        private void SetAcreSqMile(TextBox txtAcre, TextBox txtSqMile, bool isMile)
        {
            decimal acre = 0;
            decimal sqmile = 0;
            if (isMile)
            {
                if (GlobalCode.ToString(txtSqMile.Text) == txtSqMile.Tag.ToString())
                    return;
                sqmile = ParseDecimal(txtSqMile.Text);
                acre = Math.Round((sqmile * 640m), 2);
            }
            else
            {
                if (GlobalCode.ToString(txtAcre.Text) == GlobalCode.ToString(txtAcre.Tag))
                    return;
                acre = ParseDecimal(txtAcre.Text);
                sqmile = Math.Round((acre / 640m), 2);
            }
            txtAcre.Text = acre.ToString("0.00");
            txtAcre.Tag = txtAcre.Text;
            txtSqMile.Text = sqmile.ToString("0.00");
            txtSqMile.Tag = txtSqMile.Text;
        }

        private void txtAcreage_Leave(object sender, EventArgs e)
        {
            TextBoxNumeric((TextBox)sender);
            SetAcreSqMile(txtAcreage, txtSquareMiles, false);
        }

        private void txtSquareMiles_Leave(object sender, EventArgs e)
        {
           TextBoxNumeric((TextBox)sender);
            SetAcreSqMile(txtAcreage, txtSquareMiles, true);
        }

        private void lbAssembly_Click(object sender, EventArgs e)
        {
            if (lbAssembly.SelectedItems.Count == 0)
                blnSkip = true;
        }

        private void lbAssembly_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (blnSkip == true)
            {
                blnSkip = false;
                if (lbAssembly.SelectedIndex == 0)
                    lbAssembly.SetSelected(0, false);
            }
        }

        private void lbSenate_Click(object sender, EventArgs e)
        {
            if (lbSenate.SelectedItems.Count == 0)
                blnSkip = true;
        }

        private void lbSenate_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (blnSkip == true)
            {
                blnSkip = false;
                if (lbSenate.SelectedIndex == 0)
                    lbSenate.SetSelected(0, false);
            }
        }

        private void lbCongressional_Click(object sender, EventArgs e)
        {
            if (lbCongressional.SelectedItems.Count == 0)
                blnSkip = true;
        }

        private void lbCongressional_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (blnSkip == true)
            {
                blnSkip = false;
                if (lbCongressional.SelectedIndex == 0)
                    lbCongressional.SetSelected(0, false);
            }
        }


        private void cbCurrentPM_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (blnDataLoaded == true)
            {
                string[] fitlerKey = { Convert.ToString(projectId)};
                string[] updateKey = { ((DataRowView)cbCurrentPM.Items[cbCurrentPM.SelectedIndex])["ProjectManagerID"].ToString(), cbCurrentPM.Text};

                GridEdit ge = new GridEdit("ProjectContractsManagers", txtProjectName.Text, false, false, false, fitlerKey,updateKey);
                ge.Show(this);

            }
        }

        private void lblStaff_Click(object sender, EventArgs e)
        {

        }

        private void lblAttorney_Click(object sender, EventArgs e)
        {

        }

        private void label4_Click(object sender, EventArgs e)
        {

        }

        private void lblSummary_Click(object sender, EventArgs e)
        {

        }

        private void txtSummary_TextChanged(object sender, EventArgs e)
        {

        }

        private void label2_Click(object sender, EventArgs e)
        {

        }

        private void lblDescription_Click(object sender, EventArgs e)
        {

        }

        private void txtDescription_TextChanged(object sender, EventArgs e)
        {

        }

        private void lblProgramType_Click(object sender, EventArgs e)
        {

        }

        private void lbProgramType_SelectedIndexChanged(object sender, EventArgs e)
        {

        }

        private void lblProjectType_Click(object sender, EventArgs e)
        {

        }

        private void lbProjectType_SelectedIndexChanged(object sender, EventArgs e)
        {

        }

        private void txtLatitude_TextChanged(object sender, EventArgs e)
        {

        }

        private void lblLongitude_Click(object sender, EventArgs e)
        {

        }

        private void lblLatitude_Click(object sender, EventArgs e)
        {

        }

        private void lbCounty_SelectedIndexChanged(object sender, EventArgs e)
        {

        }

        private void label7_Click(object sender, EventArgs e)
        {

        }

        private void txtLocationDescription_TextChanged(object sender, EventArgs e)
        {

        }

        private void lbCity_SelectedIndexChanged(object sender, EventArgs e)
        {

        }

        private void lbAttorney_SelectedIndexChanged(object sender, EventArgs e)
        {

        }

        private void lblCounty_Click(object sender, EventArgs e)
        {

        }

        private void lblCity_Click(object sender, EventArgs e)
        {

        }

        private void uwdtCompletionDate_Enter(object sender, EventArgs e)
        {
            uwdtCompletionDate.SelectAll();
        }

        private void DynamicDD1_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {

            // Hide columns that you dont want displayed in the drop down. 
            this.DynamicDD1.DisplayLayout.Bands[0].ColHeadersVisible = false;
            this.DynamicDD1.DisplayLayout.Bands[0].Columns[0].Hidden = true;
            this.DynamicDD1.DisplayLayout.Bands[0].Columns[1].Hidden = true;
            this.DynamicDD1.DisplayLayout.Bands[0].Columns[2].Hidden = true;
            this.DynamicDD1.DisplayLayout.Bands[0].Columns[3].Hidden = false;
            this.DynamicDD1.DisplayLayout.Bands[0].Columns[3].Width = this.DynamicDD1.Width ;

            // Set the scroll style to immediate so when the user scrolls the drop down  
            // using scroll thumb, rows get scrolled imediately. 
            this.DynamicDD1.DisplayLayout.ScrollStyle = ScrollStyle.Immediate;  

        }

        private void DynamicDD2_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            // Hide columns that you dont want displayed in the drop down. 
            this.DynamicDD2.DisplayLayout.Bands[0].ColHeadersVisible = false;
            this.DynamicDD2.DisplayLayout.Bands[0].Columns[0].Hidden = true;
            this.DynamicDD2.DisplayLayout.Bands[0].Columns[1].Hidden = true;
            this.DynamicDD2.DisplayLayout.Bands[0].Columns[2].Hidden = true;
            this.DynamicDD2.DisplayLayout.Bands[0].Columns[3].Hidden = false;
            this.DynamicDD2.DisplayLayout.Bands[0].Columns[3].Width = this.DynamicDD2.Width;

            // Set the scroll style to immediate so when the user scrolls the drop down  
            // using scroll thumb, rows get scrolled imediately. 
            this.DynamicDD2.DisplayLayout.ScrollStyle = ScrollStyle.Immediate;  

        }

        private void ProjectCreateOrUpdate_Load_1(object sender, EventArgs e)
        {

        }


	}
}
