using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using CCPM.Data;
using System.Data;

namespace CCPM.Project
{
	/// <summary>
	/// Provides the tabbed interface for projects and displays
	/// project general information.
	/// </summary>
	public class ProjectForm : System.Windows.Forms.Form
	{
		#region Class Fields

        private DataRow drProject = null;
		private DataSet dsProject = null;
		private DataSet dsGrantee = null;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.MenuItem miEditProject;
		private System.Windows.Forms.MenuItem miProjectUpdateClose;
		private System.Windows.Forms.ContextMenu generalInfoContextMenu;
		private System.Windows.Forms.MenuItem menuItem3;
		private System.Windows.Forms.MenuItem miGeneralInfoRefresh;
		private int projectId = 0;
		private string projectName = string.Empty;
		private string fileNumber = string.Empty;
        private int currentTabIndex = 0;
		private CCPM.Contact.MasterDetailControl mdc = null;
        private CCPM.Contact.MasterContacts mc = null;
		private System.Windows.Forms.ContextMenu contextMenu1;
		private System.Windows.Forms.MenuItem miAuthorization;
		private System.Windows.Forms.MenuItem miAddAuthorization;
		private System.Windows.Forms.MenuItem miEditAuthorization;
		private System.Windows.Forms.MenuItem menuItem4;
		private System.Windows.Forms.MenuItem miDeleteAuthorization;
		private System.Windows.Forms.MenuItem menuItem1;
		private System.Windows.Forms.MenuItem miMatchingFund;
		private System.Windows.Forms.MenuItem miAddMatchingFund;
		private System.Windows.Forms.MenuItem miEditMatchingFund;
		private System.Windows.Forms.MenuItem menuItem2;
		private System.Windows.Forms.MenuItem miDeleteMatchingFund;
		private CCPM.Project.Authorizations funding = null;
		// MAR 2005-03-05 - added MatchingFunds
		private CCPM.Project.MatchingFunds MatchingFunds = null;
        private CCPM.Project.StrategicObjectives Objectives = null;
		private CCPM.ProjectImages.Images images = null;
		private CCPM.Report.ReportList reportList = null;
        private CCPM.Links.LinkList linkList = null;
		private CCPM.RelatedProjects.RelatetProjectList relatedProjectList = null;
        private CCPM.Contract.Contracts contract = null;
		// use names instead of numbers for tabbed pages
		private const int tabGeneral = 0;
		private const int tabContacts = 1;
		private const int tabObjectives = 2;
		private const int tabFunding = 3;
		//private const int tabMatchingFunds = 4;
        private const int tabContract = 4;
		private const int tabImages = 5;
		private const int tabLinks = 6;
		private const int tabRelatedProjects = 7;
        private TabPage reportsPage;
        private TabPage relatedProjectPage;
        private TabPage linksPage;
        private TabPage imagesPage;
        private TabPage fundingTab;
        private TabPage objectivesPage;
        private TabPage ContactsPage;
        private TabPage ProjectPage;
        private TabControl tabControl1;
        private TabPage contractTab;
        private TextBox lblScroll;
		private const int tabReport = 8;


		#endregion
		#region Properties
		public int ProjectId
		{
			get{return projectId;}
			set{projectId = value;}
		}

		public string ProjectName
		{
			get{return projectName;}
			set{projectName = value;}
		}
		public string FileNumber
		{
			get{return fileNumber;}
			set{fileNumber = value;}
		}

        public CCPM.Contact.MasterContacts GetMasterContacts
        {
            get { return mc; }
        }

		public CCPM.Contact.MasterDetailControl GetMasterDetailControl
		{
			get{return mdc;}
		}

		//Retrun an instance of the Funding User control
		public CCPM.Project.Authorizations FundingControl
		{
			get{return funding;}
		}
		//Return an instance of ProjectImage.Image User control
		public CCPM.ProjectImages.Images ImagesControl
		{
			get{return images;}
		}
		//Return an instance of the LinkList User control
		public CCPM.Links.LinkList LinkListControl
		{
			get{return linkList;}
		}

		// ADS 15-Nov-2007 - Added call to ensure the control is initialized
		//Return an instance of the RelatedProjectList User Control
		public CCPM.RelatedProjects.RelatetProjectList RelatedProjectListControl
		{
			get
			{
				EnsureRelatedListIsInitialized();
				return relatedProjectList;
			}
		}
		#endregion
		public ProjectForm(int projectId)
		{
			this.projectId = projectId;
			GlobalSettings.projectId = projectId;   // MAR 2005-02-21
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			SetDisplay();
			VerifyLinks();
			
		}

		private void SetDisplay()
		{
			dsProject = CCPM.Data.ProjectData.GetProject(projectId);
            if (dsProject.Tables["Project"].Rows.Count == 0)
            {
                MessageBox.Show("Error loading project", "Invalid Project", MessageBoxButtons.OK, MessageBoxIcon.Error);
                this.Close();
                return;
            }

			drProject = dsProject.Tables["Project"].Rows[0];
			ProjectName = (string)drProject["ProjectName"];
			FileNumber = (string)drProject["FileNumber"];

           
            //dsGrantee = CCPM.Data.ProjectData.GetContactTypeByProject(projectId, 1); // 1 = grantee type
            dsGrantee = CCPM.Data.ProjectData.GetProjectGrantees(projectId);

			//Window name
			this.Text = ProjectName;
			//tracks the acumulated y position as text is added to the screen.
			int verticalPosition = 0;

			//Vertical space between items
			int vSpaceLarge = 5;
			int vSpaceSmall = 0;
			int lblHeight;
			int lblWidth = 130;
			
			//Margin and indent
			int leftMargin = 20;
			int indent = leftMargin + lblWidth;
			int copyWidth = 700;
			int colTwoWidth = copyWidth - indent;

            int leftMargin2 = 500;
            int indent2 = leftMargin2 + lblWidth;
            int leftMargin3 = 750;
            int indent3 = leftMargin3 + lblWidth +70;
            int x = 0;
			int y = 0;
			
			ArrayList labels = new ArrayList();

			Graphics g = this.CreateGraphics();
			Size size;
			
			//Don't know how to release the resources for these two fonts
			//without breaking at runtime.
			// ADS - Fonts are used by form controls for redraw.
			//	Better to make them once as private fields than re-create them for each refresh.
			//	Disposal should go in form Dispose method
			Font lblFont = new Font("Arial", 10f, FontStyle.Bold);
			Font bodyFont = new Font("Arial", 10f, FontStyle.Regular);

            //Edit button
            Button editBtn = new Button();
            editBtn.Text = "Edit General Information";
            x = leftMargin;
            y = verticalPosition += vSpaceLarge; 
            editBtn.Width = 200;
            Font btnFont = new Font("Microsoft Sans Serif", 10f, FontStyle.Regular);
            editBtn.Font = btnFont;
            Point p = new Point(x, y);
            editBtn.Location = p;
            editBtn.BackColor = Color.LightGray;
            editBtn.ForeColor = Color.Black;
            editBtn.Click += new EventHandler(editBtn_Click);
            
            //Project Name
			string nameLbl = "Project Name:";
			x = leftMargin;
			//y = (verticalPosition += vSpaceLarge);
            y = verticalPosition += vSpaceLarge + 25;
            size = GetLabelSize(nameLbl, lblFont, lblWidth, g);
			lblHeight = size.Height; //only to need to set once since all labels are the same height
			labels.Add(LabelFactory("lblName", nameLbl, lblFont, size, x, y));

			string name = ProjectName;
			x = indent;
			size = GetLabelSize(name, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("name", name, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;

			//File Number
			string fileNumberLbl = "Project Number: ";
			x = leftMargin;
			y = (verticalPosition += vSpaceLarge);
			size = GetLabelSize(fileNumberLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("fileNumberLbl", fileNumberLbl, lblFont, size, x, y));
			
			string fileNumber = FileNumber;
			x = indent;
			size = GetLabelSize(fileNumber, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("fileNumber", fileNumber, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;
			
			//Status
			string statusLbl = "Status:";
			x = leftMargin;
			y = (verticalPosition += vSpaceLarge);
			size = GetLabelSize(statusLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblStatus", statusLbl, lblFont, size, x, y));

			string status = string.Empty;
			switch((int)drProject["StatusId"])
			{
				case 0 :
					status = "Active";
					break;
				case 1 :
					status = string.Format("Inactive - Marked inactive on {0:d}", drProject["StatusDate"]);
					break;
				case 2 :
					status = string.Format("Complete - Marked complete on {0:d}",  drProject["StatusDate"]);
					break;
                case 3:
                    status = string.Format("Closed - Marked closed on {0:d}", drProject["StatusDate"]);
                    break;
            }

			x = indent;
			size = GetLabelSize(status, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("status", status, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;

            //Completion Date
            string dateCompletedLbl = "Date Completed:";
            x = leftMargin2;
            size = GetLabelSize(dateCompletedLbl, lblFont, lblWidth, g);
            labels.Add(LabelFactory("lblDateCompleted", dateCompletedLbl, lblFont, size, x, y));

            string CompletionDate = string.Empty;
            CompletionDate = string.Format("{0:d}",drProject["DateCompleted"]);
            x = indent2;
            size = GetLabelSize(CompletionDate, bodyFont, colTwoWidth, g);
            labels.Add(LabelFactory("DateCompleted", CompletionDate, bodyFont, size, x, y));              
             
            //Website
            string websiteLbl = "Include project on web map: ";
            x = leftMargin3;
            size = GetLabelSize(websiteLbl, lblFont, colTwoWidth, g);
            labels.Add(LabelFactory("lblIsWebsite", websiteLbl, lblFont, size, x, y));

            string isWebsite = string.Empty;
            switch ((bool)drProject["IsWebsite"])
            {
                case true:
                    isWebsite = "Yes";
                    break;
                case false:
                    isWebsite = "";
                    break;
            }
            x = indent3;
            size = GetLabelSize(isWebsite, bodyFont, colTwoWidth, g);
            labels.Add(LabelFactory("chkIsWebsite", isWebsite, bodyFont, size, x, y));

           
            //Project staff
			string staffLbl = "Project Manager: ";
			x = leftMargin;
			y = (verticalPosition += vSpaceLarge);
			size = GetLabelSize(staffLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblStaff", staffLbl, lblFont, size, x, y));

			// ADS 9-Nov-2007 - Identify the current primary project manager by font change
			// Current PM
			DataTable dtStaff = dsProject.Tables["ProjectManager"];
			x = indent;
			string staff = string.Empty;

			if( drProject.Table.Columns.Contains( "CurrentPM" ) && ( drProject["CurrentPM"] != DBNull.Value ) )
			{
				foreach( DataRow dr in dtStaff.Rows )
				{
					if( (int)dr["ProjectManagerID"] == (int)drProject["CurrentPM"] )
					{
						Font boldBody = new Font( bodyFont, FontStyle.Bold );
						string pmName = dr["Name"].ToString().Trim() + (( dtStaff.Rows.Count > 1 ) ? "," : string.Empty );
						size = GetLabelSize( pmName, boldBody, colTwoWidth, g );
						labels.Add( LabelFactory( "currentPM", pmName, boldBody, size, x, y ) );
						x += size.Width;
						break;
					}
				}
			}

			// Everyone else
			foreach( DataRow dr in dtStaff.Rows )
			{
				if( ( drProject["CurrentPM"] == DBNull.Value ) || ( (int)dr["ProjectManagerID"] != (int)drProject["CurrentPM"] ) )
				{
					staff = string.Concat(staff, staff == string.Empty ? string.Empty : ", ", (string)dr["Name"]);
				}
			}
			//x = size.Width + leftMargin;
			size = GetLabelSize(staff, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("staff", staff, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;
			
            //Contract Manager
            //string contractManagerLbl = "Proj Contract Mgr: ";
            //x = leftMargin;
            //y = (verticalPosition += vSpaceLarge);
            //size = GetLabelSize(contractManagerLbl, lblFont, lblWidth, g);
            //labels.Add(LabelFactory("contractManagerLbl", contractManagerLbl, lblFont, size, x, y));

            //DataRow drCM = dsProject.Tables["ContractManager"].Rows[0];
            //string contractManager = drCM[0].ToString();
            //x = indent;
            //size = GetLabelSize(contractManager, bodyFont, colTwoWidth, g);
            //labels.Add(LabelFactory("contractManager", contractManager, bodyFont, size, x, y));
            //verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;

			//Attorney
			string attorneyLbl = "Attorney: ";
			x = leftMargin;
			y = (verticalPosition += vSpaceLarge);
			size = GetLabelSize(attorneyLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblAttorney", attorneyLbl, lblFont, size, x, y));
			
			string attorney = string.Empty;
			DataTable dtAttorney = dsProject.Tables["ProjectAttorney"];
			foreach(DataRow dr in dtAttorney.Rows)
			{
				attorney = string.Concat(attorney, attorney == string.Empty? string.Empty : ", ", (string)dr["Name"]);
			}
			x = indent;
			size = GetLabelSize(attorney, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("attorney", attorney, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;

			// ADS - 14-Dec-2007 - Totals
			// SAO - moved totals in between Attorney and Summary per KG; modified masks
			string label = "Conservancy Contribution: ";
			x = leftMargin;
			y = verticalPosition += vSpaceLarge;
			size = GetLabelSize(label, lblFont, lblWidth * 2, g);
			labels.Add(LabelFactory("lbltotalContribution", label, lblFont, size, x, y));

			decimal totalContribution = ProjectFundingData.GetFundTotal( projectId, "N" );
			string total = totalContribution.ToString("$###,###,###.00"); // string.Format("${0:#.##;;}", totalContribution );
			x = indent * 2 - 50;
			size = GetLabelSize(total, bodyFont, colTwoWidth, g);
            Label lbl = LabelFactory("totalContribution", total, bodyFont, size, x, y);
            lbl.Width = 110;
            lbl.TextAlign = ContentAlignment.BottomRight;
			labels.Add(lbl);
            verticalPosition += size.Height == 0 ? lblHeight : size.Height;

			label = "Matching Funds: ";
			x = leftMargin;
			y = verticalPosition += vSpaceLarge;
			size = GetLabelSize(label, lblFont, lblWidth * 2, g);
			labels.Add(LabelFactory("lbltotalFunds", label, lblFont, size, x, y));

			decimal totalMatching = ProjectFundingData.GetFundTotal( projectId, "M" );
			total = totalMatching.ToString("$###,###,###.00"); // string.Format("${0:#.##;;}", totalMatching );
			x = indent * 2 - 50;
			size = GetLabelSize(total, bodyFont, colTwoWidth, g);
            lbl = LabelFactory("totalMatching", total, bodyFont, size, x, y);
            lbl.Width = 110;
            lbl.TextAlign = ContentAlignment.BottomRight;
            labels.Add(lbl);
            verticalPosition += size.Height == 0 ? lblHeight : size.Height;

			label = "Total Project Cost: ";
			x = leftMargin;
			y = verticalPosition += vSpaceLarge;
			size = GetLabelSize(label, lblFont, lblWidth * 2, g);
			labels.Add(LabelFactory("lbltotalCosts", label, lblFont, size, x, y));


			decimal totalCosts = ProjectFundingData.GetFundTotal( projectId, "P" );
			total = totalCosts.ToString("$###,###,###.00");		// string.Format("${0:#.##;;}", totalCosts );
			x = indent * 2 - 50;
			size = GetLabelSize(total, bodyFont, colTwoWidth, g);
            lbl = LabelFactory("totalContribution", total, bodyFont, size, x, y);
            lbl.Width = 110;
            lbl.TextAlign = ContentAlignment.BottomRight;
            labels.Add(lbl);
            verticalPosition += size.Height == 0 ? lblHeight : size.Height;

            // Grantee Contact List
            string granteesLbl = "Grantees: ";
            x = leftMargin;
            y = verticalPosition += vSpaceLarge;
            size = GetLabelSize(granteesLbl, lblFont, lblWidth, g);
            labels.Add(LabelFactory("lblGrantees", granteesLbl, lblFont, size, x, y));

            string strGranteeList = "";
            foreach (DataRow dr in dsGrantee.Tables[0].Rows)
            {
                if (strGranteeList.Length > 0)
                    strGranteeList += ", ";
                strGranteeList += dr["Organization"].ToString();
            }
            x = indent;

            if (strGranteeList.Length == 0)
            {
                string msg = "Enter Grantee on Project Contacts Page";
                Font hintFont = new Font(bodyFont, FontStyle.Italic);
                size = GetLabelSize(msg, hintFont, colTwoWidth, g);
                labels.Add(LabelFactory("strGranteeHint", msg, hintFont, size, x, y));
                verticalPosition += size.Height == 0 ? lblHeight : size.Height;
            }
            else
            {
                size = GetLabelSize(strGranteeList, bodyFont, colTwoWidth, g);
                labels.Add(LabelFactory("strGranteeList", strGranteeList, bodyFont, size, x, y));
                verticalPosition += size.Height == 0 ? lblHeight : size.Height;
            }

			//Summary
			string summaryLbl = "Summary: ";
			x = leftMargin;
			y = (verticalPosition += vSpaceLarge);
			size = GetLabelSize(summaryLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblSummary", summaryLbl, lblFont, size, x, y));

			string summary = (string)drProject["Summary"];
			x = indent;
			size = GetLabelSize(summary, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("summary", summary, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;
			
			//Description
			string descriptionLbl = "Description: ";
			x = leftMargin;
			y = (verticalPosition += vSpaceLarge);
			size = GetLabelSize(descriptionLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblDescription", descriptionLbl, lblFont, size, x, y));
			
			string description = (string)drProject["Description"];
			x = indent;
			y = (verticalPosition += vSpaceSmall);
			size = GetLabelSize(description, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("description", description, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;;
				
			//ProgramTypes
			string programTypeLbl = "Program Type: ";
			x = leftMargin;
			y = (verticalPosition += vSpaceLarge);
			size = GetLabelSize(programTypeLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblProgram", programTypeLbl, lblFont, size, x, y));

			string programType = string.Empty;
			DataTable dtProgramType = dsProject.Tables["ProjectProgramType"];
			foreach(DataRow dr in dtProgramType.Rows)
			{
				programType = string.Concat(programType, programType == string.Empty ? string.Empty : ", ", (string)dr["ProgramType"]);
			}
			x = indent;
			size = GetLabelSize(programType, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("programType", programType, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;

			// MAR 2005-06-17 - added ProjectType
			string projectTypeLbl = "Project Type: ";
			x = leftMargin;
			y = (verticalPosition += vSpaceLarge);
			size = GetLabelSize(projectTypeLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblProjectType", projectTypeLbl, lblFont, size, x, y));

			string projectType = string.Empty;
			DataTable dtProjectType = dsProject.Tables["ProjectType"];
			foreach(DataRow dr in dtProjectType.Rows)
			{
				projectType = string.Concat(projectType, projectType == string.Empty ? string.Empty : ", ", (string)dr["ProjectType"]);
			}
			x = indent;
			size = GetLabelSize(projectType, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("projectType", projectType, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;


			// MAR 2005-03-10 - added strategic objectives
			//Strategic Objectives
			string ObjectiveLbl = "Objectives: ";
			x = leftMargin;
			y = (verticalPosition += vSpaceLarge);
			size = GetLabelSize(ObjectiveLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblObjectives", ObjectiveLbl, lblFont, size, x, y));

			string objectives = string.Empty;
			DataTable dtObjective = dsProject.Tables["ProjectObjective"];
			foreach(DataRow dr in dtObjective.Rows)
			{
				objectives = string.Concat(objectives, objectives == string.Empty ? string.Empty : ", ", (string)dr["Objective"]);
			}
			x = indent;
			size = GetLabelSize(objectives, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("objectives", objectives, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;

			// ADS 2-Nov-2007 - Added new field
			// APN# (Parcel Number)
			string apnnumLbl = "APN#: ";
			x = leftMargin;
			y = verticalPosition += vSpaceLarge;
			size = GetLabelSize(apnnumLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblAPNnum", apnnumLbl, lblFont, size, x, y));

			string apnnum = drProject["APNNumber"].ToString();
			x = indent;
			size = GetLabelSize(apnnum, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("apnnum", apnnum, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;

			//County
			string countyLbl = "County: ";
			x = leftMargin;
			y = verticalPosition += vSpaceLarge;
			size = GetLabelSize(countyLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblCounty", countyLbl, lblFont, size, x, y));

			string county = string.Empty;
			foreach(DataRow drCounty in dsProject.Tables["ProjectCounty"].Rows)
			{
				county = string.Concat(county, county == string.Empty ? string.Empty : ", ", (string)drCounty["CountyName"]);
			}
			x = indent;
			size = GetLabelSize(county, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("county", county, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;
			
			//City
			string cityLbl = "City: ";
			x = leftMargin;
			y = (verticalPosition += vSpaceLarge);
			size = GetLabelSize(cityLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblCity", cityLbl, lblFont, size, x, y));

			string city = string.Empty;
			foreach(DataRow drCity in dsProject.Tables["ProjectCity"].Rows)
			{
				city = string.Concat(city, city == string.Empty ? string.Empty : ", ", (string)drCity["CityName"]);
			}
			x = indent;
			size = GetLabelSize(city, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("city", city, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;

			//Region
			string regionLbl = "Region: ";
			x = leftMargin;
			y = verticalPosition += vSpaceLarge;
			size = GetLabelSize(regionLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblRegion", regionLbl, lblFont, size, x, y));

			string region = string.Empty;
			foreach(DataRow drRegion in dsProject.Tables["ProjectRegion"].Rows)
			{
				region = string.Concat(region, region == string.Empty ? string.Empty : ", ", (string)drRegion["Region"]);
			}
			x = indent;
			size = GetLabelSize(region, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("region", region, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;

            //Watershed - MAR 2005-02-18 - added 
			string watershedLbl = "Watershed: ";
			x = leftMargin;
			y = verticalPosition += vSpaceLarge;
			size = GetLabelSize(watershedLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblwatershed", watershedLbl, lblFont, size, x, y));

			string watershed = string.Empty;
			foreach(DataRow drWatershed in dsProject.Tables["ProjectWatershed"].Rows)
			{
				watershed = string.Concat(watershed, watershed == string.Empty ? string.Empty : ", ", (string)drWatershed["Watershed"]);
			}

			x = indent;
			size = GetLabelSize(watershed, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("watershed", watershed, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;

			
			//Latitude Longitude
			string longLatLbl = "Lat/Long:";
			x = leftMargin;
			y = verticalPosition += vSpaceLarge;
			size = GetLabelSize(longLatLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lbllongLat", longLatLbl, lblFont, size, x, y));
			
			string latLong = string.Format("N: {0:#.######;;} / W: {1:#.######;-#.######;}", drProject["Latitude"],  drProject["Longitude"]);
			x = indent;
			size = GetLabelSize(latLong, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("latLong", latLong, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;


            //Location Description
            string locationDescLbl = "Coordinates Represent:";
            x = leftMargin;
            y = verticalPosition += vSpaceLarge;
            size = GetLabelSize(locationDescLbl, lblFont, lblWidth, g);
            labels.Add(LabelFactory("lblLocationDescription", locationDescLbl, lblFont, size, x, y));

            string locationDesc2 = drProject["LocationDescription"].ToString();
            x = indent;
            size = GetLabelSize(locationDesc2, bodyFont, colTwoWidth, g);
            labels.Add(LabelFactory("locationDescription", locationDesc2, bodyFont, size, x, y));
            verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;
            verticalPosition += 20;

            //Political Districts
			string politicalLbl = "Districts:";
			x = leftMargin;
			y = verticalPosition += vSpaceLarge;
			size = GetLabelSize(politicalLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblPolical", politicalLbl, lblFont, size, x, y));

			string assembly = string.Empty;
			foreach(DataRow drAssembly in dsProject.Tables["ProjectAssemblyDistrict"].Rows)
			{
				assembly = string.Concat(assembly, assembly == string.Empty ? string.Empty : ", ", drAssembly["AssemblyDistrictNumber"].ToString());
			}
			string senate = string.Empty;
			foreach(DataRow drSenate in dsProject.Tables["ProjectSenateDistrict"].Rows)
			{
				senate = string.Concat(senate, senate == string.Empty ? string.Empty : ", ", drSenate["SenateDistrictNumber"].ToString());
			}
			string congressional = string.Empty;
			foreach(DataRow drCongressional in dsProject.Tables["ProjectCongressionalDistrict"].Rows)
			{
				congressional = string.Concat(congressional, congressional == string.Empty ? string.Empty : ", ", drCongressional["CongressionalDistrictNumber"].ToString());
			}
			string politicalDistricts = string.Format("Assembly: {0} \nState Senate: {1} \nCongressional: {2}", assembly, senate, congressional);
			x = indent;
			size = GetLabelSize(politicalDistricts, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("politicalDistricts", politicalDistricts, bodyFont, size, x, y));
			verticalPosition += size.Height == 0 ? lblHeight : size.Height;
            
            //Dynamic Dropdown 1
            DataSet dsDD = ProjectData.GetDynamicDropDown("DynamicDD1");
            string dd1Lbl = "Dropdown 1:";
            dd1Lbl = dsDD.Tables[0].Rows.Count > 1 ? dsDD.Tables[0].Rows[1]["LabelName"].ToString() + ": " : string.Empty;
            x = leftMargin;
            y = verticalPosition += vSpaceLarge;
            size = GetLabelSize(dd1Lbl, lblFont, lblWidth, g);
            labels.Add(LabelFactory("lblDropDown1", dd1Lbl, lblFont, size, x, y));

            string dd1 = string.Empty;
            if ((string)drProject["DynamicDD1"].ToString() != string.Empty)
            {
                DataRow[] drDD = dsDD.Tables[0].Select("Code = '" + (string)drProject["DynamicDD1"].ToString() + "'");
                dd1 = drDD[0]["DisplayName"].ToString();
            }
            x = indent;
            size = GetLabelSize(dd1, bodyFont, colTwoWidth, g);
            labels.Add(LabelFactory("dd1", dd1, bodyFont, size, x, y));
            verticalPosition += size.Height == 0 ? lblHeight : size.Height;

            //Dynamic Dropdown 2
            dsDD = ProjectData.GetDynamicDropDown("DynamicDD2");
            string dd2Lbl = "Dropdown 2: ";
            dd2Lbl = dsDD.Tables[0].Rows.Count > 1 ? dsDD.Tables[0].Rows[1]["LabelName"].ToString() + ": " : string.Empty;
            x = leftMargin;
            y = verticalPosition += vSpaceLarge;
            size = GetLabelSize(dd2Lbl, lblFont, colTwoWidth, g);
            labels.Add(LabelFactory("lblDropDown2", dd2Lbl, lblFont, size, x, y));

            string dd2 = string.Empty;
            dd2 = (string)drProject["DynamicDD2"].ToString();
            if ((string)drProject["DynamicDD2"].ToString() != string.Empty)
            {
                DataRow[] drDD = dsDD.Tables[0].Select("Code = '" + (string)drProject["DynamicDD2"].ToString() + "'");
                dd2 = drDD[0]["DisplayName"].ToString();
            }
            x = indent;
            size = GetLabelSize(dd2, bodyFont, colTwoWidth, g);
            labels.Add(LabelFactory("dd2", dd2, bodyFont, size, x, y));
            verticalPosition += size.Height == 0 ? lblHeight : size.Height;

            //Dynamic MultiSelect 1
            DataTable dtMultiSelect1 = ProjectData.GetDynamicMultiSelect("Project_ProjectDynamicMultiSelect1");
            string dms1Lbl = "MultiSelect 1: ";
            dms1Lbl = dtMultiSelect1.Rows.Count > 1 ? dtMultiSelect1.Rows[1]["LabelName"].ToString() + ": " : string.Empty;
            x = leftMargin;
            y = verticalPosition += vSpaceLarge;
            size = GetLabelSize(dms1Lbl, lblFont, colTwoWidth, g);
            labels.Add(LabelFactory("lblDynamicMultiSelect1", dms1Lbl, lblFont, size, x, y));

            string dms1value = string.Empty;

            if (dsProject.Tables["DynamicMultiSelect1"].Rows.Count > 0)
            {
                foreach (DataRow drMultiSelect in dsProject.Tables["DynamicMultiSelect1"].Rows)
                {
                    dms1value += drMultiSelect["DisplayName"].ToString() + ", ";
                }
            }

            dms1value = dms1value.TrimEnd(',', ' ');

            x = indent;
            size = GetLabelSize(dms1value, bodyFont, colTwoWidth, g);
            labels.Add(LabelFactory("lbMultiSelect1", dms1value, bodyFont, size, x, y));
            verticalPosition += size.Height == 0 ? lblHeight : size.Height;

			//Acreage
			string acreageLbl = "Acreage: ";
			x = leftMargin;
			y = verticalPosition += vSpaceLarge;
			size = GetLabelSize(acreageLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblcreage", acreageLbl, lblFont, size, x, y));

			decimal acreage = (decimal)drProject["acreage"];
			decimal sqMiles = (decimal)drProject["SquareMiles"];
			string landSize = string.Format("Acreage: {0:#0.##;;}\nSquare Miles: {1:#0.##;;}", acreage, sqMiles);
			x = indent;
			size = GetLabelSize(landSize, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("landSize", landSize, bodyFont, size, x, y));
			verticalPosition += size.Height == 0 ? lblHeight : size.Height;

            //Coastal Trail
            string ctrailLbl = "CA Coastal Trail: ";
            x = leftMargin;
            y = verticalPosition += vSpaceLarge;
            size = GetLabelSize(ctrailLbl, lblFont, lblWidth, g);
            labels.Add(LabelFactory("lblCoastTrail", ctrailLbl, lblFont, size, x, y));

            decimal ctrailMiles = (decimal)drProject["CCTmiles"];
            decimal ctrailFeet = (decimal)drProject["CCTLinearFeet"];
            string ctrail = string.Format("Trail Miles: {0:#0.##;;}\nTrail Linear Feet: {1:#0.##;;}", ctrailMiles, ctrailFeet);
            x = indent;
            size = GetLabelSize(ctrail, bodyFont, colTwoWidth, g);
            labels.Add(LabelFactory("coasttrail", ctrail, bodyFont, size, x, y));
            verticalPosition += size.Height == 0 ? lblHeight : size.Height;

            //Trail
			string trailLbl = "Other Trail: ";
			x = leftMargin;
			y = verticalPosition += vSpaceLarge;
			size = GetLabelSize(trailLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblTrail", trailLbl, lblFont, size, x, y));

			decimal trailMiles = (decimal)drProject["TrailMiles"];
			decimal trailFeet = (decimal)drProject["TrailLinearFeet"];
			string trail = string.Format("Trail Miles: {0:#0.##;;}\nTrail Linear Feet: {1:#0.##;;}", trailMiles, trailFeet);
			x = indent;
			size = GetLabelSize(trail, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("trail", trail, bodyFont, size, x, y));
			verticalPosition += size.Height == 0 ? lblHeight : size.Height;

			//Stream
			string streamLbl = "Stream: ";
			x = leftMargin;
			y = verticalPosition += vSpaceLarge;
			size = GetLabelSize(streamLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblStream", streamLbl, lblFont, size, x, y));

			decimal streamMiles = (decimal)drProject["StreamMiles"];
			decimal streamFeet = (decimal)drProject["StreamLinearFeet"];
			string stream = string.Format("Stream Miles: {0:#0.##;;}\nStream Linear Feet: {1:#0.##;;}", streamMiles, streamFeet);
			x = indent;
			size = GetLabelSize(stream, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("stream", stream, bodyFont, size, x, y));
			verticalPosition += size.Height == 0 ? lblHeight : size.Height;

			//Notes
			string notesLbl = "Notes: ";
			x = leftMargin;
			y = verticalPosition += vSpaceLarge;
			size = GetLabelSize(notesLbl, lblFont, lblWidth, g);
			labels.Add(LabelFactory("lblNotes", notesLbl, lblFont, size, x, y));

			string notes = (string)drProject["ProjectNotes"];
			x = indent;
			size = GetLabelSize(notes, bodyFont, colTwoWidth, g);
			labels.Add(LabelFactory("notes", notes, bodyFont, size, x, y));
			verticalPosition = verticalPosition += size.Height == 0 ? lblHeight : size.Height;

            //Spacer
			x = indent;
			y = verticalPosition += vSpaceLarge;
			size = new Size(20,20);
			labels.Add(LabelFactory("lblSpacer", " ", lblFont, size, x, y));

            ////Edit button
            //Button editBtn = new Button();
            //editBtn.Text = "Edit General Information";           
            //x = leftMargin;
            //y = verticalPosition += vSpaceLarge + 25;
            //editBtn.Width = 200;
            //Font btnFont = new Font("Microsoft Sans Serif", 10f, FontStyle.Regular);
            //editBtn.Font = btnFont;
            //Point p = new Point(x, y);
            //editBtn.Location = p;
            //editBtn.BackColor = Color.LightGray;
            //editBtn.ForeColor = Color.Black;
            //editBtn.Click += new EventHandler(editBtn_Click);

			Label[] arLabels = (Label[])labels.ToArray(typeof(Label));
			this.ProjectPage.Controls.AddRange(arLabels);
            this.ProjectPage.Controls.Add(editBtn);
            
            lblScroll.Select();

//			lblFont.Dispose();
//			bodyFont.Dispose();
		}

        void editBtn_Click(object sender, EventArgs e)
        {
            CCPM.Project.ProjectCreateOrUpdate updateProject = new CCPM.Project.ProjectCreateOrUpdate();
            updateProject.IsUpdateMode = true;
            updateProject.ProjectId = projectId;
            //updateProject.Width = 730;
            Form1 fm = (Form1)(this.MdiParent);
            fm.OpenForm(updateProject, "Update: " + projectName);
            //DialogResult dr = updateProject.ShowDialog();
            RefreshProjectPage();
        }

		//private void RefreshProjectPage()  MAR 2005-02-11 - changed to public
		public void RefreshProjectPage()
		{
			this.ProjectPage.Controls.Clear();
			this.Refresh();
			this.SetDisplay();
		}

		public void RefreshContacts()
		{
			if(mc != null)
			{
                mc.LoadOrg();
				mc.LoadContacts();
                mc.LoadOrgAddress();
                mc.LoadProjectRole();
				//mdc.SetDetailView();
				//mc.SetSelected();
			}
		}
		public void SetTabIndex(int index)
		{
			this.tabControl1.SelectedIndex = index;
		}

		public Label LabelFactory(string name, string txt, Font font, Size size, int x, int y)
		{
			Label lbl = new Label();
			lbl.Name = name;
			lbl.Text = txt;
			lbl.Font = font;
			lbl.Size = size;
			lbl.Left = x;
			lbl.Top = y;
			return lbl;
		}
		
		public Size GetLabelSize(string txt, Font font, int width, Graphics g)
		{
			SizeF sizef = g.MeasureString(txt, font, width);
			return new Size(Convert.ToInt32(Math.Ceiling(sizef.Width)), Convert.ToInt32(Math.Ceiling(sizef.Height)));
		}

		public RectangleF GetDrawCoord(string stringToDraw, Font font,int x, int y, Graphics g)
		{
			int copyWidth = 620;
			
			SizeF sizeF = g.MeasureString(stringToDraw, font, (copyWidth - x));
			PointF pointF = new Point(x,y);
			//verticalPosition = verticalPosition += Convert.ToInt32(sizeF.Height);
			RectangleF rectangleF = new RectangleF(pointF, sizeF);
			return rectangleF;
		}

		public void RefreshFundingDisplay()
		{
			this.fundingTab.Controls.Remove(funding);
			funding = new CCPM.Project.Authorizations();
			funding.Dock = DockStyle.Fill;
			fundingTab.Controls.Add(funding);
		}

        public void RefreshContracts()
        {
            this.contractTab.Controls.Remove(contract);
            contract = new CCPM.Contract.Contracts(GlobalSettings.projectId);
            contract.Dock = DockStyle.Fill;
            contractTab.Controls.Add(contract);
        }
		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.generalInfoContextMenu = new System.Windows.Forms.ContextMenu();
            this.miEditProject = new System.Windows.Forms.MenuItem();
            this.menuItem3 = new System.Windows.Forms.MenuItem();
            this.miGeneralInfoRefresh = new System.Windows.Forms.MenuItem();
            this.miProjectUpdateClose = new System.Windows.Forms.MenuItem();
            this.contextMenu1 = new System.Windows.Forms.ContextMenu();
            this.miAuthorization = new System.Windows.Forms.MenuItem();
            this.miAddAuthorization = new System.Windows.Forms.MenuItem();
            this.miEditAuthorization = new System.Windows.Forms.MenuItem();
            this.menuItem4 = new System.Windows.Forms.MenuItem();
            this.miDeleteAuthorization = new System.Windows.Forms.MenuItem();
            this.menuItem1 = new System.Windows.Forms.MenuItem();
            this.miMatchingFund = new System.Windows.Forms.MenuItem();
            this.miAddMatchingFund = new System.Windows.Forms.MenuItem();
            this.miEditMatchingFund = new System.Windows.Forms.MenuItem();
            this.menuItem2 = new System.Windows.Forms.MenuItem();
            this.miDeleteMatchingFund = new System.Windows.Forms.MenuItem();
            this.reportsPage = new System.Windows.Forms.TabPage();
            this.relatedProjectPage = new System.Windows.Forms.TabPage();
            this.linksPage = new System.Windows.Forms.TabPage();
            this.imagesPage = new System.Windows.Forms.TabPage();
            this.fundingTab = new System.Windows.Forms.TabPage();
            this.objectivesPage = new System.Windows.Forms.TabPage();
            this.ContactsPage = new System.Windows.Forms.TabPage();
            this.ProjectPage = new System.Windows.Forms.TabPage();
            this.lblScroll = new System.Windows.Forms.TextBox();
            this.tabControl1 = new System.Windows.Forms.TabControl();
            this.contractTab = new System.Windows.Forms.TabPage();
            this.ProjectPage.SuspendLayout();
            this.tabControl1.SuspendLayout();
            this.SuspendLayout();
            // 
            // generalInfoContextMenu
            // 
            this.generalInfoContextMenu.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
            this.miEditProject,
            this.menuItem3,
            this.miGeneralInfoRefresh,
            this.miProjectUpdateClose});
            // 
            // miEditProject
            // 
            this.miEditProject.Index = 0;
            this.miEditProject.Text = "Edit";
            this.miEditProject.Click += new System.EventHandler(this.miEditProject_Click);
            // 
            // menuItem3
            // 
            this.menuItem3.Index = 1;
            this.menuItem3.Text = "-";
            // 
            // miGeneralInfoRefresh
            // 
            this.miGeneralInfoRefresh.Index = 2;
            this.miGeneralInfoRefresh.Text = "Refresh";
            this.miGeneralInfoRefresh.Click += new System.EventHandler(this.miGeneralInfoRefresh_Click);
            // 
            // miProjectUpdateClose
            // 
            this.miProjectUpdateClose.Index = 3;
            this.miProjectUpdateClose.Text = "Close";
            this.miProjectUpdateClose.Click += new System.EventHandler(this.miProjectUpdateClose_Click);
            // 
            // miAuthorization
            // 
            this.miAuthorization.Index = -1;
            this.miAuthorization.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
            this.miAddAuthorization,
            this.miEditAuthorization,
            this.menuItem4,
            this.miDeleteAuthorization});
            this.miAuthorization.Text = "";
            // 
            // miAddAuthorization
            // 
            this.miAddAuthorization.Index = 0;
            this.miAddAuthorization.Text = "";
            // 
            // miEditAuthorization
            // 
            this.miEditAuthorization.Index = 1;
            this.miEditAuthorization.Text = "";
            // 
            // menuItem4
            // 
            this.menuItem4.Index = 2;
            this.menuItem4.Text = "";
            // 
            // miDeleteAuthorization
            // 
            this.miDeleteAuthorization.Index = 3;
            this.miDeleteAuthorization.Text = "";
            // 
            // menuItem1
            // 
            this.menuItem1.Index = -1;
            this.menuItem1.Text = "";
            // 
            // miMatchingFund
            // 
            this.miMatchingFund.Index = -1;
            this.miMatchingFund.Text = "";
            // 
            // miAddMatchingFund
            // 
            this.miAddMatchingFund.Index = -1;
            this.miAddMatchingFund.Text = "";
            // 
            // miEditMatchingFund
            // 
            this.miEditMatchingFund.Index = -1;
            this.miEditMatchingFund.Text = "";
            // 
            // menuItem2
            // 
            this.menuItem2.Index = -1;
            this.menuItem2.Text = "";
            // 
            // miDeleteMatchingFund
            // 
            this.miDeleteMatchingFund.Index = -1;
            this.miDeleteMatchingFund.Text = "";
            // 
            // reportsPage
            // 
            this.reportsPage.Location = new System.Drawing.Point(4, 22);
            this.reportsPage.Name = "reportsPage";
            this.reportsPage.Size = new System.Drawing.Size(986, 628);
            this.reportsPage.TabIndex = 6;
            this.reportsPage.Text = "Reports";
            this.reportsPage.UseVisualStyleBackColor = true;
            // 
            // relatedProjectPage
            // 
            this.relatedProjectPage.Location = new System.Drawing.Point(4, 22);
            this.relatedProjectPage.Name = "relatedProjectPage";
            this.relatedProjectPage.Size = new System.Drawing.Size(986, 628);
            this.relatedProjectPage.TabIndex = 5;
            this.relatedProjectPage.Text = "Related Projects";
            this.relatedProjectPage.UseVisualStyleBackColor = true;
            // 
            // linksPage
            // 
            this.linksPage.Location = new System.Drawing.Point(4, 22);
            this.linksPage.Name = "linksPage";
            this.linksPage.Size = new System.Drawing.Size(986, 628);
            this.linksPage.TabIndex = 4;
            this.linksPage.Text = "Links";
            this.linksPage.UseVisualStyleBackColor = true;
            // 
            // imagesPage
            // 
            this.imagesPage.Location = new System.Drawing.Point(4, 22);
            this.imagesPage.Name = "imagesPage";
            this.imagesPage.Size = new System.Drawing.Size(986, 628);
            this.imagesPage.TabIndex = 3;
            this.imagesPage.Text = "Images";
            this.imagesPage.UseVisualStyleBackColor = true;
            // 
            // fundingTab
            // 
            this.fundingTab.ContextMenu = this.contextMenu1;
            this.fundingTab.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.fundingTab.Location = new System.Drawing.Point(4, 22);
            this.fundingTab.Name = "fundingTab";
            this.fundingTab.Size = new System.Drawing.Size(986, 628);
            this.fundingTab.TabIndex = 2;
            this.fundingTab.Text = "Funding";
            this.fundingTab.ToolTipText = "Funding that is associated with this project";
            this.fundingTab.UseVisualStyleBackColor = true;
            // 
            // objectivesPage
            // 
            this.objectivesPage.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.objectivesPage.Location = new System.Drawing.Point(4, 22);
            this.objectivesPage.Name = "objectivesPage";
            this.objectivesPage.Size = new System.Drawing.Size(986, 628);
            this.objectivesPage.TabIndex = 7;
            this.objectivesPage.Text = "Strategic Objectives";
            this.objectivesPage.UseVisualStyleBackColor = true;
            this.objectivesPage.Click += new System.EventHandler(this.objectivesPage_Click);
            // 
            // ContactsPage
            // 
            this.ContactsPage.Cursor = System.Windows.Forms.Cursors.Arrow;
            this.ContactsPage.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.ContactsPage.Location = new System.Drawing.Point(4, 22);
            this.ContactsPage.Name = "ContactsPage";
            this.ContactsPage.Size = new System.Drawing.Size(986, 628);
            this.ContactsPage.TabIndex = 1;
            this.ContactsPage.Text = "Project Contacts";
            this.ContactsPage.ToolTipText = "Contacts that are associated with this project";
            this.ContactsPage.UseVisualStyleBackColor = true;
            // 
            // ProjectPage
            // 
            this.ProjectPage.AutoScroll = true;
            this.ProjectPage.BackColor = System.Drawing.Color.White;
            this.ProjectPage.ContextMenu = this.generalInfoContextMenu;
            this.ProjectPage.Controls.Add(this.lblScroll);
            this.ProjectPage.Cursor = System.Windows.Forms.Cursors.Arrow;
            this.ProjectPage.Font = new System.Drawing.Font("Microsoft Sans Serif", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.ProjectPage.Location = new System.Drawing.Point(4, 22);
            this.ProjectPage.Name = "ProjectPage";
            this.ProjectPage.Size = new System.Drawing.Size(986, 628);
            this.ProjectPage.TabIndex = 0;
            this.ProjectPage.Text = "General Information";
            this.ProjectPage.ToolTipText = "General Project Information";
            this.ProjectPage.UseVisualStyleBackColor = true;
            this.ProjectPage.Click += new System.EventHandler(this.ProjectPage_Click);
            // 
            // lblScroll
            // 
            this.lblScroll.BackColor = System.Drawing.Color.White;
            this.lblScroll.BorderStyle = System.Windows.Forms.BorderStyle.None;
            this.lblScroll.Location = new System.Drawing.Point(0, 613);
            this.lblScroll.Name = "lblScroll";
            this.lblScroll.Size = new System.Drawing.Size(0, 15);
            this.lblScroll.TabIndex = 0;
            // 
            // tabControl1
            // 
            this.tabControl1.Controls.Add(this.ProjectPage);
            this.tabControl1.Controls.Add(this.ContactsPage);
            this.tabControl1.Controls.Add(this.objectivesPage);
            this.tabControl1.Controls.Add(this.fundingTab);
            this.tabControl1.Controls.Add(this.contractTab);
            this.tabControl1.Controls.Add(this.imagesPage);
            this.tabControl1.Controls.Add(this.linksPage);
            this.tabControl1.Controls.Add(this.relatedProjectPage);
            this.tabControl1.Controls.Add(this.reportsPage);
            this.tabControl1.Dock = System.Windows.Forms.DockStyle.Fill;
            this.tabControl1.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.tabControl1.Location = new System.Drawing.Point(0, 0);
            this.tabControl1.Name = "tabControl1";
            this.tabControl1.SelectedIndex = 0;
            this.tabControl1.Size = new System.Drawing.Size(994, 654);
            this.tabControl1.TabIndex = 0;
            this.tabControl1.Validating += new System.ComponentModel.CancelEventHandler(this.TabValidation);
            this.tabControl1.SelectedIndexChanged += new System.EventHandler(this.TabSelectionChanged);
            // 
            // contractTab
            // 
            this.contractTab.Location = new System.Drawing.Point(4, 22);
            this.contractTab.Name = "contractTab";
            this.contractTab.Size = new System.Drawing.Size(986, 628);
            this.contractTab.TabIndex = 8;
            this.contractTab.Text = "Contract/Invoices";
            this.contractTab.UseVisualStyleBackColor = true;
            // 
            // ProjectForm
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.BackColor = System.Drawing.Color.Yellow;
            this.ClientSize = new System.Drawing.Size(994, 654);
            this.Controls.Add(this.tabControl1);
            this.Name = "ProjectForm";
            this.StartPosition = System.Windows.Forms.FormStartPosition.Manual;
            this.Text = "ProjectForm";
            this.Load += new System.EventHandler(this.ProjectForm_Load);
            this.Activated += new System.EventHandler(this.ProjectForm_Activated);
            this.Enter += new System.EventHandler(this.ProjectForm_Enter);
            this.ProjectPage.ResumeLayout(false);
            this.ProjectPage.PerformLayout();
            this.tabControl1.ResumeLayout(false);
            this.ResumeLayout(false);

		}
		#endregion

		public void ProjectForm_Activated(object sender, System.EventArgs e)
		{
            GlobalSettings.projectId = this.projectId;
            RestoreWindowState();
		}
        private void RestoreWindowState()
        {
            // Looking for given form among all opened forms 
            Form instance = null;
            foreach (Form form in Application.OpenForms)
                if (form is ProjectForm && form.Text.Trim() == this.Text)
                {
                    instance = form;
                    
                    if (instance.WindowState == FormWindowState.Minimized)
                        instance.WindowState = FormWindowState.Normal;

                    instance.BringToFront();
                    if (instance.CanFocus)
                        instance.Focus();
                        
                    break;
                }
        }

		public void EditProjectGeneralInfoHandler(object sender, EventArgs e)
		{
			miEditProject_Click(sender, e);
		}
		private void miEditProject_Click( object sender, System.EventArgs e )
		{
			if( !ProjectData.ProjectIsLocked( projectId ) )
			{
                try
				{
                    CCPM.Project.ProjectCreateOrUpdate updateProject = new CCPM.Project.ProjectCreateOrUpdate();
                    updateProject.IsUpdateMode = true;
                    updateProject.ProjectId = projectId;
                    //updateProject.Width = 730;
                    DialogResult dr = updateProject.ShowDialog();
                    RefreshProjectPage();
				}
				catch( Exception ex )
				{
					// Include project ID information
					throw new ApplicationException( "Error updating project " + projectId.ToString(), ex );
				}
				finally
				{
					// Ensure the project always gets unlocked
					ProjectData.UnlockProject( projectId );
				}
			}
			else
			{
				MessageBox.Show( "This project is currently open for editing by another user" );
			}
		}

		private bool ObjectivesCheckPage()
		{
			if (Objectives != null)
			{
				if (Objectives.GridDirty == true)
					return (true);
			}
			return (false);
		}

		private bool MatchingFundsCheckPage()
		{
			if (MatchingFunds != null)
			{
				if (MatchingFunds.GridDirty == true)
					return (true);
			}
			return (false);
		}
		private bool FundingCheckPage()
		{
			if (funding != null)
			{
				if (funding.GridDirty == true)
					return (true);
			}
			return (false);
		}

        // ADDED 08-08-2008 ---  Req. 5.2.1
        //private bool ContractsCheckPage()
        //{
        //    if (contract != null)
        //    {
        //        if (contract.GridDirty == true)
        //            return (true);
        //    }
        //    return (false);
        //}

		private bool ImageCheckPage()
		{
			if (images != null)
			{
				if (images._mode == images._AddMode | images._mode == images._EditMode)
					return (true);
			}
			return (false);
		}

		private void TabValidation(object sender, System.ComponentModel.CancelEventArgs e)
		{
			// This event gets triggered when the user tries to close the project form
			// If unsaved changes on grid pages exist, then we need to disallow closure
			// of form, and return them to the appropriate tab

			// MAR 2005-06-05 - Set flag GlobalSettings.okayToClose to FALSE to prevent user 
			//                  from closing app when pending edits are in progress

			// Determine if edits were made on the various pages, if edits made
			if (Objectives != null)
				if (Objectives.GridDirty == true)
				{
					// If edits were made then display a dialog box to the user
					Objectives.ObjectivesSaveReminderMsg();
					tabControl1.SelectedIndex = tabObjectives;
					GlobalSettings.okayToClose = false;
					e.Cancel = true;
				}
				else
				{
					GlobalSettings.okayToClose = true;
				}
            //if (MatchingFunds != null)
            //    if (MatchingFunds.GridDirty == true)
            //    {
            //        // If edits were made then display a dialog box to the user
            //        MatchingFunds.MatchingFundsSaveReminderMsg();
            //        tabControl1.SelectedIndex = tabMatchingFunds;
            //        GlobalSettings.okayToClose = false;
            //        e.Cancel = true;			
            //    }
            //    else
            //    {
            //        GlobalSettings.okayToClose = true;
            //    }
			if (funding != null)
				if (funding.GridDirty == true)
				{
					// If edits were made then display a dialog box to the user
					funding.FundingSaveReminderMsg();
                    //funding.MatchingFundsSaveReminderMsg();
					tabControl1.SelectedIndex = tabFunding;
					GlobalSettings.okayToClose = false;
					e.Cancel = true;			
				}
				else
				{
					GlobalSettings.okayToClose = true;
				}
			if (images != null)
				if (images._mode==images._AddMode | images._mode==images._EditMode)
				{
					// If edits were made then display a dialog box to the user
					images.ImagesSaveReminderMsg();
					tabControl1.SelectedIndex = tabImages;
					GlobalSettings.okayToClose = false;
					e.Cancel = true;			
				}
				else
				{
					GlobalSettings.okayToClose = true;
				}

		}

		//Loads the various tab pages
		private void TabSelectionChanged(object sender, EventArgs e)
		{
			bool okToChange = true;
			int selectedTabIndex = tabControl1.SelectedIndex;

            // 2005-04-01 - check for unsaved changes on grid pages
			// Reset the selected tab to the page with unsaved changes, if necessary
			if (this.currentTabIndex!=selectedTabIndex)
			{
				if (this.currentTabIndex==tabObjectives & ObjectivesCheckPage())
				{
					tabControl1.SelectedIndex = tabObjectives;
					Objectives.ObjectivesSaveReminderMsg();
					okToChange = false;
				}
                //else if (this.currentTabIndex==tabMatchingFunds & MatchingFundsCheckPage())
                //{
                //    tabControl1.SelectedIndex = tabMatchingFunds;
                //    MatchingFunds.MatchingFundsSaveReminderMsg();
                //    okToChange = false;
                //}
				else if (this.currentTabIndex==tabFunding & FundingCheckPage())
				{
					tabControl1.SelectedIndex = tabFunding;
					funding.FundingSaveReminderMsg();
					okToChange = false;
				}

				else if (this.currentTabIndex==tabImages & ImageCheckPage())
				{
					tabControl1.SelectedIndex = tabImages;
					images.ImagesSaveReminderMsg();
					okToChange = false;
				}
                //else if (this.currentTabIndex == tabRelatedProjects)
                //{
                //    tabControl1.SelectedIndex = tabRelatedProjects;
                //    okToChange = false;
                //}

				if (okToChange==true)
					this.currentTabIndex = selectedTabIndex;
			}

			switch(tabControl1.SelectedIndex)
			{
                case tabGeneral: //General
                    {
                        lblScroll.Select();
                        break;
                    }
				case tabContacts : //Contacts
					bool masterDetailExists = false;
					foreach(Control cntrl in ContactsPage.Controls)
					{
						if(cntrl.GetType() == typeof(CCPM.Contact.MasterContacts)) //.MasterDetailControl))
						{
							masterDetailExists = true;
							break;
						}
					}
					if( ! masterDetailExists)//Only load MasterDeatilControl if it has not already been loaded.
					{
						mc = new CCPM.Contact.MasterContacts(); //.MasterDetailControl();
						mc.Dock = DockStyle.Fill;
						mc.IsProjectView = true;
						mc.ProjectId = this.ProjectId;
						ContactsPage.Controls.Add(mc);
					}
					break;
				case tabObjectives : //Objectives
					bool objectiveExists = false;
					//this.AcceptButton = "btnSave";
					foreach(Control cntrl in objectivesPage.Controls)
					{
						if(cntrl.GetType() == typeof(CCPM.Project.StrategicObjectives))
						{
							objectiveExists = true;
							break;
						}
					}
					if( ! objectiveExists)//Only load if it has not already been loaded.
					{
						Objectives = new CCPM.Project.StrategicObjectives();
						//Objectives.Dock = DockStyle.Fill;
						objectivesPage.Controls.Add(Objectives);
					}
					break;

				case tabFunding : //Funding
					bool fundingExists = false;
					foreach(Control cntrl in fundingTab.Controls)
					{
						if(cntrl.GetType() == typeof(CCPM.Project.Authorizations))
						{
							fundingExists = true;
							break;
						}
					}
					if( ! fundingExists)//Only load funding if it has not already been loaded.
					{
						funding = new CCPM.Project.Authorizations();
						funding.Dock = DockStyle.Fill;
						fundingTab.Controls.Add(funding);
					}
					else 
					{
						funding.LoadTotals();
					}
					break;

                case tabContract: //Contract/Invoice
                    bool contractExists = false;
                    foreach (Control cntrl in contractTab.Controls)
                    {
                        if (cntrl.GetType() == typeof(CCPM.Contract.Contracts))
                        {
                            contractExists = true;
                            break;
                        }
                    }
                    if (!contractExists)//Only load funding if it has not already been loaded.
                    {
                        contract = new CCPM.Contract.Contracts(GlobalSettings.projectId);
                        contract.Dock = DockStyle.Fill;
                        contractTab.Controls.Add(contract);
                    }
                    break;

                case tabImages : //Images
					bool imagesExists = false;
					foreach(Control cntrl in imagesPage.Controls)
					{
						if(cntrl.GetType() == typeof(CCPM.ProjectImages.Images))
						{
							imagesExists = true;
							break;
						}
					}
					if( ! imagesExists)//Only load funding if it has not already been loaded.
					{
						images = new CCPM.ProjectImages.Images(ProjectId);
						images.Dock = DockStyle.Fill;
						imagesPage.Controls.Add(images);
					}
					break;
				case tabLinks : //Links
					VerifyLinks();
					break;
				case tabRelatedProjects : //Related project
					bool relatedProjectExists = false;
					foreach(Control cntrl in this.relatedProjectPage.Controls)
					{
						if(cntrl.GetType() == typeof(CCPM.RelatedProjects.RelatetProjectList))
						{
							relatedProjectExists = true;
							break;
						}
					}
					if( ! relatedProjectExists)//Only load related project list if it has not already been loaded.
					{
						// ADS 15-Nov-2007 - Moved initialization into a method to allow calls from elsewhere
						EnsureRelatedListIsInitialized();
					}
					break;
				case tabReport : //One page report
					bool reportListExists = false;
					foreach(Control cntrl in this.reportsPage.Controls)
					{
						if(cntrl.GetType() == typeof(CCPM.Report.ReportList))
						{
							reportListExists = true;
							break;
						}
					}
					if( ! reportListExists)//Only load report list if it has not already been loaded.
					{
						reportList = new CCPM.Report.ReportList(ProjectId);
						reportList.Dock = DockStyle.Fill;
						reportsPage.Controls.Add(reportList);
					}
					break;
			}
		}

		private void EnsureRelatedListIsInitialized()
		{
			if( relatedProjectList == null )
			{
				relatedProjectList = new CCPM.RelatedProjects.RelatetProjectList(ProjectId);
				relatedProjectList.Dock = DockStyle.Fill;
				relatedProjectPage.Controls.Add(relatedProjectList);
			}
		}

		private void miProjectUpdateClose_Click(object sender, System.EventArgs e)
		{
			this.Close();
		}

		private void miGeneralInfoRefresh_Click(object sender, System.EventArgs e)
		{
			RefreshProjectPage();
		}

		#region Funding Context Menu Events
		//Methods are public so that they can be accessed via MainForm.cs menu events.
//		public void miAddAuthorization_Click(object sender, System.EventArgs e)
//		{
//			CCPM.Funding.CreateEditAuthorizations cea = new CCPM.Funding.CreateEditAuthorizations(this.ProjectId);
//			DialogResult dialogResult = cea.ShowDialog(this);
//			if(dialogResult == DialogResult.OK)
//			{
//				this.RefreshFundingDisplay();
//			}
//		}

//		public void miEditAuthorization_Click(object sender, System.EventArgs e)
//		{
//			int authorizationId = this.funding.AuthorizationId;
//			if(authorizationId > 0)
//			{
//				CCPM.Funding.CreateEditAuthorizations cea = new CCPM.Funding.CreateEditAuthorizations(this.ProjectId);
//				cea.IsEditMode = true;
//				cea.AuthorizationId = authorizationId;
//				DialogResult dialogResult = cea.ShowDialog(this);
//				if(dialogResult == DialogResult.OK)
//				{
//					this.RefreshFundingDisplay();
//				}
//			}
//			else
//			{
//				MessageBox.Show("Please select an authorization to edit!");
//			}
//		}
//
//		public void miDeleteAuthorization_Click(object sender, System.EventArgs e)
//		{
//			int authorizationId = this.funding.AuthorizationId;
//			if(authorizationId > 0)
//			{
//				// MAR 2005-01-31 - fix typo in dialog text
//				DialogResult dialogResult = MessageBox.Show(
//					"You are about to delete an authorization! Are you sure you want to do this?",
//					"Confirm Delete",
//					MessageBoxButtons.OKCancel,
//					MessageBoxIcon.Stop);
//				if(dialogResult == DialogResult.OK)
//				{
//					FundingData.AuthorizationDelete(authorizationId);
//					this.RefreshFundingDisplay();
//				}
//			}
//			else
//			{
//				MessageBox.Show("Please select an authorization to delete");
//			}
//		}

//		public void miAddMatchingFund_Click(object sender, System.EventArgs e)
//		{
//			CCPM.Funding.CreateEditMatchingFund cea = new CCPM.Funding.CreateEditMatchingFund(ProjectId);
//			DialogResult dialogResult = cea.ShowDialog(this);
//			if(dialogResult == DialogResult.OK)
//			{
//				this.RefreshFundingDisplay();
//			}
//		}

//		public void miEditMatchingFund_Click(object sender, System.EventArgs e)
//		{
//			int matchingFundId = this.funding.MatchingFundId;
//			if(matchingFundId > 0)//A selection was made
//			{
//				CCPM.Funding.CreateEditMatchingFund cea = new CCPM.Funding.CreateEditMatchingFund(ProjectId);
//				cea.IsEditMode = true;
//				cea.MatchingFundId = matchingFundId;
//				DialogResult dialogResult = cea.ShowDialog(this);
//				if(dialogResult == DialogResult.OK)
//				{
//					this.RefreshFundingDisplay();
//				}
//			}
//			else
//			{
//				MessageBox.Show("Please select a matching fund to edit!");
//			}
//		}

//		public void miDeleteMatchingFund_Click(object sender, System.EventArgs e)
//		{
//			int matchingFundId = this.funding.MatchingFundId;
//			if(matchingFundId > 0)//A selection was made
//			{
//				DialogResult dialogResult = MessageBox.Show(
//					"You are about to delete a Matching Fund! Are you sure you want to do this?",
//					"Delete Confirmation",
//					MessageBoxButtons.OKCancel,
//					MessageBoxIcon.Stop);
//				if(dialogResult == DialogResult.OK)
//				{
//					FundingData.MatchingFundDelete(matchingFundId);
//					this.RefreshFundingDisplay();
//				}
//			}
//			else
//			{
//				MessageBox.Show("Please select a matching fund to delete!");
//			}
//		}

		#endregion
		/// <summary>
		/// Keep the main form informed of the current project of focus so
		/// that menu items on the main form can operate.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void ProjectForm_Enter(object sender, System.EventArgs e)
		{
			CCPM.Form1 parentForm = (CCPM.Form1)this.MdiParent;
			parentForm.CurrentProjectFocus = ProjectId;

		}

		private void objectivesPage_Click(object sender, System.EventArgs e)
		{
//			projectId = GlobalSettings.projectId;
//			DataSet dsObjectiveList = ProjectObjectiveData.GetListProjectObjective(this.projectId);
//			//this.lbObjectives.DataSource = dsObjectiveList
//			this.dgObjectives.DataSource = dsObjectiveList;
		}

		private void VerifyLinks()
		{
			bool linksExists = false;
			foreach(Control cntrl in this.linksPage.Controls)
			{
				if(cntrl.GetType() == typeof(CCPM.Links.LinkList))
				{
					linksExists = true;
					break;
				}
			}
			if( ! linksExists)//Only load links list if it has not already been loaded.
			{
				linkList = new CCPM.Links.LinkList(ProjectId);
				linkList.Dock = DockStyle.Fill;
				linksPage.Controls.Add(linkList);
			}
		}

        private void ProjectPage_Click(object sender, EventArgs e)
        {

        }

        private void ProjectForm_Load(object sender, EventArgs e)
        {
            
        }

	}
}
