using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using System.Text;
using CCPM.Data;
using Infragistics.Win.UltraWinGrid;

namespace CCPM.Project
{
	/// <summary>
    /// used by:  ProjectSearch
	/// SearchCriteria builds a subquery that is spliced into an outer query, which
	/// returns ProjectId numbers. The outer query is assembled in ProjectSearch.cs.
	/// cbColumn ComboBox: Provides a database column option to the user and populates the
	/// subQueryStub private field. The cbColumn.SelectedIndexChanged event calls the SetOperator method
	/// that populates the cbOperator ComboBox with sql operator options. 
	/// cbOperator ComboBox: Provides a sql operator option to the user and populates
	/// the subQueryCondition private field. The cbOperator.SelectedIndexChanged event
	/// calls the LoadValueControls method.
	/// Both subQueryStub and subQueryCondition are populated with substitution parameter format strings.
	/// LoadValueControls: This method loads appropriate controls for the value on the
	/// right side of the sql operator and populates the valueControlDelegate private field.
	/// valueControlDelegate: Because the application cannot know which set of value controls
	/// have been loaded until runtime a delegate encapsulates an appropriate method that knows
	/// which value controls to read based on the value controls that have been loaded.
	/// SqlWhereCondition: A Property that calls the method encapsulated in valueControlDelegate, passing
	/// in subQueryStub and subQueryCondition as parameters and returning the resultant sql string.
	/// </summary>
	public class SearchCriteria : System.Windows.Forms.UserControl
	{
		private System.Windows.Forms.ComboBox cbColumn;
		private System.Windows.Forms.ComboBox cbOperator;
		private System.Windows.Forms.Label lblLineNumber;
		private System.Windows.Forms.ComboBox cbLineOperator;
		private System.Windows.Forms.Button btnReset;
		private System.EventHandler cbOperatorSelectionChanged = null;
		private System.Windows.Forms.Panel panelValue;
		private string selectedColumn = string.Empty;
		private string subQueryStub = string.Empty;
		private string subQueryCondition = string.Empty;
		private ValueControlDelegate valueControlDelegate = null;
		private TextBox txtValue = null;
		//private ComboBox comboBox1 = null;
        private UltraCombo comboBox1 = null;
		private ComboBox comboBox2 = null;
		private ComboBox comboBox3 = null;
		private Label lblBetween = null;
        //private Label lbDate = null;
        private Infragistics.Win.UltraWinGrid.UltraCombo cmbFundingItem;
		/// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		
		public bool ShowLineOperator
		{
			set{cbLineOperator.Visible = value;}
		}

		public string LineNumber
		{
			get{return this.lblLineNumber.Text;}
			set{lblLineNumber.Text = value;}
		}

		public string SqlWhereCondition
		{
			get
			{
				if(subQueryStub != string.Empty && subQueryCondition != string.Empty)
				{
					return valueControlDelegate(this.subQueryStub, this.subQueryCondition);
				}
				return string.Empty;
			}
			
		}
		public string LineOperator
		{
			get{return this.cbLineOperator.GetItemText(cbLineOperator.SelectedItem);}
		}
		public delegate string ValueControlDelegate(string subQueryStub, string subQueryCondition);
		public SearchCriteria()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			SetColumnList();
			this.cbColumn.SelectedIndexChanged += new System.EventHandler(this.cbColumn_SelectedIndexChanged);
			
			this.cbOperatorSelectionChanged = new System.EventHandler(this.cbOperator_SelectedIndexChanged);
			
			txtValue = new TextBox();
			txtValue.Size = new Size(300, 20);
			txtValue.Anchor = AnchorStyles.Left | AnchorStyles.Top | AnchorStyles.Right;
			//comboBox1 = new ComboBox();
            comboBox1 = new UltraCombo();
			comboBox1.Size = new Size( 400,  20);
			//comboBox1.DropDownStyle = ComboBoxStyle.DropDownList;
            comboBox1.DropDownStyle = UltraComboStyle.DropDown;
            comboBox1.Anchor = AnchorStyles.Left | AnchorStyles.Top;
			comboBox2 = new ComboBox();
			comboBox2.Size = new Size(85,20);
			comboBox2.DropDownStyle = ComboBoxStyle.DropDownList;
			comboBox2.Anchor = AnchorStyles.Left | AnchorStyles.Top | AnchorStyles.Right;
			comboBox3 = new ComboBox();
			comboBox3.Size = new Size(85,20);
			comboBox3.DropDownStyle = ComboBoxStyle.DropDownList;
			comboBox3.Anchor = AnchorStyles.Left | AnchorStyles.Top | AnchorStyles.Right;
			lblBetween = new Label();
			lblBetween.Text = " And ";
			lblBetween.Left = 85;
			lblBetween.Size = new Size(35, 20);
			lblBetween.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
			lblBetween.Anchor = AnchorStyles.Top | AnchorStyles.Right;
            panelValue.Controls.Add(txtValue);
		}
		
		protected void SetColumnList()
		{
			ArrayList colList = new ArrayList();
            colList.Add(new SearchColumn("", "", OperatorOptions.LookUp));
            //colList.Add(new SearchColumn("Authorization Date", " ProjectId IN (SELECT ProjectId FROM AuthorizationDetail WHERE dbo.usfDateOnly(AuthorizationDate) {0})", OperatorOptions.Date));
            colList.Add(new SearchColumn("Assembly District", " ProjectId IN (SELECT ProjectId FROM Project_AssemblyDistrict WHERE AssemblyDistrictId {0}) ", OperatorOptions.Advanced));
            colList.Add(new SearchColumn("Authorization Date", " ProjectId IN (SELECT Project.ProjectId FROM Project left outer join AuthorizationDetail on AuthorizationDetail.ProjectId = Project.ProjectId WHERE dbo.usfDateOnly(AuthorizationDate) {0})", OperatorOptions.Date));
            colList.Add(new SearchColumn("Authorization Month", " ProjectId IN (SELECT ProjectId FROM AuthorizationDetail WHERE month(AuthorizationDate) {0})", OperatorOptions.Equal));
            colList.Add(new SearchColumn("Authorization Year", " ProjectId IN (SELECT ProjectId FROM AuthorizationDetail WHERE year(AuthorizationDate) {0})", OperatorOptions.Equal));
            colList.Add(new SearchColumn("City", " ProjectId IN (SELECT ProjectId FROM Project_ProjectCity WHERE ProjectCityId {0}) ", OperatorOptions.Equal));
			colList.Add(new SearchColumn("Congressional District", " ProjectId IN (SELECT ProjectId FROM Project_CongressionalDistrict WHERE CongressionalDistrictId {0}) ", OperatorOptions.Advanced));
            colList.Add(new SearchColumn("County", " ProjectId IN (SELECT ProjectId FROM Project_ProjectCounty WHERE ProjectCountyId {0}) ", OperatorOptions.Equal));
            colList.Add(new SearchColumn("Fiscal Years", " ProjectId IN (select ProjectId from AuthorizationDetail " +
                    "left join ReservEncumb on AuthorizationDetail.AuthorizationId = ReservEncumb.AuthorizationId " +
                    "left join FundingSource on FundingSource.FundID = ReservEncumb.FundID " +
                    "where FundingSource.FiscalYearID {0}) ", OperatorOptions.Equal));
            colList.Add(new SearchColumn("Fund Number", " ProjectId IN (SELECT ProjectId FROM vwProjectFundingSource WHERE FundNumber {0}) ", OperatorOptions.Equal));
            colList.Add(new SearchColumn("Fund Short Name", " ProjectId IN (SELECT ProjectId FROM vwProjectFundingSource vpf INNER JOIN FundingSource fs ON vpf.FundID = fs.FundID WHERE fs.Source {0}) ", OperatorOptions.Equal));
            colList.Add(new SearchColumn("Funding Item", " ProjectId IN (SELECT ProjectId FROM vwProjectFundingSource WHERE FundID {0}) ", OperatorOptions.Equal));
            //colList.Add(new SearchColumn("Funding Source", " ProjectId IN (SELECT ProjectId FROM vwProjectFundingSource WHERE FundID {0}) ", OperatorOptions.LookUp));
            colList.Add(new SearchColumn("Grantee/Contractor", " ProjectId IN (SELECT ProjectId FROM vwGranteeForProject WHERE OrgID {0}) ", OperatorOptions.Equal));
            colList.Add(new SearchColumn("Grantee Name", " ProjectId IN (SELECT ProjectId FROM vwGrantee WHERE Organization {0}) ", OperatorOptions.ContainsOnly));
            colList.Add(new SearchColumn("Matching Fund Organization", " ProjectId IN (SELECT ProjectId FROM vwMatchingFunds WHERE OrgId {0}) ", OperatorOptions.Equal));
            colList.Add(new SearchColumn("Primary Project Manager", " ProjectId IN (SELECT ProjectId FROM Project WHERE CurrentPM {0}) ", OperatorOptions.LookUp2));
            colList.Add(new SearchColumn("Program Type", " ProjectId IN (SELECT ProjectId FROM Project_ProjectProgramType WHERE ProjectProgramTypeId {0}) ", OperatorOptions.LookUp2));
			colList.Add(new SearchColumn("Project Attorney", " ProjectId IN (SELECT ProjectId FROM Project_ProjectAttorney WHERE ProjectAttorneyId {0}) ", OperatorOptions.LookUp2));
			colList.Add(new SearchColumn("Project Description", " Project.Description {0} ", OperatorOptions.ContainsOnly));
            colList.Add(new SearchColumn("Project Manager", " ProjectId IN (SELECT ProjectId FROM Project_ProjectManager WHERE ProjectManagerId {0}) ", OperatorOptions.LookUp2));
            colList.Add(new SearchColumn("Project Name", " Project.ProjectName {0} ", OperatorOptions.General));
			colList.Add(new SearchColumn("Project Number", " Project.FileNumber {0} ", OperatorOptions.General));
            colList.Add(new SearchColumn("Project Status", " Project.StatusId {0} ", OperatorOptions.LookUp2));
			colList.Add(new SearchColumn("Project Type", " ProjectId IN (SELECT ProjectId FROM Project_ProjectType WHERE ProjectTypeId {0}) ", OperatorOptions.LookUp2));
			colList.Add(new SearchColumn("Region", " ProjectId IN (SELECT ProjectId FROM Project_ProjectRegion WHERE ProjectRegionId {0}) ", OperatorOptions.LookUp2));
			colList.Add(new SearchColumn("State Senate District", " ProjectId IN (SELECT ProjectId FROM Project_SenateDistrict WHERE SenateDistrictId {0}) ", OperatorOptions.Advanced));
			colList.Add(new SearchColumn("Strategic Objective", " ProjectId IN (SELECT ProjectId FROM Project_ProjectObjective WHERE ObjectiveId {0}) ", OperatorOptions.LookUp2));
			colList.Add(new SearchColumn("Watershed", " ProjectId IN (SELECT ProjectId FROM Project_ProjectWatershed WHERE WatershedId {0}) ", OperatorOptions.LookUp2));
			this.cbColumn.DataSource = colList;
			cbColumn.DisplayMember = "Description";
		}

		protected void SetOperatorList(OperatorOptions operatorOptions)
		{
			//Don't want to handle the SelectedIndexChanged event during DataBinding.
			this.cbOperator.SelectedIndexChanged -= this.cbOperatorSelectionChanged;

			ArrayList operatorList = new ArrayList();
			if(operatorOptions == OperatorOptions.LookUp)
			{
				operatorList.Add(new SearchOperator("contains", " = {0} "));
				operatorList.Add(new SearchOperator("does NOT contain", " <> {0} "));
                operatorList.Add(new SearchOperator("is equal to", " = {0} "));
                operatorList.Add(new SearchOperator("is NOT equal to", " <> {0} "));
				operatorList.Add(new SearchOperator("is empty", " IS NULL "));
				//operatorList.Add(new SearchOperator("is NOT empty"," IS NOT NULL "));
			}
            else if (operatorOptions == OperatorOptions.LookUp2)
            {
                operatorList.Add(new SearchOperator("is equal to", " = {0} "));
                operatorList.Add(new SearchOperator("is NOT equal to", " <> {0} "));
            }
            else if (operatorOptions == OperatorOptions.ContainsOnly)
			{
				operatorList.Add(new SearchOperator("contains", " LIKE '%{0}%'"));
			}
            else if (operatorOptions == OperatorOptions.Equal)
            {
                operatorList.Add(new SearchOperator("is equal to", " = {0} "));
            }
            else if (operatorOptions == OperatorOptions.Date)
            {
                operatorList.Add(new SearchOperator("is equal to", " = '{0}' "));
                operatorList.Add(new SearchOperator("is greater than", " > '{0}' "));
                operatorList.Add(new SearchOperator("is greater than or equal to", " >= '{0}' "));
                operatorList.Add(new SearchOperator("is less than", " < '{0}' "));
                operatorList.Add(new SearchOperator("is less than or equal to", " <= '{0}' "));
                operatorList.Add(new SearchOperator("is empty", " IS NULL "));
                operatorList.Add(new SearchOperator("is NOT empty", " IS NOT NULL "));
            }
			else if(operatorOptions == OperatorOptions.General)
			{
				operatorList.Add(new SearchOperator("is equal to", " = '{0}' "));
				operatorList.Add(new SearchOperator("is NOT equal to", " <> '{0}' "));
				operatorList.Add(new SearchOperator("contains", " LIKE '%{0}%'"));
				operatorList.Add(new SearchOperator("does NOT contain", " NOT LIKE '%{0}%' "));
				operatorList.Add(new SearchOperator("starts with", " LIKE '{0}%'"));
				operatorList.Add(new SearchOperator("does NOT start with", " NOT LIKE '{0}%'"));
			}
			else if(operatorOptions == OperatorOptions.Advanced)
			{
				operatorList.Add(new SearchOperator("is equal to", " = {0} "));
				operatorList.Add(new SearchOperator("is NOT equal to", " <> {0} "));
				operatorList.Add(new SearchOperator("is between", "	BETWEEN {0} AND {1} "));
				operatorList.Add(new SearchOperator("is NOT between", "	NOT BETWEEN {0} AND {1} "));
				operatorList.Add(new SearchOperator("is greater than", " > {0} "));
				operatorList.Add(new SearchOperator("is greater than or equal to", " >= {0} "));
				operatorList.Add(new SearchOperator("is less than", " < {0} "));
				operatorList.Add(new SearchOperator("is less than or equal to", " <= {0} "));
				operatorList.Add(new SearchOperator("is empty", " IS NOT NULL "));
				operatorList.Add(new SearchOperator("is NOT empty"," IS NOT NULL "));
			}
			cbOperator.DataSource = null;
			cbOperator.Items.Clear();
			cbOperator.DataSource = operatorList;
			cbOperator.DisplayMember = "Description";
			cbOperator.Refresh();
			cbOperator.SelectedIndexChanged += this.cbOperatorSelectionChanged;
		}
		
		/// <summary>
		/// The operatorString parameter is a format string containing the sql operator
		/// and either one or two substitution paramaeters.
		/// This method loads an appropriate contorl(s) based on the column and operator.
		/// The control(s) that gets loaded is responsible for the value part of a sql condition (right side of the operator).
		/// </summary>
		/// <param name="operatorString"></param>
		/// <returns>A finised operator and value string that will be combined with the sql in the SearchColumn object.</returns>
		private void LoadValueControls(string operatorDescription)
		{
            this.panelValue.Controls.Clear();
			
			switch(this.selectedColumn)
			{
				case "Project Name" :
					this.panelValue.Controls.Add(txtValue);
                    txtValue.Text = "";
					this.valueControlDelegate = new ValueControlDelegate(this.SingleTextBoxValue);
					break;
				case "Project Description" :
					this.panelValue.Controls.Add(txtValue);
                    txtValue.Text = "";
					this.valueControlDelegate = new ValueControlDelegate(this.SingleTextBoxValue);
					break;
				case "Project Number" :
					this.panelValue.Controls.Add(txtValue);
                    txtValue.Text = "";
					this.valueControlDelegate = new ValueControlDelegate(this.SingleTextBoxValue);
					break;
                case "Primary Project Manager":
                    this.SetLookupControls(ProjectData.ProjectStaffList(), "Table.Name", "Table.ProjectManagerId", operatorDescription);
                    break;
                case "Project Manager":
					this.SetLookupControls(ProjectData.ProjectStaffList(), "Table.Name", "Table.ProjectManagerId", operatorDescription);
					break;
				case "Project Attorney" :
					this.SetLookupControls(ProjectData.ProjectAttorneyList(), "Table.Name", "Table.AttorneyId", operatorDescription);
					break;
				case "Program Type" :
					this.SetLookupControls(ProjectData.ProjectProgramTypeList(), "Table.ProgramType", "Table.ProgramTypeId", operatorDescription);
					break;
				case "Project Type" :
					this.SetLookupControls(ProjectData.ProjectTypeList(), "Table.ProjectType", "Table.ProjectTypeId", operatorDescription);
					break;
				case "County" :
					this.SetLookupControls(ProjectData.ProjectCounties(), "Table.CountyName", "Table.CountyId", operatorDescription);
					break;
				case "City" :
					this.SetLookupControls(ProjectData.ProjectCities(), "Table.CityName", "Table.CityId", operatorDescription);
					break;
				case "Region" :
					this.SetLookupControls(ProjectData.ProjectRegionList(), "Table.Region", "Table.RegionId", operatorDescription);
					break;
				case "Assembly District" :
					this.SetAdvancedControls(ProjectData.ProjectAssemblyDistrictList(), "Table.AssemblyDistrictNumber", "Table.AssemblyDistrictId", operatorDescription);
					break;
				case "State Senate District" :
					this.SetAdvancedControls(ProjectData.ProjectStateSenateDistrictList(), "Table.StateSenateDistrictNumber", "Table.StateSenateDistrictId", operatorDescription);
					break;
				case "Congressional District" :
					this.SetAdvancedControls(ProjectData.ProjectCongressionalDistrictList(), "Table.CongressionalDistrictNumber", "Table.CongressionalDistrictId", operatorDescription);
					break;
				// MAR 2005-03-10 - added
				case "Watershed" :
					this.SetAdvancedControls(ProjectData.ProjectWatershedList(), "Table.Watershed", "Table.WatershedID", operatorDescription);
					break;
				case "Strategic Objective" :
					this.SetAdvancedControls(ProjectObjectiveData.GetObjectiveSearchSelectionList(), "Table.Objective", "Table.ObjectiveID", operatorDescription);
					break;
                case "Fiscal Years":
                    this.SetAdvancedControls(ProjectData.GetFiscalYears(), "Table.Years", "Table.FiscalYearId", operatorDescription);
                    break;
                case "Funding Item":
                    this.SetAdvancedControls(ProjectData.GetFundItem(), "Table.FundingItem", "Table.FundID", operatorDescription);
                    break;
                case "Funding Source":
                    this.SetAdvancedControls(ProjectData.GetFundSource(), "Table.FundingItem", "Table.FundID", operatorDescription);
                    break;
                case "Fund Number" :
                    //this.SetAdvancedControls(ProjectData.GetFundNumber(), "Table.FundDesc", "Table.FundNumber", operatorDescription);
                    //this.SetAdvancedControls(ProjectData.GetFundNumber(), "Table.FundingItem", "Table.FundID", operatorDescription);
                    this.SetLookupControls(ProjectData.GetFundNumber(), "Table.FundNumber", "Table.FundNumber", operatorDescription);
                    break;
                case "Fund Short Name":
                    this.SetAdvancedControls(ProjectData.GetFundTitle(), "Table.Source", null, operatorDescription);
                    break;
                case "Project Status" :
                    this.SetAdvancedControls(ProjectData.GetProjectStatus(), "Table.Status", "Table.StatusId", operatorDescription);
                    break;
                case "Matching Fund Organization" :
                    //this.panelValue.Controls.Add(txtValue);
                    //txtValue.Text = "";
                    //this.valueControlDelegate = new ValueControlDelegate(this.SingleTextBoxValue);
                    this.SetAdvancedControls(ProjectData.GetMatchingFundOrganizations(), "Table.Organization", "Table.OrgID", operatorDescription);
                    break;
                case "Grantee/Contractor":
                    this.SetAdvancedControls(ProjectData.GetOrganizations(), "Table.Organization", "Table.OrgID", operatorDescription);
                    break;
                case "Grantee Name":
                    this.panelValue.Controls.Add(txtValue);
                    txtValue.Text = "";
                    this.valueControlDelegate = new ValueControlDelegate(this.SingleTextBoxValue);
                    break;
                case "Authorization Date":
                    this.panelValue.Controls.Add(txtValue);
                    txtValue.Text = "Enter date in MM/DD/YYYY format";
                    txtValue.Focus();
                    this.valueControlDelegate = new ValueControlDelegate(this.SingleTextBoxValue);
                    break;
                case "Authorization Year":
                    this.panelValue.Controls.Add(txtValue);
                    txtValue.Text = "Enter year in YYYY format";
                    txtValue.Focus();
                    this.valueControlDelegate = new ValueControlDelegate(this.SingleTextBoxValue);
                    break;
                case "Authorization Month":
                    this.panelValue.Controls.Add(txtValue);
                    txtValue.Text = "Enter month in MM format";
                    txtValue.Focus();
                    this.valueControlDelegate = new ValueControlDelegate(this.SingleTextBoxValue);
                    break;
            }

		}
		private void SetLookupControls(DataSet ds, string displayMember, string valueMember, string operatorDescription)
		{
			if(operatorDescription == "is empty")
			{
				panelValue.Controls.Clear();
				this.valueControlDelegate = new ValueControlDelegate(this.IsEmptyValueControl);
			}
			else
			{
                panelValue.Controls.Clear();
                this.valueControlDelegate = new ValueControlDelegate(this.IsEmptyValueControl);

                comboBox1.DisplayMember = null;
                comboBox1.ValueMember = null;
				comboBox1.DataSource = ds;
				comboBox1.DisplayMember = displayMember;
                comboBox1.ValueMember = valueMember;
                //comboBox1.DataBind();
                comboBox1.DisplayLayout.Bands[0].ColHeadersVisible = false;
                if (comboBox1.DisplayLayout.Bands[0].Columns.Count == 1)
                {
                    comboBox1.DisplayLayout.Bands[0].Columns[0].Width = comboBox1.Width - 20;
                }
                else
                {
                    comboBox1.DisplayLayout.Bands[0].Columns[0].Hidden = true;
                    comboBox1.DisplayLayout.Bands[0].Columns[1].Width = comboBox1.Width - 20;
                    for (int i = 2; i < comboBox1.DisplayLayout.Bands[0].Columns.Count; i++)
                        comboBox1.DisplayLayout.Bands[0].Columns[i].Hidden = true;
                }
                comboBox1.Text = "";
                this.panelValue.Controls.Add(comboBox1);
				this.valueControlDelegate = new ValueControlDelegate(this.SingleComboBoxValue);
			}
		}
		private void SetAdvancedControls(DataSet ds, string displayMember, string valueMember, string operatorDescription)
		{
			if(operatorDescription == "is between" || operatorDescription == "is NOT between")
			{
                comboBox1.DisplayMember = null;
                comboBox1.ValueMember = null;
				comboBox2.DataSource = ds;
				comboBox2.DisplayMember = displayMember;
				comboBox2.ValueMember = valueMember;
				comboBox3.DataSource = ds;
				comboBox3.DisplayMember = displayMember;
				comboBox3.ValueMember = valueMember;
				comboBox3.Left = 115;
				comboBox3.BindingContext = new BindingContext();
				this.panelValue.Controls.Clear();
				this.panelValue.Controls.AddRange(new Control[]{comboBox2, lblBetween, comboBox3}); 
				this.valueControlDelegate = new ValueControlDelegate(this.DualComboBoxValue);
			}
			else if(operatorDescription == "is empty")
			{
				panelValue.Controls.Clear();
				this.valueControlDelegate = new ValueControlDelegate(this.IsEmptyValueControl);
			}
			else if(operatorDescription == "is NOT empty")
			{
				panelValue.Controls.Clear();
				this.valueControlDelegate = new ValueControlDelegate(this.IsNotEmptyValueControl);
			}
			else
			{
                comboBox1.DisplayMember = null;
                comboBox1.ValueMember = null;
				comboBox1.DataSource = ds;
				comboBox1.DisplayMember = displayMember;
				comboBox1.ValueMember = valueMember;
                comboBox1.DisplayLayout.Bands[0].ColHeadersVisible = false;
                if (comboBox1.DisplayLayout.Bands[0].Columns.Count == 1)
                {
                    comboBox1.DisplayLayout.Bands[0].Columns[0].Width = comboBox1.Width - 20;
                }
                else
                {
                    comboBox1.DisplayLayout.Bands[0].Columns[0].Hidden = true;
                    comboBox1.DisplayLayout.Bands[0].Columns[1].Width = comboBox1.Width - 20;
                    for (int i = 2; i < comboBox1.DisplayLayout.Bands[0].Columns.Count; i++)
                        comboBox1.DisplayLayout.Bands[0].Columns[i].Hidden = true;
                }
                comboBox1.Text = "";
                this.panelValue.Controls.Add(comboBox1);
				this.valueControlDelegate = new ValueControlDelegate(this.SingleComboBoxValue);
			}
		}

		public string SingleTextBoxValue(string subQueryStub, string subQueryCondition)
		{
			string input = txtValue.Text.Replace("'", "''").Replace(";", "");
            return string.Format(subQueryStub, string.Format(subQueryCondition, input));
		}
		public string SingleComboBoxValue(string subQueryStub, string subQueryCondition)
		{
			//return string.Format(subQueryStub, string.Format(subQueryCondition, comboBox1.SelectedValue));
            string input = GlobalCode.ToString(comboBox1.Value).Replace("'", "''").Replace(";", "");
            if (comboBox1.ValueMember == null)
                subQueryCondition = subQueryCondition.Replace("{", "'{").Replace("}", "}'");
            return string.Format(subQueryStub, string.Format(subQueryCondition, input));
		}
		public string DualComboBoxValue(string subQueryStub, string subQueryCondition)
		{
			return string.Format(subQueryStub, string.Format(subQueryCondition, comboBox2.SelectedValue, comboBox3.SelectedValue));
		}

		public string IsEmptyValueControl(string subQueryStub, string subQueryCondition)
		{
			return string.Format(subQueryStub.Replace("IN", "NOT IN"), subQueryCondition);
		}
		public string IsNotEmptyValueControl(string subQueryStub, string subQueryCondition)
		{
			return string.Format(subQueryStub, subQueryCondition);
		}

			/// <summary> 
			/// Clean up any resources being used.
			/// </summary>
			protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.cbLineOperator = new System.Windows.Forms.ComboBox();
            this.cbColumn = new System.Windows.Forms.ComboBox();
            this.cbOperator = new System.Windows.Forms.ComboBox();
            this.lblLineNumber = new System.Windows.Forms.Label();
            this.btnReset = new System.Windows.Forms.Button();
            this.panelValue = new System.Windows.Forms.Panel();
            this.SuspendLayout();
            // 
            // cbLineOperator
            // 
            this.cbLineOperator.Items.AddRange(new object[] {
            "AND",
            "OR"});
            this.cbLineOperator.Location = new System.Drawing.Point(24, 1);
            this.cbLineOperator.Name = "cbLineOperator";
            this.cbLineOperator.Size = new System.Drawing.Size(45, 21);
            this.cbLineOperator.TabIndex = 0;
            this.cbLineOperator.Text = "AND";
            // 
            // cbColumn
            // 
            this.cbColumn.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.cbColumn.Location = new System.Drawing.Point(72, 1);
            this.cbColumn.Name = "cbColumn";
            this.cbColumn.Size = new System.Drawing.Size(150, 21);
            this.cbColumn.TabIndex = 1;
            // 
            // cbOperator
            // 
            this.cbOperator.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.cbOperator.Location = new System.Drawing.Point(224, 1);
            this.cbOperator.Name = "cbOperator";
            this.cbOperator.Size = new System.Drawing.Size(150, 21);
            this.cbOperator.TabIndex = 2;
            // 
            // lblLineNumber
            // 
            this.lblLineNumber.Location = new System.Drawing.Point(0, 1);
            this.lblLineNumber.Name = "lblLineNumber";
            this.lblLineNumber.Size = new System.Drawing.Size(22, 21);
            this.lblLineNumber.TabIndex = 4;
            this.lblLineNumber.Text = "1";
            this.lblLineNumber.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
            // 
            // btnReset
            // 
            this.btnReset.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
            this.btnReset.CausesValidation = false;
            this.btnReset.Location = new System.Drawing.Point(667, 1);
            this.btnReset.Name = "btnReset";
            this.btnReset.Size = new System.Drawing.Size(70, 21);
            this.btnReset.TabIndex = 4;
            this.btnReset.Text = "Reset";
            this.btnReset.Click += new System.EventHandler(this.btnReset_Click);
            // 
            // panelValue
            // 
            this.panelValue.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.panelValue.Location = new System.Drawing.Point(376, 1);
            this.panelValue.Name = "panelValue";
            this.panelValue.Size = new System.Drawing.Size(285, 20);
            this.panelValue.TabIndex = 3;
            // 
            // SearchCriteria
            // 
            this.Controls.Add(this.panelValue);
            this.Controls.Add(this.btnReset);
            this.Controls.Add(this.lblLineNumber);
            this.Controls.Add(this.cbOperator);
            this.Controls.Add(this.cbColumn);
            this.Controls.Add(this.cbLineOperator);
            this.Name = "SearchCriteria";
            this.Size = new System.Drawing.Size(740, 24);
            this.ResumeLayout(false);

		}
		#endregion

		private void cbColumn_SelectedIndexChanged(object sender, System.EventArgs e)
		{
            if (cbColumn.SelectedIndex <= 0)
            {
                cbOperator.DataSource = null;
                cbOperator.Items.Clear();
            }
            else
			{
			    SearchColumn sc = (SearchColumn)cbColumn.Items[cbColumn.SelectedIndex];
			    selectedColumn = sc.Description;
			    this.subQueryStub = sc.SubQueryStub;
			    SetOperatorList(sc._OperatorOptions);
			    //Set the operator menu accordingly
		        //cbOperator_SelectedIndexChanged(sender, e);
                OperatorChange();
			}
		}

        private void OperatorChange()
        {
            if (cbOperator.SelectedIndex == -1)
                return;

			SearchOperator so = (SearchOperator)cbOperator.Items[cbOperator.SelectedIndex];
			subQueryCondition = so.SubQueryCondition;
            try
            {
 			    LoadValueControls(so.Description);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }

        }

		private void cbOperator_SelectedIndexChanged(object sender, System.EventArgs e)
		{
            OperatorChange();
        }

		private void btnReset_Click(object sender, System.EventArgs e)
		{
			cbColumn.SelectedIndex = 0;
            //comboBox1.Text = "";

			panelValue.Controls.Clear();
			txtValue.Text = string.Empty;
			panelValue.Controls.Add(txtValue);
			
			this.subQueryStub = string.Empty;
			this.subQueryCondition = string.Empty;
		}
	}

	public class SearchColumn
	{
		private string _subQueryStub;
		private OperatorOptions _operatorOptions;
		private string _description;
		public string SubQueryStub
		{
			get{return _subQueryStub;}
			set{_subQueryStub = value;}
		}
		//Data type of the column in the Project table. Foreign keys will all be int.
		public OperatorOptions _OperatorOptions
		{
			get{return _operatorOptions;}
			set{_operatorOptions = value;}
		}

		public string Description
		{
			get{return _description;}
			set{_description = value;}
		}

		public SearchColumn(string description, string subQueryStub, OperatorOptions operatorOptions)
		{
			Description = description;
			SubQueryStub = subQueryStub;
			_OperatorOptions = operatorOptions;
		}
	}

	public class SearchOperator
	{
		private string _subQueryCondition;
		private string _description;

		public string SubQueryCondition
		{
			get{return _subQueryCondition;}
			set{_subQueryCondition = value;}
		}
		public string Description
		{
			get{return _description;}
			set{_description = value;}
		}

		public SearchOperator(string description, string subQueryCondition)
		{
			Description = description;
			SubQueryCondition = subQueryCondition;
		}
	}

	public enum OperatorOptions
	{
		LookUp,
		General,
		Advanced,
		ContainsOnly,
        Date,
        Equal,
        LookUp2
	}
}
