using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using Infragistics.Shared; 
using Infragistics.Win; 
using Infragistics.Win.UltraWinGrid; 
using CCPM.Data;

namespace CCPM.Project
{
	/// <summary>
	/// DirtyFlag values:
	///    0 = database row not edited
	///    1 = database row edited by user
	///    2 = database row marked as deleted
	///    3 = new row added by user
	/// </summary>
	public class StrategicObjectives : System.Windows.Forms.UserControl
	{
        private DataSet dsProjectObjectives;
        private DataSet dsAllObjectives;
        private bool blnGridDirty = false;

		/// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		private System.Windows.Forms.Button btnDelete;
		private System.Windows.Forms.Button btnSave;
		private System.Windows.Forms.Button btnCancel;
		private System.Windows.Forms.Button btnAdd;
		private Infragistics.Win.UltraWinGrid.UltraGrid uwgObjectives;
        private Button btnRefresh;
		private System.Windows.Forms.Label lblInstructions;

		public StrategicObjectives()
		{

			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			// Create the objectives dataset and bind to a value list
			dsAllObjectives = ProjectObjectiveData.GetObjectiveSelectionList(true);
			uwgObjectives.DisplayLayout.ValueLists.Add("Objectives");
			for(int i = 0; i < dsAllObjectives.Tables[0].Rows.Count; i++)
			{
				Infragistics.Win.ValueListItem ListItem = new Infragistics.Win.ValueListItem();
				ListItem.DataValue = dsAllObjectives.Tables[0].Rows[i].ItemArray.GetValue(0);
				ListItem.DisplayText = (string) dsAllObjectives.Tables[0].Rows[i].ItemArray.GetValue(1);
				uwgObjectives.DisplayLayout.ValueLists["Objectives"].ValueListItems.Add (ListItem);
			}

			// Initialize the grid with data
			LoadGrid();
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		public bool GridDirty
		{
			get { return blnGridDirty;	}
		}

		private void LoadGrid()
		{
			//Create the project objectives dataset and bind to the grid
			dsProjectObjectives = ProjectObjectiveData.GetProjectObjectives(GlobalSettings.projectId);
			uwgObjectives.DataSource = dsProjectObjectives.Tables[0];
			uwgObjectives.DataBind();
            blnGridDirty = false;
		}

		private void uwgObjectives_InitializeLayout(object sender, Infragistics.Win.UltraWinGrid.InitializeLayoutEventArgs e)
		{
			e.Layout.Bands[0].Columns[0].Hidden = true;

            e.Layout.Bands[0].Columns["Objective"].Width = 600;
            e.Layout.Bands[0].Columns["Objective"].Header.Caption = "Objective";
            e.Layout.Bands[0].Columns["Objective"].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDownList;
            e.Layout.Bands[0].Columns["Objective"].ValueList = uwgObjectives.DisplayLayout.ValueLists["Objectives"];
			e.Layout.ValueLists["Objectives"].DisplayStyle = Infragistics.Win.ValueListDisplayStyle.DisplayText;
			
			e.Layout.Bands[0].Columns[2].Width = 125;
			e.Layout.Bands[0].Columns[2].Header.Caption = "Number of Units";
			e.Layout.Bands[0].Columns[2].MinValue = 0;
			e.Layout.Bands[0].Columns[2].MaxValue = 99999999.99;
			e.Layout.Bands[0].Columns[2].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
			
			e.Layout.Bands[0].Columns[3].Width = 160;
			e.Layout.Bands[0].Columns[3].Header.Caption = "Unit of Measurement";
			e.Layout.Bands[0].Columns[3].CellActivation = Infragistics.Win.UltraWinGrid.Activation.Disabled;
			e.Layout.Bands[0].Columns[3].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;
			e.Layout.Bands[0].Columns[3].CellAppearance.BackColorDisabled = GlobalSettings.nonEditableBackColor;
			e.Layout.Bands[0].Columns[3].CellAppearance.ForeColorDisabled = GlobalSettings.nonEditableForeColor;
			
			e.Layout.Bands[0].Columns[4].Hidden = true;
            e.Layout.Bands[0].Columns["ObjectiveId"].Hidden = true;

            //filter row
            e.Layout.Override.AllowRowFiltering = Infragistics.Win.DefaultableBoolean.True;
            e.Layout.Override.FilterClearButtonLocation = FilterClearButtonLocation.Row;
            e.Layout.Override.FilterUIType = Infragistics.Win.UltraWinGrid.FilterUIType.FilterRow;
            e.Layout.Override.FilterOperatorDefaultValue = FilterOperatorDefaultValue.Contains;

            //column sorting
            e.Layout.Override.HeaderClickAction = HeaderClickAction.SortMulti;
        }

		private void uwgObjectives_CellListSelect(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e) 
		{
			// Validate that the selected objective has not already been assigned to the project (in another grid row) 
			int SelectedItemIndex = this.uwgObjectives.DisplayLayout.ValueLists["Objectives"].SelectedIndex;
  			string ObjectiveId = this.uwgObjectives.DisplayLayout.ValueLists["Objectives"].ValueListItems[SelectedItemIndex].DataValue.ToString();
			// Set the id for the selected objective into the row
			this.uwgObjectives.ActiveRow.Cells["ObjectiveID"].Value = ObjectiveId;
			// If this was a an existing row then set the dirty flag accordingly
			if (this.uwgObjectives.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
				this.uwgObjectives.ActiveRow.Cells["DirtyFlag"].Value = "1";
			blnGridDirty = true;
			// Set the units of measurement column with the value associated to the selected objective
			for(int i = 0; i < dsAllObjectives.Tables[0].Rows.Count; i++)
			{
				if (ObjectiveId == dsAllObjectives.Tables[0].Rows[i].ItemArray.GetValue(0).ToString())
				{
					this.uwgObjectives.ActiveRow.Cells["UnitOfMeasurement"].Value = 
						dsAllObjectives.Tables[0].Rows[i].ItemArray.GetValue(2);
				}
			}
		}

		private void uwgObjectives_AfterCellUpdate(object sender, Infragistics.Win.UltraWinGrid.CellEventArgs e) 
		{ 
			// If editing an existing row then set the dirty flag to edit mode for this row
			if (this.uwgObjectives.ActiveRow.Cells["DirtyFlag"].Value.ToString() == "0")
				this.uwgObjectives.ActiveRow.Cells["DirtyFlag"].Value = "1";
			blnGridDirty = true;
			Form1 f = (Form1) this.ParentForm.MdiParent;
			f.DisableMenusAll();
			SetButtons();
		}

		private void uwgObjectives_AfterRowActivate(object sender, System.EventArgs e) 
		{ 
			SetButtons();
		}

		private void btnDelete_Click(object sender, System.EventArgs e)
		{ 
 
			// Get the row to delete. In this case we will use the active row. 
			UltraGridRow row = this.uwgObjectives.ActiveRow;

			if ( null != row ) 
			{ 
				DialogResult intDiagResult = MessageBox.Show("Do you want to delete this row and save all other pending changes?","Delete Row", 
					MessageBoxButtons.YesNo);
				if (intDiagResult == DialogResult.Yes)
				{
					// if the row is a database row then mark it for deletion and hide it in the grid
					if (row.Cells["DirtyFlag"].Value.ToString() == "0")
					{
						row.Hidden = true;
						row.Cells["DirtyFlag"].Value = "2";
						blnGridDirty = true;
					}
						// else it was added by the user and not saved to the database - delete it from the grid
					else
					{
						row.Delete(false);
					}
					// set the active row to first (non-hidden) row
					GridManager.FirstButtonHandler(uwgObjectives);
					SaveGrid();
				}
			} 
			else 
			{ 
				// If there is no active row, then prompt the user to select one. 
				MessageBox.Show( "Please select a single row to delete." ); 
			} 
		} 

		private void SetButtons()
		{
			if (blnGridDirty == true)
			{
				this.btnSave.Enabled = true;
				this.btnCancel.Enabled = true;
			}
			else
			{
				this.btnSave.Enabled = false;
				this.btnCancel.Enabled = false;
			}

			if (this.uwgObjectives.ActiveRow == null)
				this.btnDelete.Enabled = false;
			else
				this.btnDelete.Enabled = true;
		}

		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			if (blnGridDirty == true)
			{
				DialogResult intDiagResult = MessageBox.Show("Data has changed - Do you want to cancel changes?","Cancel Changes", 
					MessageBoxButtons.YesNo,MessageBoxIcon.Question);
				if (intDiagResult == DialogResult.Yes)
				{
					this.LoadGrid();
					SetButtons();
					// get a handle to the main form so we can enable / disable the menus
					Form1 f = (Form1) this.ParentForm.MdiParent;
					f.EnableMenusAll();
					blnGridDirty = false;
				}
			}
		}

		private void btnAdd_Click(object sender, System.EventArgs e)
		{
			UltraGridRow addedRow = uwgObjectives.DisplayLayout.Bands[0].AddNew( );
			addedRow.Cells["NumberOfUnits"].Value = "0";
			addedRow.Cells["DirtyFlag"].Value = "3";
			blnGridDirty = true;
			SetButtons();
		}

		private void btnSave_Click(object sender, System.EventArgs e)
		{
			SaveGrid();
		}

		private void SaveGrid()
		{

			// Validate grid prior to update
			bool GridValid = true;
			int row;
			for(int i = 0; i < uwgObjectives.Rows.Count; i++)
			{
				row = i + 1;
				if (uwgObjectives.Rows[i].Cells["ObjectiveId"].Value.ToString() == "")
				{
					MessageBox.Show("Please select a valid Objective for row " + row.ToString(),
						"Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);

					GridValid = false;
					break;
				}
				if (uwgObjectives.Rows[i].Cells["NumberOfUnits"].Value.ToString() == String.Empty)
				{
					MessageBox.Show("Missing Number of Units in row " + row.ToString(),
						"Data Entry Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
					GridValid = false;
					break;
				}
			}
			
			// Perform updates
			if (GridValid == true)
			{
				// Iterate through each grid row and determine if an update is needed
				for(int i = 0; i < uwgObjectives.Rows.Count; i++)
				{
					switch (uwgObjectives.Rows[i].Cells["DirtyFlag"].Value.ToString())
					{
						case "1":
						{
							ProjectObjectiveData.ProjectObjectiveUpdate(
								Convert.ToInt32(uwgObjectives.Rows[i].Cells["RecordID"].Value),
								GlobalSettings.projectId,
								Convert.ToInt32(uwgObjectives.Rows[i].Cells["ObjectiveID"].Value), 
								Convert.ToDecimal(uwgObjectives.Rows[i].Cells["NumberOfUnits"].Value));
							break;
						}
						case "2":
						{
							ProjectObjectiveData.ProjectObjectiveDelete(Convert.ToInt32(uwgObjectives.Rows[i].Cells["RecordID"].Value));
							break;
						}
						case "3":
						{
							ProjectObjectiveData.ProjectObjectiveInsert(GlobalSettings.projectId, 
								Convert.ToInt32(uwgObjectives.Rows[i].Cells["ObjectiveID"].Value), 
								Convert.ToDecimal(uwgObjectives.Rows[i].Cells["NumberOfUnits"].Value));

							break;
						}
					}
				}
				// Reset the dirty flag, reload the grid and reset the form buttons
				blnGridDirty = false;
				LoadGrid();
				SetButtons();
				Form1 f = (Form1) this.ParentForm.MdiParent;
				f.EnableMenusAll();
			}
		}

		private void pbFirst_Click(object sender, System.EventArgs e)
		{
			GridManager.FirstButtonHandler(uwgObjectives);
		}

		private void pbPrevious_Click(object sender, System.EventArgs e)
		{
			GridManager.PreviousButtonHandler(uwgObjectives);
		}

		private void pbNext_Click(object sender, System.EventArgs e)
		{
			GridManager.NextButtonHandler(uwgObjectives);
		}

		private void pbLast_Click(object sender, System.EventArgs e)
		{
			GridManager.LastButtonHandler(uwgObjectives);
		}

		public void ObjectivesSaveReminderMsg()
		{
			string msg = "Changes have been made on the Strategic Objectives screen. Please save or cancel your changes before closing the project form.";
			DialogResult intDiagResult = MessageBox.Show(this,msg, "Data Changed", MessageBoxButtons.OK, MessageBoxIcon.Warning);
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.btnDelete = new System.Windows.Forms.Button();
            this.btnSave = new System.Windows.Forms.Button();
            this.btnCancel = new System.Windows.Forms.Button();
            this.btnAdd = new System.Windows.Forms.Button();
            this.uwgObjectives = new Infragistics.Win.UltraWinGrid.UltraGrid();
            this.lblInstructions = new System.Windows.Forms.Label();
            this.btnRefresh = new System.Windows.Forms.Button();
            ((System.ComponentModel.ISupportInitialize)(this.uwgObjectives)).BeginInit();
            this.SuspendLayout();
            // 
            // btnDelete
            // 
            this.btnDelete.Enabled = false;
            this.btnDelete.Font = new System.Drawing.Font("Arial", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.btnDelete.Location = new System.Drawing.Point(99, 321);
            this.btnDelete.Name = "btnDelete";
            this.btnDelete.Size = new System.Drawing.Size(64, 23);
            this.btnDelete.TabIndex = 23;
            this.btnDelete.Text = "Delete";
            this.btnDelete.Click += new System.EventHandler(this.btnDelete_Click);
            // 
            // btnSave
            // 
            this.btnSave.Enabled = false;
            this.btnSave.Font = new System.Drawing.Font("Arial", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.btnSave.Location = new System.Drawing.Point(183, 321);
            this.btnSave.Name = "btnSave";
            this.btnSave.Size = new System.Drawing.Size(64, 23);
            this.btnSave.TabIndex = 24;
            this.btnSave.Text = "Save";
            this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
            // 
            // btnCancel
            // 
            this.btnCancel.Enabled = false;
            this.btnCancel.Font = new System.Drawing.Font("Arial", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.btnCancel.Location = new System.Drawing.Point(267, 321);
            this.btnCancel.Name = "btnCancel";
            this.btnCancel.Size = new System.Drawing.Size(64, 23);
            this.btnCancel.TabIndex = 25;
            this.btnCancel.Text = "Cancel";
            this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
            // 
            // btnAdd
            // 
            this.btnAdd.Font = new System.Drawing.Font("Arial", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.btnAdd.Location = new System.Drawing.Point(15, 321);
            this.btnAdd.Name = "btnAdd";
            this.btnAdd.Size = new System.Drawing.Size(64, 23);
            this.btnAdd.TabIndex = 22;
            this.btnAdd.Text = "Add";
            this.btnAdd.Click += new System.EventHandler(this.btnAdd_Click);
            // 
            // uwgObjectives
            // 
            this.uwgObjectives.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.uwgObjectives.Location = new System.Drawing.Point(13, 17);
            this.uwgObjectives.Name = "uwgObjectives";
            this.uwgObjectives.Size = new System.Drawing.Size(911, 282);
            this.uwgObjectives.TabIndex = 28;
            this.uwgObjectives.Text = "Strategic Plan Objectives";
            this.uwgObjectives.InitializeLayout += new Infragistics.Win.UltraWinGrid.InitializeLayoutEventHandler(this.uwgObjectives_InitializeLayout);
            this.uwgObjectives.CellListSelect += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgObjectives_CellListSelect);
            this.uwgObjectives.AfterCellUpdate += new Infragistics.Win.UltraWinGrid.CellEventHandler(this.uwgObjectives_AfterCellUpdate);
            this.uwgObjectives.AfterRowActivate += new System.EventHandler(this.uwgObjectives_AfterRowActivate);
            // 
            // lblInstructions
            // 
            this.lblInstructions.Font = new System.Drawing.Font("Arial", 7.75F);
            this.lblInstructions.ForeColor = System.Drawing.Color.Green;
            this.lblInstructions.Location = new System.Drawing.Point(17, 302);
            this.lblInstructions.Name = "lblInstructions";
            this.lblInstructions.Size = new System.Drawing.Size(512, 16);
            this.lblInstructions.TabIndex = 34;
            this.lblInstructions.Text = "Use Tab to navigate between cells within a row";
            this.lblInstructions.Click += new System.EventHandler(this.lblInstructions_Click);
            // 
            // btnRefresh
            // 
            this.btnRefresh.Font = new System.Drawing.Font("Arial", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.btnRefresh.Location = new System.Drawing.Point(351, 321);
            this.btnRefresh.Name = "btnRefresh";
            this.btnRefresh.Size = new System.Drawing.Size(64, 23);
            this.btnRefresh.TabIndex = 35;
            this.btnRefresh.Text = "Refresh";
            this.btnRefresh.Click += new System.EventHandler(this.btnRefresh_Click);
            // 
            // StrategicObjectives
            // 
            this.Controls.Add(this.btnRefresh);
            this.Controls.Add(this.lblInstructions);
            this.Controls.Add(this.uwgObjectives);
            this.Controls.Add(this.btnCancel);
            this.Controls.Add(this.btnSave);
            this.Controls.Add(this.btnDelete);
            this.Controls.Add(this.btnAdd);
            this.Name = "StrategicObjectives";
            this.Size = new System.Drawing.Size(943, 464);
            ((System.ComponentModel.ISupportInitialize)(this.uwgObjectives)).EndInit();
            this.ResumeLayout(false);

		}
		#endregion

		private void lblInstructions_Click(object sender, System.EventArgs e)
		{
		
		}

        private void btnRefresh_Click(object sender, EventArgs e)
        {
            if (blnGridDirty)
            {
                if (DialogResult.OK == MessageBox.Show("Save changes first?", "Data changed warning.", MessageBoxButtons.OKCancel))
                {
                    SaveGrid();
                    return;
                }
            }
            blnGridDirty = false;
            LoadGrid();
            SetButtons();
        }
	}
}
