﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using System.Drawing;
using System.Drawing.Imaging;

namespace CCPM.ProjectImages
{
	internal class ImageSizeValidation
	{
		public delegate void MessageEventHandler( string msg );
		public event MessageEventHandler ImageMessage;

		public byte[] ReduceToSize( Bitmap src, int maxSize )
		{
			return ReduceToSize( src, maxSize, 0.9F );
		}

		public byte[] ReduceToSize( Bitmap src, int maxSize, float reductionStep )
		{
			byte[] result = null;

			// Attempt 1: Recompress with PNG
			byte[] test = CompressImage( src, ImageFormat.Png );

			if( test.Length < maxSize )
			{
				result = test;
				SendMessage( "Recompressed to PNG.  New size: {0}", result.Length );
			}

			if( result == null )
			{
				// Attempt 2: Recompress with JPG
				test = CompressImage( src, ImageFormat.Jpeg );

				if( test.Length < maxSize )
				{
					result = test;
					SendMessage( "Recompressed to JPG.  New size: {0}", result.Length );
				}
			}

			// Attempt 3: Resize and recompress
			if( result == null )
			{
				int workingWidth = src.Width;
				int workingHeight = src.Height;

				do
				{
					// Reduce size 
					int newWidth = (int)( workingWidth * reductionStep );
					int newHeight = (int)( workingHeight * reductionStep );

					Bitmap resizedImg = new Bitmap( src.GetThumbnailImage(
						newWidth,
						newHeight,
						delegate()
						{
							SendMessage( "*** Unable to resize image" );
							return true;
						},
						System.IntPtr.Zero ) );

					if( resizedImg != null )
					{
						test = CompressImage( resizedImg, ImageFormat.Png );

						if( test.Length < maxSize )
						{
							SendMessage( "Resized and compressed to PNG.  New size: ({0}, {1}) - {2} bytes",
								resizedImg.Width, resizedImg.Height, test.Length );
							result = test;
						}
						else
						{
							test = CompressImage( resizedImg, ImageFormat.Jpeg );

							if( test.Length < maxSize )
							{
								SendMessage( "Resized and compressed to JPG.  New size: ({0}, {1}) - {2} bytes",
									resizedImg.Width, resizedImg.Height, test.Length );
								result = test;
							}
							else
							{
								// prepare for next iteration
								workingWidth = newWidth;
								workingHeight = newHeight;
							}
						}
					}
					else
					{
						// Failed to resize, get out of the loop
						break;
					}
				} while( result == null );
			}

			return result;
		}

		private void SendMessage( string msg, params object[] args )
		{
			string output = string.Format( msg, args );

			if( ImageMessage != null )
				ImageMessage( output );
		}

		private byte[] CompressImage( Bitmap src, ImageFormat imageFormat )
		{
			byte[] result = null;

			using( System.IO.MemoryStream stream = new System.IO.MemoryStream() )
			{
				src.Save( stream, imageFormat );
				result = stream.ToArray();
			}
			return result;
		}
	}
}
