using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using System.IO;
using CCPM.Data;

namespace CCPM.ProjectImages
{
	/// <summary>
	/// Summary description for Images.
	/// </summary>
	public class Images : System.Windows.Forms.UserControl
	{
		private System.Windows.Forms.TextBox txtCaption;
		private System.Windows.Forms.ContextMenu cmImageList;
//		private System.Windows.Forms.MenuItem miAddImage;
//		private System.Windows.Forms.MenuItem miEditCaption;
//		private System.Windows.Forms.MenuItem menuItem4;
//		private System.Windows.Forms.MenuItem miDeleteImage;
		private System.Windows.Forms.OpenFileDialog FileOpenDlg;
		private System.Windows.Forms.Button btnSave;
		private int projectId;
		private int imageId = 0;
		private System.Windows.Forms.PictureBox pictureBox;
		private System.Windows.Forms.ListBox lbImage;
//		private System.Windows.Forms.MenuItem miEditImageName;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label lblImageCredit;
		private System.Windows.Forms.TextBox txtImageCredit;
		private System.Windows.Forms.Button btnCancel;
		private System.Windows.Forms.Button btnAdd;
		private System.Windows.Forms.Button btnDelete;
		public string _AddMode = "ADD";
		public string _ViewMode = "VIEW";
		public string _EditMode = "EDIT";
		public string _mode = "";   // Project form references this
		private System.Windows.Forms.Button btnEdit;  // current mode for form

		/// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		
		public int ProjectId
		{
			get{return projectId;}
			set{projectId = value;}
		}
		public int ImageId
		{
			get{return imageId;}
			set{imageId = value;}
		}
		private void Images_Load(object sender, System.EventArgs e)
		{
			BindList();
			if(lbImage.Items.Count > 0)
			{
				DataRowView drv = (DataRowView)lbImage.Items[0];
				ImageId = (int)drv["ImageId"];
				ShowImage(ImageId);
			}
			this.lbImage.SelectedIndexChanged +=new EventHandler(lbImage_SelectedIndexChanged);

			this._mode = this._ViewMode;
			this.SetControls();
			this.SetButtons();
		}

		public Images(int projectId)
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			ProjectId = projectId;
			this.Load += new EventHandler(Images_Load);
		}
		private void ShowImage(int imageId)
		{
			if (imageId>0)
				{
				DataSet dsImage = ResourceData.ImageById(imageId);
				DataRow dr = dsImage.Tables[0].Rows[0];
		
				byte[] b = (byte[])dr["Image"];
				if(b.Length > 0)
				{
					System.IO.MemoryStream stream = new System.IO.MemoryStream(b);
					// Draw photo to scale of picturebox
					DrawToScale(new Bitmap(stream));
				
					stream.Close();
				}

				//	lblCaption.Text = (string)dr["Caption"] == string.Empty ? "click here to enter caption" : (string)dr["Caption"];
				//  lblImageCredit.Text = dr["ImageCredit"].ToString();
				txtCaption.Text = dr["Caption"].ToString();
				txtImageCredit.Text = dr["ImageCredit"].ToString();
			}
		}
		private void ShowImage(byte[] b)
		{
			if(b.Length > 0)
			{
				System.IO.MemoryStream stream = new System.IO.MemoryStream(b, true);
					
				// Draw photo to scale of picturebox
				DrawToScale(new Bitmap(stream));
				
				stream.Close();
			}
		}
		private void BindList()
		{
			this.lbImage.DataSource = ResourceData.ImageList(ProjectId);
			lbImage.DisplayMember = "Table.ImageName";
			lbImage.ValueMember = "Table.ImageId";
			
		}
		private void DrawToScale(Image bmp)
		{
			// The client rectangle
			Rectangle rc = pictureBox.ClientRectangle;

			// Figure out the scaling necessary for the image
			SizeF size = new SizeF( bmp.Width / bmp.HorizontalResolution, bmp.Height / bmp.VerticalResolution);
			float fScale = Math.Min( rc.Width / size.Width, rc.Height / size.Height);

			size.Width *= fScale;
			size.Height *= fScale;

			// Create a new bitmap of the proper size for the existing bitmap
			// and assign it to the picture box
			pictureBox.Image = new Bitmap(bmp, size.ToSize());
		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}


		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.pictureBox = new System.Windows.Forms.PictureBox();
			this.txtCaption = new System.Windows.Forms.TextBox();
			this.btnSave = new System.Windows.Forms.Button();
			this.cmImageList = new System.Windows.Forms.ContextMenu();
			this.FileOpenDlg = new System.Windows.Forms.OpenFileDialog();
			this.lbImage = new System.Windows.Forms.ListBox();
			this.lblImageCredit = new System.Windows.Forms.Label();
			this.label1 = new System.Windows.Forms.Label();
			this.label2 = new System.Windows.Forms.Label();
			this.txtImageCredit = new System.Windows.Forms.TextBox();
			this.btnCancel = new System.Windows.Forms.Button();
			this.btnAdd = new System.Windows.Forms.Button();
			this.btnDelete = new System.Windows.Forms.Button();
			this.btnEdit = new System.Windows.Forms.Button();
			this.SuspendLayout();
			// 
			// pictureBox
			// 
			this.pictureBox.Location = new System.Drawing.Point(131, 0);
			this.pictureBox.Name = "pictureBox";
			this.pictureBox.Size = new System.Drawing.Size(500, 300);
			this.pictureBox.TabIndex = 1;
			this.pictureBox.TabStop = false;
			// 
			// txtCaption
			// 
			this.txtCaption.Location = new System.Drawing.Point(200, 323);
			this.txtCaption.MaxLength = 255;
			this.txtCaption.Multiline = true;
			this.txtCaption.Name = "txtCaption";
			this.txtCaption.Size = new System.Drawing.Size(504, 45);
			this.txtCaption.TabIndex = 3;
			this.txtCaption.Text = "";
			// 
			// btnSave
			// 
			this.btnSave.Location = new System.Drawing.Point(435, 440);
			this.btnSave.Name = "btnSave";
			this.btnSave.Size = new System.Drawing.Size(59, 23);
			this.btnSave.TabIndex = 5;
			this.btnSave.Text = "Save";
			this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
			// 
			// FileOpenDlg
			// 
			this.FileOpenDlg.Filter = "Jpeg Files|*.jpg;*.jpeg|Gif files|*.gif|Bmp Files|*.bmp";
			this.FileOpenDlg.Multiselect = true;
			this.FileOpenDlg.Title = "Select Photos";
			// 
			// lbImage
			// 
			this.lbImage.Location = new System.Drawing.Point(0, 323);
			this.lbImage.Name = "lbImage";
			this.lbImage.Size = new System.Drawing.Size(192, 108);
			this.lbImage.TabIndex = 7;
			// 
			// lblImageCredit
			// 
			this.lblImageCredit.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.lblImageCredit.Location = new System.Drawing.Point(200, 389);
			this.lblImageCredit.Name = "lblImageCredit";
			this.lblImageCredit.Size = new System.Drawing.Size(504, 40);
			this.lblImageCredit.TabIndex = 5;
			// 
			// label1
			// 
			this.label1.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.label1.Location = new System.Drawing.Point(203, 373);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(100, 11);
			this.label1.TabIndex = 6;
			this.label1.Text = "Photo Credit:";
			// 
			// label2
			// 
			this.label2.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
			this.label2.Location = new System.Drawing.Point(205, 306);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(100, 16);
			this.label2.TabIndex = 7;
			this.label2.Text = "Caption:";
			// 
			// txtImageCredit
			// 
			this.txtImageCredit.Location = new System.Drawing.Point(200, 389);
			this.txtImageCredit.MaxLength = 80;
			this.txtImageCredit.Multiline = true;
			this.txtImageCredit.Name = "txtImageCredit";
			this.txtImageCredit.Size = new System.Drawing.Size(504, 40);
			this.txtImageCredit.TabIndex = 4;
			this.txtImageCredit.Text = "";
			// 
			// btnCancel
			// 
			this.btnCancel.Location = new System.Drawing.Point(510, 440);
			this.btnCancel.Name = "btnCancel";
			this.btnCancel.Size = new System.Drawing.Size(59, 23);
			this.btnCancel.TabIndex = 6;
			this.btnCancel.Text = "Cancel";
			this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
			// 
			// btnAdd
			// 
			this.btnAdd.Location = new System.Drawing.Point(200, 440);
			this.btnAdd.Name = "btnAdd";
			this.btnAdd.Size = new System.Drawing.Size(64, 23);
			this.btnAdd.TabIndex = 1;
			this.btnAdd.Text = "Add";
			this.btnAdd.Click += new System.EventHandler(this.btnAdd_Click);
			// 
			// btnDelete
			// 
			this.btnDelete.Location = new System.Drawing.Point(360, 440);
			this.btnDelete.Name = "btnDelete";
			this.btnDelete.Size = new System.Drawing.Size(59, 23);
			this.btnDelete.TabIndex = 11;
			this.btnDelete.Text = "Delete";
			this.btnDelete.Click += new System.EventHandler(this.btnDelete_Click);
			// 
			// btnEdit
			// 
			this.btnEdit.Location = new System.Drawing.Point(280, 440);
			this.btnEdit.Name = "btnEdit";
			this.btnEdit.Size = new System.Drawing.Size(64, 23);
			this.btnEdit.TabIndex = 2;
			this.btnEdit.Text = "Edit";
			this.btnEdit.Click += new System.EventHandler(this.btnEdit_Click);
			// 
			// Images
			// 
			this.ContextMenu = this.cmImageList;
			this.Controls.Add(this.btnEdit);
			this.Controls.Add(this.btnDelete);
			this.Controls.Add(this.btnAdd);
			this.Controls.Add(this.btnCancel);
			this.Controls.Add(this.txtImageCredit);
			this.Controls.Add(this.label2);
			this.Controls.Add(this.label1);
			this.Controls.Add(this.lblImageCredit);
			this.Controls.Add(this.btnSave);
			this.Controls.Add(this.pictureBox);
			this.Controls.Add(this.lbImage);
			this.Controls.Add(this.txtCaption);
			this.Name = "Images";
			this.Size = new System.Drawing.Size(762, 464);
			this.ResumeLayout(false);

		}
		#endregion


		private void SetControls()
		{
			if (_mode == _ViewMode)
			{
				this.txtCaption.Enabled = false;
				this.txtImageCredit.Enabled = false;
				this.lbImage.Enabled = true;
			}
			else
			{
				this.lbImage.Enabled = false;
				this.txtCaption.Enabled = true;
				this.txtImageCredit.Enabled = true;
			}
		}

		private void SetButtons()
		{
			// set detail page buttons to appropriate state
			if (_mode==_ViewMode)
			{
				if(lbImage.Items.Count > 0)
				{
					this.btnEdit.Enabled = true;
					this.btnDelete.Enabled = true;
				}
				else
				{
					this.btnEdit.Enabled = false;
					this.btnDelete.Enabled = false;
				}

				// ADS 6-Nov-2007 - Changed to only allow adding a total of 2 images
				this.btnAdd.Enabled = ( lbImage.Items.Count < 2 );

				this.btnSave.Enabled = false;
				this.btnCancel.Enabled = false;
			}
			else if (_mode == _EditMode | _mode == _AddMode)
			{
				this.btnEdit.Enabled = false;
				this.btnAdd.Enabled = false;
				this.btnDelete.Enabled = false;
				this.btnSave.Enabled = true;
				this.btnCancel.Enabled = true;
			}
		}
        	
		public void miAddImage_Click(object sender, System.EventArgs e)
		{
			// Show the file open dialog
			if( DialogResult.OK == FileOpenDlg.ShowDialog() )
			{
				byte[] buffer = null;
				int limit = int.Parse( System.Configuration.ConfigurationSettings.AppSettings[ "ImageSizeLimit" ]) * 1024;

				// We allow multiple selections so loop through each one
				foreach( string file in FileOpenDlg.FileNames )
				{
					// ADS 13-Dec-2007 - 2.9.2 - Check file size for limit excursion
					System.IO.FileInfo info = new FileInfo( file );
					string name = System.IO.Path.GetFileNameWithoutExtension( file );

					if( info.Length > limit )
					{
						// ADS 11-Jul-2008 - 2.9.4 - Image is too large, resize it to fit
						Bitmap original = new Bitmap( info.FullName );
						ImageSizeValidation resizer = new ImageSizeValidation();
						buffer = resizer.ReduceToSize( original, limit );
					}
					else
					{
						// Create a new stream to load this photo into
						System.IO.FileStream stream = new System.IO.FileStream( file, System.IO.FileMode.Open, System.IO.FileAccess.Read );
						buffer = new byte[stream.Length];
						stream.Read( buffer, 0, (int)stream.Length );
						stream.Close();
					}

					// Insert the image into the database
					ResourceData.ImageInsert( ProjectId, name, ref buffer );
					buffer = null;

					BindList();
					lbImage.SelectedIndex = lbImage.Items.Count - 1;
				}
			}
		}

		private void btnSave_Click(object sender, System.EventArgs e)
		{
//			if (_mode==_AddMode)
			{
                ResourceData.ImageCaptionUpdate(ImageId, txtCaption.Text, txtImageCredit.Text);			
				_mode = _ViewMode;
				Form1 f = (Form1) this.ParentForm.MdiParent;
				f.EnableMenusAll();

				this.SetControls();
				this.SetButtons();
			}	


//			//if(txtCaption.Text != string.Empty)
//			//{
//				ResourceData.ImageCaptionUpdate(ImageId, txtCaption.Text, txtImageCredit.Text);
//				lblCaption.Text = txtCaption.Text;
//				lblImageCredit.Text = txtImageCredit.Text;
//			//}
//			txtCaption.Visible = false;
//			lblCaption.Visible = true;
//
//			txtImageCredit.Visible = false;
//			lblImageCredit.Visible = true;
//
//			btnSave.Visible = false;
//			btnCancel.Visible = false;
		}

//		public void lblCaption_Click(object sender, System.EventArgs e)
//		{
//			if(ImageId != 0)
//			{
//				lblCaption.Visible = false;
//				txtCaption.Visible = true;
//				lblImageCredit.Visible = false;
//				txtImageCredit.Visible = true;
//				btnSave.Visible = true;
//				btnCancel.Visible = true;
//
//				if(lblCaption.Text	!= "click here to enter caption")
//				{
//					txtCaption.Text = lblCaption.Text;
//					txtImageCredit.Text = lblImageCredit.Text;
//				}
//				else
//				{
//					txtCaption.Focus();
//				}
//			}
			
//		}
		public void lbImage_SelectedIndexChanged(object sender, EventArgs e)
		{
		//	txtCaption.Visible = false;
		//	lblCaption.Visible = true;
	//		txtImageCredit.Visible = false;
	//		lblImageCredit.Visible = true;
			DataRowView drv = (DataRowView)lbImage.Items[lbImage.SelectedIndex];
			ImageId = (int)drv["ImageId"];
			ShowImage(ImageId);
		}

		public void miReplaceImage_Click(object sender, System.EventArgs e)
		{
			byte[] buffer = null;
			// Show the file open dialog
			if( DialogResult.OK == FileOpenDlg.ShowDialog() )
			{
				// Create a new stream to load this photo into
				string file = FileOpenDlg.FileName;
				System.IO.FileStream stream = new System.IO.FileStream(file, System.IO.FileMode.Open, System.IO.FileAccess.Read);
				buffer = new byte[stream.Length];
				stream.Read(buffer, 0, (int)stream.Length);
				stream.Close();

				string name = System.IO.Path.GetFileNameWithoutExtension(file);

				// Insert the image into the database
				ResourceData.ImageRplace(ImageId, ref buffer);
			}
			
			ShowImage(buffer);
			buffer = null;
		}

		private void DeleteRow()
		{
			//Delete image
			int selectedIndex = lbImage.SelectedIndex;
			DataRowView drv = (DataRowView)lbImage.Items[selectedIndex];
			ImageId = (int)drv["ImageId"];
			ResourceData.ImageDelte(ImageId);
			//Reset the image list
			BindList();
			//Set image list to top
			if(lbImage.Items.Count > 0)
			{
				lbImage.SelectedIndex = 0;
				drv = (DataRowView)lbImage.Items[lbImage.SelectedIndex];
				ImageId = (int)drv["ImageId"];
				ShowImage(ImageId);
			}
			else
			{
				ImageId = 0;
				pictureBox.Image = null;
				this.txtCaption.Text= "";
				this.txtImageCredit.Text = "";
			}
		}

//		private void menuItem1_Click(object sender, System.EventArgs e)
//		{
//			
//			int selectedIndex = lbImage.SelectedIndex;
//			if(selectedIndex != -1)
//			{
//				DataRowView drv = (DataRowView)lbImage.Items[selectedIndex];
//				ImageId = (int)drv["ImageId"];
//				string imageName = (string)drv["ImageName"];
//				ImageUpdateName iun = new ImageUpdateName(ImageId, imageName);
//				DialogResult dialogResult = iun.ShowDialog(this);
//				if(dialogResult == DialogResult.OK)
//				{
//					//Reset the image list
//					BindList();
//					lbImage.SelectedIndex = selectedIndex;
//				}
//			}
//		}

		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			if (this._mode==this._AddMode)
				DeleteRow();
            
			this._mode = this._ViewMode;
			Form1 f = (Form1) this.ParentForm.MdiParent;
			f.EnableMenusAll();
			this.SetButtons();
			this.SetControls();
			this.ShowImage(this.imageId);
		}

		private void btnAdd_Click(object sender, System.EventArgs e)
		{
			// Show the file open dialog
			if( DialogResult.OK == FileOpenDlg.ShowDialog() )
			{
				
				this._mode = this._AddMode;
				this.SetButtons();
				this.SetControls();
				Form1 f = (Form1) this.ParentForm.MdiParent;
				f.DisableMenusAll();

				byte[] buffer = null;
				int limit = int.Parse( System.Configuration.ConfigurationSettings.AppSettings[ "ImageSizeLimit" ]) * 1024;
				int count = 0;
               
				// We allow multiple selections so loop through each one
				foreach( string file in FileOpenDlg.FileNames )
				{
					// ADS 13-Dec-2007 - 2.9.2 - Check file size for limit excursion
					System.IO.FileInfo info = new FileInfo( file );
                    string name = System.IO.Path.GetFileNameWithoutExtension(file);
					if( info.Length > limit )
					{
                        //string msg = string.Format( "Image {0} is too large.  The limit is {1} bytes.", file, limit );
                        //MessageBox.Show( msg, "Image Size Error", MessageBoxButtons.OK, MessageBoxIcon.Error );
                        Bitmap original = new Bitmap(info.FullName);
                        ImageSizeValidation resizer = new ImageSizeValidation();
                        buffer = resizer.ReduceToSize(original, limit);
					}
					else
					{
						// Create a new stream to load this photo into
						System.IO.FileStream stream = new System.IO.FileStream(file, System.IO.FileMode.Open, System.IO.FileAccess.Read);
						buffer = new byte[stream.Length];
						stream.Read(buffer, 0, (int)stream.Length);
						stream.Close();

						//string name = System.IO.Path.GetFileNameWithoutExtension(file);

						// Insert the image into the database
                        //ResourceData.ImageInsert(ProjectId, name, ref buffer);
                        //buffer = null;
                        //count ++;
					}
                    ResourceData.ImageInsert(ProjectId, name, ref buffer);
                    buffer = null;

                    BindList();
                    lbImage.SelectedIndex = lbImage.Items.Count - 1;

				}
              
				// ADS 12-Feb-2008 - Revert if no images added
                //if( count > 0 )
                //{
                //    BindList();
                //    lbImage.SelectedIndex = lbImage.Items.Count - 1;
                //    this.txtCaption.Focus();
                //}
                //else
                //{
                //    this._mode = this._ViewMode;
                //    f.EnableMenusAll();
                //    this.SetButtons();
                //    this.SetControls();
                //}
			}
		}

		private void btnEdit_Click(object sender, System.EventArgs e)
		{
			_mode = _EditMode;
			Form1 f = (Form1) this.ParentForm.MdiParent;
			f.DisableMenusAll();

			SetButtons();
			SetControls();
		}

		private void btnDelete_Click(object sender, System.EventArgs e)
		{
			int selectedIndex = lbImage.SelectedIndex;
			if(selectedIndex != -1)
			{
				DialogResult intDiagResult = MessageBox.Show("Do you want to delete this Image?","Delete Image", 
					MessageBoxButtons.YesNo, MessageBoxIcon.Question);
				if (intDiagResult == DialogResult.Yes)
				{
					//Delete image
					DeleteRow();
				}
			}
			SetButtons();
		}

		public void ImagesSaveReminderMsg()
		{
			string msg = "Changes have been made on the Images screen. Please save or cancel your changes.";
			DialogResult intDiagResult = MessageBox.Show(this,msg, "Data Changed", MessageBoxButtons.OK, MessageBoxIcon.Warning);
		}

	}
}
//public class Images : System.Windows.Forms.UserControl
//{
//	private System.Windows.Forms.TextBox txtCaption;
//	private System.Windows.Forms.ContextMenu cmImageList;
//	private System.Windows.Forms.MenuItem miAddImage;
//	private System.Windows.Forms.MenuItem miEditCaption;
//	private System.Windows.Forms.MenuItem menuItem4;
//	private System.Windows.Forms.MenuItem miDeleteImage;
//	private System.Windows.Forms.OpenFileDialog FileOpenDlg;
//	private System.Windows.Forms.Label lblCaption;
//	private System.Windows.Forms.Button btnSave;
//	private int projectId;
//	private int imageId = 0;
//	private System.Windows.Forms.PictureBox pictureBox;
//	private System.Windows.Forms.ListBox lbImage;
//	private System.Windows.Forms.MenuItem miEditImageName;
//	private System.Windows.Forms.Label label1;
//	private System.Windows.Forms.Label label2;
//	private System.Windows.Forms.Label lblImageCredit;
//	private System.Windows.Forms.TextBox txtImageCredit;
//	private System.Windows.Forms.Button btnCancel;
//	/// <summary> 
//	/// Required designer variable.
//	/// </summary>
//	private System.ComponentModel.Container components = null;
//		
//	public int ProjectId
//	{
//		get{return projectId;}
//		set{projectId = value;}
//	}
//	public int ImageId
//	{
//		get{return imageId;}
//		set{imageId = value;}
//	}
//	public Images(int projectId)
//	{
//		// This call is required by the Windows.Forms Form Designer.
//		InitializeComponent();
//
//		ProjectId = projectId;
//		this.Load += new EventHandler(Images_Load);
//	}
//	private void ShowImage(int imageId)
//	{
//		DataSet dsImage = ResourceData.ImageById(imageId);
//		DataRow dr = dsImage.Tables[0].Rows[0];
//		
//		byte[] b = (byte[])dr["Image"];
//		if(b.Length > 0)
//		{
//			System.IO.MemoryStream stream = new System.IO.MemoryStream(b);
//			// Draw photo to scale of picturebox
//			DrawToScale(new Bitmap(stream));
//				
//			stream.Close();
//		}
//
//		lblCaption.Text = (string)dr["Caption"] == string.Empty ? "click here to enter caption" : (string)dr["Caption"];
//		lblImageCredit.Text = dr["ImageCredit"].ToString();
//	}
//	private void ShowImage(byte[] b)
//	{
//		if(b.Length > 0)
//		{
//			System.IO.MemoryStream stream = new System.IO.MemoryStream(b, true);
//					
//			// Draw photo to scale of picturebox
//			DrawToScale(new Bitmap(stream));
//				
//			stream.Close();
//		}
//	}
//	private void BindList()
//	{
//		this.lbImage.DataSource = ResourceData.ImageList(ProjectId);
//		lbImage.DisplayMember = "Table.ImageName";
//		lbImage.ValueMember = "Table.ImageId";
//			
//	}
//	private void DrawToScale(Image bmp)
//	{
//		// The client rectangle
//		Rectangle rc = pictureBox.ClientRectangle;
//
//		// Figure out the scaling necessary for the image
//		SizeF size = new SizeF( bmp.Width / bmp.HorizontalResolution, bmp.Height / bmp.VerticalResolution);
//		float fScale = Math.Min( rc.Width / size.Width, rc.Height / size.Height);
//
//		size.Width *= fScale;
//		size.Height *= fScale;
//
//		// Create a new bitmap of the proper size for the existing bitmap
//		// and assign it to the picture box
//		pictureBox.Image = new Bitmap(bmp, size.ToSize());
//	}
//
//	/// <summary> 
//	/// Clean up any resources being used.
//	/// </summary>
//	protected override void Dispose( bool disposing )
//	{
//		if( disposing )
//		{
//			if(components != null)
//			{
//				components.Dispose();
//			}
//		}
//		base.Dispose( disposing );
//	}
//
//
//	#region Component Designer generated code
//	/// <summary> 
//	/// Required method for Designer support - do not modify 
//	/// the contents of this method with the code editor.
//	/// </summary>
//	private void InitializeComponent()
//	{
//		this.pictureBox = new System.Windows.Forms.PictureBox();
//		this.lblCaption = new System.Windows.Forms.Label();
//		this.txtCaption = new System.Windows.Forms.TextBox();
//		this.btnSave = new System.Windows.Forms.Button();
//		this.cmImageList = new System.Windows.Forms.ContextMenu();
//		this.miAddImage = new System.Windows.Forms.MenuItem();
//		this.miEditCaption = new System.Windows.Forms.MenuItem();
//		this.miEditImageName = new System.Windows.Forms.MenuItem();
//		this.menuItem4 = new System.Windows.Forms.MenuItem();
//		this.miDeleteImage = new System.Windows.Forms.MenuItem();
//		this.FileOpenDlg = new System.Windows.Forms.OpenFileDialog();
//		this.lbImage = new System.Windows.Forms.ListBox();
//		this.lblImageCredit = new System.Windows.Forms.Label();
//		this.label1 = new System.Windows.Forms.Label();
//		this.label2 = new System.Windows.Forms.Label();
//		this.txtImageCredit = new System.Windows.Forms.TextBox();
//		this.btnCancel = new System.Windows.Forms.Button();
//		this.SuspendLayout();
//		// 
//		// pictureBox
//		// 
//		this.pictureBox.Location = new System.Drawing.Point(208, 0);
//		this.pictureBox.Name = "pictureBox";
//		this.pictureBox.Size = new System.Drawing.Size(500, 300);
//		this.pictureBox.TabIndex = 1;
//		this.pictureBox.TabStop = false;
//		// 
//		// lblCaption
//		// 
//		this.lblCaption.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
//		this.lblCaption.Location = new System.Drawing.Point(200, 323);
//		this.lblCaption.Name = "lblCaption";
//		this.lblCaption.Size = new System.Drawing.Size(504, 45);
//		this.lblCaption.TabIndex = 2;
//		this.lblCaption.Text = "Click to add caption";
//		this.lblCaption.Click += new System.EventHandler(this.lblCaption_Click);
//		// 
//		// txtCaption
//		// 
//		this.txtCaption.Location = new System.Drawing.Point(200, 323);
//		this.txtCaption.MaxLength = 255;
//		this.txtCaption.Multiline = true;
//		this.txtCaption.Name = "txtCaption";
//		this.txtCaption.Size = new System.Drawing.Size(504, 45);
//		this.txtCaption.TabIndex = 3;
//		this.txtCaption.Text = "";
//		this.txtCaption.Visible = false;
//		// 
//		// btnSave
//		// 
//		this.btnSave.Location = new System.Drawing.Point(511, 436);
//		this.btnSave.Name = "btnSave";
//		this.btnSave.Size = new System.Drawing.Size(88, 23);
//		this.btnSave.TabIndex = 4;
//		this.btnSave.Text = "Save";
//		this.btnSave.Visible = false;
//		this.btnSave.Click += new System.EventHandler(this.btnSave_Click);
//		// 
//		// cmImageList
//		// 
//		this.cmImageList.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
//																					this.miAddImage,
//																					this.miEditCaption,
//																					this.miEditImageName,
//																					this.menuItem4,
//																					this.miDeleteImage});
//		// 
//		// miAddImage
//		// 
//		this.miAddImage.Index = 0;
//		this.miAddImage.Text = "Add Image";
//		this.miAddImage.Click += new System.EventHandler(this.miAddImage_Click);
//		// 
//		// miEditCaption
//		// 
//		this.miEditCaption.Index = 1;
//		this.miEditCaption.Text = "Edit Caption and Credit";
//		this.miEditCaption.Click += new System.EventHandler(this.lblCaption_Click);
//		// 
//		// miEditImageName
//		// 
//		this.miEditImageName.Index = 2;
//		this.miEditImageName.Text = "Edit Image Name";
//		this.miEditImageName.Click += new System.EventHandler(this.menuItem1_Click);
//		// 
//		// menuItem4
//		// 
//		this.menuItem4.Index = 3;
//		this.menuItem4.Text = "-";
//		// 
//		// miDeleteImage
//		// 
//		this.miDeleteImage.Index = 4;
//		this.miDeleteImage.Text = "Delete Image";
//		this.miDeleteImage.Click += new System.EventHandler(this.miDeleteImage_Click);
//		// 
//		// FileOpenDlg
//		// 
//		this.FileOpenDlg.Filter = "Jpeg Files|*.jpg;*.jpeg|Gif files|*.gif|Bmp Files|*.bmp";
//		this.FileOpenDlg.Multiselect = true;
//		this.FileOpenDlg.Title = "Select Photos";
//		// 
//		// lbImage
//		// 
//		this.lbImage.Dock = System.Windows.Forms.DockStyle.Left;
//		this.lbImage.Location = new System.Drawing.Point(0, 0);
//		this.lbImage.Name = "lbImage";
//		this.lbImage.Size = new System.Drawing.Size(192, 459);
//		this.lbImage.TabIndex = 0;
//		// 
//		// lblImageCredit
//		// 
//		this.lblImageCredit.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
//		this.lblImageCredit.Location = new System.Drawing.Point(200, 389);
//		this.lblImageCredit.Name = "lblImageCredit";
//		this.lblImageCredit.Size = new System.Drawing.Size(504, 40);
//		this.lblImageCredit.TabIndex = 5;
//		// 
//		// label1
//		// 
//		this.label1.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
//		this.label1.Location = new System.Drawing.Point(203, 373);
//		this.label1.Name = "label1";
//		this.label1.Size = new System.Drawing.Size(100, 11);
//		this.label1.TabIndex = 6;
//		this.label1.Text = "Credit:";
//		// 
//		// label2
//		// 
//		this.label2.Font = new System.Drawing.Font("Arial", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
//		this.label2.Location = new System.Drawing.Point(205, 306);
//		this.label2.Name = "label2";
//		this.label2.Size = new System.Drawing.Size(100, 16);
//		this.label2.TabIndex = 7;
//		this.label2.Text = "Caption:";
//		// 
//		// txtImageCredit
//		// 
//		this.txtImageCredit.Location = new System.Drawing.Point(200, 389);
//		this.txtImageCredit.Multiline = true;
//		this.txtImageCredit.Name = "txtImageCredit";
//		this.txtImageCredit.Size = new System.Drawing.Size(504, 40);
//		this.txtImageCredit.TabIndex = 8;
//		this.txtImageCredit.Text = "";
//		this.txtImageCredit.Visible = false;
//		// 
//		// btnCancel
//		// 
//		this.btnCancel.Location = new System.Drawing.Point(616, 436);
//		this.btnCancel.Name = "btnCancel";
//		this.btnCancel.Size = new System.Drawing.Size(88, 23);
//		this.btnCancel.TabIndex = 9;
//		this.btnCancel.Text = "Cancel";
//		this.btnCancel.Visible = false;
//		this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
//		// 
//		// Images
//		// 
//		this.ContextMenu = this.cmImageList;
//		this.Controls.Add(this.btnCancel);
//		this.Controls.Add(this.txtImageCredit);
//		this.Controls.Add(this.label2);
//		this.Controls.Add(this.label1);
//		this.Controls.Add(this.lblImageCredit);
//		this.Controls.Add(this.btnSave);
//		this.Controls.Add(this.pictureBox);
//		this.Controls.Add(this.lbImage);
//		this.Controls.Add(this.lblCaption);
//		this.Controls.Add(this.txtCaption);
//		this.Name = "Images";
//		this.Size = new System.Drawing.Size(762, 464);
//		this.ResumeLayout(false);
//
//	}
//	#endregion
//
//	private void Images_Load(object sender, System.EventArgs e)
//	{
//		BindList();
//		if(lbImage.Items.Count > 0)
//		{
//			DataRowView drv = (DataRowView)lbImage.Items[0];
//			ImageId = (int)drv["ImageId"];
//			ShowImage(ImageId);
//		}
//		this.lbImage.SelectedIndexChanged +=new EventHandler(lbImage_SelectedIndexChanged);
//	}
//		
//	public void miAddImage_Click(object sender, System.EventArgs e)
//	{
//		// Show the file open dialog
//		if( DialogResult.OK == FileOpenDlg.ShowDialog() )
//		{
//			byte[] buffer = null;
//			// We allow multiple selections so loop through each one
//			foreach( string file in FileOpenDlg.FileNames )
//			{
//				// Create a new stream to load this photo into
//				System.IO.FileStream stream = new System.IO.FileStream(file, System.IO.FileMode.Open, System.IO.FileAccess.Read);
//				buffer = new byte[stream.Length];
//				stream.Read(buffer, 0, (int)stream.Length);
//				stream.Close();
//
//				string name = System.IO.Path.GetFileNameWithoutExtension(file);
//
//				// Insert the image into the database
//				ResourceData.ImageInsert(ProjectId, name, ref buffer);
//				buffer = null;
//			}
//		
//			BindList();
//			lbImage.SelectedIndex = lbImage.Items.Count - 1;
//		}
//	}
//
//	private void btnSave_Click(object sender, System.EventArgs e)
//	{
//		//if(txtCaption.Text != string.Empty)
//		//{
//		ResourceData.ImageCaptionUpdate(ImageId, txtCaption.Text, txtImageCredit.Text);
//		lblCaption.Text = txtCaption.Text;
//		lblImageCredit.Text = txtImageCredit.Text;
//		//}
//		txtCaption.Visible = false;
//		lblCaption.Visible = true;
//
//		txtImageCredit.Visible = false;
//		lblImageCredit.Visible = true;
//
//		btnSave.Visible = false;
//		btnCancel.Visible = false;
//	}
//
//	public void lblCaption_Click(object sender, System.EventArgs e)
//	{
//		if(ImageId != 0)
//		{
//			lblCaption.Visible = false;
//			txtCaption.Visible = true;
//			lblImageCredit.Visible = false;
//			txtImageCredit.Visible = true;
//			btnSave.Visible = true;
//			btnCancel.Visible = true;
//
//			if(lblCaption.Text	!= "click here to enter caption")
//			{
//				txtCaption.Text = lblCaption.Text;
//				txtImageCredit.Text = lblImageCredit.Text;
//			}
//			else
//			{
//				txtCaption.Focus();
//			}
//		}
//			
//	}
//	public void lbImage_SelectedIndexChanged(object sender, EventArgs e)
//	{
//		txtCaption.Visible = false;
//		lblCaption.Visible = true;
//		txtImageCredit.Visible = false;
//		lblImageCredit.Visible = true;
//		DataRowView drv = (DataRowView)lbImage.Items[lbImage.SelectedIndex];
//		ImageId = (int)drv["ImageId"];
//		ShowImage(ImageId);
//		btnSave.Visible = false;
//		btnCancel.Visible = false;
//	}
//
//	public void miReplaceImage_Click(object sender, System.EventArgs e)
//	{
//		byte[] buffer = null;
//		// Show the file open dialog
//		if( DialogResult.OK == FileOpenDlg.ShowDialog() )
//		{
//			// Create a new stream to load this photo into
//			string file = FileOpenDlg.FileName;
//			System.IO.FileStream stream = new System.IO.FileStream(file, System.IO.FileMode.Open, System.IO.FileAccess.Read);
//			buffer = new byte[stream.Length];
//			stream.Read(buffer, 0, (int)stream.Length);
//			stream.Close();
//
//			string name = System.IO.Path.GetFileNameWithoutExtension(file);
//
//			// Insert the image into the database
//			ResourceData.ImageRplace(ImageId, ref buffer);
//		}
//			
//		ShowImage(buffer);
//		buffer = null;
//	}
//
//	public void miDeleteImage_Click(object sender, System.EventArgs e)
//	{
//		int selectedIndex = lbImage.SelectedIndex;
//		if(selectedIndex != -1)
//		{
//			if(DialogResult.OK == MessageBox.Show(
//				"You are about to delete an image! Are you sure you want to do this?",
//				"Confirm Delete",
//				MessageBoxButtons.OKCancel,
//				MessageBoxIcon.Stop))
//			{
//				//Delete image
//				DataRowView drv = (DataRowView)lbImage.Items[selectedIndex];
//				ImageId = (int)drv["ImageId"];
//				ResourceData.ImageDelte(ImageId);
//				//Reset the image list
//				BindList();
//				//Set image list to top
//				if(lbImage.Items.Count > 0)
//				{
//					lbImage.SelectedIndex = 0;
//					drv = (DataRowView)lbImage.Items[lbImage.SelectedIndex];
//					ImageId = (int)drv["ImageId"];
//					ShowImage(ImageId);
//				}
//				else
//				{
//					pictureBox.Image = null;
//				}
//			}
//		}
//	}
//
//	private void menuItem1_Click(object sender, System.EventArgs e)
//	{
//			
//		int selectedIndex = lbImage.SelectedIndex;
//		if(selectedIndex != -1)
//		{
//			DataRowView drv = (DataRowView)lbImage.Items[selectedIndex];
//			ImageId = (int)drv["ImageId"];
//			string imageName = (string)drv["ImageName"];
//			ImageUpdateName iun = new ImageUpdateName(ImageId, imageName);
//			DialogResult dialogResult = iun.ShowDialog(this);
//			if(dialogResult == DialogResult.OK)
//			{
//				//Reset the image list
//				BindList();
//				lbImage.SelectedIndex = selectedIndex;
//			}
//		}
//	}
//
//	private void btnCancel_Click(object sender, System.EventArgs e)
//	{
//		txtCaption.Visible = false;
//		lblCaption.Visible = true;
//
//		txtImageCredit.Visible = false;
//		lblImageCredit.Visible = true;
//
//		btnSave.Visible = false;
//		btnCancel.Visible = false;
//
//		this.ShowImage(this.imageId);
//	}
//
//}

