﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace CCPM.ProjectRelated
{
    public partial class Agency : Form
    {
        private DataTable dtAgency = null;
        private int AgencyIndex = 0;
        private int AgencyId = -1;

        public Agency()
        {
            InitializeComponent();
            LoadAgency();
            NewAgency();
            btnSave.Enabled = false;
            btnDelete.Enabled = false;
        }

        private void LoadAgency()
        {
            dtAgency = Data.ProjectData.GetAllAgency().Tables[0];
            lstAgency.DataSource = dtAgency;
            lstAgency.ValueMember = "AgencyId";
            lstAgency.DisplayMember = "AgencyName";
        }


        private void lstAgency_SelectedIndexChanged(object sender, EventArgs e)
        {
            if ((AgencyId == -1) || (lstAgency.SelectedIndex == -1 ))
                return;

            if (btnSave.Enabled)
            {
                if (DialogResult.OK == MessageBox.Show("Save changes first?", "", MessageBoxButtons.OKCancel))
                    SaveAgency();
            }

            AgencyIndex = lstAgency.SelectedIndex;
            AgencyId = (int)dtAgency.Rows[AgencyIndex]["AgencyId"];
            txtAgencyId.Text = AgencyId.ToString();
            txtName.Text = dtAgency.Rows[AgencyIndex]["AgencyName"].ToString();
            txtAddress.Text = dtAgency.Rows[AgencyIndex]["Address"].ToString();
            txtCity.Text = dtAgency.Rows[AgencyIndex]["City"].ToString();
            txtState.Text = dtAgency.Rows[AgencyIndex]["State"].ToString();
            txtZip.Text = dtAgency.Rows[AgencyIndex]["Zip"].ToString();
            txtPhone.Text = dtAgency.Rows[AgencyIndex]["Phone"].ToString();
            txtFax.Text = dtAgency.Rows[AgencyIndex]["Fax"].ToString();
            txtWebAddress.Text = dtAgency.Rows[AgencyIndex]["WebAddress"].ToString();
            chkIsActive.Checked = (bool)dtAgency.Rows[AgencyIndex]["IsActive"];
            btnSave.Enabled = false;
            btnDelete.Enabled = true;
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            SaveAgency();
        }

        private void SaveAgency()
        {
            bool blnNewAgency = (AgencyId == 0);

            if (txtName.Text == string.Empty)
            {
                MessageBox.Show("Name required.");
                txtName.Focus();
                return;
            }
            int RetVal = CCPM.Data.ProjectData.AgencySave(AgencyId, txtName.Text.Trim(), txtAddress.Text.Trim(), 
                        txtCity.Text.Trim(), txtState.Text.Trim(),txtZip.Text.Trim(), txtPhone.Text.Trim(), txtFax.Text.Trim(),
                        txtWebAddress.Text.Trim(), chkIsActive.Checked);
            if (RetVal == -1)
            {
                MessageBox.Show("Agency save failure");
                return;
            }
            btnSave.Enabled = false; 
            
            if (blnNewAgency)
                AgencyId = RetVal;

            if (blnNewAgency)
            {
                AgencyId = RetVal;
                LoadAgency();
            }

        }

        private void cmdRefresh_Click(object sender, EventArgs e)
        {
            LoadAgency();
            if (AgencyId > 0)
                SetAgency();
            btnDelete.Enabled = false;
        }

        private void SetAgency()
        {
            for (int i = 0; i < dtAgency.Rows.Count; i++)
            {
                if ((int)dtAgency.Rows[i]["AgencyId"] == AgencyId)
                {
                    lstAgency.SelectedIndex = i;
                    break;
                }
            }
        }

        private void NewAgency()
        {
            lstAgency.SelectedIndex = -1;
            AgencyId = 0;
            txtAgencyId.Text=string.Empty;
            txtName.Text = string.Empty;
            txtAddress.Text = string.Empty;
            txtCity.Text = string.Empty;
            txtState.Text = string.Empty;
            txtZip.Text = string.Empty;
            txtPhone.Text = string.Empty;
            txtFax.Text = string.Empty;
            txtWebAddress.Text = string.Empty;
            chkIsActive.Checked = true;
            btnSave.Enabled = false;
            btnDelete.Enabled = false;
        }

        private void btnNewAgency_Click(object sender, EventArgs e)
        {
            if (btnSave.Enabled)
            {
                if (DialogResult.OK == MessageBox.Show("Save changes first?", "", MessageBoxButtons.OKCancel))
                    SaveAgency();
            }
            NewAgency();
            btnDelete.Enabled = false;
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            if (DialogResult.OK == MessageBox.Show("Delete " + txtName.Text + "?", "Confirm", MessageBoxButtons.OKCancel))
                DeleteAgency();
        }
        private void DeleteAgency()
        {
            if (AgencyId < 1)
            {
                btnDelete.Enabled = false;
                return;
            }
            btnSave.Enabled = false;
            int RetVal = CCPM.Data.ProjectData.AgencyDelete(AgencyId);
            if (RetVal == -1)
            {
                MessageBox.Show("Agency delete failure");
                return;
            }
        
                LoadAgency();
                NewAgency();
        }

        private bool ValidateName()
        {
            if (txtName.Text == string.Empty)
            {
                MessageBox.Show("Name required.");
                txtName.Focus();
                return false;
            }
            return true;
        }
        private void txtName_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void txtWebAddress_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void chkIsActive_CheckedChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void Agency_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (btnSave.Enabled)
            {
                if (DialogResult.OK == MessageBox.Show("Save changes first?", "", MessageBoxButtons.OKCancel))
                    SaveAgency();
            }
        }

        private void txtPhone_Leave(object sender, EventArgs e)
        {
            if (txtPhone.Text != string.Empty)
            {
                string pattern = "^\\(?(\\d{3})\\)?[- ]?(\\d{3})[- ]?(\\d{4})$";
                if (System.Text.RegularExpressions.Regex.IsMatch(txtPhone.Text, pattern) == false)
                {
                    MessageBox.Show("Invalid Phone Number !!", "Data Entry Error", MessageBoxButtons.OK);
                    txtPhone.Focus();
                }
            }

        }

        private void txtFax_Leave(object sender, EventArgs e)
        {

            if (txtFax.Text != string.Empty)
            {
                string pattern = "^\\(?(\\d{3})\\)?[- ]?(\\d{3})[- ]?(\\d{4})$";
                if (System.Text.RegularExpressions.Regex.IsMatch(txtFax.Text, pattern) == false)
                {
                    MessageBox.Show("Invalid Fax Number !!", "Data Entry Error", MessageBoxButtons.OK);
                    txtFax.Focus();
                }
            }
        }

        private void txtZip_Leave(object sender, EventArgs e)
        {
            if (txtZip.Text != string.Empty)
            {
                string pattern = @"^(\d{5}-\d{4}|\d{5}|\d{9})$";
                if (System.Text.RegularExpressions.Regex.IsMatch(txtZip.Text, pattern) == false)
                {
                    MessageBox.Show("Invalid Zip Code !!", "Data Entry Error", MessageBoxButtons.OK);
                    txtZip.Focus();
                }
            }

        }

        private void Agency_Load(object sender, EventArgs e)
        {

        }

        private void txtStreet_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void txtCity_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void txtState_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void txtZip_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void txtPhone_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void txtFax_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }


    }
}
