﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace CCPM.ProjectRelated
{
    public partial class AlertEmail : Form
    {
        private DataTable dtAlertEmail = null;
        private int AlertEmailIndex = 0;
        private int AlertEmailId = -1;

        public AlertEmail()
        {
            InitializeComponent();
            LoadAlertEmail();
            NewAlertEmail();
            btnSave.Enabled = false;
            btnDelete.Enabled = false;
        }

        private void LoadAlertEmail()
        {
            dtAlertEmail = Data.ProjectData.GetAllAlertEmails().Tables[0];
            lstAlertEmail.DataSource = dtAlertEmail;
            lstAlertEmail.ValueMember = "AlertId";
            lstAlertEmail.DisplayMember = "AlertType";
        }


        private void lstAlertEmail_SelectedIndexChanged(object sender, EventArgs e)
        {
            if ((AlertEmailId == -1) || (lstAlertEmail.SelectedIndex == -1 ))
                return;

            if (btnSave.Enabled)
            {
                if (DialogResult.OK == MessageBox.Show("Save changes first?", "", MessageBoxButtons.OKCancel))
                    SaveAlertEmail();
            }

            AlertEmailIndex = lstAlertEmail.SelectedIndex;
            AlertEmailId = (int)dtAlertEmail.Rows[AlertEmailIndex]["AlertId"];
            txtAlertEmailId.Text = AlertEmailId.ToString();
            txtAlertType.Text = dtAlertEmail.Rows[AlertEmailIndex]["AlertType"].ToString();
            txtName.Text = dtAlertEmail.Rows[AlertEmailIndex]["ProfileName"].ToString();
            txtRecipients.Text = dtAlertEmail.Rows[AlertEmailIndex]["Recipients"].ToString();
            txtEmailSubject.Text = dtAlertEmail.Rows[AlertEmailIndex]["EmailSubject"].ToString();
            txtEmailText.Text = dtAlertEmail.Rows[AlertEmailIndex]["EmailText"].ToString();
            chkIsActive.Checked = (bool)dtAlertEmail.Rows[AlertEmailIndex]["IsActive"];
            btnSave.Enabled = false;
            btnDelete.Enabled = true;
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            SaveAlertEmail();
        }

        private void SaveAlertEmail()
        {
            bool blnNewAlertEmail = (AlertEmailId == 0);

            if (txtAlertType.Text == string.Empty)
            {
                MessageBox.Show("Alert Type required.");
                txtAlertType.Focus();
                return;
            }

            if (txtName.Text == string.Empty)
            {
                MessageBox.Show("Name required.");
                txtName.Focus();
                return;
            }

            int RetVal = CCPM.Data.ProjectData.AlertEmailSave(AlertEmailId ,txtAlertType.Text.Trim(), txtName.Text.Trim(), txtRecipients.Text.Trim(),
                        txtEmailSubject.Text.Trim(), txtEmailText.Text.Trim(), chkIsActive.Checked);
            if (RetVal == -1)
            {
                MessageBox.Show("AlertEmail save failure");
                return;
            }
            btnSave.Enabled = false;

            if (blnNewAlertEmail)
                AlertEmailId = RetVal;

            if (blnNewAlertEmail)
            {
                AlertEmailId = RetVal;
                LoadAlertEmail();
            }
        }

        private void cmdRefresh_Click(object sender, EventArgs e)
        {
            LoadAlertEmail();
            if (AlertEmailId > 0)
                SetAlertEmail();
            btnDelete.Enabled = false;
        }

        private void SetAlertEmail()
        {
            for (int i = 0; i < dtAlertEmail.Rows.Count; i++)
            {
                if ((int)dtAlertEmail.Rows[i]["AlertId"] == AlertEmailId)
                {
                    lstAlertEmail.SelectedIndex = i;
                    break;
                }
            }
        }

        private void NewAlertEmail()
        {
            lstAlertEmail.SelectedIndex = -1;
            AlertEmailId = 0;
            txtAlertEmailId.Text=string.Empty;
            txtAlertType.Text = string.Empty;
            txtName.Text = string.Empty;
            txtRecipients.Text = string.Empty;
            txtEmailText.Text = string.Empty;
            txtEmailSubject.Text = string.Empty;
            chkIsActive.Checked = true;
            btnSave.Enabled = false;
            btnDelete.Enabled = false;
        }

        private void btnNewAlertEmail_Click(object sender, EventArgs e)
        {
            if (btnSave.Enabled)
            {
                if (DialogResult.OK == MessageBox.Show("Save changes first?", "", MessageBoxButtons.OKCancel))
                    SaveAlertEmail();
            }
            NewAlertEmail();
            btnDelete.Enabled = false;
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            if (DialogResult.OK == MessageBox.Show("Delete " + txtAlertType.Text + "?", "Confirm", MessageBoxButtons.OKCancel))
                DeleteAlertEmail();
        }
        private void DeleteAlertEmail()
        {
            if (AlertEmailId < 1)
            {
                btnDelete.Enabled = false;
                return;
            }
            btnSave.Enabled = false;
            int RetVal = CCPM.Data.ProjectData.AlertEmailDelete(AlertEmailId);
            if (RetVal == -1)
            {
                MessageBox.Show("AlertEmail delete failure");
                return;
            }
        
                LoadAlertEmail();
                NewAlertEmail();
        }

       
        private void txtName_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void txtEmailSubject_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }
        private void txtEmailText_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void chkIsActive_CheckedChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void AlertEmail_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (btnSave.Enabled)
            {
                if (DialogResult.OK == MessageBox.Show("Save changes first?", "", MessageBoxButtons.OKCancel))
                    SaveAlertEmail();
            }
        }


        private void txtRecipients_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void txtAlertType_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }


    }
}
