﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace CCPM.ProjectRelated
{
    public partial class StaffMain : Form
    {
        private DataTable dtStaff = null;
        private DataTable dtStaffRoles = null;
        private int StaffIndex = 0;
        private int ProjectManagerId = -1;

        public StaffMain()
        {
            InitializeComponent();
            LoadStaff();
            LoadStaffRoles();
            NewStaff();
            btnSave.Enabled = false;
            btnDelete.Enabled = false;
        }

        private void LoadStaff()
        {
            dtStaff = Data.ProjectData.GetAllStaff().Tables[0];
            lstStaff.DataSource = dtStaff;
            lstStaff.ValueMember = "ProjectManagerId";
            lstStaff.DisplayMember = "Name";
        }

        private void LoadStaffRoles()
        {
            dtStaffRoles = Data.ProjectData.GetStaffRoles(ProjectManagerId).Tables[0];
            clstRole.DataSource = dtStaffRoles;
            clstRole.ValueMember = "StaffRoleId";
            clstRole.DisplayMember = "StaffRoleName";
            for (int i = 0; i < dtStaffRoles.Rows.Count; i++)
            {
                clstRole.SetItemChecked(i, Convert.ToBoolean(dtStaffRoles.Rows[i]["inRole"]));
            }
            clstRole.SelectedIndex = -1;
        }

        private void lstStaff_SelectedIndexChanged(object sender, EventArgs e)
        {
            if ((ProjectManagerId == -1) || (lstStaff.SelectedIndex == -1 || lstStaff.SelectedIndex == StaffIndex))
                return;

            if (btnSave.Enabled)
            {
                if (DialogResult.OK == MessageBox.Show("Save changes first?", "", MessageBoxButtons.OKCancel))
                    SaveStaff();
            }

            StaffIndex = lstStaff.SelectedIndex;
            ProjectManagerId = (int)dtStaff.Rows[StaffIndex]["ProjectManagerId"];
            txtProjectManagerId.Text = ProjectManagerId.ToString();
            txtName.Text = dtStaff.Rows[StaffIndex]["Name"].ToString();
            txtInitials.Text = dtStaff.Rows[StaffIndex]["Initials"].ToString();
            txtEmail.Text = dtStaff.Rows[StaffIndex]["Email"].ToString();
            chkIsActive.Checked = (bool)dtStaff.Rows[StaffIndex]["IsActive"];
            LoadStaffRoles();
            btnSave.Enabled = false;
            btnDelete.Enabled = true;
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            SaveStaff();
        }

        private void SaveStaff()
        {
            bool blnNewStaff = (ProjectManagerId == 0);

            if (txtName.Text == string.Empty)
            {
                MessageBox.Show("Name required.");
                txtName.Focus();
                return;
            }

            DataRow dr = dtStaff.Rows[StaffIndex];
            dr["Name"] = txtName.Text;
            dr["Initials"] = txtInitials.Text;
            dr["Email"] = txtEmail.Text;
            dr["IsActive"] = chkIsActive.Checked;
            int RetVal = CCPM.Data.ProjectData.ProjectStaffSave(ProjectManagerId, txtName.Text.Trim(), txtInitials.Text.Trim(), txtEmail.Text.Trim(), chkIsActive.Checked);
            if (RetVal == -1)
            {
                MessageBox.Show("Staff save failure");
                return;
            }
            if (blnNewStaff)
                ProjectManagerId = RetVal;

            //save roles
            string s = "";
            foreach (DataRowView myRow in clstRole.CheckedItems)
                s += myRow[0].ToString() + ",";
            if (s.Length > 1)
                s = s.Substring(0, s.Length - 1);
            RetVal = CCPM.Data.ProjectData.StaffRoleSave(ProjectManagerId, s);
            if (RetVal == -1)
            {
                MessageBox.Show("Staff role save failure");
                return;
            }

            if (blnNewStaff)
            {
                ProjectManagerId = RetVal;
                LoadStaff();
            }
            btnSave.Enabled = false;
        }

        private void cmdRefresh_Click(object sender, EventArgs e)
        {
            LoadStaff();
            LoadStaffRoles();
            if (ProjectManagerId > 0)
                SetStaff();
            btnDelete.Enabled = false;
        }

        private void SetStaff()
        {
            for (int i = 0; i < dtStaff.Rows.Count; i++)
            {
                if ((int)dtStaff.Rows[i]["ProjectManagerId"] == ProjectManagerId)
                {
                    lstStaff.SelectedIndex = i;
                    break;
                }
            }
        }

        private void NewStaff()
        {
            lstStaff.SelectedIndex = -1;
            ProjectManagerId = 0;
            txtProjectManagerId.Text = string.Empty;
            txtName.Text = string.Empty;
            txtInitials.Text = string.Empty;
            txtEmail.Text = string.Empty;
            chkIsActive.Checked = true;
            LoadStaffRoles();
            btnSave.Enabled = false;
            btnDelete.Enabled = false;
        }

        private void btnNewStaff_Click(object sender, EventArgs e)
        {
            if (btnSave.Enabled)
            {
                if (DialogResult.OK == MessageBox.Show("Save changes first?", "", MessageBoxButtons.OKCancel))
                    SaveStaff();
            }
            NewStaff();
            btnDelete.Enabled = false;
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            if (DialogResult.OK == MessageBox.Show("Delete " + txtName.Text + "?", "Confirm", MessageBoxButtons.OKCancel))
                DeleteStaff();
        }
        private void DeleteStaff()
        {
            if (ProjectManagerId < 1)
            {
                btnDelete.Enabled = false;
                return;
            }
            btnSave.Enabled = false;
            int RetVal = CCPM.Data.ProjectData.ProjectStaffDelete(ProjectManagerId);
            if (RetVal == -1)
            {
                MessageBox.Show("Staff delete failure");
                return;
            }
        
                LoadStaff();
                NewStaff();
        }

        private bool ValidateName()
        {
            if (txtName.Text == string.Empty)
            {
                MessageBox.Show("Name required.");
                txtName.Focus();
                return false;
            }
            return true;
        }
        private void txtName_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void txtInitials_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void txtEmail_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void chkIsActive_CheckedChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void clstRole_ItemCheck(object sender, ItemCheckEventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void StaffMain_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (btnSave.Enabled)
            {
                if (DialogResult.OK == MessageBox.Show("Save changes first?", "", MessageBoxButtons.OKCancel))
                    SaveStaff();
            }
        }


    }
}
