using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using CCPM.Data;
using System.Data;
using System.Text.RegularExpressions;

namespace CCPM.RelatedProjects
{
	/// <summary>
	/// Related projects may be preexisting in the database or entered ad hock.
	/// If a project is preexisting in the database then 
	/// the project information is read from the Project table otherwise
	/// it is read from the RelatedProject table. If the related project being
	/// entered is ad hock then a value of 0 will be entered for the RelatedProjectId
	/// field.
	/// </summary>
	public class CreateRelatedProject : System.Windows.Forms.Form
	{
        protected System.Windows.Forms.GroupBox groupBox1;
		//protected System.Windows.Forms.Button btnShowProjectPicker;
        protected System.Windows.Forms.TextBox txtDescription;
		private int projectId;
		private int recordId = 0;
		private int relatedProjectId = 0;
		protected System.Windows.Forms.TextBox txtProjectName;
		protected System.Windows.Forms.TextBox txtFileNumber_old;
		protected Infragistics.Win.UltraWinMaskedEdit.UltraMaskedEdit txtFileNumber;
      	/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
        private Label label1;
        protected ComboBox cmbRelType1;
        protected ComboBox cbFileNumber1;
        protected GroupBox groupBox2;
        private RadioButton rdoFileNumber;
        private RadioButton rdoProjectName;
        protected ComboBox cmbRelType;
        private Label label3;
        protected TextBox txtNotes;
        private Label label5;
        protected ComboBox cbFileNumber;
        private Button btnSave;
        private Button btnCancel;
        protected GroupBox groupBox3;
        private RadioButton rbAll;
        private RadioButton rbActive;
        private RadioButton rbInactive;
        private RadioButton rbComplete;
        protected ComboBox cbProjectName;
        private RadioButton rbClosed;
        
       	public int ProjectId
		{
			get{return projectId;}
			set{projectId = value;}
		}
		protected int RecordId
		{
			get{return recordId;}
			set{recordId = value;}
		}

		protected int RelatedProjectId
		{
			get{return relatedProjectId;}
			set{relatedProjectId = value;}
		}

		private const string PROJECT_NAME_PROMPT = "Enter Project Name (required)";

		public CreateRelatedProject(int projectId)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();
            
			ProjectId = projectId;
            if (rdoProjectName.Checked == true)
            {
                cbProjectName.Enabled = true;
            }
            else if (rdoFileNumber.Checked == true)
            {
                cbFileNumber.Enabled = true;
            }
            txtProjectName.Text = PROJECT_NAME_PROMPT;

            PopulateOpenMenu();
		}

        public int GetStatusFilter()
        {
            int statusFilter = 0;
            if (rbInactive.Checked) statusFilter = 1;
            else if (rbComplete.Checked) statusFilter = 2;
            else if (rbAll.Checked) statusFilter = 4;
            else if (rbClosed.Checked) statusFilter = 3;
            
            return statusFilter;
        }

        public void PopulateOpenMenu()
        {

            System.Data.DataSet ds = CCPM.Data.ProjectData.GetProjectList(GetStatusFilter());
            //Handle empty DataTable condition

            //add a row to provide a blank first item in the dropdown.    

            if (ds.Tables[0].Rows.Count < 1)//Project Name
            {
                DataRow dr = ds.Tables[0].NewRow();
                dr["ProjectName"] = "N/A";
                dr["ProjectId"] = 0;
                ds.Tables[0].Rows.Add(dr);
            }
            if (ds.Tables[1].Rows.Count < 1)//Project Number
            {
                DataRow dr = ds.Tables[1].NewRow();
                dr["FileNumber"] = "N/A";
                dr["ProjectId"] = 0;
                ds.Tables[1].Rows.Add(dr);
            }


            cbProjectName.DataSource = null;
            cbProjectName.Items.Clear();
            cbProjectName.DataSource = ds.Tables[0];
            cbProjectName.DisplayMember = "ProjectName";
            cbProjectName.ValueMember = "ProjectId";

            cbFileNumber.DataSource = null;
            cbFileNumber.Items.Clear();
            cbFileNumber.DataSource = ds.Tables[1];
            cbFileNumber.DisplayMember = "FileNumber";
            cbFileNumber.ValueMember = "ProjectId";

            // Populate Relation Type Combo box
            // Added 07/16/08 -- Gatika

            System.Data.DataSet ds1 = CCPM.Data.RelatedProjectData.GetRelTypeSelectionList();
            cmbRelType.DataSource = null;
            cmbRelType.Items.Clear();
            cmbRelType.DataSource = ds1.Tables[0];
            cmbRelType.DisplayMember = "RelType";
            cmbRelType.ValueMember = "RelTypeId";
        }


        // <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		protected virtual void Save()
		{
			string projectName = cbProjectName.Text == PROJECT_NAME_PROMPT ? string.Empty : cbProjectName.Text;
			string description = txtNotes.Text;
            //string type = cmbRelType.Text; 
            int type = Convert.ToInt32(cmbRelType.SelectedValue);		
			
            // ADS - 17-July-2008 -- Added field "Relationship Type" in database
            if(RelatedProjectId != 0) //project is preexisting in database
			{
                RelatedProjectData.RelatedProjectInsert(
                    ProjectId,
                    RelatedProjectId,
                    description, type);
				DialogResult = DialogResult.OK;
				this.Close();
			}
			else
			{
				if( ( projectName == null ) || ( projectName.Trim().Equals( string.Empty)))
				{
					MessageBox.Show("The project name is required.", "Required Field", MessageBoxButtons.OK, MessageBoxIcon.Error);
				}
				else
				{
					string pattern = GlobalSettings.ProjectRegex;
					Regex regex = new Regex(pattern);
					if(regex.IsMatch(cbFileNumber.Text))
					{
						// ADS 4-Dec-2007 - 2.10 - Changed how duplicates are handled
						int existingProjectID = ProjectData.GetProjectIDByFileNumber( cbFileNumber.Text );

						if( existingProjectID == 0 )
						{
							int newID = ProjectData.InsertProject( cbFileNumber.Text, projectName, description);						
							RelatedProjectData.RelatedProjectInsert(ProjectId, newID, description, type);
							DialogResult = DialogResult.OK;
							this.Close();
						}
						else
						{
							if( MessageBox.Show("The project number already exists.  Do you wish to link to the existing project?", "Project Number Exists", MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation)
								== DialogResult.Yes )
							{
							 	RelatedProjectData.RelatedProjectInsert(ProjectId, existingProjectID, description, type);
								DialogResult = DialogResult.OK;
								this.Close();
							}
						}
					}
					else
					{
						MessageBox.Show("Project Number must be in the format ##-###-##!",
							"Format Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
					}
				}
			}
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.groupBox1 = new System.Windows.Forms.GroupBox();
            this.cbFileNumber1 = new System.Windows.Forms.ComboBox();
            this.cmbRelType1 = new System.Windows.Forms.ComboBox();
            this.label1 = new System.Windows.Forms.Label();
            this.txtFileNumber = new Infragistics.Win.UltraWinMaskedEdit.UltraMaskedEdit();
            this.txtProjectName = new System.Windows.Forms.TextBox();
            this.txtFileNumber_old = new System.Windows.Forms.TextBox();
            this.txtDescription = new System.Windows.Forms.TextBox();
            this.groupBox2 = new System.Windows.Forms.GroupBox();
            this.cbProjectName = new System.Windows.Forms.ComboBox();
            this.groupBox3 = new System.Windows.Forms.GroupBox();
            this.rbClosed = new System.Windows.Forms.RadioButton();
            this.rbAll = new System.Windows.Forms.RadioButton();
            this.rbActive = new System.Windows.Forms.RadioButton();
            this.rbInactive = new System.Windows.Forms.RadioButton();
            this.rbComplete = new System.Windows.Forms.RadioButton();
            this.btnSave = new System.Windows.Forms.Button();
            this.btnCancel = new System.Windows.Forms.Button();
            this.rdoFileNumber = new System.Windows.Forms.RadioButton();
            this.rdoProjectName = new System.Windows.Forms.RadioButton();
            this.cmbRelType = new System.Windows.Forms.ComboBox();
            this.label3 = new System.Windows.Forms.Label();
            this.txtNotes = new System.Windows.Forms.TextBox();
            this.label5 = new System.Windows.Forms.Label();
            this.cbFileNumber = new System.Windows.Forms.ComboBox();
            this.groupBox1.SuspendLayout();
            this.groupBox2.SuspendLayout();
            this.groupBox3.SuspendLayout();
            this.SuspendLayout();
            // 
            // groupBox1
            // 
            this.groupBox1.Controls.Add(this.cbFileNumber1);
            this.groupBox1.Controls.Add(this.cmbRelType1);
            this.groupBox1.Controls.Add(this.label1);
            this.groupBox1.Controls.Add(this.txtFileNumber);
            this.groupBox1.Controls.Add(this.txtProjectName);
            this.groupBox1.Controls.Add(this.txtFileNumber_old);
            this.groupBox1.Controls.Add(this.txtDescription);
            this.groupBox1.Location = new System.Drawing.Point(12, 322);
            this.groupBox1.Name = "groupBox1";
            this.groupBox1.Size = new System.Drawing.Size(448, 200);
            this.groupBox1.TabIndex = 0;
            this.groupBox1.TabStop = false;
            this.groupBox1.Visible = false;
            // 
            // cbFileNumber1
            // 
            this.cbFileNumber1.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
            this.cbFileNumber1.FormattingEnabled = true;
            this.cbFileNumber1.Location = new System.Drawing.Point(174, 25);
            this.cbFileNumber1.Name = "cbFileNumber1";
            this.cbFileNumber1.Size = new System.Drawing.Size(128, 21);
            this.cbFileNumber1.TabIndex = 9;
            // 
            // cmbRelType1
            // 
            this.cmbRelType1.FormattingEnabled = true;
            this.cmbRelType1.Location = new System.Drawing.Point(111, 128);
            this.cmbRelType1.Name = "cmbRelType1";
            this.cmbRelType1.Size = new System.Drawing.Size(195, 21);
            this.cmbRelType1.TabIndex = 8;
            // 
            // label1
            // 
            this.label1.AutoSize = true;
            this.label1.Location = new System.Drawing.Point(13, 131);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(92, 13);
            this.label1.TabIndex = 7;
            this.label1.Text = "Relationship Type";
            // 
            // txtFileNumber
            // 
            this.txtFileNumber.Location = new System.Drawing.Point(325, 26);
            this.txtFileNumber.Name = "txtFileNumber";
            this.txtFileNumber.PromptChar = ' ';
            this.txtFileNumber.Size = new System.Drawing.Size(88, 20);
            this.txtFileNumber.TabIndex = 1;
            this.txtFileNumber.Text = "00-000-01";
            this.txtFileNumber.Visible = false;
            this.txtFileNumber.Enter += new System.EventHandler(this.txtFileNumber_Enter);
            // 
            // txtProjectName
            // 
            this.txtProjectName.Location = new System.Drawing.Point(16, 56);
            this.txtProjectName.MaxLength = 100;
            this.txtProjectName.Name = "txtProjectName";
            this.txtProjectName.Size = new System.Drawing.Size(416, 20);
            this.txtProjectName.TabIndex = 3;
            this.txtProjectName.Text = "Enter Project Name (required)";
            this.txtProjectName.Enter += new System.EventHandler(this.txtProjectName_Enter);
            // 
            // txtFileNumber_old
            // 
            this.txtFileNumber_old.BorderStyle = System.Windows.Forms.BorderStyle.None;
            this.txtFileNumber_old.Location = new System.Drawing.Point(16, 28);
            this.txtFileNumber_old.MaxLength = 50;
            this.txtFileNumber_old.Name = "txtFileNumber_old";
            this.txtFileNumber_old.ReadOnly = true;
            this.txtFileNumber_old.Size = new System.Drawing.Size(152, 13);
            this.txtFileNumber_old.TabIndex = 0;
            this.txtFileNumber_old.TabStop = false;
            this.txtFileNumber_old.Text = "Enter Project Number (required) ##-###-01";
            this.txtFileNumber_old.Enter += new System.EventHandler(this.txtFileNumber_Enter);
            // 
            // txtDescription
            // 
            this.txtDescription.Location = new System.Drawing.Point(16, 88);
            this.txtDescription.MaxLength = 350;
            this.txtDescription.Multiline = true;
            this.txtDescription.Name = "txtDescription";
            this.txtDescription.Size = new System.Drawing.Size(416, 30);
            this.txtDescription.TabIndex = 4;
            this.txtDescription.Enter += new System.EventHandler(this.txtDescription_Enter);
            // 
            // groupBox2
            // 
            this.groupBox2.Controls.Add(this.cbProjectName);
            this.groupBox2.Controls.Add(this.groupBox3);
            this.groupBox2.Controls.Add(this.btnSave);
            this.groupBox2.Controls.Add(this.btnCancel);
            this.groupBox2.Controls.Add(this.rdoFileNumber);
            this.groupBox2.Controls.Add(this.rdoProjectName);
            this.groupBox2.Controls.Add(this.cmbRelType);
            this.groupBox2.Controls.Add(this.label3);
            this.groupBox2.Controls.Add(this.txtNotes);
            this.groupBox2.Controls.Add(this.label5);
            this.groupBox2.Controls.Add(this.cbFileNumber);
            this.groupBox2.Location = new System.Drawing.Point(12, 12);
            this.groupBox2.Name = "groupBox2";
            this.groupBox2.Size = new System.Drawing.Size(442, 304);
            this.groupBox2.TabIndex = 17;
            this.groupBox2.TabStop = false;
            this.groupBox2.Text = "Select an Existing Project to Relate";
            this.groupBox2.Enter += new System.EventHandler(this.groupBox2_Enter);
            // 
            // cbProjectName
            // 
            this.cbProjectName.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.cbProjectName.Location = new System.Drawing.Point(9, 86);
            this.cbProjectName.MaxDropDownItems = 20;
            this.cbProjectName.Name = "cbProjectName";
            this.cbProjectName.Size = new System.Drawing.Size(418, 21);
            this.cbProjectName.TabIndex = 25;
            this.cbProjectName.SelectionChangeCommitted += new System.EventHandler(this.cbProjectName_SelectionChangeCommitted);
            // 
            // groupBox3
            // 
            this.groupBox3.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.groupBox3.Controls.Add(this.rbClosed);
            this.groupBox3.Controls.Add(this.rbAll);
            this.groupBox3.Controls.Add(this.rbActive);
            this.groupBox3.Controls.Add(this.rbInactive);
            this.groupBox3.Controls.Add(this.rbComplete);
            this.groupBox3.Location = new System.Drawing.Point(11, 19);
            this.groupBox3.Name = "groupBox3";
            this.groupBox3.Size = new System.Drawing.Size(418, 46);
            this.groupBox3.TabIndex = 24;
            this.groupBox3.TabStop = false;
            this.groupBox3.Text = "Filter By Project Status";
            // 
            // rbClosed
            // 
            this.rbClosed.Location = new System.Drawing.Point(250, 19);
            this.rbClosed.Name = "rbClosed";
            this.rbClosed.Size = new System.Drawing.Size(71, 24);
            this.rbClosed.TabIndex = 11;
            this.rbClosed.TabStop = true;
            this.rbClosed.Text = "Closed";
            this.rbClosed.CheckedChanged += new System.EventHandler(this.rbClosed_CheckedChanged);
            // 
            // rbAll
            // 
            this.rbAll.Checked = true;
            this.rbAll.Location = new System.Drawing.Point(329, 19);
            this.rbAll.Name = "rbAll";
            this.rbAll.Size = new System.Drawing.Size(42, 24);
            this.rbAll.TabIndex = 10;
            this.rbAll.TabStop = true;
            this.rbAll.Text = "All";
            this.rbAll.CheckedChanged += new System.EventHandler(this.rbAll_CheckedChanged);
            // 
            // rbActive
            // 
            this.rbActive.Location = new System.Drawing.Point(16, 23);
            this.rbActive.Name = "rbActive";
            this.rbActive.Size = new System.Drawing.Size(56, 16);
            this.rbActive.TabIndex = 7;
            this.rbActive.Text = "Active";
            this.rbActive.CheckedChanged += new System.EventHandler(this.rbActive_CheckedChanged);
            // 
            // rbInactive
            // 
            this.rbInactive.Location = new System.Drawing.Point(87, 19);
            this.rbInactive.Name = "rbInactive";
            this.rbInactive.Size = new System.Drawing.Size(73, 24);
            this.rbInactive.TabIndex = 8;
            this.rbInactive.Text = "InActive";
            this.rbInactive.CheckedChanged += new System.EventHandler(this.rbInactive_CheckedChanged);
            // 
            // rbComplete
            // 
            this.rbComplete.Location = new System.Drawing.Point(167, 19);
            this.rbComplete.Name = "rbComplete";
            this.rbComplete.Size = new System.Drawing.Size(71, 24);
            this.rbComplete.TabIndex = 9;
            this.rbComplete.Text = "Complete";
            this.rbComplete.CheckedChanged += new System.EventHandler(this.rbComplete_CheckedChanged);
            // 
            // btnSave
            // 
            this.btnSave.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
            this.btnSave.Location = new System.Drawing.Point(78, 264);
            this.btnSave.Name = "btnSave";
            this.btnSave.Size = new System.Drawing.Size(75, 23);
            this.btnSave.TabIndex = 21;
            this.btnSave.Text = "Save";
            this.btnSave.Click += new System.EventHandler(this.btnSave_Click_1);
            // 
            // btnCancel
            // 
            this.btnCancel.CausesValidation = false;
            this.btnCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            this.btnCancel.FlatStyle = System.Windows.Forms.FlatStyle.Flat;
            this.btnCancel.Location = new System.Drawing.Point(257, 264);
            this.btnCancel.Name = "btnCancel";
            this.btnCancel.Size = new System.Drawing.Size(75, 23);
            this.btnCancel.TabIndex = 22;
            this.btnCancel.Text = "Cancel";
            this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click_1);
            // 
            // rdoFileNumber
            // 
            this.rdoFileNumber.AutoSize = true;
            this.rdoFileNumber.Location = new System.Drawing.Point(13, 109);
            this.rdoFileNumber.Name = "rdoFileNumber";
            this.rdoFileNumber.Size = new System.Drawing.Size(98, 17);
            this.rdoFileNumber.TabIndex = 20;
            this.rdoFileNumber.Text = "Project Number";
            this.rdoFileNumber.UseVisualStyleBackColor = true;
            this.rdoFileNumber.Click += new System.EventHandler(this.rdoFileNumber_Click);
            // 
            // rdoProjectName
            // 
            this.rdoProjectName.AutoSize = true;
            this.rdoProjectName.Checked = true;
            this.rdoProjectName.Location = new System.Drawing.Point(12, 67);
            this.rdoProjectName.Name = "rdoProjectName";
            this.rdoProjectName.Size = new System.Drawing.Size(89, 17);
            this.rdoProjectName.TabIndex = 19;
            this.rdoProjectName.TabStop = true;
            this.rdoProjectName.Text = "Project Name";
            this.rdoProjectName.UseVisualStyleBackColor = true;
            this.rdoProjectName.Click += new System.EventHandler(this.rdoProjectName_Click);
            // 
            // cmbRelType
            // 
            this.cmbRelType.FormattingEnabled = true;
            this.cmbRelType.Items.AddRange(new object[] {
            "Same Project/Different Phase",
            "Similar Project/Same Location",
            "Similar Project/Different Location",
            "Programmatically Related",
            "Historically Related",
            "Other"});
            this.cmbRelType.Location = new System.Drawing.Point(11, 175);
            this.cmbRelType.Name = "cmbRelType";
            this.cmbRelType.Size = new System.Drawing.Size(200, 21);
            this.cmbRelType.TabIndex = 13;
            // 
            // label3
            // 
            this.label3.Location = new System.Drawing.Point(11, 157);
            this.label3.Name = "label3";
            this.label3.Size = new System.Drawing.Size(160, 23);
            this.label3.TabIndex = 12;
            this.label3.Text = "Relationship Type";
            // 
            // txtNotes
            // 
            this.txtNotes.Location = new System.Drawing.Point(13, 223);
            this.txtNotes.Name = "txtNotes";
            this.txtNotes.Size = new System.Drawing.Size(168, 20);
            this.txtNotes.TabIndex = 18;
            // 
            // label5
            // 
            this.label5.Location = new System.Drawing.Point(11, 203);
            this.label5.Name = "label5";
            this.label5.Size = new System.Drawing.Size(59, 23);
            this.label5.TabIndex = 17;
            this.label5.Text = "Notes";
            // 
            // cbFileNumber
            // 
            this.cbFileNumber.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.cbFileNumber.Enabled = false;
            this.cbFileNumber.Location = new System.Drawing.Point(9, 128);
            this.cbFileNumber.MaxDropDownItems = 20;
            this.cbFileNumber.Name = "cbFileNumber";
            this.cbFileNumber.Size = new System.Drawing.Size(418, 21);
            this.cbFileNumber.TabIndex = 4;
            this.cbFileNumber.SelectionChangeCommitted += new System.EventHandler(this.cbFileNumber_SelectionChangeCommitted_1);
            // 
            // CreateRelatedProject
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(480, 327);
            this.Controls.Add(this.groupBox2);
            this.Controls.Add(this.groupBox1);
            this.Name = "CreateRelatedProject";
            this.Text = "Edit Related Project";
            this.groupBox1.ResumeLayout(false);
            this.groupBox1.PerformLayout();
            this.groupBox2.ResumeLayout(false);
            this.groupBox2.PerformLayout();
            this.groupBox3.ResumeLayout(false);
            this.ResumeLayout(false);

		}
		#endregion

		// ADS 30-Nov-2007 - Deprecated
//		private void btnShowProjectPicker_Click(object sender, System.EventArgs e)
//		{
//			RelatedProjectPicker rpp = new RelatedProjectPicker();
//			if(DialogResult.OK == rpp.ShowDialog(this))
//			{
//				//Get the project selected by the "project picker" dialog.
//				DataSet dsProject = ProjectData.GetProject(rpp.ProjectId);
//				DataRow dr = dsProject.Tables[0].Rows[0];
//				txtFileNumber.Text = dr["FileNumber"].ToString();
//				txtProjectName.Text = dr["ProjectName"].ToString();
//				RelatedProjectId = (int)dr["ProjectId"]; 
//				//Disable input for file number because this project is preexisting in the database.
//				txtFileNumber.ReadOnly = true;
//				txtProjectName.ReadOnly = true;
//			}
//		}

		private void txtFileNumber_Enter(object sender, System.EventArgs e)
		{
			if(txtFileNumber.Text == "Enter Project Number")
			{
				txtFileNumber.Text	= string.Empty;
			}
		}

		private void txtProjectName_Enter(object sender, System.EventArgs e)
		{
			if(txtProjectName.Text == PROJECT_NAME_PROMPT)
			{
				txtProjectName.Text	= string.Empty;
			}
		}

		private void txtDescription_Enter(object sender, System.EventArgs e)
		{
			if(txtDescription.Text == "")
			{
				txtDescription.Text = string.Empty;
			}
		}
      
        private void btnCancel_Click_1(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.Cancel;
            this.Close();
        }

        private void rdoProjectName_Click(object sender, EventArgs e)
        {
            if (rdoProjectName.Checked == false)
            {
                cbProjectName.Enabled = false;
                cbFileNumber.Enabled = true;
            }
            else
            {
                cbProjectName.Enabled = true;
                cbFileNumber.Enabled = false;
            }
        }

        private void rdoFileNumber_Click(object sender, EventArgs e)
        {
            if (rdoFileNumber.Checked == false)
            {
                cbFileNumber.Enabled = false;
                cbProjectName.Enabled = true;
            }
            else
            {
                cbFileNumber.Enabled = true;
                cbProjectName.Enabled = false;
            }
        }

        private void btnSave_Click_1(object sender, EventArgs e)
        {
            //if (MessageBox.Show("Are you sure you want to create a new project record?", "Confirmation", MessageBoxButtons.YesNo)
           //     == DialogResult.Yes)
            //{
                Save();
            //}
        }

        private void cbFileNumber_SelectionChangeCommitted_1(object sender, EventArgs e)
        {
            int RelatedprojectId = Convert.ToInt32(cbFileNumber.SelectedValue);
            DataTable dt = RelatedProjectData.GetProject(GlobalSettings.projectId, RelatedprojectId).Tables[0];
            if (dt.Rows.Count >0 )
            {
                DataRow dr = RelatedProjectData.GetProject(GlobalSettings.projectId, RelatedprojectId).Tables[0].Rows[0];
                cbProjectName.Text = dr["ProjectName"].ToString() == string.Empty ? "Enter Project Name" : dr["ProjectName"].ToString();
                txtNotes.Text = dr["Notes"].ToString() == string.Empty ? "" : dr["Notes"].ToString();
                RecordId = Convert.ToInt32(dr["RecordId"]);
                try
                {
                    DataRow dr1 = RelatedProjectData.GetRelatedProject(RelatedprojectId).Tables[0].Rows[0];
                    cmbRelType.Text = dr1["RelType"].ToString() == string.Empty ? "Enter Relationship Type" : dr1["RelType"].ToString();
                }

                catch (Exception)
                {
                    cmbRelType.Text = " ";
                }
            }
        }

        private void cbProjectName_SelectionChangeCommitted(object sender, EventArgs e)
        {
            int RelatedprojectId = Convert.ToInt32(cbProjectName.SelectedValue);
            try
            {
                DataRow dr = RelatedProjectData.GetProject(GlobalSettings.projectId, RelatedprojectId).Tables[0].Rows[0];
                cbFileNumber.Text = dr["FileNumber"].ToString() == string.Empty ? "Enter Project Name" : dr["FileNumber"].ToString();
                txtNotes.Text = dr["Notes"].ToString() == string.Empty ? "" : dr["Notes"].ToString();
                RecordId = Convert.ToInt32(dr["RecordId"]);
                try
                {
                    DataRow dr1 = RelatedProjectData.GetRelatedProject(RelatedprojectId).Tables[0].Rows[0];
                    cmbRelType.Text = dr1["RelType"].ToString() == string.Empty ? "Enter Relationship Type" : dr1["RelType"].ToString();
                }
                catch (Exception ex)
                {
                    cmbRelType.Text = " ";
                }
            }
            catch (Exception ex1)
            {
            }
        }

        private void groupBox2_Enter(object sender, EventArgs e)
        {

        }

        private void rbClosed_CheckedChanged(object sender, EventArgs e)
        {
            PopulateOpenMenu();
        }

        private void rbAll_CheckedChanged(object sender, EventArgs e)
        {
            PopulateOpenMenu();
        }

        private void rbComplete_CheckedChanged(object sender, EventArgs e)
        {
            PopulateOpenMenu();
        }

        private void rbActive_CheckedChanged(object sender, EventArgs e)
        {
            PopulateOpenMenu();
        }

        private void rbInactive_CheckedChanged(object sender, EventArgs e)
        {
            PopulateOpenMenu();
        }		        
	}
}
