using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using ReportPrinting;
using System.Data;
using CCPM.Data;

namespace CCPM.Report
{
	/// <summary>
	/// Configure a one page page report for print.
	/// </summary>
	public class OnePage : System.Windows.Forms.Form
	{
		#region Class Fields
		private ReportPrinting.ReportDocument reportDocument1;
		private ReportPrinting.PrintControlToolBar printControlToolBar1;
		private int projectId;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.Label label6;
		private System.Windows.Forms.Label label7;
		private System.Windows.Forms.Label label8;
		private System.Windows.Forms.Label label9;
		private System.Windows.Forms.Label label10;
		private System.Windows.Forms.Label label11;
		private System.Windows.Forms.Label label12;
		private System.Windows.Forms.Label label13;
		private System.Windows.Forms.Label label14;
		private System.Windows.Forms.Label label16;
		private System.Windows.Forms.ListBox lbPrograms;
		private System.Windows.Forms.CheckBox cbxPrograms;
		private System.Windows.Forms.ListBox lbProjectTypes;
		private System.Windows.Forms.CheckBox cbxProjectTypes;
		private System.Windows.Forms.ListBox lbCities;
		private System.Windows.Forms.CheckBox cbxCities;
		private System.Windows.Forms.ListBox lbCounties;
		private System.Windows.Forms.CheckBox cbxCounties;
		private System.Windows.Forms.TextBox txtDescription;
		private System.Windows.Forms.ListBox lbRegions;
		private System.Windows.Forms.CheckBox cbxRegions;
		private System.Windows.Forms.ListBox lbStaff;
		private System.Windows.Forms.Label label15;
		private System.Windows.Forms.CheckBox cbxProjectSize;
		private System.Windows.Forms.CheckBox cbxTrailMiles;
		private System.Windows.Forms.CheckBox cbxConservancyFunds;
		private System.Windows.Forms.CheckBox cbxMatchingFunds;
		private System.Windows.Forms.CheckBox cbxTotalFunds;
		private System.Windows.Forms.CheckBox cbxStaff;
		private System.Windows.Forms.ListBox lbImage;
		private System.Windows.Forms.PictureBox pictureBox;
		private int imageId;
		private Image projectImage = null;
		private System.Windows.Forms.CheckBox cbxStreamMiles;
		private DataSet dsProject = null;
		private decimal conservancyFunds = 0;
		private decimal matchingFunds = 0;
		private decimal totalFunds = 0;
		private System.Windows.Forms.Label lblProjectName;
		private System.Windows.Forms.CheckBox cbxCheckAll;
		private System.Windows.Forms.CheckBox cbxImage;
		private System.Windows.Forms.Button btnClose;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.CheckedListBox clbPartner;
		private System.Windows.Forms.Label label17;
		private System.Windows.Forms.Label label18;
		private System.Windows.Forms.CheckBox cbxStateSenateDistricts;
		private System.Windows.Forms.CheckBox cbxCongressionalDistricts;
		private System.Windows.Forms.Label label19;
		private System.Windows.Forms.CheckBox cbxAssemblyDistricts;
		private System.Windows.Forms.CheckBox cbxImageCredit;
		private System.Windows.Forms.Label label20;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		#endregion

		public int ProjectId
		{
			get{return projectId;}
			set{projectId = value;}
		}

		public int ImageId
		{
			get{return imageId;}
			set{imageId = value;}
		}

		public OnePage(int projectId)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			this.reportDocument1 = new ReportDocument();
			this.reportDocument1.Body = null;
			this.reportDocument1.PageFooter = null;
			this.reportDocument1.PageHeader = null;
			
			this.printControlToolBar1 = new PrintControlToolBar();
			this.printControlToolBar1.Dock = System.Windows.Forms.DockStyle.Top;
			this.printControlToolBar1.Document = null;
			this.printControlToolBar1.Location = new System.Drawing.Point(0, 0);
			this.printControlToolBar1.Name = "printControlToolBar1";
			this.printControlToolBar1.Size = new System.Drawing.Size(772, 40);
			this.printControlToolBar1.TabIndex = 0;
			this.printControlToolBar1.Printing += new System.EventHandler(this.printControlToolBar1_Printing);

			this.Controls.Add(printControlToolBar1);
			
			ProjectId = projectId;
			this.printControlToolBar1.Document = this.reportDocument1;
			this.Text = "One Page Report";
			this.Load += new System.EventHandler(OnePage_Load);
			this.reportDocument1.DefaultPageSettings.Margins.Top = 50;
			this.reportDocument1.DefaultPageSettings.Margins.Bottom = 50;
			this.reportDocument1.DefaultPageSettings.Margins.Left = 50;
			this.reportDocument1.DefaultPageSettings.Margins.Right = 50;
		}
		
		
		private IReportMaker GetReportMaker()
		{
			return new OnePageReportMaker(GetReportOptions()) as IReportMaker;
			
		}

		private OnePageReportOptions GetReportOptions()
		{	
			DataRow projectRow = dsProject.Tables["Project"].Rows[0];
			OnePageReportOptions options = new OnePageReportOptions();
			options.ProjectName = projectRow["ProjectName"].ToString();
			options.Description = txtDescription.Text;

			if(cbxPrograms.Checked)
			{
				options.ProjectPrograms = dsProject.Tables["ProjectProgramType"];
			}
			if(cbxProjectTypes.Checked)
			{
				options.ProjectTypes = dsProject.Tables["ProjectType"];
			}
			if(cbxCities.Checked)
			{
				options.Cities = dsProject.Tables["ProjectCity"];
			}
			if(cbxCounties.Checked)
			{
				options.Counties = dsProject.Tables["ProjectCounty"];
			}
			if(cbxRegions.Checked)
			{
				options.Regions = dsProject.Tables["ProjectRegion"];
			}
			if(cbxStaff.Checked)
			{
				options.Staff = dsProject.Tables["ProjectManager"];
			}
			if(cbxProjectSize.Checked)
			{
				options.ProjectSize = (decimal)projectRow["Acreage"];
			}
			if(cbxTrailMiles.Checked)
			{
                options.TrailMiles = (decimal)projectRow["TrailMiles"] + (decimal)projectRow["CCTmiles"];
			}
			if(cbxStreamMiles.Checked)
			{
				options.StreamMiles = (decimal)projectRow["StreamMiles"];
			}
			if(cbxConservancyFunds.Checked)
			{
				// MAR 2005-01-27 - change to 0 decimals
				options.ConservancyFunds = this.conservancyFunds;
			}
			if(cbxMatchingFunds.Checked)
			{
				// MAR 2005-01-27 - change to 0 decimals
				options.MatchingFunds = this.matchingFunds;
			}
			if(cbxTotalFunds.Checked)
			{
				// MAR 2005-01-27 - change to 0 decimals
				options.TotalFunds = this.totalFunds;
			}
			if(cbxStaff.Checked)
			{
				options.Staff = dsProject.Tables["ProjectManager"];
			}
			if(cbxImage.Checked)
			{
				if(this.projectImage != null)
				{
					options.ProjectImage = ScaleImage(this.projectImage);
				}
			}
			if(cbxImageCredit.Checked)
			{
				if(this.cbxImageCredit.Text != null)
				{
					options.ImageCredit = cbxImageCredit.Text;
				}
			}
			options.Partners.Clear();
			for(int i = 0; i < clbPartner.Items.Count; i++)
			{
				if(clbPartner.GetItemChecked(i))
				{
					options.Partners.Add(clbPartner.Items[i]);
				}
			}
			if(cbxAssemblyDistricts.Checked)
			{
				options.AssemblyDistricts = cbxAssemblyDistricts.Text;
			}
			if(cbxStateSenateDistricts.Checked)
			{
				options.StateSenateDistricts = cbxStateSenateDistricts.Text;
			}    
			if(cbxCongressionalDistricts.Checked)
			{
				options.CongressionalDistricts = cbxCongressionalDistricts.Text;
			}    

			return options;
		}

		private void ShowImage(int imageId)
		{
			DataSet dsImage = ResourceData.ImageById(imageId);
			DataRow dr = dsImage.Tables[0].Rows[0];
		
			byte[] b = (byte[])dr["Image"];
			if(b.Length > 0)
			{
				System.IO.MemoryStream stream = new System.IO.MemoryStream(b, true);
				stream.Write(b, 0, b.Length);
				this.projectImage = new Bitmap(stream);
				// Draw photo to scale of picturebox
				DrawToScale(this.projectImage);
				
				stream.Close();
			}
			this.cbxImageCredit.Text = dr["ImageCredit"].ToString();
		}
		/// <summary>
		/// Populate the list of image titles and Partners
		/// </summary>
		private void BindList()
		{
			this.lbImage.DataSource = ResourceData.ImageList(ProjectId);
			lbImage.DisplayMember = "Table.ImageName";
			lbImage.ValueMember = "Table.ImageId";
	
			DataSet dsParter = ContactData.GetProjectPartners(ProjectId);
			DataTable dt = dsParter.Tables[0];
			foreach(DataRow dr in dt.Rows)
			{
				this.clbPartner.Items.Add((string)dr["Partner"]);
			}
		}
		/// <summary>
		/// Set the form values that provide an informed set of options for the user.
		/// </summary>
		private void PopulateForm()
		{
			dsProject = ProjectData.GetProject(projectId);
			DataRow projectRow = dsProject.Tables["Project"].Rows[0];
			DataRow fundsRow = dsProject.Tables["ProjectFunds"].Rows[0];
            conservancyFunds = (decimal)fundsRow["ConservancyFunds"] - (decimal)fundsRow["GrantAmount"];
			matchingFunds = (decimal)fundsRow["MatchingFunds"];
			totalFunds = conservancyFunds + matchingFunds;
			//Project name
			lblProjectName.Text = projectRow["ProjectName"].ToString();
			//Programs
			lbPrograms.DataSource = dsProject.Tables["ProjectProgramType"];
			lbPrograms.DisplayMember = "ProgramType";
			//Project Types
			lbProjectTypes.DataSource = dsProject.Tables["ProjectType"];
			lbProjectTypes.DisplayMember = "ProjectType";
			//Cities
			lbCities.DataSource = dsProject.Tables["ProjectCity"];
			lbCities.DisplayMember = "CityName";
			//Counties
			lbCounties.DataSource = dsProject.Tables["ProjectCounty"];
			lbCounties.DisplayMember = "CountyName";
			//Regions
			lbRegions.DataSource = dsProject.Tables["ProjectRegion"];
			lbRegions.DisplayMember = "Region";

			//Conservancy staff
			lbStaff.DataSource = dsProject.Tables["ProjectManager"];
			lbStaff.DisplayMember = "Name";
			
			//Project size (Acres)
			cbxProjectSize.Text = string.Concat(StripZero(Replace(projectRow["Acreage"].ToString(),".00","")), " Acres");
						
			//Trail miles
            decimal miles = (decimal)projectRow["TrailMiles"] + (decimal)projectRow["CCTmiles"];
            cbxTrailMiles.Text = StripZero(Replace(miles.ToString(), ".00", ""));
			
			//Stream miles
			cbxStreamMiles.Text = StripZero(Replace(projectRow["StreamMiles"].ToString(),".00",""));
			
			//Funds
			// MAR 2005-01-27 Format to 0 decimals
			//cbxConservancyFunds.Text = conservancyFunds.ToString("C");
			//cbxMatchingFunds.Text = matchingFunds.ToString("C");
			//cbxTotalFunds.Text = totalFunds.ToString("C");
			cbxConservancyFunds.Text = conservancyFunds.ToString(GlobalSettings.MoneyFormat);
            cbxMatchingFunds.Text = matchingFunds.ToString(GlobalSettings.MoneyFormat);
            cbxTotalFunds.Text = totalFunds.ToString(GlobalSettings.MoneyFormat);
			
			//Descritption
			txtDescription.Text = projectRow["Description"].ToString();

			// MAR 2005-02-04 - added district info
			//Assembly District
			cbxAssemblyDistricts.Text = ProjectData.GetDistrictText(projectId, "AssemblyDistrict");
			//State Senate District
			cbxStateSenateDistricts.Text = ProjectData.GetDistrictText(projectId, "StateSenateDistrict");
			// Congressional District
			cbxCongressionalDistricts.Text = ProjectData.GetDistrictText(projectId, "CongressionalDistrict");
            
			//lbStaff.DataSource = dsProject.Tables["ProjectManager"];
			//lbStaff.DisplayMember = "Name";


		}
		/// <summary>
		/// Scale an image to fit the size of the image container
		/// </summary>
		/// <param name="bmp">System.Drawing.Image to use</param>
		private void DrawToScale(Image bmp)
		{
			// The client rectangle
			Rectangle rc = pictureBox.ClientRectangle;

			// Figure out the scaling necessary for the image
			SizeF size = new SizeF( bmp.Width / bmp.HorizontalResolution, bmp.Height / bmp.VerticalResolution);
			float fScale = Math.Min( rc.Width / size.Width, rc.Height / size.Height);

			size.Width *= fScale;
			size.Height *= fScale;

			// Create a new bitmap of the proper size for the existing bitmap
			// and assign it to the picture box
			pictureBox.Image = new Bitmap(bmp, size.ToSize());
		}
		private Image ScaleImage(Image bmp)
		{
			// Optimized for the one page report
			int height = 250;
			int width = 475;

			// Figure out the scaling necessary for the image
			SizeF size = new SizeF( bmp.Width / bmp.HorizontalResolution, bmp.Height / bmp.VerticalResolution);
			float fScale = Math.Min( width / size.Width, height / size.Height);

			size.Width *= fScale;
			size.Height *= fScale;

			// Create a new bitmap of the proper size for the existing bitmap
			// and assign it to the picture box
			return new Bitmap(bmp, size.ToSize());
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.lblProjectName = new System.Windows.Forms.Label();
            this.label2 = new System.Windows.Forms.Label();
            this.label3 = new System.Windows.Forms.Label();
            this.label4 = new System.Windows.Forms.Label();
            this.label5 = new System.Windows.Forms.Label();
            this.label6 = new System.Windows.Forms.Label();
            this.label7 = new System.Windows.Forms.Label();
            this.label8 = new System.Windows.Forms.Label();
            this.label9 = new System.Windows.Forms.Label();
            this.label10 = new System.Windows.Forms.Label();
            this.label11 = new System.Windows.Forms.Label();
            this.label12 = new System.Windows.Forms.Label();
            this.label13 = new System.Windows.Forms.Label();
            this.label14 = new System.Windows.Forms.Label();
            this.label16 = new System.Windows.Forms.Label();
            this.cbxPrograms = new System.Windows.Forms.CheckBox();
            this.lbPrograms = new System.Windows.Forms.ListBox();
            this.lbProjectTypes = new System.Windows.Forms.ListBox();
            this.cbxProjectTypes = new System.Windows.Forms.CheckBox();
            this.lbCities = new System.Windows.Forms.ListBox();
            this.cbxCities = new System.Windows.Forms.CheckBox();
            this.lbCounties = new System.Windows.Forms.ListBox();
            this.cbxCounties = new System.Windows.Forms.CheckBox();
            this.lbRegions = new System.Windows.Forms.ListBox();
            this.cbxRegions = new System.Windows.Forms.CheckBox();
            this.cbxProjectSize = new System.Windows.Forms.CheckBox();
            this.cbxTrailMiles = new System.Windows.Forms.CheckBox();
            this.cbxStreamMiles = new System.Windows.Forms.CheckBox();
            this.cbxConservancyFunds = new System.Windows.Forms.CheckBox();
            this.cbxMatchingFunds = new System.Windows.Forms.CheckBox();
            this.cbxTotalFunds = new System.Windows.Forms.CheckBox();
            this.txtDescription = new System.Windows.Forms.TextBox();
            this.lbStaff = new System.Windows.Forms.ListBox();
            this.cbxStaff = new System.Windows.Forms.CheckBox();
            this.label15 = new System.Windows.Forms.Label();
            this.lbImage = new System.Windows.Forms.ListBox();
            this.pictureBox = new System.Windows.Forms.PictureBox();
            this.cbxCheckAll = new System.Windows.Forms.CheckBox();
            this.cbxImage = new System.Windows.Forms.CheckBox();
            this.btnClose = new System.Windows.Forms.Button();
            this.clbPartner = new System.Windows.Forms.CheckedListBox();
            this.label1 = new System.Windows.Forms.Label();
            this.label17 = new System.Windows.Forms.Label();
            this.cbxAssemblyDistricts = new System.Windows.Forms.CheckBox();
            this.cbxStateSenateDistricts = new System.Windows.Forms.CheckBox();
            this.label18 = new System.Windows.Forms.Label();
            this.cbxCongressionalDistricts = new System.Windows.Forms.CheckBox();
            this.label19 = new System.Windows.Forms.Label();
            this.cbxImageCredit = new System.Windows.Forms.CheckBox();
            this.label20 = new System.Windows.Forms.Label();
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox)).BeginInit();
            this.SuspendLayout();
            // 
            // lblProjectName
            // 
            this.lblProjectName.Location = new System.Drawing.Point(120, 48);
            this.lblProjectName.Name = "lblProjectName";
            this.lblProjectName.Size = new System.Drawing.Size(368, 23);
            this.lblProjectName.TabIndex = 1;
            // 
            // label2
            // 
            this.label2.Location = new System.Drawing.Point(8, 48);
            this.label2.Name = "label2";
            this.label2.Size = new System.Drawing.Size(88, 23);
            this.label2.TabIndex = 200;
            this.label2.Text = "Project Name";
            // 
            // label3
            // 
            this.label3.Location = new System.Drawing.Point(8, 252);
            this.label3.Name = "label3";
            this.label3.Size = new System.Drawing.Size(96, 23);
            this.label3.TabIndex = 300;
            this.label3.Text = "Project Size";
            // 
            // label4
            // 
            this.label4.Location = new System.Drawing.Point(424, 136);
            this.label4.Name = "label4";
            this.label4.Size = new System.Drawing.Size(64, 23);
            this.label4.TabIndex = 400;
            this.label4.Text = "Region(s)";
            // 
            // label5
            // 
            this.label5.Location = new System.Drawing.Point(424, 80);
            this.label5.Name = "label5";
            this.label5.Size = new System.Drawing.Size(64, 23);
            this.label5.TabIndex = 500;
            this.label5.Text = "County(s)";
            // 
            // label6
            // 
            this.label6.Location = new System.Drawing.Point(8, 191);
            this.label6.Name = "label6";
            this.label6.Size = new System.Drawing.Size(64, 23);
            this.label6.TabIndex = 600;
            this.label6.Text = "City(s)";
            // 
            // label7
            // 
            this.label7.Location = new System.Drawing.Point(8, 136);
            this.label7.Name = "label7";
            this.label7.Size = new System.Drawing.Size(88, 23);
            this.label7.TabIndex = 700;
            this.label7.Text = "Project Type(s)";
            // 
            // label8
            // 
            this.label8.Location = new System.Drawing.Point(8, 80);
            this.label8.Name = "label8";
            this.label8.Size = new System.Drawing.Size(80, 23);
            this.label8.TabIndex = 800;
            this.label8.Text = "Program(s)";
            // 
            // label9
            // 
            this.label9.Location = new System.Drawing.Point(8, 320);
            this.label9.Name = "label9";
            this.label9.Size = new System.Drawing.Size(104, 23);
            this.label9.TabIndex = 900;
            this.label9.Text = "Conservancy Contribution";
            this.label9.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // label10
            // 
            this.label10.Location = new System.Drawing.Point(8, 300);
            this.label10.Name = "label10";
            this.label10.Size = new System.Drawing.Size(100, 16);
            this.label10.TabIndex = 1000;
            this.label10.Text = "Stream Miles";
            // 
            // label11
            // 
            this.label11.Location = new System.Drawing.Point(8, 276);
            this.label11.Name = "label11";
            this.label11.Size = new System.Drawing.Size(100, 23);
            this.label11.TabIndex = 1100;
            this.label11.Text = "Trail Miles";
            // 
            // label12
            // 
            this.label12.Location = new System.Drawing.Point(8, 368);
            this.label12.Name = "label12";
            this.label12.Size = new System.Drawing.Size(100, 23);
            this.label12.TabIndex = 1200;
            this.label12.Text = "Total Project Cost";
            this.label12.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // label13
            // 
            this.label13.Location = new System.Drawing.Point(8, 344);
            this.label13.Name = "label13";
            this.label13.Size = new System.Drawing.Size(100, 23);
            this.label13.TabIndex = 1313;
            this.label13.Text = "Matching Funds";
            this.label13.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // label14
            // 
            this.label14.Location = new System.Drawing.Point(0, 501);
            this.label14.Name = "label14";
            this.label14.Size = new System.Drawing.Size(88, 32);
            this.label14.TabIndex = 1400;
            this.label14.Text = "Description";
            // 
            // label16
            // 
            this.label16.Location = new System.Drawing.Point(8, 621);
            this.label16.Name = "label16";
            this.label16.Size = new System.Drawing.Size(40, 23);
            this.label16.TabIndex = 1600;
            this.label16.Text = "Image";
            // 
            // cbxPrograms
            // 
            this.cbxPrograms.Location = new System.Drawing.Point(104, 76);
            this.cbxPrograms.Name = "cbxPrograms";
            this.cbxPrograms.Size = new System.Drawing.Size(16, 24);
            this.cbxPrograms.TabIndex = 1;
            // 
            // lbPrograms
            // 
            this.lbPrograms.Location = new System.Drawing.Point(120, 80);
            this.lbPrograms.Name = "lbPrograms";
            this.lbPrograms.SelectionMode = System.Windows.Forms.SelectionMode.None;
            this.lbPrograms.Size = new System.Drawing.Size(240, 43);
            this.lbPrograms.TabIndex = 1601;
            this.lbPrograms.TabStop = false;
            // 
            // lbProjectTypes
            // 
            this.lbProjectTypes.Location = new System.Drawing.Point(120, 136);
            this.lbProjectTypes.Name = "lbProjectTypes";
            this.lbProjectTypes.SelectionMode = System.Windows.Forms.SelectionMode.None;
            this.lbProjectTypes.Size = new System.Drawing.Size(240, 43);
            this.lbProjectTypes.TabIndex = 1603;
            this.lbProjectTypes.TabStop = false;
            // 
            // cbxProjectTypes
            // 
            this.cbxProjectTypes.Location = new System.Drawing.Point(104, 131);
            this.cbxProjectTypes.Name = "cbxProjectTypes";
            this.cbxProjectTypes.Size = new System.Drawing.Size(16, 24);
            this.cbxProjectTypes.TabIndex = 2;
            // 
            // lbCities
            // 
            this.lbCities.Location = new System.Drawing.Point(120, 192);
            this.lbCities.Name = "lbCities";
            this.lbCities.SelectionMode = System.Windows.Forms.SelectionMode.None;
            this.lbCities.Size = new System.Drawing.Size(240, 43);
            this.lbCities.TabIndex = 1605;
            this.lbCities.TabStop = false;
            // 
            // cbxCities
            // 
            this.cbxCities.Location = new System.Drawing.Point(104, 187);
            this.cbxCities.Name = "cbxCities";
            this.cbxCities.Size = new System.Drawing.Size(16, 24);
            this.cbxCities.TabIndex = 3;
            // 
            // lbCounties
            // 
            this.lbCounties.Location = new System.Drawing.Point(512, 80);
            this.lbCounties.Name = "lbCounties";
            this.lbCounties.SelectionMode = System.Windows.Forms.SelectionMode.None;
            this.lbCounties.Size = new System.Drawing.Size(240, 43);
            this.lbCounties.TabIndex = 1607;
            this.lbCounties.TabStop = false;
            // 
            // cbxCounties
            // 
            this.cbxCounties.Location = new System.Drawing.Point(494, 76);
            this.cbxCounties.Name = "cbxCounties";
            this.cbxCounties.Size = new System.Drawing.Size(24, 24);
            this.cbxCounties.TabIndex = 8;
            // 
            // lbRegions
            // 
            this.lbRegions.Location = new System.Drawing.Point(512, 136);
            this.lbRegions.Name = "lbRegions";
            this.lbRegions.SelectionMode = System.Windows.Forms.SelectionMode.None;
            this.lbRegions.Size = new System.Drawing.Size(240, 43);
            this.lbRegions.TabIndex = 1609;
            this.lbRegions.TabStop = false;
            // 
            // cbxRegions
            // 
            this.cbxRegions.Location = new System.Drawing.Point(494, 131);
            this.cbxRegions.Name = "cbxRegions";
            this.cbxRegions.Size = new System.Drawing.Size(24, 24);
            this.cbxRegions.TabIndex = 9;
            // 
            // cbxProjectSize
            // 
            this.cbxProjectSize.Location = new System.Drawing.Point(120, 248);
            this.cbxProjectSize.Name = "cbxProjectSize";
            this.cbxProjectSize.Size = new System.Drawing.Size(259, 24);
            this.cbxProjectSize.TabIndex = 5;
            // 
            // cbxTrailMiles
            // 
            this.cbxTrailMiles.Location = new System.Drawing.Point(120, 272);
            this.cbxTrailMiles.Name = "cbxTrailMiles";
            this.cbxTrailMiles.Size = new System.Drawing.Size(259, 24);
            this.cbxTrailMiles.TabIndex = 6;
            // 
            // cbxStreamMiles
            // 
            this.cbxStreamMiles.Location = new System.Drawing.Point(120, 296);
            this.cbxStreamMiles.Name = "cbxStreamMiles";
            this.cbxStreamMiles.Size = new System.Drawing.Size(259, 24);
            this.cbxStreamMiles.TabIndex = 7;
            // 
            // cbxConservancyFunds
            // 
            this.cbxConservancyFunds.Location = new System.Drawing.Point(120, 320);
            this.cbxConservancyFunds.Name = "cbxConservancyFunds";
            this.cbxConservancyFunds.Size = new System.Drawing.Size(256, 24);
            this.cbxConservancyFunds.TabIndex = 11;
            // 
            // cbxMatchingFunds
            // 
            this.cbxMatchingFunds.Location = new System.Drawing.Point(120, 344);
            this.cbxMatchingFunds.Name = "cbxMatchingFunds";
            this.cbxMatchingFunds.Size = new System.Drawing.Size(256, 24);
            this.cbxMatchingFunds.TabIndex = 12;
            // 
            // cbxTotalFunds
            // 
            this.cbxTotalFunds.Location = new System.Drawing.Point(120, 368);
            this.cbxTotalFunds.Name = "cbxTotalFunds";
            this.cbxTotalFunds.Size = new System.Drawing.Size(256, 24);
            this.cbxTotalFunds.TabIndex = 13;
            // 
            // txtDescription
            // 
            this.txtDescription.Enabled = false;
            this.txtDescription.Location = new System.Drawing.Point(120, 501);
            this.txtDescription.MaxLength = 1968;
            this.txtDescription.Multiline = true;
            this.txtDescription.Name = "txtDescription";
            this.txtDescription.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
            this.txtDescription.Size = new System.Drawing.Size(624, 107);
            this.txtDescription.TabIndex = 1618;
            this.txtDescription.TextChanged += new System.EventHandler(this.txtDescription_TextChanged);
            // 
            // lbStaff
            // 
            this.lbStaff.Location = new System.Drawing.Point(512, 192);
            this.lbStaff.Name = "lbStaff";
            this.lbStaff.SelectionMode = System.Windows.Forms.SelectionMode.None;
            this.lbStaff.Size = new System.Drawing.Size(240, 43);
            this.lbStaff.TabIndex = 1621;
            this.lbStaff.TabStop = false;
            // 
            // cbxStaff
            // 
            this.cbxStaff.Location = new System.Drawing.Point(494, 187);
            this.cbxStaff.Name = "cbxStaff";
            this.cbxStaff.Size = new System.Drawing.Size(24, 24);
            this.cbxStaff.TabIndex = 10;
            // 
            // label15
            // 
            this.label15.Location = new System.Drawing.Point(424, 192);
            this.label15.Name = "label15";
            this.label15.Size = new System.Drawing.Size(48, 23);
            this.label15.TabIndex = 1619;
            this.label15.Text = "Staff";
            // 
            // lbImage
            // 
            this.lbImage.Location = new System.Drawing.Point(120, 621);
            this.lbImage.Name = "lbImage";
            this.lbImage.Size = new System.Drawing.Size(120, 95);
            this.lbImage.TabIndex = 14;
            // 
            // pictureBox
            // 
            this.pictureBox.Location = new System.Drawing.Point(424, 626);
            this.pictureBox.Name = "pictureBox";
            this.pictureBox.Size = new System.Drawing.Size(144, 88);
            this.pictureBox.TabIndex = 1623;
            this.pictureBox.TabStop = false;
            // 
            // cbxCheckAll
            // 
            this.cbxCheckAll.Location = new System.Drawing.Point(495, 48);
            this.cbxCheckAll.Name = "cbxCheckAll";
            this.cbxCheckAll.Size = new System.Drawing.Size(104, 24);
            this.cbxCheckAll.TabIndex = 1624;
            this.cbxCheckAll.Text = "Check All";
            this.cbxCheckAll.CheckedChanged += new System.EventHandler(this.cbxCheckAll_CheckedChanged);
            // 
            // cbxImage
            // 
            this.cbxImage.Location = new System.Drawing.Point(96, 618);
            this.cbxImage.Name = "cbxImage";
            this.cbxImage.Size = new System.Drawing.Size(24, 24);
            this.cbxImage.TabIndex = 1625;
            // 
            // btnClose
            // 
            this.btnClose.Location = new System.Drawing.Point(664, 685);
            this.btnClose.Name = "btnClose";
            this.btnClose.Size = new System.Drawing.Size(75, 23);
            this.btnClose.TabIndex = 1626;
            this.btnClose.Text = "Close";
            this.btnClose.Click += new System.EventHandler(this.btnClose_Click);
            // 
            // clbPartner
            // 
            this.clbPartner.CheckOnClick = true;
            this.clbPartner.Location = new System.Drawing.Point(512, 248);
            this.clbPartner.Name = "clbPartner";
            this.clbPartner.Size = new System.Drawing.Size(240, 139);
            this.clbPartner.TabIndex = 1627;
            // 
            // label1
            // 
            this.label1.Location = new System.Drawing.Point(424, 248);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(64, 23);
            this.label1.TabIndex = 1628;
            this.label1.Text = "Partner(s)";
            // 
            // label17
            // 
            this.label17.Location = new System.Drawing.Point(8, 408);
            this.label17.Name = "label17";
            this.label17.Size = new System.Drawing.Size(120, 21);
            this.label17.TabIndex = 1629;
            this.label17.Text = "Assembly District(s)";
            this.label17.Click += new System.EventHandler(this.label17_Click);
            // 
            // cbxAssemblyDistricts
            // 
            this.cbxAssemblyDistricts.Location = new System.Drawing.Point(136, 408);
            this.cbxAssemblyDistricts.Name = "cbxAssemblyDistricts";
            this.cbxAssemblyDistricts.Size = new System.Drawing.Size(360, 16);
            this.cbxAssemblyDistricts.TabIndex = 1630;
            // 
            // cbxStateSenateDistricts
            // 
            this.cbxStateSenateDistricts.Location = new System.Drawing.Point(136, 456);
            this.cbxStateSenateDistricts.Name = "cbxStateSenateDistricts";
            this.cbxStateSenateDistricts.Size = new System.Drawing.Size(352, 16);
            this.cbxStateSenateDistricts.TabIndex = 1633;
            // 
            // label18
            // 
            this.label18.Location = new System.Drawing.Point(8, 456);
            this.label18.Name = "label18";
            this.label18.Size = new System.Drawing.Size(120, 24);
            this.label18.TabIndex = 1632;
            this.label18.Text = "State Senate District(s)";
            this.label18.Click += new System.EventHandler(this.label18_Click);
            // 
            // cbxCongressionalDistricts
            // 
            this.cbxCongressionalDistricts.Location = new System.Drawing.Point(136, 431);
            this.cbxCongressionalDistricts.Name = "cbxCongressionalDistricts";
            this.cbxCongressionalDistricts.Size = new System.Drawing.Size(352, 16);
            this.cbxCongressionalDistricts.TabIndex = 1637;
            // 
            // label19
            // 
            this.label19.Location = new System.Drawing.Point(8, 431);
            this.label19.Name = "label19";
            this.label19.Size = new System.Drawing.Size(136, 27);
            this.label19.TabIndex = 1636;
            this.label19.Text = "Congressional District(s)";
            // 
            // cbxImageCredit
            // 
            this.cbxImageCredit.Location = new System.Drawing.Point(99, 728);
            this.cbxImageCredit.Name = "cbxImageCredit";
            this.cbxImageCredit.Size = new System.Drawing.Size(469, 24);
            this.cbxImageCredit.TabIndex = 1638;
            this.cbxImageCredit.Visible = false;
            // 
            // label20
            // 
            this.label20.Location = new System.Drawing.Point(8, 731);
            this.label20.Name = "label20";
            this.label20.Size = new System.Drawing.Size(80, 16);
            this.label20.TabIndex = 1639;
            this.label20.Text = "Image Credit";
            this.label20.Visible = false;
            // 
            // OnePage
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.AutoScroll = true;
            this.ClientSize = new System.Drawing.Size(768, 757);
            this.Controls.Add(this.label20);
            this.Controls.Add(this.cbxImageCredit);
            this.Controls.Add(this.cbxCongressionalDistricts);
            this.Controls.Add(this.label19);
            this.Controls.Add(this.cbxStateSenateDistricts);
            this.Controls.Add(this.label18);
            this.Controls.Add(this.cbxAssemblyDistricts);
            this.Controls.Add(this.label17);
            this.Controls.Add(this.label1);
            this.Controls.Add(this.clbPartner);
            this.Controls.Add(this.btnClose);
            this.Controls.Add(this.cbxCheckAll);
            this.Controls.Add(this.pictureBox);
            this.Controls.Add(this.lbImage);
            this.Controls.Add(this.lbStaff);
            this.Controls.Add(this.cbxStaff);
            this.Controls.Add(this.label15);
            this.Controls.Add(this.txtDescription);
            this.Controls.Add(this.cbxTotalFunds);
            this.Controls.Add(this.cbxMatchingFunds);
            this.Controls.Add(this.cbxConservancyFunds);
            this.Controls.Add(this.cbxStreamMiles);
            this.Controls.Add(this.cbxTrailMiles);
            this.Controls.Add(this.cbxProjectSize);
            this.Controls.Add(this.lbRegions);
            this.Controls.Add(this.cbxRegions);
            this.Controls.Add(this.lbCounties);
            this.Controls.Add(this.cbxCounties);
            this.Controls.Add(this.lbCities);
            this.Controls.Add(this.cbxCities);
            this.Controls.Add(this.lbProjectTypes);
            this.Controls.Add(this.cbxProjectTypes);
            this.Controls.Add(this.lbPrograms);
            this.Controls.Add(this.cbxPrograms);
            this.Controls.Add(this.label16);
            this.Controls.Add(this.label14);
            this.Controls.Add(this.label13);
            this.Controls.Add(this.label12);
            this.Controls.Add(this.label11);
            this.Controls.Add(this.label10);
            this.Controls.Add(this.label9);
            this.Controls.Add(this.label8);
            this.Controls.Add(this.label7);
            this.Controls.Add(this.label6);
            this.Controls.Add(this.label5);
            this.Controls.Add(this.label4);
            this.Controls.Add(this.label3);
            this.Controls.Add(this.label2);
            this.Controls.Add(this.lblProjectName);
            this.Controls.Add(this.cbxImage);
            this.Name = "OnePage";
            this.Text = "Form2";
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox)).EndInit();
            this.ResumeLayout(false);
            this.PerformLayout();

		}
		#endregion

		private void OnePage_Load(object sender, EventArgs e)
		{
			PopulateForm();
			BindList();
			if(lbImage.Items.Count > 0)
			{
				DataRowView drv = (DataRowView)lbImage.Items[0];
				ImageId = (int)drv["ImageId"];
				ShowImage(ImageId);
			}
			this.lbImage.SelectedIndexChanged +=new EventHandler(lbImage_SelectedIndexChanged);
		}
		private void printControlToolBar1_Printing(object sender, System.EventArgs e)
		{
			try
			{
				this.reportDocument1.ReportMaker = GetReportMaker();
			}
			catch(Exception ex)
			{
				MessageBox.Show(string.Concat("An error occurred!\nError message: ", ex.Message),
					"Print Error",
					MessageBoxButtons.OK,
					MessageBoxIcon.Information);
			}
		}

		private void lbImage_SelectedIndexChanged(object sender, EventArgs e)
		{
			DataRowView drv = (DataRowView)lbImage.Items[lbImage.SelectedIndex];
			ImageId = (int)drv["ImageId"];
			ShowImage(ImageId);
		}

		private void cbxCheckAll_CheckedChanged(object sender, System.EventArgs e)
		{
			foreach(Control cntrl in this.Controls)
			{
				if(cntrl.GetType().Equals(typeof(CheckBox)))
				{
					if(cbxCheckAll.Checked)
					{
						((CheckBox)cntrl).Checked = true;
					}
					else
					{
						((CheckBox)cntrl).Checked = false;
					}
				}
			}
			//Partner CheckBoxList
			for(int i = 0; i < clbPartner.Items.Count; i++)
			{
				if(cbxCheckAll.Checked)
				{
					clbPartner.SetItemCheckState(i, CheckState.Checked);
				}
				else
				{
					clbPartner.SetItemCheckState(i, CheckState.Unchecked);
				}
			}
		}

		private void btnClose_Click(object sender, System.EventArgs e)
		{
			this.Close();
		}

		private void txtDescription_TextChanged(object sender, System.EventArgs e)
		{
		
		}

		private void label17_Click(object sender, System.EventArgs e)
		{
		
		}

		private void label18_Click(object sender, System.EventArgs e)
		{
		
		}

		public static String Replace(String strText,String strFind,String strReplace)
		{
			int iPos=strText.IndexOf(strFind);
			String strReturn="";
			while(iPos!=-1)
			{
				strReturn+=strText.Substring(0,iPos) + strReplace;
				strText=strText.Substring(iPos+strFind.Length);
				iPos=strText.IndexOf(strFind);
			}
			if(strText.Length>0)
				strReturn+=strText;
			return strReturn;
		}
		public static String StripZero(String strText)
		{
			String strReturn=strText;
			int strLen = strText.Length;
			if(strText.IndexOf(".")>0)
			{
				// strip the trailing zero, if there is one
				if (strText.Substring(strLen-1)=="0")
				{
					strReturn = strText.Substring(0,strLen-1);
				}
			}
			return strReturn;
		}

	}
}
