﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Microsoft.ApplicationBlocks.Data;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid; 

namespace CCPM.Report
{
    public partial class QueryGrid : Form
    {
        DataSet dsQuery = null;
        DataSet dsColumn = null;
        DataSet dsOperator = null;
        string sql = "";
        int viewId = 0;
        string viewName = "";
        string viewDescription = "";
        string columnList = "";
        int orderIndex = 0;
        bool noUpdate = false;
        string sqlWhere = "";
        string customCriteria = "";
        bool hasProjectId = false;
        bool hasContractId = false;
        bool viewHasProjectId = false;
        bool viewHasContractId = false;
        bool boolSkip = false;

        public QueryGrid()
        {
            InitializeComponent();
            this.Text = "Query Tool";
            lblFilter.Text = "";
            lblFilterOn.Text = "";
            lblCustom.Visible = false;
            cmbCustom.Visible = false;
            btnRun.Enabled = false;
            btnFilter.Enabled = false;
            btnExport.Enabled = false;
            btnSave.Enabled = false;
            btnDelete.Enabled = false;
            btnRemove.Enabled = false;
            btnClear.Enabled = false;

            uwgColumn.AllowDrop = true;
            uwgQuery.Visible = false;

            LoadViews();

            cmbCustom.Items.Add("");
            cmbCustom.Items.Add("Assembly Districts");
            cmbCustom.Items.Add("Authorization Dates");
            cmbCustom.Items.Add("Authorization Types");
            cmbCustom.Items.Add("Congressional Districts");
            cmbCustom.Items.Add("Counties");
            cmbCustom.Items.Add("Fiscal Years");
            cmbCustom.Items.Add("Fund Numbers");
            cmbCustom.Items.Add("Funding Items");
            cmbCustom.Items.Add("Funding Sources");
            cmbCustom.Items.Add("Grantee");
            cmbCustom.Items.Add("Program Types");
            cmbCustom.Items.Add("Project Managers");
            cmbCustom.Items.Add("Project Manager - Contract");
            cmbCustom.Items.Add("Project Manager - Current");
            cmbCustom.Items.Add("Project Status");
            cmbCustom.Items.Add("Project Types");
            cmbCustom.Items.Add("Regions");
            cmbCustom.Items.Add("Senate Districts");
            cmbCustom.Items.Add("Strategic Objectives");

            uwgColumn.DisplayLayout.Override.HeaderClickAction = Infragistics.Win.UltraWinGrid.HeaderClickAction.SortSingle;
            uwgQuery.DisplayLayout.Override.HeaderClickAction = Infragistics.Win.UltraWinGrid.HeaderClickAction.SortSingle;


            dsOperator = SqlHelper.ExecuteDataset(GlobalSettings.ConnectionString, CommandType.Text, "exec SqlOperators");
            uwgColumn.DisplayLayout.ValueLists.Add("SqlOperators");
            for (int i = 0; i < dsOperator.Tables[0].Rows.Count; i++)
            {
                Infragistics.Win.ValueListItem ListItem = new Infragistics.Win.ValueListItem();
                ListItem.DataValue = dsOperator.Tables[0].Rows[i].ItemArray.GetValue(0);
                ListItem.DisplayText = (string)dsOperator.Tables[0].Rows[i].ItemArray.GetValue(1);
                uwgColumn.DisplayLayout.ValueLists["SqlOperators"].ValueListItems.Add(ListItem);
            } 
        }

        private void LoadViews()
        {
            sql = "select 0 as ViewId, '' as Description, '' as ViewName, '' as Columns " +
                "UNION select ViewId, Description, ViewName, isnull(Columns, '') as Columns from QueryView order by ViewName";
            DataSet dsView = null;
            dsView = SqlHelper.ExecuteDataset(GlobalSettings.ConnectionString, CommandType.Text, sql);
            cmbView.DataSource = dsView.Tables[0];
            cmbView.DisplayMember = "Description";
            cmbView.ValueMember = "ViewId";
        }

        private void btnRun_Click(object sender, EventArgs e)
        {
            btnRun.Enabled = false;
            LoadQueryGrid();
            btnRun.Enabled = true;
        }

        private void LoadQueryGrid()
        {
            hasProjectId = false;
            hasContractId = false;
            lblFilter.Text = "";
            lblFilterOn.Text = "";
            if (customCriteria != "")
            {
                FilterLabel(customCriteria, false);
            }

            if (viewName == "")
            {
                MessageBox.Show("Select a view name first.");
                return;
            }

            uwgQuery.DisplayLayout.Bands[0].ColumnFilters.ClearAllFilters();
            uwgQuery.DataSource = null;
            System.Collections.SortedList sl = new System.Collections.SortedList();

            sql = "";
            int cols = 0;
            int indx = 0;
            string colname = "";
            string where = sqlWhere;

            foreach (UltraGridRow ugr in uwgColumn.Rows)
            {
                colname = ugr.Cells[(int)ColumnNames.column_name].Value.ToString();
                if ((bool)ugr.Cells["is_included"].Value)
                {
                    if (colname.ToLower() == "projectid")
                    {
                        hasProjectId = true;
                    }
                    if (colname.ToLower() == "contractid")
                    {
                        hasContractId = true;
                    }
                    cols++;
                    sql += colname + ", ";
                }

                indx = (int)ugr.Cells[(int)ColumnNames.order_index].Value;
                if (indx > 0)
                {
                    if ((bool)ugr.Cells[(int)ColumnNames.is_descending].Value)
                        colname += " DESC";
                    sl.Add(indx.ToString("000"), colname);
                }
                string s = "";
                int opIndex = 0;
                string op = "";

                //operator1
                opIndex = (int)ugr.Cells[(int)ColumnNames.operator1].Value;
                s = ugr.Cells[(int)ColumnNames.criteria1].Value.ToString();
                if (opIndex > 0)
                {
                    if (opIndex < 9 && s == "")
                    {
                    }
                    else
                    {
                        op = OperatorString(opIndex);
                        if (where != "")
                            where += " AND ";
                        if (opIndex == 9 || opIndex == 10)     //null, not null
                        {
                            where += " " + colname + op;
                        }
                        else if (ugr.Cells[(int)ColumnNames.data_type].Value.ToString() == "bit")
                        {
                            where += " " + colname + op + (s == "true" ? "1" : "0");
                        }
                        else if ((bool)ugr.Cells[(int)ColumnNames.is_number].Value)
                        {
                            where += " " + colname + op + s;
                        }
                        else
                        {
                            if (opIndex == 7)       //starts with
                                s += "%";
                            if (opIndex == 8)       //contains
                                s = "%" + s + "%";
                            where += " " + colname + op + GlobalCode.SqlString(s);
                        }
                    }
                }

                //operator2
                opIndex = (int)ugr.Cells[(int)ColumnNames.operator2].Value;
                s = ugr.Cells[(int)ColumnNames.criteria2].Value.ToString();
                if (opIndex > 0)
                {
                    if (opIndex < 9 && s == "")
                    {
                    }
                    else
                    {
                        op = OperatorString(opIndex);
                        if (where != "")
                            where += " AND ";
                        if (opIndex == 9 || opIndex == 10)     //null, not null
                        {
                            where += " " + colname + op;
                        }
                        else if (ugr.Cells[(int)ColumnNames.data_type].Value.ToString() == "bit")
                        {
                            where += " " + colname + op + (s == "true" ? "1" : "0");
                        }
                        else if ((bool)ugr.Cells[(int)ColumnNames.is_number].Value)
                        {
                            where += " " + colname + op + s;
                        }
                        else
                        {
                            if (opIndex == 7)       //starts with
                                s += "%";
                            if (opIndex == 8)       //contains
                                s = "%" + s + "%";
                            where += " " + colname + op + GlobalCode.SqlString(s);
                        }
                    }
                }
            }

            if (cols == 0)
            {
                MessageBox.Show("No columns selected");
                return;
            }

            if (txtTop.Text != "")
            {
                sql = "select "
                    + (chkDistinct.Checked ? "DISTINCT " : "")
                    + "top " + txtTop.Text + (chkTopPercent.Checked ? " percent" : "") + " "
                    + sql;
            }
            else
            {
                sql = "select "
                    + (chkDistinct.Checked ? "DISTINCT " : "")
                    + sql;
            }

            sql = sql.Substring(0, sql.Length - 2);
            sql += " from " + viewName;
            if (where != "")
                sql += " where " + where;

            if (sl.Values.Count > 0)
            {
                sql += " order by";
                for (int i = 0; i < sl.Values.Count; i++)
                {
                    sql += " " + sl.GetByIndex(i);
                    if (i < sl.Values.Count - 1)
                        sql += ", ";
                }
            }

            try
            {
                dsQuery = SqlHelper.ExecuteDataset(GlobalSettings.ConnectionString, CommandType.Text, sql);
                uwgQuery.DataSource = dsQuery;
                uwgQuery.DataBind();

                UltraGridBand band = uwgQuery.DisplayLayout.Bands[0];
                string moneyFormat = GlobalSettings.MoneyFormat;

                foreach (UltraGridRow ugr in uwgColumn.Rows)
                {
                    colname = ugr.Cells[(int)ColumnNames.column_name].Value.ToString();
                    string dataType = ugr.Cells[(int)ColumnNames.data_type].Value.ToString();
                    
                    if ((bool)ugr.Cells["is_included"].Value)
                    {
                        if ((bool)ugr.Cells["is_number"].Value)
                        {
                            if (dataType == "money" || dataType == "smallmoney")
                            {
                                band.Columns[colname].Format = moneyFormat;
                            }
                            band.Columns[colname].CellAppearance.TextHAlign = Infragistics.Win.HAlign.Right;
                        }
                        if (chkHideId.Checked == true && colname.ToLower() == "projectid")
                            band.Columns[colname].Hidden = true;
                        if (chkHideId.Checked == true && colname.ToLower() == "contractid")
                            band.Columns[colname].Hidden = true;
                    }
                    try
                    {
                        band.Columns[colname].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
                    }
                    catch (Exception) { }
                }
                uwgQuery.Visible = true;
                btnFilter.Enabled = true;
                btnExport.Enabled = true;

            }
            catch (Exception ex)
            {
                MessageBox.Show("Query failed:  " + ex.Message);
            }
        }

        private string OperatorString(int opIndex)
        {
            string op = "";
            switch (opIndex)
            {
                case 0:
                    break;
                case 1:     //equal
                    op = " = ";
                    break;
                case 2:     //not equal
                    op = " <> ";
                    break;
                case 3:     //less than
                    op = " < ";
                    break;
                case 4:     //less than equal
                    op = " <= ";
                    break;
                case 5:     //greater than
                    op = " > ";
                    break;
                case 6:     //greater than equal
                    op = " >= ";
                    break;
                case 7:     //starts with
                    op = " like ";
                    break;
                case 8:     //contains
                    op = " like ";
                    break;
                case 9:     //null
                    op = " is null ";
                    break;
                case 10:
                    op = " is not null ";
                    break;
            }
            return op;
        }

        private void btnFilter_Click(object sender, EventArgs e)
        {
            if (uwgQuery.Rows.Count == 0)
                return;

            GridFilter gf = new GridFilter(uwgQuery, lblFilter, lblFilterOn, this.Text);
            gf.ShowDialog();
        }

        private void btnExport_Click(object sender, EventArgs e)
        {
            string excelFile = GlobalCode.ExcelFileName("c:\\Temp", "ccpm_export.xls", false);
            if (excelFile != string.Empty)
            {
                GlobalCode.ExportGridToExcel(uwgQuery, excelFile);
                GlobalCode.OpenAssociatedFile(excelFile);
            }
        }

        private void cmbView_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (boolSkip)
                return;

            btnDelete.Enabled = false;
            if (cmbView.SelectedIndex <= 0)
            {
                btnRun.Enabled = false;
                lblCustom.Visible = false;
                cmbCustom.Visible = false;
                lblFilter.Text = "";
                lblFilterOn.Text = "";
                sqlWhere = "";
                customCriteria = "";
                btnSave.Enabled = false;
                btnRemove.Enabled = false;
                btnClear.Enabled = false;
            }
            else
            {
                viewDescription = cmbView.Text;
                viewId = (int)cmbView.SelectedValue;
                DataRowView drv = (DataRowView)cmbView.Items[cmbView.SelectedIndex];
                viewName = drv[2].ToString();
                columnList = drv[3].ToString();
                if (viewName == "")
                {
                    btnRun.Enabled = false;
                    return;
                }
                if (columnList != string.Empty)
                    btnDelete.Enabled = true;

                btnSave.Enabled = true;
                btnRun.Enabled = true;
                btnRemove.Enabled = true;
                btnClear.Enabled = true;
                this.Text = "Query Tool: " + viewName;

                string s = (chkIncludeAll.Checked) ? "1" : "0";

                sql = "select column_name, convert(bit, " + s + ") as is_included, data_type, character_maximum_length, ordinal_position, is_nullable, is_number, is_string, is_date " +
                    ", convert(bit, 0) as order_by " +
                    ", convert(bit, 0) as is_descending " +
                    ", convert(int, 0) as order_index " +
                    ", convert(int, 0) as operator1 " +
                    ", '' as criteria1 " +
                    ", convert(int, 0) as operator2 " +
                    ", '' as criteria2 " +
                    "from vwColumn " +
                    "where table_name = '" + viewName + "' " +
                    (columnList == string.Empty ? "" : "and column_name in (" + GlobalCode.SqlStringList(columnList, ",") + ") ") +
                    "order by ordinal_position";
                dsColumn = SqlHelper.ExecuteDataset(GlobalSettings.ConnectionString, CommandType.Text, sql);
                uwgColumn.DataSource = dsColumn.Tables[0];
                uwgColumn.DataBind();
                if (columnList != string.Empty)
                {
                    int indx = 0;
                    foreach (string col in columnList.Split(',')) 
                    {
                        foreach (UltraGridRow ugr in uwgColumn.Rows)
                        {
                            if (ugr.Cells["column_name"].Value.ToString() == col)
                            {
                                uwgColumn.Rows.Move(ugr, indx);
                                break;
                            }
                        }
                        indx++;
                    }
                    orderIndex = 0;
                }


                orderIndex = 0;

                
                viewHasProjectId = false;
                viewHasContractId = false;

                foreach (UltraGridRow ugr in uwgColumn.Rows)
                {
                    string colname = ugr.Cells[(int)ColumnNames.column_name].Value.ToString();
                    if (colname.ToLower() == "projectid")
                    {
                        viewHasProjectId = true;
                        if (chkHideId.Checked)
                            ugr.Hidden = true;
                    }
                    if (colname.ToLower() == "contractid")
                    {
                        viewHasContractId = true;
                        if (chkHideId.Checked)
                            ugr.Hidden = true;
                    }
                }

                if (viewHasProjectId || viewHasContractId)
                {
                    lblCustom.Visible = true;
                    cmbCustom.Visible = true;
                }
                else
                {
                    lblCustom.Visible = false;
                    cmbCustom.Visible = false;
                    lblFilter.Text = "";
                    lblFilterOn.Text = "";
                    sqlWhere = "";
                    customCriteria = "";
                }
                if (uwgColumn.Rows.Count > 0)
                    uwgColumn.Rows[0].Activate();
            }
        }

        private void chkIncludeAll_CheckedChanged(object sender, EventArgs e)
        {
            if (uwgColumn.Rows.Count == 0)
                return;

            foreach (UltraGridRow ugr in uwgColumn.Rows)
            {
                if (!ugr.Hidden)
                    ugr.Cells["is_included"].Value = chkIncludeAll.Checked;
            }
        }

        private void uwgColumn_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {

            e.Layout.Bands[0].Columns[(int)ColumnNames.is_nullable].Hidden = true;
            e.Layout.Bands[0].Columns[(int)ColumnNames.character_maximum_length].Hidden = true;
            e.Layout.Bands[0].Columns[(int)ColumnNames.data_type].Hidden = true;
            e.Layout.Bands[0].Columns[(int)ColumnNames.is_number].Hidden = true;
            e.Layout.Bands[0].Columns[(int)ColumnNames.is_string].Hidden = true;
            e.Layout.Bands[0].Columns[(int)ColumnNames.is_date].Hidden = true;
            e.Layout.Bands[0].Columns[(int)ColumnNames.order_index].Hidden = true;
            e.Layout.Bands[0].Columns[(int)ColumnNames.ordinal_position].Hidden = true;

            e.Layout.Bands[0].Columns[(int)ColumnNames.is_included].Header.Caption = "Display";
            e.Layout.Bands[0].Columns[(int)ColumnNames.is_included].Header.ToolTipText = "Checked to include column in output grid.";
            e.Layout.Bands[0].Columns[(int)ColumnNames.order_by].Header.Caption = "Order By";
            e.Layout.Bands[0].Columns[(int)ColumnNames.order_by].Header.ToolTipText = "Checked to sort by column.";
            e.Layout.Bands[0].Columns[(int)ColumnNames.is_descending].Header.Caption = "Desc";
            e.Layout.Bands[0].Columns[(int)ColumnNames.is_descending].Header.ToolTipText = "Sort order direction.  Unchecked for ascending order.  Checked for descending order.";

            e.Layout.Bands[0].Columns[(int)ColumnNames.column_name].Width = 150;
            e.Layout.Bands[0].Columns[(int)ColumnNames.column_name].Header.Caption = "Column Name";
            e.Layout.Bands[0].Columns[(int)ColumnNames.column_name].Header.ToolTipText = "Drag and drop column rows to change the left to right order displayed in the grid.";
            e.Layout.Bands[0].Columns[(int)ColumnNames.column_name].CellActivation = Infragistics.Win.UltraWinGrid.Activation.NoEdit;
            e.Layout.Bands[0].Columns[(int)ColumnNames.column_name].CellAppearance.BackColor = GlobalSettings.nonEditableBackColor;

            e.Layout.Bands[0].Columns[(int)ColumnNames.operator1].Width = 120;
            e.Layout.Bands[0].Columns[(int)ColumnNames.operator1].Header.Caption = "Operator";
            e.Layout.Bands[0].Columns[(int)ColumnNames.operator1].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDownList;
            e.Layout.Bands[0].Columns[(int)ColumnNames.operator1].ValueList = uwgColumn.DisplayLayout.ValueLists["SQLOperators"];
            e.Layout.ValueLists["SQLOperators"].DisplayStyle = Infragistics.Win.ValueListDisplayStyle.DisplayText;

            e.Layout.Bands[0].Columns[(int)ColumnNames.criteria1].Width = 150;
            e.Layout.Bands[0].Columns[(int)ColumnNames.criteria1].Header.Caption = "Criteria";

            e.Layout.Bands[0].Columns[(int)ColumnNames.operator2].Width = 120;
            e.Layout.Bands[0].Columns[(int)ColumnNames.operator2].Header.Caption = "Operator";
            e.Layout.Bands[0].Columns[(int)ColumnNames.operator2].Style = Infragistics.Win.UltraWinGrid.ColumnStyle.DropDownList;
            e.Layout.Bands[0].Columns[(int)ColumnNames.operator2].ValueList = uwgColumn.DisplayLayout.ValueLists["SQLOperators"];
            e.Layout.ValueLists["SQLOperators"].DisplayStyle = Infragistics.Win.ValueListDisplayStyle.DisplayText;

            e.Layout.Bands[0].Columns[(int)ColumnNames.criteria2].Width = 150;
            e.Layout.Bands[0].Columns[(int)ColumnNames.criteria2].Header.Caption = "Criteria";


        }

        private void uwgColumn_DragDrop(object sender, DragEventArgs e)
        {
            int dropIndex;
            // Get the position on the grid where the dragged row(s) are to be dropped.
            UIElement uieOver = uwgColumn.DisplayLayout.UIElement.ElementFromPoint(uwgColumn.PointToClient(new Point(e.X, e.Y)));
            //get the row that is the drop zone/or where the dragged row is to be dropped
            UltraGridRow ugrOver = uieOver.GetContext(typeof(UltraGridRow), true) as UltraGridRow;
            if (ugrOver != null)
            {
                dropIndex = ugrOver.Index;    //index/position of drop zone in grid
                //get the dragged row(s)which are to be dragged to another position in the grid
                SelectedRowsCollection SelRows = (SelectedRowsCollection)e.Data.GetData (typeof(SelectedRowsCollection)) as SelectedRowsCollection;
                foreach (UltraGridRow aRow in SelRows)
                {
                    uwgColumn.Rows.Move(aRow, dropIndex);
                }
                //uwgColumn.ActiveRow = uwgColumn.Rows[0];
                uwgColumn.ActiveRowScrollRegion.ScrollRowIntoView(SelRows[0]);
            }
        }

        private void uwgColumn_SelectionDrag(object sender, CancelEventArgs e)
        {
            uwgColumn.DoDragDrop(uwgColumn.Selected.Rows, DragDropEffects.Move);
        }

        private void uwgColumn_DragOver(object sender, DragEventArgs e)
        {
            e.Effect = DragDropEffects.Move;
            UltraGrid grid = sender as UltraGrid;
            Point pointInGridCoords = grid.PointToClient(new Point(e.X, e.Y));
            if (pointInGridCoords.Y < 20)
                this.uwgColumn.ActiveRowScrollRegion.Scroll(RowScrollAction.LineUp);  // Scroll up.
            else if (pointInGridCoords.Y > grid.Height - 20)
                this.uwgColumn.ActiveRowScrollRegion.Scroll(RowScrollAction.LineDown);  // Scroll down.
        }

        private void uwgColumn_AfterCellUpdate(object sender, CellEventArgs e)
        {
            if (noUpdate)
            {
                noUpdate = false;
                return;
            }

            if (e.Cell.Column.Index == (int)ColumnNames.order_by)
            {
                if ((bool)e.Cell.Value)
                {
                    orderIndex++;
                    uwgColumn.ActiveRow.Cells[(int)ColumnNames.order_index].Value = orderIndex;
                }
                else
                {
                    uwgColumn.ActiveRow.Cells[(int)ColumnNames.order_index].Value = 0;
                }
            }
            else if (e.Cell.Column.Index == (int)ColumnNames.criteria1 || e.Cell.Column.Index == (int)ColumnNames.criteria2)
            {
                if (uwgColumn.ActiveRow.Cells[(int)ColumnNames.data_type].Value.ToString() == "bit")
                {
                    noUpdate = true;
                    e.Cell.Value = GlobalCode.ToTrueFalse(e.Cell.Value.ToString());
                }
                else if ((bool)uwgColumn.ActiveRow.Cells[(int)ColumnNames.is_number].Value)
                {
                    string s = e.Cell.Value.ToString();
                    if (s != "")
                    {
                        noUpdate = true;
                        e.Cell.Value = GlobalCode.ToDecimal(e.Cell.Value.ToString()).ToString();
                    }
                }
                else if ((bool)uwgColumn.ActiveRow.Cells[(int)ColumnNames.is_date].Value)
                {
                    string s = e.Cell.Value.ToString();
                    if (s != "")
                    {
                        noUpdate = true;
                        e.Cell.Value = GlobalCode.ToDateString(s);
                    }
                }
            }
            else if (e.Cell.Column.Index == (int)ColumnNames.operator1)
            {
                if ((int)e.Cell.Value >= 9)
                {
                    noUpdate = true;
                    uwgColumn.ActiveRow.Cells[(int)ColumnNames.criteria1].Value = "";
                    noUpdate = false;
                }
            }
            else if (e.Cell.Column.Index == (int)ColumnNames.operator2)
            {
                if ((int)e.Cell.Value >= 9)
                {
                    noUpdate = true;
                    uwgColumn.ActiveRow.Cells[(int)ColumnNames.criteria2].Value = "";
                    noUpdate = false;
                }
            }
        }


        private enum ColumnNames : int
        {
            column_name = 0,
            is_included = 1,
            data_type = 2,
            character_maximum_length = 3,
            ordinal_position = 4,
            is_nullable = 5,
            is_number = 6,
            is_string = 7,
            is_date = 8,
            order_by = 9,
            is_descending = 10,
            order_index = 11,
            operator1 = 12,
            criteria1 = 13,
            operator2 = 14,
            criteria2 = 15
        }

        private void btnClear_Click(object sender, EventArgs e)
        {
            foreach (UltraGridRow ugr in uwgColumn.Rows)
            {
                ugr.Cells[(int)ColumnNames.operator1].Value = 0;
                ugr.Cells[(int)ColumnNames.criteria1].Value = "";
                ugr.Cells[(int)ColumnNames.operator2].Value = 0;
                ugr.Cells[(int)ColumnNames.criteria2].Value = "";
            }
            sqlWhere = "";
            customCriteria = "";
            lblFilter.Text = "";
            lblFilterOn.Text = "";
        }

        private void FilterLabel(string value, bool isCustom)
        {
            if (value != "")
            {
                lblFilter.Text += value;
                if (isCustom)
                    customCriteria += value;
            }
            if (lblFilter.Text != "")
                lblFilterOn.Text = "Filter On";
        }

        private void cmbCustom_SelectedIndexChanged(object sender, EventArgs e)
        {
            string selection = cmbCustom.Text;
            if (selection == "")
                return;

            string sql = "";
            GridSelect gs = new GridSelect();
            gs.lblTitle.Text = selection;
            DialogResult dr;

            switch (selection)
            {
                case "Assembly Districts":
                    {
                        sql = "select AssemblyDistrictId, AssemblyDistrictNumber from ProjectAssemblyDistrict order by AssemblyDistrictNumber";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from Project_AssemblyDistrict where AssemblyDistrictId in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }

                case "Authorization Dates":
                    {
                        InputBox ib = new InputBox();
                        ib.IsDateRange = true;
                        ib.Caption = "Enter Authorization Date Range";
                        ib.lblValue.Text = "Starting Date >= ";
                        ib.lblDate.Text = "Ending Date < ";
                        ib.ControlBox = false;
                        ib.MinimizeBox = false;
                        ib.ShowDialog(this);
            
                        if (ib.DialogResult == DialogResult.OK)
                        {
                            if (ib.dtpValue.Value != null && ib.dtpValue2.Value != null)
                            {
                                sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                    "(select ProjectId from AuthorizationDetail where AuthorizationDate >= '" + ib.dtpValue.Value.ToString() + "'" +
                                    " and AuthorizationDate < '" + ib.dtpValue2.Value.ToString() + "')";
                            }
                            else if (ib.dtpValue.Value != null)
                            {
                                sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                    "(select ProjectId from AuthorizationDetail where AuthorizationDate >= '" + ib.dtpValue.Value.ToString() + "')";
                            }
                            else if (ib.dtpValue2.Value != null)
                            {
                                sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                    "(select ProjectId from AuthorizationDetail where AuthorizationDate < '" + ib.dtpValue2.Value.ToString() + "')";
                            }
                            FilterLabel("1 " + selection + "\n", true);
                        }

                        break;
                    }
                case "Authorization Types":
                    {
                        sql = "select AuthorizationTypeId, AuthorizationType from AuthorizationType order by AuthorizationType";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from AuthorizationDetail where AuthorizationTypeId in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Congressional Districts":
                    {
                        sql = "select CongressionalDistrictId, CongressionalDistrictNumber from ProjectCongressionalDistrict order by CongressionalDistrictNumber";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from Project_CongressionalDistrict where CongressionalDistrictId in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Counties":
                    {
                        sql = "select CountyId, CountyName from ProjectCounty order by CountyName";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from Project_ProjectCounty where ProjectCountyId in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Fiscal Years":
                    {
                        sql = "select FiscalYearId, Years from FiscalYear order by Years";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from AuthorizationDetail " +
                                "left join ReservEncumb on AuthorizationDetail.AuthorizationId = ReservEncumb.AuthorizationId " +
                                "left join FundingSource on FundingSource.FundID = ReservEncumb.FundID " +
                                "where FundingSource.FiscalYearID in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                //
                case "Fund Numbers":     //duplicate numbers, use text
                    {
                        sql = "SELECT DISTINCT FundingSource.FundNumber " +
                        "FROM FundingSource " +
                        "WHERE FundingSource.FundNumber is not null " +
                        "ORDER BY FundingSource.FundNumber ";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnWidth(0, 200);
                        gs.ColumnName(0, "Fund Number");
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from AuthorizationDetail " +
                                "left join ReservEncumb on AuthorizationDetail.AuthorizationId = ReservEncumb.AuthorizationId " +
                                "left join FundingSource on FundingSource.FundID = ReservEncumb.FundID " +
                                "where FundNumber in (" + gs.SelectedKeys(0, true) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Funding Items":
                    {
                        sql = "SELECT FundingSource.FundID, dbo.usfFundingItem2(FundingSource.FundID) AS FundingItem" +
                        ", FundingSource.Source, FundingSource.Description, FundingSource.SubScheduleName, FiscalYear.Years " +
                        "FROM FundingSource " +
                        "INNER JOIN FiscalYear ON FundingSource.FiscalYearID = FiscalYear.FiscalYearID " +
                        "WHERE FundingSource.FundId in (select FundId from ReservEncumb) " +
                        "ORDER BY Years DESC, FundNumber ASC, RefCode ASC, ScheduleNum ASC, SubScheduleNum ASC ";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 140);
                        gs.ColumnName(1, "Funding Item");
                        gs.ColumnWidth(2, 250);
                        gs.ColumnWidth(3, 250);
                        gs.ColumnWidth(4, 180);
                        gs.ColumnName(4, "Sub Schedule Name");
                        gs.ColumnWidth(5, 80);
                        gs.Width = 1000;
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from AuthorizationDetail " +
                                "left join ReservEncumb on AuthorizationDetail.AuthorizationId = ReservEncumb.AuthorizationId " +
                                "where FundID in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Funding Sources":     //duplicate sources, use text
                    {
                        sql = "SELECT DISTINCT FundingSource.Source " +
                        "FROM FundingSource " +
                        "WHERE FundingSource.FundId in (select FundId from ReservEncumb) " +
                        "AND FundingSource.Source is not null " +
                        "ORDER BY FundingSource.Source ";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnWidth(0, 300);
                        gs.ColumnName(0, "Funding Source");
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from AuthorizationDetail " +
                                "left join ReservEncumb on AuthorizationDetail.AuthorizationId = ReservEncumb.AuthorizationId " +
                                "left join FundingSource on FundingSource.FundID = ReservEncumb.FundID " +
                                "where Source in (" + gs.SelectedKeys(0, true) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Grantee":
                    {
                        sql = "select OrgId, Organization from Organization "
                            + "where OrgId in (select GranteeId from ContractDetails) "
                            + "or OrgId in (select OrgId from Org_ProjectRole where ProjectRoleId = 1) "
                            + "order by Organization ";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from ContractDetails where GranteeId in (" + gs.SelectedKeys(0, false) + ") " +
                                " union select ProjectId from Org_ProjectRole where ProjectRoleId = 1 and OrgId in (" + gs.SelectedKeys(0, false) + ") )";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Program Types":
                    {
                        sql = "select ProgramTypeId, ProgramType from ProjectProgramType order by ProgramType";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from Project_ProjectProgramType where ProjectProgramTypeId in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Project Managers":
                    {
                        sql = "select DISTINCT ProjectManagerId, ProjectManagerName from vwProjectProjectManager order by ProjectManagerName";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from Project_ProjectManager where ProjectManagerId in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Project Manager - Current":
                    {
                        sql = "select DISTINCT ProjectManagerId, ProjectManagerName from vwProjectProjectManagerCurrent order by ProjectManagerName";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from Project where CurrentPM in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Project Manager - Contract":
                    {
                        sql = "select DISTINCT ProjectManagerId, ProjectManagerName from vwProjectProjectManagerContract order by ProjectManagerName";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from ContractDetails where ProjectManagerId in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Project Status":
                    {
                        sql = "select StatusId, Status from ProjectStatus order by StatusId";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " Project_Status in " +
                                "(" + gs.SelectedKeys(1,true) + ") ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Regions":
                    {
                        sql = "select RegionId, Region from ProjectRegion order by Region";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from Project_ProjectRegion where ProjectRegionId in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Project Types":
                    {
                        sql = "select ProjectTypeId, ProjectType from ProjectType order by ProjectType";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from Project_ProjectType where ProjectTypeId in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
                case "Senate Districts":
                    {
                        sql = "select StateSenateDistrictId, StateSenateDistrictNumber from ProjectStateSenateDistrict order by StateSenateDistrictNumber";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 200);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from Project_SenateDistrict where SenateDistrictId in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }

                case "Strategic Objectives":
                    {
                        sql = "select ObjectiveId, ObjectiveShortName, ObjectiveNumber, SortOrder from ProjectObjective order by SortOrder";
                        gs.SqlStatement(sql, GlobalSettings.ConnectionString);
                        gs.ColumnHide(0);
                        gs.ColumnWidth(1, 360);
                        dr = gs.ShowDialog();
                        if (dr == DialogResult.OK)
                        {
                            sqlWhere = sqlWhere + (sqlWhere == "" ? "" : " AND ") + " ProjectId in " +
                                "(select ProjectId from Project_ProjectObjective where ObjectiveId in (" + gs.SelectedKeys(0, false) + ")) ";
                            FilterLabel(gs.SelectedRowsCount().ToString() + " " + selection + "\n", true);
                        }
                        break;
                    }
            }
        }

        private void txtTop_Leave(object sender, EventArgs e)
        {
            SetTextTop();
        }

        private void SetTextTop()
        {
            if (chkTopPercent.Checked)
            {
                GlobalCode.TextBoxInteger(txtTop, 0, 100);
            }
            else
            {
                GlobalCode.TextBoxInteger(txtTop, -1, -1);
            }
        }

        private void chkTopPercent_CheckedChanged(object sender, EventArgs e)
        {
            SetTextTop();
        }

        private void uwgQuery_DoubleClickRow(object sender, DoubleClickRowEventArgs e)
        {
            if (uwgQuery.Rows.Count == 0)
                return;
            if (hasProjectId)
            {
                int pid = Convert.ToInt32(uwgQuery.ActiveRow.Cells["ProjectId"].Value);
                ((CCPM.Form1)this.MdiParent).OpenProject(pid);
            }
        }

        private void btnRemove_Click(object sender, EventArgs e)
        {
            if (uwgColumn.Rows.Count == 0)
                return;

            Infragistics.Win.UltraWinGrid.SelectedRowsCollection selectedRows = uwgColumn.Selected.Rows;
            if (selectedRows.Count > 0)
            {
                foreach (UltraGridRow ugr in selectedRows)
                {
                    ugr.Hidden = true;
                    ugr.Cells["is_included"].Value = false;
                }
                uwgColumn.Selected.Rows.Clear();
            }
            else
            {
                uwgColumn.ActiveRow.Hidden = true;
                uwgColumn.ActiveRow.Cells["is_included"].Value = false;
            }
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            InputBox f1 = new InputBox();
            f1.Title = "Save New Column Layout";
            f1.Caption = "Enter the new view name for this column layout.";
            f1.txtValue.MaxLength = 100;
            f1.txtValue.Width = 250;
            f1.ControlBox = false;
            f1.MinimizeBox = false;
            f1.ShowDialog(this);		//modal
            
            if (f1.DialogResult == DialogResult.OK && f1.TextValue != "")
            {
                viewDescription = f1.TextValue;
                string sql = "";
                string col = "";
                foreach (UltraGridRow ugr in uwgColumn.Rows)
                {
                    col = ugr.Cells["column_name"].Value.ToString();
                    if (col.ToLower() == "projectid" || col.ToLower() == "contractid" || ugr.Hidden == false)
                    {
                        sql = sql + (sql == string.Empty ? "" : ",") + col;
                    }
                }
                sql = "insert QueryView (ViewName, Description, Columns) values (" +
                     GlobalCode.SqlString(viewName) + ", " + GlobalCode.SqlString(f1.TextValue) + ", " + 
                     GlobalCode.SqlString(sql) + ")";
                SqlHelper.ExecuteNonQuery(GlobalSettings.ConnectionString, CommandType.Text, sql);
                boolSkip = true;
                LoadViews();
                cmbView.Text = viewDescription;
                boolSkip = false;
                btnDelete.Enabled = false;
            }
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            if (DialogResult.OK == MessageBox.Show("Delete view " + viewDescription + "?", "Confirm deletion.", MessageBoxButtons.OKCancel, MessageBoxIcon.Question))
            {
                string sql = "delete QueryView where ViewId = " + viewId.ToString();
                SqlHelper.ExecuteNonQuery(GlobalSettings.ConnectionString, CommandType.Text, sql);
                boolSkip = true;
                LoadViews();
                boolSkip = false;
                btnDelete.Enabled = false;
            }
        }

        private void btnHelp_Click(object sender, EventArgs e)
        {
            string msg = "View Name\n" +
                "    First select the view to be used.\n" +
                "    All available columns will be shown in the column grid.\n" +
                "Display Columns \n" +
                "    Remove multiple columns by selecting the rows then clicking on 'Remove' \n" +
                "    or pressing the 'Delete' key. \n" +
                "    Each column with 'Display' checked will be included in the result grid. \n" +
                "    Uncheck 'Display' to exclude the column. \n" +
                "Column Order \n" +
                "    Change the left to right display order by dragging and dropping column(s) \n" +
                "    up or down in the column grid. \n" +
                "    Drag using the row selector on the left side of the grid, not the grid cells. \n" +
                "    The result grid columns can also be dragged to a new position after 'Run'. \n" +
                "Row Order \n" +
                "    Check 'Order By' to sort the results by the column.  \n" +
                "    Check 'Desc' to sort in descending order. \n" +
                "    The result grid can also be sorted after 'Run' by clicking on the column header. \n" +
                "Selection Criteria \n" +
                "    Enter column selection criteria to reduce the result rows displayed. \n" +  
                "    Two criteria fields are provided for selections like 'date >= AND date < '. \n" +
                "    Use the 'Project Criteria' dropdown to apply multiple selections to your query. \n" +
                "Run Query \n" +
                "    Click on 'Run' to execute the query.\n" +
                "    Results will be displayed in the grid at the bottom.\n" +
                "Filter Results \n" +
                "    The result grid rows can be filtered after 'Run'. \n" +
                "Export to Excel \n" +
                "    Click on 'Export' to export the result grid to Excel. \n" +
                "Save View \n" +
                "    Custom column layouts can be saved. \n" +
                "    First remove unwanted columns and place them in the preferred order. \n" +
                "    Keep columns that will be used for criteria. \n" +
                "";
            MessageBox.Show(msg, "Query Tool Instructions", MessageBoxButtons.OK);
        }

    }
}
