﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace CCPM.User
{
    public partial class UserMain : Form
    {
        private DataTable dtUsers = null;
        private DataTable dtUserRoles = null;
        private int userIndex = 0;
        private int userId = -1;
        private bool blnDataChanged = false;
        private bool blnSkip = false;

        public UserMain()
        {
            InitializeComponent();
            LoadUsers();
            LoadUserRoles();
            NewUser();
            btnSave.Enabled = false;
            btnDelete.Enabled = false;
            blnDataChanged = false;
        }

        private void LoadUsers()
        {
            dtUsers = Data.UserData.GetAllUsers().Tables[0];
            lstUser.DataSource = dtUsers;
            lstUser.ValueMember = "UserId";
            lstUser.DisplayMember = "UserNameActive";
        }

        private void LoadUserRoles()
        {
            dtUserRoles = Data.UserData.GetUserRoles(userId).Tables[0];
            clstRole.DataSource = dtUserRoles;
            clstRole.ValueMember = "UserRoleId";
            clstRole.DisplayMember = "UserRoleName";
            for (int i=0; i<dtUserRoles.Rows.Count; i++)
            {
                clstRole.SetItemChecked(i, Convert.ToBoolean( dtUserRoles.Rows[i]["inRole"]));
            }
            clstRole.SelectedIndex = -1;
        }

        private void lstUser_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (blnSkip)
                return;

            if ((userId == -1) || (lstUser.SelectedIndex == -1))
                return;

            if (btnSave.Enabled)
            {
                if (DialogResult.OK == MessageBox.Show("Save changes first?", "", MessageBoxButtons.OKCancel))
                    SaveUser();
            }

            userIndex = lstUser.SelectedIndex;
            userId = (int)dtUsers.Rows[userIndex]["UserId"];
            txtUserId.Text = userId.ToString();
            txtUserName.Text = dtUsers.Rows[userIndex]["Username"].ToString();
            txtPassword.Text = dtUsers.Rows[userIndex]["Password"].ToString();
            chkIsActive.Checked = (bool)dtUsers.Rows[userIndex]["IsActive"];
            LoadUserRoles();
            btnSave.Enabled = false;
            btnDelete.Enabled = true;

        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            SaveUser();
        }

        private void SaveUser()
        {
            bool blnNewUser = (userId == 0);

            if (txtUserName.Text == string.Empty)
            {
                MessageBox.Show("User name required.");
                txtUserName.Focus();
                return;
            }

            int RetVal = CCPM.Data.UserData.UserSave(userId, txtUserName.Text, txtPassword.Text, chkIsActive.Checked);
            if (RetVal == -1)
            {
                MessageBox.Show("User name conflicts with another user");
                return;
            }
            if (blnNewUser)
                userId = RetVal;

            //save roles
            string s = "";
            foreach (DataRowView myRow in clstRole.CheckedItems)
                s += myRow[0].ToString() + ",";
            if (s.Length > 1)
                s = s.Substring(0, s.Length - 1);
            RetVal = CCPM.Data.UserData.UserRoleSave(userId, s);
            if (RetVal == -1)
            {
                MessageBox.Show("User role save failure");
                return;
            }

            btnSave.Enabled = false;

            if (blnNewUser)
            {
                blnSkip = true;
                LoadUsers();
                blnSkip = false;
                SetUser();
            }
        }

        private void cmdRefresh_Click(object sender, EventArgs e)
        {
            LoadUsers();
            LoadUserRoles();
            if (userId > 0)
                SetUser();
        }

        private void SetUser()
        {
            for (int i = 0; i < dtUsers.Rows.Count; i++)
            {
                if ((int)dtUsers.Rows[i]["UserId"] == userId)
                {
                    lstUser.SelectedIndex = i;
                    break;
                }
            }
        }

        private void NewUser()
        {
            lstUser.SelectedIndex = -1;
            userId = 0;
            txtUserId.Text = string.Empty;
            txtUserName.Text = string.Empty;
            txtPassword.Text = string.Empty;
            chkIsActive.Checked = true;
            LoadUserRoles();
            btnSave.Enabled = false;
            btnDelete.Enabled = false;
        }

        private void btnNewUser_Click(object sender, EventArgs e)
        {
            if (btnSave.Enabled)
            {
                if (DialogResult.OK == MessageBox.Show("Save changes first?", "", MessageBoxButtons.OKCancel))
                    SaveUser();
            }
            NewUser();
        }

        private void txtUserId_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void txtUserName_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void txtPassword_TextChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void chkIsActive_CheckedChanged(object sender, EventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void clstRole_ItemCheck(object sender, ItemCheckEventArgs e)
        {
            btnSave.Enabled = true;
        }

        private void UserMain_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (btnSave.Enabled)
            {
                if (DialogResult.Yes == MessageBox.Show("Save changes first?", "", MessageBoxButtons.YesNo))
                    SaveUser();
            }
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            if (DialogResult.Yes == MessageBox.Show("Are you sure you want to delete user " + txtUserName.Text + "?", "Delete confirmation", MessageBoxButtons.YesNo))
            {
                try
                {
                    CCPM.Data.UserData.UserDelete(userId);
                    LoadUsers();
                    NewUser();
                    btnSave.Enabled = false;
                    btnDelete.Enabled = false;
                    blnDataChanged = false;
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Delete user failure.\n" + ex.Message);
                }
            }
        }

    }
}
